local MODNAME = ...

-------------------------------------------------------------------------------
-- Localized Lua globals
-------------------------------------------------------------------------------

local _G = getfenv(0)
local floor		= _G.floor
local format	= _G.format
local ipairs	= _G.ipairs
local pairs		= _G.pairs
local select	= _G.select
local tinsert	= _G.tinsert
local tonumber	= _G.tonumber
local tostring	= _G.tostring
local sort		= _G.sort
local strlen	= _G.strlen
local type		= _G.type
local wipe		= _G.wipe

local Syllabus = _G.LibStub("AceAddon-3.0"):GetAddon(MODNAME)

local BL = _G.LibStub("LibBabble-Faction-3.0"):GetLookupTable()
local BR = _G.LibStub("LibBabble-Faction-3.0"):GetReverseLookupTable()
local LMD = _G.LibStub("LibMapData-1.0")

-- Contants defined in Sullabus.lua
local ABILITY_NAME_TO_SPELLID					= Syllabus.ABILITY_NAME_TO_SPELLID
local MY_CLASS_UPPER								= Syllabus.MY_CLASS_UPPER
local MY_FACTION_FLAG							= Syllabus.MY_FACTION_FLAG
local ZONE_NAMES									= Syllabus.ZONE_NAMES

-- Functions defined in Sullabus.lua
local function err(...) Syllabus:err(...) end
local CopyTable									= Syllabus.CopyTable
local IsTableEmpty								= Syllabus.IsTableEmpty
local GetLocalProfName							= Syllabus.GetLocalProfName
local GetStaticProfName							= Syllabus.GetStaticProfName

-------------------------------------------------------------------------------
-- Main functions
-------------------------------------------------------------------------------

function Syllabus:Save()
	self:CleanCummonClassSpells()

	self:SaveTrainers()
	self:SaveSpells()
	self:Print("Spells and Trainers were saved.")

	CopyTable(self.db.global.skills.all_classes, self.db.global.skills.classes[MY_CLASS_UPPER])
end

function Syllabus:ClearAllSaves()
	self.db.global.save_spell = nil
	self.db.global.save_trainer_without_ref = nil
	self.db.global.save_trainer_without_id = nil
	self.db.global.save_trainer = nil
	self.db.global.save_missing_mapid = nil
	self.db.global.save_name_to_mapid = nil
	self.db.global.save_invalid_trainer = nil
	self.db.global.save_zone_to_mapid = nil
	self.db.global.save_zone_to_floorid = nil
	self.db.global.save_spell_ref = nil
end

-- This will add the default data to the existing user database
-- **** Only works for the english version of the game *****
function Syllabus:AppendDefaultDatabase()
	self:AddSpells()
	self:AddTrainers()
	self:AddTrainerReferences()
	CopyTable(self.db.global.skills.all_classes, self.db.global.skills.classes[MY_CLASS_UPPER])
	self:Print("Spells and Trainers were added to your database.")
end


-------------------------------------------------------------------------------
-- Utility Functions
-------------------------------------------------------------------------------

-- Add spaces at the start of the string to make it at least lenght long
local function pad(string, lenght)
	local pad_number = lenght - strlen(tostring(string))
	if pad_number > 0 then
		return (" "):rep(pad_number) .. tostring(string)
	else
		return string
	end
end


function Syllabus:FixSpellRep()
	-- Use the trainers' rep to set the spells' rep
	local trainers_db = Syllabus.db.global.trainers
	local skills_db = Syllabus.db.global.skills

	for type_name, skill_type in pairs(skills_db) do
		if type_name == "all_classes" then
			for spell_id, spell in pairs(skill_type) do
				for trainer_id in pairs(spell.trainers) do
					if trainers_db[trainer_id].rep then
						spell.valid_rep[trainers_db[trainer_id].rep] = true
					end
				end
			end
		else
			for skill_name, skill in pairs(skill_type) do
				for spell_id, spell in pairs(skill) do
					for trainer_id in pairs(spell.trainers) do
						if trainers_db[trainer_id].rep then
							spell.valid_rep[trainers_db[trainer_id].rep] = true
						end
					end
				end
			end
		end
	end

end

function Syllabus:FixTrainerRef()
	local trainers_db = Syllabus.db.global.trainers
	local skills_db = Syllabus.db.global.skills
	local name_to_id = {}

	for trainer_id, trainer in pairs(trainers_db) do
		if not IsTableEmpty(trainer) then
			local name = type(trainer_id) == "string" and trainer_id or trainer.name
			local id = type(trainer_id) == "number" and trainer_id or trainer.id
			if name and id then name_to_id[name] = id end
		end
	end

	for type_name, skill_type in pairs(skills_db) do
		if type_name == "all_classes" then
			for spell_id, spell in pairs(skill_type) do
				for trainer_id in pairs(spell.trainers) do
					if type(trainer_id) == "string" then
						if name_to_id[trainer_id] then
							spell.trainers[name_to_id[trainer_id]] = true
							spell.trainers[trainer_id] = nil
						end
					end
				end
			end
		else
			for skill_name, skill in pairs(skill_type) do
				for spell_id, spell in pairs(skill) do
					for trainer_id in pairs(spell.trainers) do
						if type(trainer_id) == "string" then
							if name_to_id[trainer_id] then
								spell.trainers[name_to_id[trainer_id]] = true
								spell.trainers[trainer_id] = nil
							end
						end
					end
				end
			end
		end
	end

end
function Syllabus:FindNearTrainerToVisit()
	self:FindTrainersWithoutRef(true, true, true)
end

function Syllabus:FindTrainersWithoutRef(faction, print_list, current_zone)
	local trainers_db = Syllabus.db.global.trainers
	local skills_db = Syllabus.db.global.skills
	local trainer_ref = {}

	_G.SetMapToCurrentZone() -- Make sure were are looking at the right zone
	local continent_id, zone_id = _G.GetCurrentMapContinent(), _G.GetCurrentMapZone()

	-- Collect all the reference to trainers from the spells
	for type_name, skill_type in pairs(skills_db) do
		if type_name == "all_classes" then
			for spell_id, spell in pairs(skill_type) do
				if not IsTableEmpty(spell) then
					for trainer_id in pairs(spell.trainers) do
						trainer_ref[trainer_id] = "Riding"
					end
				end
			end
		else
			for skill_name, skill in pairs(skill_type) do
				for spell_id, spell in pairs(skill) do
					if not IsTableEmpty(spell) then
						for trainer_id in pairs(spell.trainers) do
							trainer_ref[trainer_id] = skill_name
						end
					end
				end
			end
		end
	end

	-- All the lonely people, where do they all come from?
	Syllabus.db.global.save_trainer_without_ref = Syllabus.db.global.save_trainer_without_ref or {}
	local save = Syllabus.db.global.save_trainer_without_ref
	wipe(save)

	for trainer_id, trainer in pairs(trainers_db) do
		if not trainer_ref[trainer_id] and
			not IsTableEmpty(trainer) and
			(not faction or trainer[MY_FACTION_FLAG]) and
			(not current_zone or (continent_id == trainer.continent_id and zone_id == trainer.zone_id))
		then
			tinsert(save, trainer_id)
		end
	end

	sort(save)
	if print_list then
		for i=1,#save do
			self:Print(("%s - %s (%.1f, %.1f)"):format(
				tostring(save[i]),
				tostring(trainers_db[save[i]].name),
				tostring(trainers_db[save[i]].x * 100 or 0),
				tostring(trainers_db[save[i]].y * 100 or 0)
			))
		end
	end

	self:Print(("%d trainers without ref were found"):format(#save))
end

function Syllabus:FindTrainersWithoutID(faction, print_list)
	local trainers_db = Syllabus.db.global.trainers

	Syllabus.db.global.save_trainer_without_id = Syllabus.db.global.save_trainer_without_id or {}
	local save = Syllabus.db.global.save_trainer_without_id
	wipe(save)

	for trainer_id, trainer in pairs(trainers_db) do
		if type(trainer_id) == "string" and not IsTableEmpty(trainer) and (not faction or trainer[MY_FACTION_FLAG]) then
			tinsert(save, trainer_id)
		end
	end

	sort(save)
	if print_list then
		for i=1,#save do
			self:Print(save[i])
		end
	end

	self:Print(("%d trainers without id were found"):format(#save))
end

function Syllabus:CleanCummonClassSpells()
	local skills_db = Syllabus.db.global.skills

	-- Protection againsts a weird case when doing /reload
	if not skills_db or not skills_db["all_classes"] or not skills_db["classes"] then return end

	local is_commun_spell = {}
	local all_classes = skills_db["all_classes"]
	local classes = skills_db["classes"]

	for spell_id in pairs(all_classes) do
		is_commun_spell[spell_id] = true
	end

	for class, class_spells in pairs(classes) do
		for spell_id, spell in pairs(class_spells) do
			if is_commun_spell[spell_id] and not IsTableEmpty(spell) then
				wipe(spell)
				class_spells[spell_id] = nil
			end
		end
	end
end

local zone_to_mapid = {}
local zone_to_floorid = {}
local all_maps = {}
local name_to_mapid = {}
local function FillZoneToMapTables()
	local trainers_db = Syllabus.db.global.trainers

	wipe(zone_to_mapid)
	wipe(zone_to_floorid)

	for trainer_id, trainer in pairs(trainers_db) do
		if trainer.zone_id and trainer.continent_id and trainer.map_id then
			local id = ("%s;%s"):format(trainer.continent_id, trainer.zone_id)
			zone_to_mapid[id] = trainer.map_id
			zone_to_floorid[id] = trainer.floor or 0
		end
	end

	-- Get all the maps known by LibMapData
	all_maps = all_maps or {}
	wipe(all_maps)
	LMD:GetAllMapIDs(all_maps)

	-- Reverse lookup to get mapid from names
	name_to_mapid = name_to_mapid or {}
	wipe(name_to_mapid)
	for _, map_id in ipairs(all_maps) do
		local name = LMD:MapLocalize(map_id)
		name_to_mapid[name] = map_id
	end

	-- Debug
	Syllabus.db.global.save_name_to_mapid = name_to_mapid
	Syllabus.db.global.save_zone_to_floorid = zone_to_floorid
	Syllabus.db.global.save_zone_to_mapid = zone_to_mapid
end


-------------------------------------------------------------------------------
-- Learnable spells
-------------------------------------------------------------------------------

function Syllabus:SaveSpells()
	local skills_db = self.db.global.skills

	self.db.global.save_spell = self.db.global.save_spell or {}
	wipe(Syllabus.db.global.save_spell)

	self.db.global.save_spell_ref = self.db.global.save_spell_ref or {}
	wipe(self.db.global.save_spell_ref)

	local invalid_trainer = self.db.global.save_invalid_trainer

	local sorted_trainers = {}
	local sort_trainer_id = function(a,b)
		local na = tonumber(a) or 0
		local nb = tonumber(b) or 0

		if na ~= nb then
			return na < nb
		else
			return a < b
		end
	end

	for type_name, skill_type in pairs(skills_db) do
		if type_name == "all_classes" then
			for spell_id, spell in pairs(skill_type) do
				if not IsTableEmpty(spell) then
					local icon = spell.icon ~= _G.GetSpellTexture(spell_id) and spell.icon or nil
					if icon then
						icon = '[['..icon..']]'
					end
					local add_spell = ("\tAddSpell( [[%s]], nil, %s, %s, %s, %s, %s, %s, %s ) -- %s"):format(
						type_name,
						pad(spell_id, 5),
						tostring(spell.level_req),
						tostring(spell.rank_req),
						tostring(spell.num_reqs),
						tostring(spell.requires and ABILITY_NAME_TO_SPELLID[spell.requires] or spell.requires),
						tostring(spell.cost),
						tostring(icon),
						tostring(spell.name)
					)
					tinsert(Syllabus.db.global.save_spell, add_spell)

					-- Sort the trainers before building the string
					wipe(sorted_trainers)
					for trainer_id in pairs(spell.trainers) do
						if not invalid_trainer[trainer_id] and type(trainer_id) == 'number' then
							tinsert(sorted_trainers, trainer_id)
						end
					end
					sort(sorted_trainers, sort_trainer_id)

					local add_trainer_ref = ("\tAddTrainerRef( [[%s]], nil, %s"):format( type_name, pad(spell_id, 5) )
					for _, trainer_id in ipairs(sorted_trainers) do
						add_trainer_ref = ("%s, %s"):format(add_trainer_ref, trainer_id)
					end
					add_trainer_ref = ("%s ) -- %s"):format(add_trainer_ref, tostring(spell.name))

					tinsert(Syllabus.db.global.save_spell_ref, add_trainer_ref)
				end
			end
		else
			for skill_name, skill in pairs(skill_type) do
				for spell_id, spell in pairs(skill) do
					if not IsTableEmpty(spell) then
						local icon = spell.icon ~= _G.GetSpellTexture(spell_id) and spell.icon or nil
						if icon then
							icon = '[['..icon..']]'
						end
						local add_spell = ("\tAddSpell( [[%s]], [[%s]], %s, %s, %s, %s, %s, %s, %s ) -- %s"):format(
							type_name,
							GetStaticProfName(skill_name, true),
							pad(spell_id, 5),
							tostring(spell.level_req),
							tostring(spell.rank_req),
							tostring(spell.num_reqs),
							tostring(spell.requires and ABILITY_NAME_TO_SPELLID[spell.requires] or spell.requires),
							tostring(spell.cost),
							tostring(icon),
							tostring(spell.name)
						)
						tinsert(Syllabus.db.global.save_spell, add_spell)

						-- Sort the trainers before building the string
						wipe(sorted_trainers)
						for trainer_id in pairs(spell.trainers) do
							if not invalid_trainer[trainer_id] and type(trainer_id) == 'number' then
								tinsert(sorted_trainers, trainer_id)
							end
						end
						sort(sorted_trainers, sort_trainer_id)

						local add_trainer_ref = ("\tAddTrainerRef( [[%s]], [[%s]], %s"):format(
							type_name,
							GetStaticProfName(skill_name, true),
							pad(spell_id, 5)
						)
						for _, trainer_id in ipairs(sorted_trainers) do
							add_trainer_ref = ("%s, %s"):format(add_trainer_ref, trainer_id)
						end
						add_trainer_ref = ("%s ) -- %s"):format(add_trainer_ref, tostring(spell.name))

						tinsert(Syllabus.db.global.save_spell_ref, add_trainer_ref)
					end
				end
			end
		end
	end

	sort(Syllabus.db.global.save_spell)
	sort(Syllabus.db.global.save_spell_ref)
end

-- AddSpell( "all_classes", nil, 90267, 60, 225, 0, nil, 2500000, "nil" ) -- Flight Master's License
-- AddSpell( "professions", "ENGINEERING", 12715, nil, 205, 1, 20222, 1000, "Interface\\Icons\\INV_Scroll_03" ) -- Goblin Rocket Fuel Recipe
local function AddSpell(type_name, skill_name, spell_id, level_req, rank_req, num_reqs, requires, cost, icon)
	local skills_db = Syllabus.db.global.skills

	local local_skill_name = type_name == "professions" and GetLocalProfName(skill_name) or skill_name
	local spell
	if type_name == "all_classes"then
		spell = skills_db[type_name][spell_id]
	else
		spell = skills_db[type_name][local_skill_name][spell_id]
	end

	if spell.level_req and spell.level_req ~= level_req then
		err("Level requirement missmatch: %s (existing) ~= %s (new)", spell.level_req, level_req)
	else
		spell.level_req = level_req
	end

	if spell.rank_req and spell.rank_req ~= rank_req then
		err("Rank requirement missmatch: %s (existing) ~= %s (new)", spell.rank_req, rank_req)
	else
		spell.rank_req = rank_req
	end

	if spell.num_reqs and spell.num_reqs ~= num_reqs then
		err("Number of requirement missmatch: %s (existing) ~= %s (new)", spell.num_reqs, num_reqs)
	else
		spell.num_reqs = num_reqs
	end

	local spell_requires = spell.requires and ABILITY_NAME_TO_SPELLID[spell.requires] or spell.requires
	if spell_requires and spell_requires ~= requires then
		err("Required spell missmatch: %s (existing) ~= %s (new)", spell_requires, requires)
	else
		spell.requires = requires
	end

	if spell.cost and spell.cost ~= cost then
		err("Training cost missmatch: %s (existing) ~= %s (new)", spell.cost, cost)
	else
		spell.cost = cost
	end

	if spell.icon and spell.icon ~= icon then
		err("Icon texture missmatch: %s (existing) ~= %s (new)", spell.icon, icon)
	else
		spell.icon = icon
	end

end

function Syllabus:AddSpells()

	AddSpell( "all_classes", nil, 33388, 20, nil, 0, nil, 40000, nil ) -- Apprentice Riding
	AddSpell( "all_classes", nil, 33391, 40, 75, 0, nil, 500000, nil ) -- Journeyman Riding
	AddSpell( "all_classes", nil, 34090, 60, 150, 0, nil, 2500000, nil ) -- Expert Riding
	AddSpell( "all_classes", nil, 34091, 70, 225, 0, nil, 50000000, nil ) -- Artisan Riding
	AddSpell( "all_classes", nil, 54197, 68, 225, 0, nil, 5000000, nil ) -- Cold Weather Flying
	AddSpell( "all_classes", nil, 90265, 80, 300, 0, nil, 50000000, nil ) -- Master Riding
	AddSpell( "all_classes", nil, 90267, 60, 225, 0, nil, 2500000, nil ) -- Flight Master's License
	AddSpell( "classes", "DEATHKNIGHT",  3714, nil, nil, 0, nil, 60000, nil ) -- Path of Frost
	AddSpell( "classes", "DEATHKNIGHT", 42650, 80, nil, 0, nil, 222000, nil ) -- Army of the Dead
	AddSpell( "classes", "DEATHKNIGHT", 43265, nil, nil, 0, nil, 27000, nil ) -- Death and Decay
	AddSpell( "classes", "DEATHKNIGHT", 45524, nil, nil, 0, nil, 27000, nil ) -- Chains of Ice
	AddSpell( "classes", "DEATHKNIGHT", 45529, 64, nil, 0, nil, 93000, nil ) -- Blood Tap
	AddSpell( "classes", "DEATHKNIGHT", 46584, nil, nil, 0, nil, 25500, nil ) -- Raise Dead
	AddSpell( "classes", "DEATHKNIGHT", 47476, nil, nil, 0, nil, 27000, nil ) -- Strangulate
	AddSpell( "classes", "DEATHKNIGHT", 47528, nil, nil, 0, nil, 25500, nil ) -- Mind Freeze
	AddSpell( "classes", "DEATHKNIGHT", 47568, 75, nil, 0, nil, 177000, nil ) -- Empower Rune Weapon
	AddSpell( "classes", "DEATHKNIGHT", 48263, nil, nil, 0, nil, 25500, nil ) -- Blood Presence
	AddSpell( "classes", "DEATHKNIGHT", 48265, 70, nil, 0, nil, 132000, nil ) -- Unholy Presence
	AddSpell( "classes", "DEATHKNIGHT", 48707, 68, nil, 0, nil, 117000, nil ) -- Anti-Magic Shell
	AddSpell( "classes", "DEATHKNIGHT", 48721, nil, nil, 0, nil, 27000, nil ) -- Blood Boil
	AddSpell( "classes", "DEATHKNIGHT", 48743, 66, nil, 0, nil, 105000, nil ) -- Death Pact
	AddSpell( "classes", "DEATHKNIGHT", 48792, nil, nil, 0, nil, 81000, nil ) -- Icebound Fortitude
	AddSpell( "classes", "DEATHKNIGHT", 49020, nil, nil, 0, nil, 60000, nil ) -- Obliterate
	AddSpell( "classes", "DEATHKNIGHT", 49998, nil, nil, 0, nil, 25500, nil ) -- Death Strike
	AddSpell( "classes", "DEATHKNIGHT", 50842, nil, nil, 0, nil, 25500, nil ) -- Pestilence
	AddSpell( "classes", "DEATHKNIGHT", 53323, 63, nil, 0, nil, 87000, nil ) -- Rune of Swordshattering
	AddSpell( "classes", "DEATHKNIGHT", 53331, 60, nil, 0, nil, 27000, nil ) -- Rune of Lichbane
	AddSpell( "classes", "DEATHKNIGHT", 53341, 55, nil, 0, nil, 25500, nil ) -- Rune of Cinderglacier
	AddSpell( "classes", "DEATHKNIGHT", 53342, 57, nil, 0, nil, 25500, nil ) -- Rune of Spellshattering
	AddSpell( "classes", "DEATHKNIGHT", 53343, 55, nil, 0, nil, 25500, nil ) -- Rune of Razorice
	AddSpell( "classes", "DEATHKNIGHT", 53344, 70, nil, 0, nil, 132000, nil ) -- Rune of the Fallen Crusader
	AddSpell( "classes", "DEATHKNIGHT", 54446, 63, nil, 0, nil, 87000, nil ) -- Rune of Swordbreaking
	AddSpell( "classes", "DEATHKNIGHT", 54447, 57, nil, 0, nil, 25500, nil ) -- Rune of Spellbreaking
	AddSpell( "classes", "DEATHKNIGHT", 56222, 65, nil, 0, nil, 99000, nil ) -- Dark Command
	AddSpell( "classes", "DEATHKNIGHT", 56815, 67, nil, 0, nil, 111000, nil ) -- Rune Strike
	AddSpell( "classes", "DEATHKNIGHT", 57330, 65, nil, 0, nil, 99000, nil ) -- Horn of Winter
	AddSpell( "classes", "DEATHKNIGHT", 61999, 72, nil, 0, nil, 141000, nil ) -- Raise Ally
	AddSpell( "classes", "DEATHKNIGHT", 62158, 72, nil, 0, nil, 150000, nil ) -- Rune of the Stoneskin Gargoyle
	AddSpell( "classes", "DEATHKNIGHT", 70164, 72, nil, 0, nil, 150000, nil ) -- Rune of the Nerubian Carapace
	AddSpell( "classes", "DEATHKNIGHT", 73975, 83, nil, 0, nil, 258000, nil ) -- Necrotic Strike
	AddSpell( "classes", "DEATHKNIGHT", 77575, 81, nil, 0, nil, 234000, nil ) -- Outbreak
	AddSpell( "classes", "DEATHKNIGHT", 77606, 85, nil, 0, nil, 282000, nil ) -- Dark Simulacrum
	AddSpell( "classes", "DEATHKNIGHT", 81229, 68, nil, 0, nil, 117000, nil ) -- Runic Empowerment
	AddSpell( "classes", "DEATHKNIGHT", 85948, 64, nil, 0, nil, 117000, nil ) -- Festering Strike
	AddSpell( "classes", "DEATHKNIGHT", 87492, 80, nil, 0, nil, 222000, nil ) -- Mastery
	AddSpell( "classes", "DEATHKNIGHT", 87510, 50, nil, 0, nil, 22500, nil ) -- Plate Specialization
	AddSpell( "classes", "DRUID",    99, nil, nil, 1, 5487, 1728, nil ) -- Demoralizing Roar
	AddSpell( "classes", "DRUID",   339, nil, nil, 0, nil, 285, nil ) -- Entangling Roots
	AddSpell( "classes", "DRUID",   467, nil, nil, 0, nil, 142, nil ) -- Thorns
	AddSpell( "classes", "DRUID",   740, 68, nil, 0, nil, 117000, nil ) -- Tranquility
	AddSpell( "classes", "DRUID",   768, nil, nil, 0, nil, 390, nil ) -- Cat Form
	AddSpell( "classes", "DRUID",   770, nil, nil, 0, nil, 2550, nil ) -- Faerie Fire
	AddSpell( "classes", "DRUID",   774, nil, nil, 0, nil, 60, nil ) -- Rejuvenation
	AddSpell( "classes", "DRUID",   779, nil, nil, 1, 5487, 2785, nil ) -- Swipe
	AddSpell( "classes", "DRUID",   783, nil, nil, 0, nil, 2060, nil ) -- Travel Form
	AddSpell( "classes", "DRUID",  1066, nil, nil, 0, nil, 2060, nil ) -- Aquatic Form
	AddSpell( "classes", "DRUID",  1079, 54, nil, 1, 768, 24000, nil ) -- Rip
	AddSpell( "classes", "DRUID",  1082, nil, nil, 1, 768, 390, nil ) -- Claw
	AddSpell( "classes", "DRUID",  1126, nil, nil, 0, nil, 7500, nil ) -- Mark of the Wild
	AddSpell( "classes", "DRUID",  1822, nil, nil, 1, 768, 390, nil ) -- Rake
	AddSpell( "classes", "DRUID",  1850, nil, nil, 1, 768, 6000, nil ) -- Dash
	AddSpell( "classes", "DRUID",  2637, 48, nil, 0, nil, 21000, nil ) -- Hibernate
	AddSpell( "classes", "DRUID",  2782, nil, nil, 0, nil, 5100, nil ) -- Remove Corruption
	AddSpell( "classes", "DRUID",  2908, nil, nil, 0, nil, 7500, nil ) -- Soothe
	AddSpell( "classes", "DRUID",  2912, nil, nil, 0, nil, 390, nil ) -- Starfire
	AddSpell( "classes", "DRUID",  5185, 78, nil, 0, nil, 200400, nil ) -- Healing Touch
	AddSpell( "classes", "DRUID",  5209, nil, nil, 1, 5487, 7500, nil ) -- Challenging Roar
	AddSpell( "classes", "DRUID",  5211, nil, nil, 1, 5487, 9000, nil ) -- Bash
	AddSpell( "classes", "DRUID",  5215, nil, nil, 1, 768, 680, nil ) -- Prowl
	AddSpell( "classes", "DRUID",  5217, nil, nil, 1, 768, 5100, nil ) -- Tiger's Fury
	AddSpell( "classes", "DRUID",  5221, 46, nil, 1, 768, 19500, nil ) -- Shred
	AddSpell( "classes", "DRUID",  5225, nil, nil, 1, 768, 9000, nil ) -- Track Humanoids
	AddSpell( "classes", "DRUID",  5229, nil, nil, 1, 5487, 4200, nil ) -- Enrage
	AddSpell( "classes", "DRUID",  5487, nil, nil, 0, nil, 1728, nil ) -- Bear Form
	AddSpell( "classes", "DRUID",  5570, nil, nil, 0, nil, 3600, nil ) -- Insect Swarm
	AddSpell( "classes", "DRUID",  6785, nil, nil, 1, 768, 4200, nil ) -- Ravage
	AddSpell( "classes", "DRUID",  6795, nil, nil, 1, 5487, 1728, nil ) -- Growl
	AddSpell( "classes", "DRUID",  6807, nil, nil, 1, 5487, 1728, nil ) -- Maul
	AddSpell( "classes", "DRUID",  8921, nil, nil, 0, nil, 98, nil ) -- Moonfire
	AddSpell( "classes", "DRUID",  8936, nil, nil, 0, nil, 1077, nil ) -- Regrowth
	AddSpell( "classes", "DRUID",  8998, nil, nil, 1, 768, 6000, nil ) -- Cower
	AddSpell( "classes", "DRUID",  9005, nil, nil, 1, 768, 9000, nil ) -- Pounce
	AddSpell( "classes", "DRUID", 16689, 52, nil, 1, 339, 22500, nil ) -- Nature's Grasp
	AddSpell( "classes", "DRUID", 16857, nil, nil, 0, nil, 2550, nil ) -- Faerie Fire (Feral)
	AddSpell( "classes", "DRUID", 16864, nil, nil, 0, nil, 3600, nil ) -- Omen of Clarity
	AddSpell( "classes", "DRUID", 16914, 44, nil, 0, nil, 19500, nil ) -- Hurricane
	AddSpell( "classes", "DRUID", 18960, nil, nil, 0, nil, 1728, nil ) -- Teleport: Moonglade
	AddSpell( "classes", "DRUID", 20484, nil, nil, 0, nil, 3600, nil ) -- Rebirth
	AddSpell( "classes", "DRUID", 20719, nil, nil, 1, 768, 6000, nil ) -- Feline Grace
	AddSpell( "classes", "DRUID", 22568, nil, nil, 1, 768, 390, nil ) -- Ferocious Bite
	AddSpell( "classes", "DRUID", 22570, 62, nil, 1, 768, 81000, nil ) -- Maim
	AddSpell( "classes", "DRUID", 22812, 58, nil, 0, nil, 27000, nil ) -- Barkskin
	AddSpell( "classes", "DRUID", 22842, 52, nil, 1, 5487, 22500, nil ) -- Frenzied Regeneration
	AddSpell( "classes", "DRUID", 29166, nil, nil, 0, nil, 7500, nil ) -- Innervate
	AddSpell( "classes", "DRUID", 33745, 66, nil, 1, 5487, 105000, nil ) -- Lacerate
	AddSpell( "classes", "DRUID", 33763, 64, nil, 0, nil, 93000, nil ) -- Lifebloom
	AddSpell( "classes", "DRUID", 33786, 74, nil, 0, nil, 168000, nil ) -- Cyclone
	AddSpell( "classes", "DRUID", 33943, 60, nil, 0, 34090, 27000, nil ) -- Flight Form
	AddSpell( "classes", "DRUID", 40120, 70, nil, 2, 34091, 141000, nil ) -- Swift Flight Form
	AddSpell( "classes", "DRUID", 50464, 78, nil, 0, nil, 390, nil ) -- Nourish
	AddSpell( "classes", "DRUID", 50769, nil, nil, 0, nil, 1077, nil ) -- Revive
	AddSpell( "classes", "DRUID", 52610, 76, nil, 1, 768, 186000, nil ) -- Savage Roar
	AddSpell( "classes", "DRUID", 62078, nil, nil, 1, 768, 6000, nil ) -- Swipe
	AddSpell( "classes", "DRUID", 62600, nil, nil, 1, 5487, 15000, nil ) -- Savage Defense
	AddSpell( "classes", "DRUID", 77758, 81, nil, 1, 5487, 234000, nil ) -- Thrash
	AddSpell( "classes", "DRUID", 77761, 83, nil, 1, 5487, 129000, nil ) -- Stampeding Roar
	AddSpell( "classes", "DRUID", 77764, 83, nil, 1, 768, 129000, nil ) -- Stampeding Roar
	AddSpell( "classes", "DRUID", 80964, nil, nil, 1, 5487, 2100, nil ) -- Skull Bash
	AddSpell( "classes", "DRUID", 80965, nil, nil, 1, 768, 2100, nil ) -- Skull Bash
	AddSpell( "classes", "DRUID", 87491, 80, nil, 0, nil, 222000, nil ) -- Mastery
	AddSpell( "classes", "DRUID", 87505, 50, nil, 0, nil, 22500, nil ) -- Leather Specialization
	AddSpell( "classes", "DRUID", 88747, 85, nil, 0, nil, 141000, nil ) -- Wild Mushroom
	AddSpell( "classes", "DRUID", 88751, 85, nil, 0, nil, 0, nil ) -- Wild Mushroom: Detonate
	AddSpell( "classes", "HUNTER",   136, nil, nil, 1, 1515, 2060, nil ) -- Mend Pet
	AddSpell( "classes", "HUNTER",   674, 20, nil, 0, nil, 3600, nil ) -- Dual Wield
	AddSpell( "classes", "HUNTER",   781, 14, nil, 0, nil, 2785, nil ) -- Disengage
	AddSpell( "classes", "HUNTER",  1130, nil, nil, 0, nil, 1418, nil ) -- Hunter's Mark
	AddSpell( "classes", "HUNTER",  1462, nil, nil, 0, nil, 680, nil ) -- Beast Lore
	AddSpell( "classes", "HUNTER",  1494, nil, nil, 0, nil, 97, nil ) -- Track Beasts
	AddSpell( "classes", "HUNTER",  1499, nil, nil, 0, nil, 7500, nil ) -- Freezing Trap
	AddSpell( "classes", "HUNTER",  1513, nil, nil, 0, nil, 12000, nil ) -- Scare Beast
	AddSpell( "classes", "HUNTER",  1515, nil, nil, 0, nil, 680, nil ) -- Tame Beast
	AddSpell( "classes", "HUNTER",  1543, nil, nil, 0, nil, 13500, nil ) -- Flare
	AddSpell( "classes", "HUNTER",  1978, nil, nil, 0, nil, 1076, nil ) -- Serpent Sting
	AddSpell( "classes", "HUNTER",  2641, nil, nil, 0, nil, 680, nil ) -- Dismiss Pet
	AddSpell( "classes", "HUNTER",  2643, nil, nil, 0, nil, 5100, nil ) -- Multi-Shot
	AddSpell( "classes", "HUNTER",  2973, nil, nil, 0, nil, 190, nil ) -- Raptor Strike
	AddSpell( "classes", "HUNTER",  2974, nil, nil, 0, nil, 1076, nil ) -- Wing Clip
	AddSpell( "classes", "HUNTER",  3045, nil, nil, 0, nil, 24000, nil ) -- Rapid Fire
	AddSpell( "classes", "HUNTER",  5116, nil, nil, 0, nil, 390, nil ) -- Concussive Shot
	AddSpell( "classes", "HUNTER",  5118, nil, nil, 0, nil, 5100, nil ) -- Aspect of the Cheetah
	AddSpell( "classes", "HUNTER",  5384, nil, nil, 0, nil, 9000, nil ) -- Feign Death
	AddSpell( "classes", "HUNTER",  6197, nil, nil, 0, nil, 2060, nil ) -- Eagle Eye
	AddSpell( "classes", "HUNTER",  6991, nil, nil, 0, nil, 680, nil ) -- Feed Pet
	AddSpell( "classes", "HUNTER",  8737, 40, nil, 0, nil, 15000, nil ) -- Mail
	AddSpell( "classes", "HUNTER", 13159, nil, nil, 0, nil, 25500, nil ) -- Aspect of the Pack
	AddSpell( "classes", "HUNTER", 13165, nil, nil, 0, nil, 1076, nil ) -- Aspect of the Hawk
	AddSpell( "classes", "HUNTER", 13795, nil, nil, 0, nil, 4200, nil ) -- Immolation Trap
	AddSpell( "classes", "HUNTER", 13809, nil, nil, 0, nil, 19500, nil ) -- Ice Trap
	AddSpell( "classes", "HUNTER", 13813, nil, nil, 0, nil, 13500, nil ) -- Explosive Trap
	AddSpell( "classes", "HUNTER", 19263, 78, nil, 0, nil, 204000, nil ) -- Deterrence
	AddSpell( "classes", "HUNTER", 19503, 15, nil, 0, nil, 1728, nil ) -- Scatter Shot
	AddSpell( "classes", "HUNTER", 19801, nil, nil, 0, nil, 10500, nil ) -- Tranquilizing Shot
	AddSpell( "classes", "HUNTER", 19878, nil, nil, 0, nil, 12000, nil ) -- Track Demons
	AddSpell( "classes", "HUNTER", 19879, nil, nil, 0, nil, 22500, nil ) -- Track Dragonkin
	AddSpell( "classes", "HUNTER", 19880, nil, nil, 0, nil, 10500, nil ) -- Track Elementals
	AddSpell( "classes", "HUNTER", 19882, nil, nil, 0, nil, 19500, nil ) -- Track Giants
	AddSpell( "classes", "HUNTER", 19883, nil, nil, 0, nil, 1076, nil ) -- Track Humanoids
	AddSpell( "classes", "HUNTER", 19884, nil, nil, 0, nil, 2785, nil ) -- Track Undead
	AddSpell( "classes", "HUNTER", 19885, nil, nil, 0, nil, 6000, nil ) -- Track Hidden
	AddSpell( "classes", "HUNTER", 20043, nil, nil, 0, nil, 93000, nil ) -- Aspect of the Wild
	AddSpell( "classes", "HUNTER", 20736, nil, nil, 0, nil, 22500, nil ) -- Distracting Shot
	AddSpell( "classes", "HUNTER", 34026, nil, nil, 0, nil, 680, nil ) -- Kill Command
	AddSpell( "classes", "HUNTER", 34477, 76, nil, 0, nil, 186000, nil ) -- Misdirection
	AddSpell( "classes", "HUNTER", 34600, nil, nil, 0, nil, 105000, nil ) -- Snake Trap
	AddSpell( "classes", "HUNTER", 51753, 85, nil, 0, nil, 282000, nil ) -- Camouflage
	AddSpell( "classes", "HUNTER", 53271, 74, nil, 0, nil, 168000, nil ) -- Master's Call
	AddSpell( "classes", "HUNTER", 53351, nil, nil, 0, nil, 10500, nil ) -- Kill Shot
	AddSpell( "classes", "HUNTER", 56641, nil, nil, 0, nil, 60, nil ) -- Steady Shot
	AddSpell( "classes", "HUNTER", 77767, 81, nil, 0, nil, 234000, nil ) -- Cobra Shot
	AddSpell( "classes", "HUNTER", 77769, 48, nil, 0, nil, 21000, nil ) -- Trap Launcher
	AddSpell( "classes", "HUNTER", 79682, 10, nil, 0, nil, 680, nil ) -- Control Pet
	AddSpell( "classes", "HUNTER", 82243, 8, nil, 0, nil, 390, nil ) -- Parry
	AddSpell( "classes", "HUNTER", 82654, 40, nil, 0, nil, 15000, nil ) -- Widow Venom
	AddSpell( "classes", "HUNTER", 82661, 83, nil, 0, nil, 258000, nil ) -- Aspect of the Fox
	AddSpell( "classes", "HUNTER", 83242, 18, nil, 0, nil, 2785, nil ) -- Call Pet 2
	AddSpell( "classes", "HUNTER", 83243, 42, nil, 0, nil, 16500, nil ) -- Call Pet 3
	AddSpell( "classes", "HUNTER", 83244, 62, nil, 0, nil, 81000, nil ) -- Call Pet 4
	AddSpell( "classes", "HUNTER", 83245, 82, nil, 0, nil, 246000, nil ) -- Call Pet 5
	AddSpell( "classes", "HUNTER", 87493, 80, nil, 0, nil, 222000, nil ) -- Mastery
	AddSpell( "classes", "HUNTER", 87506, 50, nil, 0, nil, 22500, nil ) -- Mail Specialization
	AddSpell( "classes", "MAGE",    10, 52, nil, 0, nil, 22500, nil ) -- Blizzard
	AddSpell( "classes", "MAGE",    66, 78, nil, 0, nil, 204000, nil ) -- Invisibility
	AddSpell( "classes", "MAGE",   116, 7, nil, 0, nil, 284, nil ) -- Frostbolt
	AddSpell( "classes", "MAGE",   118, 14, nil, 0, nil, 1418, nil ) -- Polymorph
	AddSpell( "classes", "MAGE",   120, 18, nil, 0, nil, 2784, nil ) -- Cone of Cold
	AddSpell( "classes", "MAGE",   122, 8, nil, 0, nil, 390, nil ) -- Frost Nova
	AddSpell( "classes", "MAGE",   130, 32, nil, 0, nil, 9000, nil ) -- Slow Fall
	AddSpell( "classes", "MAGE",   475, 30, nil, 0, nil, 7500, nil ) -- Remove Curse
	AddSpell( "classes", "MAGE",   543, 36, nil, 0, nil, 3600, nil ) -- Mage Ward
	AddSpell( "classes", "MAGE",   759, 48, nil, 0, nil, 21000, nil ) -- Conjure Mana Gem
	AddSpell( "classes", "MAGE",  1449, 22, nil, 0, nil, 4400, nil ) -- Arcane Explosion
	AddSpell( "classes", "MAGE",  1459, 58, nil, 0, nil, 27000, nil ) -- Arcane Brilliance
	AddSpell( "classes", "MAGE",  1463, 46, nil, 0, nil, 19500, nil ) -- Mana Shield
	AddSpell( "classes", "MAGE",  1953, 16, nil, 0, nil, 2060, nil ) -- Blink
	AddSpell( "classes", "MAGE",  2120, 44, nil, 0, nil, 19500, nil ) -- Flamestrike
	AddSpell( "classes", "MAGE",  2136, 5, nil, 0, nil, 142, nil ) -- Fire Blast
	AddSpell( "classes", "MAGE",  2139, 9, nil, 0, nil, 524, nil ) -- Counterspell
	AddSpell( "classes", "MAGE",  2948, 26, nil, 0, nil, 6000, nil ) -- Scorch
	AddSpell( "classes", "MAGE",  3561, 24, nil, 0, nil, 5100, nil ) -- Teleport: Stormwind
	AddSpell( "classes", "MAGE",  3562, 24, nil, 0, nil, 5100, nil ) -- Teleport: Ironforge
	AddSpell( "classes", "MAGE",  3563, nil, nil, 0, nil, 5100, nil ) -- Teleport: Undercity
	AddSpell( "classes", "MAGE",  3565, 24, nil, 0, nil, 5100, nil ) -- Teleport: Darnassus
	AddSpell( "classes", "MAGE",  3566, nil, nil, 0, nil, 5100, nil ) -- Teleport: Thunder Bluff
	AddSpell( "classes", "MAGE",  3567, nil, nil, 0, nil, 5100, nil ) -- Teleport: Orgrimmar
	AddSpell( "classes", "MAGE",  5143, 3, nil, 0, nil, 60, nil ) -- Arcane Missiles
	AddSpell( "classes", "MAGE",  6117, 68, nil, 0, nil, 117000, nil ) -- Mage Armor
	AddSpell( "classes", "MAGE",  7302, 54, nil, 0, nil, 24000, nil ) -- Frost Armor
	AddSpell( "classes", "MAGE", 10059, 42, nil, 0, nil, 16500, nil ) -- Portal: Stormwind
	AddSpell( "classes", "MAGE", 11416, 42, nil, 0, nil, 16500, nil ) -- Portal: Ironforge
	AddSpell( "classes", "MAGE", 11417, 42, nil, 0, nil, 16500, nil ) -- Portal: Orgrimmar
	AddSpell( "classes", "MAGE", 11418, 42, nil, 0, nil, 16500, nil ) -- Portal: Undercity
	AddSpell( "classes", "MAGE", 11419, 42, nil, 0, nil, 16500, nil ) -- Portal: Darnassus
	AddSpell( "classes", "MAGE", 11420, 42, nil, 0, nil, 16500, nil ) -- Portal: Thunder Bluff
	AddSpell( "classes", "MAGE", 12051, 12, nil, 0, nil, 1076, nil ) -- Evocation
	AddSpell( "classes", "MAGE", 30449, 70, nil, 0, nil, 132000, nil ) -- Spellsteal
	AddSpell( "classes", "MAGE", 30451, 20, nil, 0, nil, 10500, nil ) -- Arcane Blast
	AddSpell( "classes", "MAGE", 30455, 28, nil, 0, nil, 7500, nil ) -- Ice Lance
	AddSpell( "classes", "MAGE", 30482, 34, nil, 0, nil, 12000, nil ) -- Molten Armor
	AddSpell( "classes", "MAGE", 32266, 42, nil, 0, nil, 16500, nil ) -- Portal: Exodar
	AddSpell( "classes", "MAGE", 32267, 42, nil, 0, nil, 16500, nil ) -- Portal: Silvermoon
	AddSpell( "classes", "MAGE", 32271, 24, nil, 0, nil, 5100, nil ) -- Teleport: Exodar
	AddSpell( "classes", "MAGE", 32272, nil, nil, 0, nil, 5100, nil ) -- Teleport: Silvermoon
	AddSpell( "classes", "MAGE", 33690, 62, nil, 0, nil, 81000, nil ) -- Teleport: Shattrath
	AddSpell( "classes", "MAGE", 33691, 66, nil, 0, nil, 105000, nil ) -- Portal: Shattrath
	AddSpell( "classes", "MAGE", 35715, 62, nil, 0, nil, 81000, nil ) -- Teleport: Shattrath
	AddSpell( "classes", "MAGE", 35717, 66, nil, 0, nil, 105000, nil ) -- Portal: Shattrath
	AddSpell( "classes", "MAGE", 42955, 38, nil, 0, nil, 13500, nil ) -- Conjure Refreshment
	AddSpell( "classes", "MAGE", 43987, 76, nil, 1, 42955, 186000, nil ) -- Ritual of Refreshment
	AddSpell( "classes", "MAGE", 44614, 56, nil, 0, nil, 25500, nil ) -- Frostfire Bolt
	AddSpell( "classes", "MAGE", 45438, 30, nil, 0, nil, 7500, nil ) -- Ice Block
	AddSpell( "classes", "MAGE", 49358, 52, nil, 0, nil, 22500, nil ) -- Teleport: Stonard
	AddSpell( "classes", "MAGE", 49359, 24, nil, 0, nil, 5100, nil ) -- Teleport: Theramore
	AddSpell( "classes", "MAGE", 49360, 42, nil, 0, nil, 16500, nil ) -- Portal: Theramore
	AddSpell( "classes", "MAGE", 49361, 52, nil, 0, nil, 22500, nil ) -- Portal: Stonard
	AddSpell( "classes", "MAGE", 53140, 71, nil, 0, nil, 150000, nil ) -- Teleport: Dalaran
	AddSpell( "classes", "MAGE", 53142, 74, nil, 0, nil, 168000, nil ) -- Portal: Dalaran
	AddSpell( "classes", "MAGE", 55342, 50, nil, 0, nil, 22500, nil ) -- Mirror Image
	AddSpell( "classes", "MAGE", 80353, 85, nil, 0, nil, 282000, nil ) -- Time Warp
	AddSpell( "classes", "MAGE", 82676, 83, nil, 0, nil, 258000, nil ) -- Ring of Frost
	AddSpell( "classes", "MAGE", 82731, 81, nil, 0, nil, 234000, nil ) -- Flame Orb
	AddSpell( "classes", "MAGE", 86467, 80, nil, 0, nil, 222000, nil ) -- Mastery
	AddSpell( "classes", "MAGE", 88342, 85, nil, 0, nil, 282000, nil ) -- Teleport: Tol Barad
	AddSpell( "classes", "MAGE", 88344, 85, nil, 0, nil, 282000, nil ) -- Teleport: Tol Barad
	AddSpell( "classes", "MAGE", 88345, 85, nil, 0, nil, 282000, nil ) -- Portal: Tol Barad
	AddSpell( "classes", "MAGE", 88346, 85, nil, 0, nil, 282000, nil ) -- Portal: Tol Barad
	AddSpell( "classes", "MAGE", 89744, 50, nil, 0, nil, 22500, nil ) -- Wizardry
	AddSpell( "classes", "PALADIN",   465, nil, nil, 0, nil, 142, nil ) -- Devotion Aura
	AddSpell( "classes", "PALADIN",   498, nil, nil, 0, nil, 7500, nil ) -- Divine Protection
	AddSpell( "classes", "PALADIN",   633, nil, nil, 0, nil, 2060, nil ) -- Lay on Hands
	AddSpell( "classes", "PALADIN",   635, nil, nil, 0, nil, 285, nil ) -- Holy Light
	AddSpell( "classes", "PALADIN",   642, nil, nil, 0, nil, 21000, nil ) -- Divine Shield
	AddSpell( "classes", "PALADIN",   750, 40, nil, 0, nil, 15000, nil ) -- Plate Mail
	AddSpell( "classes", "PALADIN",   853, nil, nil, 0, nil, 1418, nil ) -- Hammer of Justice
	AddSpell( "classes", "PALADIN",   879, nil, nil, 0, nil, 2785, nil ) -- Exorcism
	AddSpell( "classes", "PALADIN",  1022, nil, nil, 0, nil, 2785, nil ) -- Hand of Protection
	AddSpell( "classes", "PALADIN",  1038, 66, nil, 0, nil, 105000, nil ) -- Hand of Salvation
	AddSpell( "classes", "PALADIN",  1044, nil, nil, 0, nil, 22500, nil ) -- Hand of Freedom
	AddSpell( "classes", "PALADIN",  2812, nil, nil, 0, nil, 7500, nil ) -- Holy Wrath
	AddSpell( "classes", "PALADIN",  4987, nil, nil, 0, nil, 10500, nil ) -- Cleanse
	AddSpell( "classes", "PALADIN",  6940, 80, nil, 0, nil, 222000, nil ) -- Hand of Sacrifice
	AddSpell( "classes", "PALADIN",  7294, nil, nil, 0, nil, 6000, nil ) -- Retribution Aura
	AddSpell( "classes", "PALADIN",  7328, nil, nil, 0, nil, 1077, nil ) -- Redemption
	AddSpell( "classes", "PALADIN", 10326, 78, nil, 0, nil, 204000, nil ) -- Turn Evil
	AddSpell( "classes", "PALADIN", 13819, 20, nil, 0, nil, 3600, nil ) -- Summon Warhorse
	AddSpell( "classes", "PALADIN", 19740, nil, nil, 0, nil, 25500, nil ) -- Blessing of Might
	AddSpell( "classes", "PALADIN", 19746, nil, nil, 0, nil, 16500, nil ) -- Concentration Aura
	AddSpell( "classes", "PALADIN", 19750, nil, nil, 0, nil, 2060, nil ) -- Flash of Light
	AddSpell( "classes", "PALADIN", 19891, 76, nil, 0, nil, 186000, nil ) -- Resistance Aura
	AddSpell( "classes", "PALADIN", 20154, nil, nil, 0, nil, 60, nil ) -- Seal of Righteousness
	AddSpell( "classes", "PALADIN", 20164, 64, nil, 0, nil, 93000, nil ) -- Seal of Justice
	AddSpell( "classes", "PALADIN", 20165, nil, nil, 0, nil, 9000, nil ) -- Seal of Insight
	AddSpell( "classes", "PALADIN", 20217, nil, nil, 0, nil, 4200, nil ) -- Blessing of Kings
	AddSpell( "classes", "PALADIN", 20271, nil, nil, 0, nil, 60, nil ) -- Judgement
	AddSpell( "classes", "PALADIN", 23214, 40, nil, 1, 33391, 15000, nil ) -- Summon Charger
	AddSpell( "classes", "PALADIN", 24275, nil, nil, 0, nil, 19500, nil ) -- Hammer of Wrath
	AddSpell( "classes", "PALADIN", 25780, nil, nil, 0, nil, 1077, nil ) -- Righteous Fury
	AddSpell( "classes", "PALADIN", 26573, nil, nil, 0, nil, 5100, nil ) -- Consecration
	AddSpell( "classes", "PALADIN", 31789, nil, nil, 0, nil, 12000, nil ) -- Righteous Defense
	AddSpell( "classes", "PALADIN", 31801, nil, nil, 0, nil, 19500, nil ) -- Seal of Truth
	AddSpell( "classes", "PALADIN", 31884, 72, nil, 0, nil, 150000, nil ) -- Avenging Wrath
	AddSpell( "classes", "PALADIN", 32223, 62, nil, 0, nil, 81000, nil ) -- Crusader Aura
	AddSpell( "classes", "PALADIN", 34767, 40, nil, 1, 33391, 15000, nil ) -- Summon Charger
	AddSpell( "classes", "PALADIN", 34769, 20, nil, 0, nil, 3600, nil ) -- Summon Warhorse
	AddSpell( "classes", "PALADIN", 54428, nil, nil, 0, nil, 19500, nil ) -- Divine Plea
	AddSpell( "classes", "PALADIN", 62124, nil, nil, 0, nil, 1418, nil ) -- Hand of Reckoning
	AddSpell( "classes", "PALADIN", 82242, 10, nil, 0, nil, 680, nil ) -- Parry
	AddSpell( "classes", "PALADIN", 82326, 62, nil, 0, nil, 81000, nil ) -- Divine Light
	AddSpell( "classes", "PALADIN", 82327, 83, nil, 0, nil, 258000, nil ) -- Holy Radiance
	AddSpell( "classes", "PALADIN", 84963, 81, nil, 0, nil, 234000, nil ) -- Inquisition
	AddSpell( "classes", "PALADIN", 85673, nil, nil, 0, nil, 552, nil ) -- Word of Glory
	AddSpell( "classes", "PALADIN", 86150, 85, nil, 0, nil, 282000, nil ) -- Guardian of Ancient Kings
	AddSpell( "classes", "PALADIN", 87494, 80, nil, 0, nil, 222000, nil ) -- Mastery
	AddSpell( "classes", "PALADIN", 87511, nil, nil, 0, nil, 22500, nil ) -- Plate Specialization
	AddSpell( "classes", "PALADIN", 96231, 54, nil, 0, nil, 24000, nil ) -- Rebuke
	AddSpell( "classes", "PRIEST",    17, 5, nil, 0, nil, 142, nil ) -- Power Word: Shield
	AddSpell( "classes", "PRIEST",   139, 8, nil, 0, nil, 390, nil ) -- Renew
	AddSpell( "classes", "PRIEST",   453, 56, nil, 0, nil, 25500, nil ) -- Mind Soothe
	AddSpell( "classes", "PRIEST",   527, 26, nil, 0, nil, 6000, nil ) -- Dispel Magic
	AddSpell( "classes", "PRIEST",   528, 22, nil, 0, nil, 4200, nil ) -- Cure Disease
	AddSpell( "classes", "PRIEST",   586, 24, nil, 0, nil, 5100, nil ) -- Fade
	AddSpell( "classes", "PRIEST",   588, 7, nil, 0, nil, 285, nil ) -- Inner Fire
	AddSpell( "classes", "PRIEST",   589, 4, nil, 0, nil, 97, nil ) -- Shadow Word: Pain
	AddSpell( "classes", "PRIEST",   596, 44, nil, 0, nil, 19500, nil ) -- Prayer of Healing
	AddSpell( "classes", "PRIEST",   605, 38, nil, 0, nil, 13500, nil ) -- Mind Control
	AddSpell( "classes", "PRIEST",  1706, 34, nil, 0, nil, 10500, nil ) -- Levitate
	AddSpell( "classes", "PRIEST",  2006, 14, nil, 0, nil, 1418, nil ) -- Resurrection
	AddSpell( "classes", "PRIEST",  2050, 16, nil, 0, nil, 2060, nil ) -- Heal
	AddSpell( "classes", "PRIEST",  2060, 38, nil, 0, nil, 16500, nil ) -- Greater Heal
	AddSpell( "classes", "PRIEST",  2061, 3, nil, 0, nil, 60, nil ) -- Flash Heal
	AddSpell( "classes", "PRIEST",  2096, 36, nil, 0, nil, 12000, nil ) -- Mind Vision
	AddSpell( "classes", "PRIEST",  2944, 28, nil, 0, nil, 7500, nil ) -- Devouring Plague
	AddSpell( "classes", "PRIEST",  6346, 54, nil, 0, nil, 24000, nil ) -- Fear Ward
	AddSpell( "classes", "PRIEST",  8092, 9, nil, 0, nil, 552, nil ) -- Mind Blast
	AddSpell( "classes", "PRIEST",  8122, 12, nil, 0, nil, 1077, nil ) -- Psychic Scream
	AddSpell( "classes", "PRIEST",  8129, 58, nil, 0, nil, 27000, nil ) -- Mana Burn
	AddSpell( "classes", "PRIEST",  9484, 32, nil, 0, nil, 9000, nil ) -- Shackle Undead
	AddSpell( "classes", "PRIEST", 14914, 18, nil, 0, nil, 2785, nil ) -- Holy Fire
	AddSpell( "classes", "PRIEST", 15237, 62, nil, 0, nil, 81000, nil ) -- Holy Nova
	AddSpell( "classes", "PRIEST", 21562, 14, nil, 0, nil, 1418, nil ) -- Power Word: Fortitude
	AddSpell( "classes", "PRIEST", 27683, 52, nil, 0, nil, 22500, nil ) -- Shadow Protection
	AddSpell( "classes", "PRIEST", 32375, 72, nil, 1, 527, 150000, nil ) -- Mass Dispel
	AddSpell( "classes", "PRIEST", 32379, 32, nil, 0, nil, 9000, nil ) -- Shadow Word: Death
	AddSpell( "classes", "PRIEST", 32546, 48, nil, 0, nil, 21000, nil ) -- Binding Heal
	AddSpell( "classes", "PRIEST", 33076, 68, nil, 0, nil, 117000, nil ) -- Prayer of Mending
	AddSpell( "classes", "PRIEST", 34433, 66, nil, 0, nil, 105000, nil ) -- Shadowfiend
	AddSpell( "classes", "PRIEST", 48045, 74, nil, 0, nil, 168000, nil ) -- Mind Sear
	AddSpell( "classes", "PRIEST", 64843, 78, nil, 0, nil, 204000, nil ) -- Divine Hymn
	AddSpell( "classes", "PRIEST", 64901, 64, nil, 0, nil, 93000, nil ) -- Hymn of Hope
	AddSpell( "classes", "PRIEST", 73325, 85, nil, 0, nil, 282000, nil ) -- Leap of Faith
	AddSpell( "classes", "PRIEST", 73413, 83, nil, 0, nil, 258000, nil ) -- Inner Will
	AddSpell( "classes", "PRIEST", 73510, 81, nil, 0, nil, 234000, nil ) -- Mind Spike
	AddSpell( "classes", "PRIEST", 87495, 80, nil, 0, nil, 222000, nil ) -- Mastery
	AddSpell( "classes", "PRIEST", 89745, 50, nil, 0, nil, 22500, nil ) -- Mysticism
	AddSpell( "classes", "ROGUE",    53, nil, nil, 0, nil, 2785, nil ) -- Backstab
	AddSpell( "classes", "ROGUE",   408, nil, nil, 0, nil, 7500, nil ) -- Kidney Shot
	AddSpell( "classes", "ROGUE",   703, nil, nil, 0, nil, 15000, nil ) -- Garrote
	AddSpell( "classes", "ROGUE",   921, nil, nil, 0, nil, 285, nil ) -- Pick Pocket
	AddSpell( "classes", "ROGUE",  1725, nil, nil, 0, nil, 7500, nil ) -- Distract
	AddSpell( "classes", "ROGUE",  1766, nil, nil, 0, nil, 1418, nil ) -- Kick
	AddSpell( "classes", "ROGUE",  1776, nil, nil, 0, nil, 2060, nil ) -- Gouge
	AddSpell( "classes", "ROGUE",  1784, nil, nil, 0, nil, 142, nil ) -- Stealth
	AddSpell( "classes", "ROGUE",  1804, nil, nil, 0, nil, 3600, nil ) -- Pick Lock
	AddSpell( "classes", "ROGUE",  1833, nil, nil, 0, nil, 6000, nil ) -- Cheap Shot
	AddSpell( "classes", "ROGUE",  1842, nil, nil, 1, 2836, 19500, nil ) -- Disarm Trap
	AddSpell( "classes", "ROGUE",  1856, nil, nil, 1, 1784, 5100, nil ) -- Vanish
	AddSpell( "classes", "ROGUE",  1860, nil, nil, 0, nil, 21000, nil ) -- Safe Fall
	AddSpell( "classes", "ROGUE",  1943, nil, nil, 0, nil, 19500, nil ) -- Rupture
	AddSpell( "classes", "ROGUE",  1966, nil, nil, 0, nil, 16500, nil ) -- Feint
	AddSpell( "classes", "ROGUE",  2094, nil, nil, 0, nil, 10500, nil ) -- Blind
	AddSpell( "classes", "ROGUE",  2098, nil, nil, 0, nil, 60, nil ) -- Eviscerate
	AddSpell( "classes", "ROGUE",  2836, nil, nil, 0, nil, 9000, nil ) -- Detect Traps
	AddSpell( "classes", "ROGUE",  2983, nil, nil, 0, nil, 2060, nil ) -- Sprint
	AddSpell( "classes", "ROGUE",  5171, nil, nil, 0, nil, 4200, nil ) -- Slice and Dice
	AddSpell( "classes", "ROGUE",  5277, nil, nil, 0, nil, 552, nil ) -- Evasion
	AddSpell( "classes", "ROGUE",  5938, nil, nil, 0, nil, 132000, nil ) -- Shiv
	AddSpell( "classes", "ROGUE",  6770, nil, nil, 0, nil, 680, nil ) -- Sap
	AddSpell( "classes", "ROGUE",  8647, nil, nil, 0, nil, 12000, nil ) -- Expose Armor
	AddSpell( "classes", "ROGUE",  8676, nil, nil, 0, nil, 390, nil ) -- Ambush
	AddSpell( "classes", "ROGUE", 26679, nil, nil, 0, nil, 81000, nil ) -- Deadly Throw
	AddSpell( "classes", "ROGUE", 31224, nil, nil, 0, nil, 27000, nil ) -- Cloak of Shadows
	AddSpell( "classes", "ROGUE", 32645, nil, nil, 0, nil, 24000, nil ) -- Envenom
	AddSpell( "classes", "ROGUE", 51722, nil, nil, 0, nil, 13500, nil ) -- Dismantle
	AddSpell( "classes", "ROGUE", 51723, nil, nil, 0, nil, 222000, nil ) -- Fan of Knives
	AddSpell( "classes", "ROGUE", 57934, nil, nil, 0, nil, 177000, nil ) -- Tricks of the Trade
	AddSpell( "classes", "ROGUE", 73651, nil, nil, 0, nil, 1077, nil ) -- Recuperate
	AddSpell( "classes", "ROGUE", 73981, 83, nil, 0, nil, 258000, nil ) -- Redirect
	AddSpell( "classes", "ROGUE", 74001, 81, nil, 0, nil, 234000, nil ) -- Combat Readiness
	AddSpell( "classes", "ROGUE", 76577, 85, nil, 0, nil, 282000, nil ) -- Smoke Bomb
	AddSpell( "classes", "ROGUE", 82245, 12, nil, 0, nil, 1077, nil ) -- Parry
	AddSpell( "classes", "ROGUE", 87496, nil, nil, 0, nil, 222000, nil ) -- Mastery
	AddSpell( "classes", "ROGUE", 87504, nil, nil, 0, nil, 22500, nil ) -- Leather Specialization
	AddSpell( "classes", "SHAMAN",   131, 46, nil, 0, nil, 19500, nil ) -- Water Breathing
	AddSpell( "classes", "SHAMAN",   324, 8, nil, 0, nil, 390, nil ) -- Lightning Shield
	AddSpell( "classes", "SHAMAN",   331, 7, nil, 0, nil, 285, nil ) -- Healing Wave
	AddSpell( "classes", "SHAMAN",   370, 12, nil, 0, nil, 1077, nil ) -- Purge
	AddSpell( "classes", "SHAMAN",   421, 28, nil, 0, nil, 7500, nil ) -- Chain Lightning
	AddSpell( "classes", "SHAMAN",   546, 24, nil, 0, nil, 5100, nil ) -- Water Walking
	AddSpell( "classes", "SHAMAN",   556, 30, nil, 0, nil, 7500, nil ) -- Astral Recall
	AddSpell( "classes", "SHAMAN",  1064, 40, nil, 0, nil, 15000, nil ) -- Chain Heal
	AddSpell( "classes", "SHAMAN",  1535, 28, nil, 0, nil, 7500, nil ) -- Fire Nova
	AddSpell( "classes", "SHAMAN",  2008, 12, nil, 0, nil, 1077, nil ) -- Ancestral Spirit
	AddSpell( "classes", "SHAMAN",  2062, 56, nil, 0, nil, 25500, nil ) -- Earth Elemental Totem
	AddSpell( "classes", "SHAMAN",  2484, 18, nil, 0, nil, 2785, nil ) -- Earthbind Totem
	AddSpell( "classes", "SHAMAN",  2645, 15, nil, 0, nil, 1728, nil ) -- Ghost Wolf
	AddSpell( "classes", "SHAMAN",  2825, 70, nil, 0, nil, 132000, nil ) -- Bloodlust
	AddSpell( "classes", "SHAMAN",  2894, 66, nil, 0, nil, 105000, nil ) -- Fire Elemental Totem
	AddSpell( "classes", "SHAMAN",  3599, 10, nil, 0, nil, 680, nil ) -- Searing Totem
	AddSpell( "classes", "SHAMAN",  3738, 44, nil, 0, nil, 19500, nil ) -- Wrath of Air Totem
	AddSpell( "classes", "SHAMAN",  5394, 20, nil, 0, nil, 3600, nil ) -- Healing Stream Totem
	AddSpell( "classes", "SHAMAN",  5675, 42, nil, 0, nil, 16500, nil ) -- Mana Spring Totem
	AddSpell( "classes", "SHAMAN",  5730, 58, nil, 0, nil, 27000, nil ) -- Stoneclaw Totem
	AddSpell( "classes", "SHAMAN",  6196, 36, nil, 0, nil, 12000, nil ) -- Far Sight
	AddSpell( "classes", "SHAMAN",  8004, 20, nil, 0, nil, 3600, nil ) -- Healing Surge
	AddSpell( "classes", "SHAMAN",  8017, 75, nil, 0, nil, 177000, nil ) -- Rockbiter Weapon
	AddSpell( "classes", "SHAMAN",  8024, 10, nil, 0, nil, 680, nil ) -- Flametongue Weapon
	AddSpell( "classes", "SHAMAN",  8033, 26, nil, 0, nil, 6000, nil ) -- Frostbrand Weapon
	AddSpell( "classes", "SHAMAN",  8042, 5, nil, 0, nil, 142, nil ) -- Earth Shock
	AddSpell( "classes", "SHAMAN",  8050, 14, nil, 0, nil, 1418, nil ) -- Flame Shock
	AddSpell( "classes", "SHAMAN",  8056, 22, nil, 0, nil, 4200, nil ) -- Frost Shock
	AddSpell( "classes", "SHAMAN",  8071, 48, nil, 0, nil, 21000, nil ) -- Stoneskin Totem
	AddSpell( "classes", "SHAMAN",  8075, 4, nil, 0, nil, 97, nil ) -- Strength of Earth Totem
	AddSpell( "classes", "SHAMAN",  8143, 52, nil, 0, nil, 22500, nil ) -- Tremor Totem
	AddSpell( "classes", "SHAMAN",  8177, 38, nil, 0, nil, 13500, nil ) -- Grounding Totem
	AddSpell( "classes", "SHAMAN",  8184, 62, nil, 0, nil, 81000, nil ) -- Elemental Resistance Totem
	AddSpell( "classes", "SHAMAN",  8190, 36, nil, 0, nil, 12000, nil ) -- Magma Totem
	AddSpell( "classes", "SHAMAN",  8227, 12, nil, 0, nil, 1077, nil ) -- Flametongue Totem
	AddSpell( "classes", "SHAMAN",  8232, 32, nil, 0, nil, 9000, nil ) -- Windfury Weapon
	AddSpell( "classes", "SHAMAN",  8512, 30, nil, 0, nil, 7500, nil ) -- Windfury Totem
	AddSpell( "classes", "SHAMAN",  8737, 40, nil, 0, nil, 15000, nil ) -- Mail
	AddSpell( "classes", "SHAMAN", 20608, 30, nil, 0, nil, 7500, nil ) -- Reincarnation
	AddSpell( "classes", "SHAMAN", 32182, nil, nil, 0, nil, 132000, nil ) -- Heroism
	AddSpell( "classes", "SHAMAN", 36936, 30, nil, 0, nil, 7500, nil ) -- Totemic Recall
	AddSpell( "classes", "SHAMAN", 51505, 34, nil, 0, nil, 10500, nil ) -- Lava Burst
	AddSpell( "classes", "SHAMAN", 51514, 80, nil, 0, nil, 222000, nil ) -- Hex
	AddSpell( "classes", "SHAMAN", 51730, 54, nil, 0, nil, 24000, nil ) -- Earthliving Weapon
	AddSpell( "classes", "SHAMAN", 51886, 18, nil, 0, nil, 2785, nil ) -- Cleanse Spirit
	AddSpell( "classes", "SHAMAN", 52127, 20, nil, 0, nil, 3600, nil ) -- Water Shield
	AddSpell( "classes", "SHAMAN", 57994, 16, nil, 0, nil, 2060, nil ) -- Wind Shear
	AddSpell( "classes", "SHAMAN", 66842, 30, nil, 0, nil, 7500, nil ) -- Call of the Elements
	AddSpell( "classes", "SHAMAN", 66843, 40, nil, 0, nil, 15000, nil ) -- Call of the Ancestors
	AddSpell( "classes", "SHAMAN", 66844, 50, nil, 0, nil, 22500, nil ) -- Call of the Spirits
	AddSpell( "classes", "SHAMAN", 73680, 81, nil, 0, nil, 234000, nil ) -- Unleash Elements
	AddSpell( "classes", "SHAMAN", 73899, 3, nil, 0, nil, 60, nil ) -- Primal Strike
	AddSpell( "classes", "SHAMAN", 73920, 83, nil, 0, nil, 258000, nil ) -- Healing Rain
	AddSpell( "classes", "SHAMAN", 76780, 64, nil, 0, nil, 93000, nil ) -- Bind Elemental
	AddSpell( "classes", "SHAMAN", 77472, 68, nil, 0, nil, 117000, nil ) -- Greater Healing Wave
	AddSpell( "classes", "SHAMAN", 79206, 85, nil, 0, nil, 282000, nil ) -- Spiritwalker's Grace
	AddSpell( "classes", "SHAMAN", 87497, 80, nil, 0, nil, 222000, nil ) -- Mastery
	AddSpell( "classes", "SHAMAN", 87507, 50, nil, 0, nil, 22500, nil ) -- Mail Specialization
	AddSpell( "classes", "SHAMAN", 87718, 74, nil, 0, nil, 168000, nil ) -- Totem of Tranquil Mind
	AddSpell( "classes", "WARLOCK",   126, nil, nil, 0, nil, 4200, nil ) -- Eye of Kilrogg
	AddSpell( "classes", "WARLOCK",   172, nil, nil, 0, nil, 97, nil ) -- Corruption
	AddSpell( "classes", "WARLOCK",   348, nil, nil, 0, nil, 60, nil ) -- Immolate
	AddSpell( "classes", "WARLOCK",   603, nil, nil, 0, nil, 3600, nil ) -- Bane of Doom
	AddSpell( "classes", "WARLOCK",   687, nil, nil, 0, nil, 480, nil ) -- Demon Armor
	AddSpell( "classes", "WARLOCK",   689, nil, nil, 0, nil, 190, nil ) -- Drain Life
	AddSpell( "classes", "WARLOCK",   691, nil, nil, 0, nil, 7500, nil ) -- Summon Felhunter
	AddSpell( "classes", "WARLOCK",   693, nil, nil, 1, 1120, 2785, nil ) -- Create Soulstone
	AddSpell( "classes", "WARLOCK",   697, nil, nil, 0, nil, 390, nil ) -- Summon Voidwalker
	AddSpell( "classes", "WARLOCK",   698, nil, nil, 0, nil, 16500, nil ) -- Ritual of Summoning
	AddSpell( "classes", "WARLOCK",   702, nil, nil, 0, nil, 2060, nil ) -- Curse of Weakness
	AddSpell( "classes", "WARLOCK",   710, nil, nil, 0, nil, 9000, nil ) -- Banish
	AddSpell( "classes", "WARLOCK",   712, nil, nil, 0, nil, 3600, nil ) -- Summon Succubus
	AddSpell( "classes", "WARLOCK",   755, nil, nil, 0, nil, 1077, nil ) -- Health Funnel
	AddSpell( "classes", "WARLOCK",   980, nil, nil, 0, nil, 1077, nil ) -- Bane of Agony
	AddSpell( "classes", "WARLOCK",  1098, nil, nil, 0, nil, 7500, nil ) -- Enslave Demon
	AddSpell( "classes", "WARLOCK",  1120, nil, nil, 0, nil, 680, nil ) -- Drain Soul
	AddSpell( "classes", "WARLOCK",  1122, nil, nil, 1, 1120, 22500, nil ) -- Summon Infernal
	AddSpell( "classes", "WARLOCK",  1454, nil, nil, 0, nil, 142, nil ) -- Life Tap
	AddSpell( "classes", "WARLOCK",  1490, nil, nil, 0, nil, 22500, nil ) -- Curse of the Elements
	AddSpell( "classes", "WARLOCK",  1714, nil, nil, 0, nil, 6000, nil ) -- Curse of Tongues
	AddSpell( "classes", "WARLOCK",  1949, nil, nil, 0, nil, 7500, nil ) -- Hellfire
	AddSpell( "classes", "WARLOCK",  5138, nil, nil, 0, nil, 5100, "Interface\\Icons\\Spell_Shadow_SiphonMana" ) -- Drain Mana
	AddSpell( "classes", "WARLOCK",  5484, nil, nil, 0, nil, 19500, nil ) -- Howl of Terror
	AddSpell( "classes", "WARLOCK",  5676, nil, nil, 0, nil, 2785, nil ) -- Searing Pain
	AddSpell( "classes", "WARLOCK",  5697, nil, nil, 0, nil, 2060, nil ) -- Unending Breath
	AddSpell( "classes", "WARLOCK",  5740, nil, nil, 0, nil, 2785, nil ) -- Rain of Fire
	AddSpell( "classes", "WARLOCK",  5782, nil, nil, 0, nil, 1418, nil ) -- Fear
	AddSpell( "classes", "WARLOCK",  5784, 20, nil, 0, nil, 3600, nil ) -- Felsteed
	AddSpell( "classes", "WARLOCK",  6201, nil, nil, 0, nil, 552, nil ) -- Create Healthstone
	AddSpell( "classes", "WARLOCK",  6229, nil, nil, 0, nil, 10500, nil ) -- Shadow Ward
	AddSpell( "classes", "WARLOCK",  6353, nil, nil, 0, nil, 24000, nil ) -- Soul Fire
	AddSpell( "classes", "WARLOCK",  6789, nil, nil, 0, nil, 16500, nil ) -- Death Coil
	AddSpell( "classes", "WARLOCK", 18540, nil, nil, 1, 1120, 27000, nil ) -- Summon Doomguard
	AddSpell( "classes", "WARLOCK", 19028, nil, nil, 0, nil, 3600, nil ) -- Soul Link
	AddSpell( "classes", "WARLOCK", 23161, 40, nil, 1, 33391, 15000, nil ) -- Dreadsteed
	AddSpell( "classes", "WARLOCK", 27243, 72, nil, 0, nil, 150000, nil ) -- Seed of Corruption
	AddSpell( "classes", "WARLOCK", 28176, nil, nil, 0, nil, 81000, nil ) -- Fel Armor
	AddSpell( "classes", "WARLOCK", 29722, nil, nil, 0, nil, 93000, nil ) -- Incinerate
	AddSpell( "classes", "WARLOCK", 29858, nil, nil, 1, 1120, 105000, nil ) -- Soulshatter
	AddSpell( "classes", "WARLOCK", 29893, nil, nil, 1, 1120, 117000, nil ) -- Ritual of Souls
	AddSpell( "classes", "WARLOCK", 47897, 76, nil, 0, nil, 186000, nil ) -- Shadowflame
	AddSpell( "classes", "WARLOCK", 48018, 78, nil, 0, nil, 102000, nil ) -- Demonic Circle: Summon
	AddSpell( "classes", "WARLOCK", 48020, 78, nil, 0, nil, 102000, nil ) -- Demonic Circle: Teleport
	AddSpell( "classes", "WARLOCK", 74434, nil, nil, 0, nil, 680, nil ) -- Soulburn
	AddSpell( "classes", "WARLOCK", 77799, 81, nil, 0, nil, 234000, nil ) -- Fel Flame
	AddSpell( "classes", "WARLOCK", 77801, 85, nil, 0, nil, 282000, nil ) -- Demon Soul
	AddSpell( "classes", "WARLOCK", 79268, nil, nil, 0, nil, 1077, nil ) -- Soul Harvest
	AddSpell( "classes", "WARLOCK", 80388, nil, nil, 0, nil, 680, nil ) -- Control Demon
	AddSpell( "classes", "WARLOCK", 80398, 83, nil, 0, nil, 258000, nil ) -- Dark Intent
	AddSpell( "classes", "WARLOCK", 86091, nil, nil, 0, nil, 22500, nil ) -- Nethermancy
	AddSpell( "classes", "WARLOCK", 87498, 80, nil, 0, nil, 222000, nil ) -- Mastery
	AddSpell( "classes", "WARRIOR",    71, nil, nil, 0, nil, 680, nil ) -- Defensive Stance
	AddSpell( "classes", "WARRIOR",    72, nil, nil, 0, nil, 3600, nil ) -- Shield Bash
	AddSpell( "classes", "WARRIOR",    78, nil, nil, 0, nil, 1418, nil ) -- Heroic Strike
	AddSpell( "classes", "WARRIOR",   100, 3, nil, 0, nil, 60, nil ) -- Charge
	AddSpell( "classes", "WARRIOR",   355, nil, nil, 0, nil, 1076, nil ) -- Taunt
	AddSpell( "classes", "WARRIOR",   469, 68, nil, 0, nil, 117000, nil ) -- Commanding Shout
	AddSpell( "classes", "WARRIOR",   676, 34, nil, 1, 71, 10500, nil ) -- Disarm
	AddSpell( "classes", "WARRIOR",   750, 40, nil, 0, nil, 15000, nil ) -- Plate Mail
	AddSpell( "classes", "WARRIOR",   772, nil, nil, 0, nil, 284, nil ) -- Rend
	AddSpell( "classes", "WARRIOR",   845, 24, nil, 0, nil, 5100, nil ) -- Cleave
	AddSpell( "classes", "WARRIOR",   871, 48, nil, 1, 71, 21000, nil ) -- Shield Wall
	AddSpell( "classes", "WARRIOR",  1134, 56, nil, 0, nil, 25500, nil ) -- Inner Rage
	AddSpell( "classes", "WARRIOR",  1160, 52, nil, 0, nil, 22500, nil ) -- Demoralizing Shout
	AddSpell( "classes", "WARRIOR",  1161, 46, nil, 0, nil, 19500, nil ) -- Challenging Shout
	AddSpell( "classes", "WARRIOR",  1464, 44, nil, 0, nil, 19500, nil ) -- Slam
	AddSpell( "classes", "WARRIOR",  1680, 36, nil, 1, 2458, 12000, nil ) -- Whirlwind
	AddSpell( "classes", "WARRIOR",  1715, 26, nil, 0, nil, 6000, nil ) -- Hamstring
	AddSpell( "classes", "WARRIOR",  1719, 64, nil, 1, 2458, 93000, nil ) -- Recklessness
	AddSpell( "classes", "WARRIOR",  2458, 30, nil, 0, nil, 7500, nil ) -- Berserker Stance
	AddSpell( "classes", "WARRIOR",  2565, 28, nil, 1, 71, 7500, nil ) -- Shield Block
	AddSpell( "classes", "WARRIOR",  3127, 10, nil, 0, nil, 680, nil ) -- Parry
	AddSpell( "classes", "WARRIOR",  3411, 72, nil, 0, nil, 150000, nil ) -- Intervene
	AddSpell( "classes", "WARRIOR",  5246, 42, nil, 0, nil, 16500, nil ) -- Intimidating Shout
	AddSpell( "classes", "WARRIOR",  5308, 16, nil, 0, nil, 2060, nil ) -- Execute
	AddSpell( "classes", "WARRIOR",  6343, nil, nil, 0, nil, 551, nil ) -- Thunder Clap
	AddSpell( "classes", "WARRIOR",  6544, 85, nil, 0, nil, 282000, nil ) -- Heroic Leap
	AddSpell( "classes", "WARRIOR",  6552, 38, nil, 1, 2458, 13500, nil ) -- Pummel
	AddSpell( "classes", "WARRIOR",  6572, 40, nil, 1, 71, 15000, nil ) -- Revenge
	AddSpell( "classes", "WARRIOR",  6673, nil, nil, 0, nil, 3600, nil ) -- Battle Shout
	AddSpell( "classes", "WARRIOR",  7384, nil, nil, 0, nil, 4200, nil ) -- Overpower
	AddSpell( "classes", "WARRIOR",  7386, nil, nil, 0, nil, 2784, nil ) -- Sunder Armor
	AddSpell( "classes", "WARRIOR", 12678, 58, nil, 0, nil, 27000, nil ) -- Stance Mastery
	AddSpell( "classes", "WARRIOR", 18499, 54, nil, 0, nil, 24000, nil ) -- Berserker Rage
	AddSpell( "classes", "WARRIOR", 20230, 62, nil, 0, nil, 81000, nil ) -- Retaliation
	AddSpell( "classes", "WARRIOR", 20252, 50, nil, 1, 2458, 22500, nil ) -- Intercept
	AddSpell( "classes", "WARRIOR", 23920, 66, nil, 0, nil, 105000, nil ) -- Spell Reflection
	AddSpell( "classes", "WARRIOR", 34428, 5, nil, 0, nil, 142, nil ) -- Victory Rush
	AddSpell( "classes", "WARRIOR", 55694, 76, nil, 0, nil, 186000, nil ) -- Enraged Regeneration
	AddSpell( "classes", "WARRIOR", 57755, 20, nil, 0, nil, 3600, nil ) -- Heroic Throw
	AddSpell( "classes", "WARRIOR", 64382, 74, nil, 0, nil, 168000, nil ) -- Shattering Throw
	AddSpell( "classes", "WARRIOR", 86346, 81, nil, 0, nil, 234000, nil ) -- Colossus Smash
	AddSpell( "classes", "WARRIOR", 87500, 80, nil, 0, nil, 222000, nil ) -- Mastery
	AddSpell( "classes", "WARRIOR", 87509, 50, nil, 0, nil, 22500, nil ) -- Plate Specialization
	AddSpell( "classes", "WARRIOR", 97462, 83, nil, 0, nil, 258000, nil ) -- Rallying Cry
	AddSpell( "professions", "ALCHEMY",  2259, 5, nil, 0, nil, 10, nil ) -- Apprentice Alchemist
	AddSpell( "professions", "ALCHEMY",  2331, nil, 25, 0, nil, 100, "Interface\\Icons\\INV_Potion_70" ) -- Minor Mana Potion
	AddSpell( "professions", "ALCHEMY",  2332, nil, 40, 0, nil, 150, "Interface\\Icons\\INV_Potion_02" ) -- Minor Rejuvenation Potion
	AddSpell( "professions", "ALCHEMY",  2334, nil, 50, 0, nil, 250, "Interface\\Icons\\INV_Potion_42" ) -- Elixir of Minor Fortitude
	AddSpell( "professions", "ALCHEMY",  2337, nil, 55, 0, nil, 1000, "Interface\\Icons\\INV_Potion_50" ) -- Lesser Healing Potion
	AddSpell( "professions", "ALCHEMY",  3101, 10, 50, 0, nil, 500, nil ) -- Journeyman Alchemist
	AddSpell( "professions", "ALCHEMY",  3170, nil, 15, 0, nil, 50, "Interface\\Icons\\INV_Potion_77" ) -- Weak Troll's Blood Elixir
	AddSpell( "professions", "ALCHEMY",  3171, nil, 90, 0, nil, 500, "Interface\\Icons\\INV_Potion_06" ) -- Elixir of Wisdom
	AddSpell( "professions", "ALCHEMY",  3173, nil, 120, 0, nil, 1500, "Interface\\Icons\\INV_Potion_71" ) -- Lesser Mana Potion
	AddSpell( "professions", "ALCHEMY",  3176, nil, 125, 0, nil, 1500, "Interface\\Icons\\INV_Potion_78" ) -- Strong Troll's Blood Elixir
	AddSpell( "professions", "ALCHEMY",  3177, nil, 130, 0, nil, 2000, "Interface\\Icons\\INV_Potion_64" ) -- Elixir of Defense
	AddSpell( "professions", "ALCHEMY",  3447, nil, 110, 0, nil, 4000, "Interface\\Icons\\INV_Potion_51" ) -- Healing Potion
	AddSpell( "professions", "ALCHEMY",  3448, nil, 165, 0, nil, 5000, "Interface\\Icons\\INV_Potion_18" ) -- Lesser Invisibility Potion
	AddSpell( "professions", "ALCHEMY",  3449, nil, 165, 0, nil, 5000, "Interface\\Icons\\INV_Potion_23" ) -- Shadow Oil
	AddSpell( "professions", "ALCHEMY",  3450, nil, 175, 0, nil, 6000, "Interface\\Icons\\INV_Potion_43" ) -- Elixir of Fortitude
	AddSpell( "professions", "ALCHEMY",  3452, nil, 160, 0, nil, 5000, "Interface\\Icons\\INV_Potion_72" ) -- Mana Potion
	AddSpell( "professions", "ALCHEMY",  3464, 20, 125, 0, nil, 5000, nil ) -- Expert Alchemist
	AddSpell( "professions", "ALCHEMY",  7179, nil, 90, 0, nil, 450, "Interface\\Icons\\INV_Potion_17" ) -- Elixir of Water Breathing
	AddSpell( "professions", "ALCHEMY",  7181, nil, 155, 0, nil, 5000, "Interface\\Icons\\INV_Potion_52" ) -- Greater Healing Potion
	AddSpell( "professions", "ALCHEMY",  7836, nil, 80, 0, nil, 250, "Interface\\Icons\\INV_Drink_12" ) -- Blackmouth Oil
	AddSpell( "professions", "ALCHEMY",  7837, nil, 130, 0, nil, 1000, "Interface\\Icons\\INV_Potion_38" ) -- Fire Oil
	AddSpell( "professions", "ALCHEMY",  7841, nil, 100, 0, nil, 1000, "Interface\\Icons\\INV_Potion_13" ) -- Swim Speed Potion
	AddSpell( "professions", "ALCHEMY",  7845, nil, 140, 0, nil, 3000, "Interface\\Icons\\INV_Potion_33" ) -- Elixir of Firepower
	AddSpell( "professions", "ALCHEMY", 11448, nil, 205, 0, nil, 9000, "Interface\\Icons\\INV_Potion_73" ) -- Greater Mana Potion
	AddSpell( "professions", "ALCHEMY", 11449, nil, 185, 0, nil, 6500, "Interface\\Icons\\INV_Potion_93" ) -- Elixir of Agility
	AddSpell( "professions", "ALCHEMY", 11450, nil, 195, 0, nil, 7500, "Interface\\Icons\\INV_Potion_65" ) -- Elixir of Greater Defense
	AddSpell( "professions", "ALCHEMY", 11451, nil, 205, 0, nil, 8000, "Interface\\Icons\\INV_Potion_11" ) -- Oil of Immolation
	AddSpell( "professions", "ALCHEMY", 11457, nil, 215, 0, nil, 10000, "Interface\\Icons\\INV_Potion_53" ) -- Superior Healing Potion
	AddSpell( "professions", "ALCHEMY", 11460, nil, 230, 0, nil, 5000, "Interface\\Icons\\INV_Potion_53" ) -- Elixir of Detect Undead
	AddSpell( "professions", "ALCHEMY", 11461, nil, 235, 0, nil, 10000, "Interface\\Icons\\INV_Potion_30" ) -- Arcane Elixir
	AddSpell( "professions", "ALCHEMY", 11465, nil, 235, 0, nil, 12000, "Interface\\Icons\\INV_Potion_10" ) -- Elixir of Greater Intellect
	AddSpell( "professions", "ALCHEMY", 11467, nil, 240, 0, nil, 12000, "Interface\\Icons\\INV_Potion_94" ) -- Elixir of Greater Agility
	AddSpell( "professions", "ALCHEMY", 11478, nil, 250, 0, nil, 14000, "Interface\\Icons\\INV_Potion_53" ) -- Elixir of Detect Demon
	AddSpell( "professions", "ALCHEMY", 11611, 35, 200, 0, nil, 50000, nil ) -- Artisan Alchemist
	AddSpell( "professions", "ALCHEMY", 12609, nil, 200, 0, nil, 8000, "Interface\\Icons\\INV_Potion_36" ) -- Catseye Elixir
	AddSpell( "professions", "ALCHEMY", 15833, nil, 230, 0, nil, 10000, "Interface\\Icons\\INV_Potion_83" ) -- Dreamless Sleep Potion
	AddSpell( "professions", "ALCHEMY", 17551, nil, 250, 0, nil, 15000, "Interface\\Icons\\INV_Potion_68" ) -- Stonescale Oil
	AddSpell( "professions", "ALCHEMY", 17552, nil, 255, 0, nil, 15000, "Interface\\Icons\\INV_Potion_41" ) -- Mighty Rage Potion
	AddSpell( "professions", "ALCHEMY", 17553, nil, 260, 0, nil, 15000, "Interface\\Icons\\INV_Potion_74" ) -- Superior Mana Potion
	AddSpell( "professions", "ALCHEMY", 17555, nil, 270, 0, nil, 15000, "Interface\\Icons\\INV_Potion_29" ) -- Elixir of the Sages
	AddSpell( "professions", "ALCHEMY", 17556, nil, 275, 0, nil, 20000, "Interface\\Icons\\INV_Potion_54" ) -- Major Healing Potion
	AddSpell( "professions", "ALCHEMY", 17557, nil, 275, 0, nil, 20000, "Interface\\Icons\\INV_Potion_59" ) -- Elixir of Brute Force
	AddSpell( "professions", "ALCHEMY", 17572, nil, 285, 0, nil, 20000, "Interface\\Icons\\INV_Potion_31" ) -- Purification Potion
	AddSpell( "professions", "ALCHEMY", 17573, nil, 285, 0, nil, 20000, "Interface\\Icons\\INV_Potion_25" ) -- Greater Arcane Elixir
	AddSpell( "professions", "ALCHEMY", 22808, nil, 215, 0, nil, 10000, "Interface\\Icons\\INV_Potion_05" ) -- Elixir of Greater Water Breathing
	AddSpell( "professions", "ALCHEMY", 28544, nil, 305, 0, nil, 25000, "Interface\\Icons\\INV_Potion_147" ) -- Elixir of Major Strength
	AddSpell( "professions", "ALCHEMY", 28545, nil, 310, 0, nil, 25000, "Interface\\Icons\\INV_Potion_142" ) -- Elixir of Healing Power
	AddSpell( "professions", "ALCHEMY", 28551, nil, 325, 0, nil, 50000, "Interface\\Icons\\INV_Potion_131" ) -- Super Healing Potion
	AddSpell( "professions", "ALCHEMY", 28596, 50, 275, 0, nil, 100000, nil ) -- Master Alchemist
	AddSpell( "professions", "ALCHEMY", 33732, nil, 300, 0, nil, 20000, "Interface\\Icons\\INV_Potion_40" ) -- Volatile Healing Potion
	AddSpell( "professions", "ALCHEMY", 33733, nil, 310, 0, nil, 25000, "Interface\\Icons\\INV_Potion_75" ) -- Unstable Mana Potion
	AddSpell( "professions", "ALCHEMY", 33738, nil, 300, 0, nil, 20000, "Interface\\Icons\\INV_Potion_58" ) -- Onslaught Elixir
	AddSpell( "professions", "ALCHEMY", 33740, nil, 300, 0, nil, 20000, "Interface\\Icons\\INV_Potion_96" ) -- Adept's Elixir
	AddSpell( "professions", "ALCHEMY", 33741, nil, 315, 0, nil, 30000, "Interface\\Icons\\INV_Potion_111" ) -- Elixir of Mastery
	AddSpell( "professions", "ALCHEMY", 38070, nil, 325, 0, nil, 20000, "Interface\\Icons\\INV_Misc_Gem_LionsEye_01" ) -- Mercurial Stone
	AddSpell( "professions", "ALCHEMY", 39636, nil, 310, 0, nil, 25000, "Interface\\Icons\\INV_Potion_158" ) -- Elixir of Major Fortitude
	AddSpell( "professions", "ALCHEMY", 39638, nil, 320, 0, nil, 30000, "Interface\\Icons\\INV_Potion_155" ) -- Elixir of Draenic Wisdom
	AddSpell( "professions", "ALCHEMY", 45061, nil, 325, 0, nil, 35000, "Interface\\Icons\\INV_Potion_28" ) -- Mad Alchemist's Potion
	AddSpell( "professions", "ALCHEMY", 51304, 65, 350, 0, nil, 350000, nil ) -- Grand Master Alchemist
	AddSpell( "professions", "ALCHEMY", 53812, nil, 375, 0, nil, 60000, "Interface\\Icons\\INV_Potion_07" ) -- Pygmy Oil
	AddSpell( "professions", "ALCHEMY", 53836, nil, 405, 0, nil, 150000, "Interface\\Icons\\INV_Alchemy_Elixir_05" ) -- Runic Healing Potion
	AddSpell( "professions", "ALCHEMY", 53837, nil, 410, 0, nil, 150000, "Interface\\Icons\\INV_Alchemy_Elixir_02" ) -- Runic Mana Potion
	AddSpell( "professions", "ALCHEMY", 53838, nil, 350, 0, nil, 40000, "Interface\\Icons\\INV_Potion_120" ) -- Resurgent Healing Potion
	AddSpell( "professions", "ALCHEMY", 53839, nil, 360, 0, nil, 40000, "Interface\\Icons\\INV_Potion_126" ) -- Icy Mana Potion
	AddSpell( "professions", "ALCHEMY", 53840, nil, 395, 0, nil, 120000, "Interface\\Icons\\INV_Potion_162" ) -- Elixir of Mighty Agility
	AddSpell( "professions", "ALCHEMY", 53841, nil, 355, 0, nil, 40000, "Interface\\Icons\\INV_Potion_114" ) -- Wrath Elixir
	AddSpell( "professions", "ALCHEMY", 53842, nil, 365, 0, nil, 40000, "Interface\\Icons\\INV_Alchemy_Potion_05" ) -- Spellpower Elixir
	AddSpell( "professions", "ALCHEMY", 53847, nil, 385, 0, nil, 65000, "Interface\\Icons\\INV_Potion_02" ) -- Elixir of Spirit
	AddSpell( "professions", "ALCHEMY", 53848, nil, 375, 0, nil, 60000, "Interface\\Icons\\INV_Potion_112" ) -- Guru's Elixir
	AddSpell( "professions", "ALCHEMY", 53898, nil, 390, 0, nil, 120000, "Interface\\Icons\\INV_Potion_164" ) -- Elixir of Mighty Fortitude
	AddSpell( "professions", "ALCHEMY", 53899, nil, 375, 0, nil, 60000, "Interface\\Icons\\INV_Alchemy_EndlessFlask_02" ) -- Lesser Flask of Toughness
	AddSpell( "professions", "ALCHEMY", 53900, nil, 380, 0, nil, 120000, "Interface\\Icons\\INV_Alchemy_Elixir_03" ) -- Potion of Nightmares
	AddSpell( "professions", "ALCHEMY", 53901, nil, 435, 0, nil, 180000, "Interface\\Icons\\INV_Alchemy_EndlessFlask_04" ) -- Flask of the Frost Wyrm
	AddSpell( "professions", "ALCHEMY", 53902, nil, 435, 0, nil, 150000, "Interface\\Icons\\INV_Alchemy_EndlessFlask_05" ) -- Flask of Stoneblood
	AddSpell( "professions", "ALCHEMY", 53903, nil, 435, 0, nil, 180000, "Interface\\Icons\\INV_Alchemy_EndlessFlask_06" ) -- Flask of Endless Rage
	AddSpell( "professions", "ALCHEMY", 53905, nil, 395, 0, nil, 120000, "Interface\\Icons\\INV_Alchemy_Elixir_Empty" ) -- Indestructible Potion
	AddSpell( "professions", "ALCHEMY", 54213, nil, 435, 0, nil, 150000, "Interface\\Icons\\INV_Alchemy_EndlessFlask_03" ) -- Flask of Pure Mojo
	AddSpell( "professions", "ALCHEMY", 54218, nil, 385, 0, nil, 120000, "Interface\\Icons\\INV_Potion_165" ) -- Elixir of Mighty Strength
	AddSpell( "professions", "ALCHEMY", 57425, nil, 430, 0, nil, 150000, "Interface\\Icons\\INV_Jewelcrafting_IceDiamond_01" ) -- Transmute: Skyflare Diamond
	AddSpell( "professions", "ALCHEMY", 57427, nil, 425, 0, nil, 150000, "Interface\\Icons\\INV_Jewelcrafting_ShadowSpirit_01" ) -- Transmute: Earthsiege Diamond
	AddSpell( "professions", "ALCHEMY", 58868, nil, 410, 0, nil, 150000, "Interface\\Icons\\INV_Alchemy_EndlessFlask_04" ) -- Endless Mana Potion
	AddSpell( "professions", "ALCHEMY", 58871, nil, 410, 0, nil, 150000, "Interface\\Icons\\INV_Alchemy_EndlessFlask_06" ) -- Endless Healing Potion
	AddSpell( "professions", "ALCHEMY", 60350, nil, 395, 0, nil, 150000, "Interface\\Icons\\INV_Ingot_Platinum" ) -- Transmute: Titanium
	AddSpell( "professions", "ALCHEMY", 60367, nil, 395, 0, nil, 120000, "Interface\\Icons\\INV_Potion_161" ) -- Elixir of Mighty Thoughts
	AddSpell( "professions", "ALCHEMY", 60396, nil, 400, 0, nil, 200000, "Interface\\Icons\\Spell_Holy_Aspiration" ) -- Mercurial Alchemist Stone
	AddSpell( "professions", "ALCHEMY", 60403, nil, 400, 0, nil, 200000, "Interface\\Icons\\Spell_Holy_Aspiration" ) -- Indestructible Alchemist Stone
	AddSpell( "professions", "ALCHEMY", 60405, nil, 400, 0, nil, 200000, "Interface\\Icons\\Spell_Holy_Aspiration" ) -- Mighty Alchemist Stone
	AddSpell( "professions", "ALCHEMY", 60893, nil, 400, 0, nil, 200000, nil ) -- Northrend Alchemy Research
	AddSpell( "professions", "ALCHEMY", 62213, nil, 385, 0, nil, 120000, "Interface\\Icons\\INV_Potion_118" ) -- Lesser Flask of Resistance
	AddSpell( "professions", "ALCHEMY", 62409, nil, 375, 0, nil, 60000, "Interface\\Icons\\INV_Drink_11" ) -- Ethereal Oil
	AddSpell( "professions", "ALCHEMY", 63732, nil, 135, 0, nil, 2000, "Interface\\Icons\\INV_Potion_159" ) -- Elixir of Minor Accuracy
	AddSpell( "professions", "ALCHEMY", 66658, nil, 450, 0, nil, 200000, nil ) -- Transmute: Ametrine
	AddSpell( "professions", "ALCHEMY", 66660, nil, 450, 0, nil, 200000, nil ) -- Transmute: King's Amber
	AddSpell( "professions", "ALCHEMY", 66662, nil, 450, 0, nil, 200000, nil ) -- Transmute: Dreadstone
	AddSpell( "professions", "ALCHEMY", 66663, nil, 450, 0, nil, 200000, nil ) -- Transmute: Majestic Zircon
	AddSpell( "professions", "ALCHEMY", 66664, nil, 450, 0, nil, 200000, nil ) -- Transmute: Eye of Zul
	AddSpell( "professions", "ALCHEMY", 67025, nil, 425, 0, nil, 100000, "Interface\\Icons\\INV_Alchemy_EndlessFlask_05" ) -- Flask of the North
	AddSpell( "professions", "ALCHEMY", 78866, nil, 485, 0, nil, 175000, "Interface\\Icons\\INV_Elemental_Mote_Nether" ) -- Transmute: Living Elements
	AddSpell( "professions", "ALCHEMY", 80237, nil, 525, 0, nil, 250000, "Interface\\Icons\\inv_misc_metagemuncut_b" ) -- Transmute: Shadowspirit Diamond
	AddSpell( "professions", "ALCHEMY", 80243, nil, 525, 0, nil, 250000, "Interface\\Icons\\inv_misc_truegold" ) -- Transmute: Truegold
	AddSpell( "professions", "ALCHEMY", 80244, nil, 520, 0, nil, 200000, "Interface\\Icons\\inv_misc_pyriumbar_02" ) -- Transmute: Pyrium Bar
	AddSpell( "professions", "ALCHEMY", 80245, nil, 525, 0, nil, 250000, "Interface\\Icons\\inv_misc_uncutgemnormal3" ) -- Transmute: Inferno Ruby
	AddSpell( "professions", "ALCHEMY", 80246, nil, 515, 0, nil, 200000, "Interface\\Icons\\inv_misc_uncutgemnormal2" ) -- Transmute: Ocean Sapphire
	AddSpell( "professions", "ALCHEMY", 80247, nil, 520, 0, nil, 200000, "Interface\\Icons\\inv_misc_uncutgemnormal5" ) -- Transmute: Amberjewel
	AddSpell( "professions", "ALCHEMY", 80248, nil, 515, 0, nil, 200000, "Interface\\Icons\\inv_misc_uncutgemnormal4" ) -- Transmute: Demonseye
	AddSpell( "professions", "ALCHEMY", 80250, nil, 510, 0, nil, 200000, "Interface\\Icons\\inv_misc_uncutgemnormal" ) -- Transmute: Ember Topaz
	AddSpell( "professions", "ALCHEMY", 80251, nil, 505, 0, nil, 200000, "Interface\\Icons\\inv_misc_uncutgemnormal1" ) -- Transmute: Dream Emerald
	AddSpell( "professions", "ALCHEMY", 80269, nil, 460, 0, nil, 160000, "Interface\\Icons\\inv_potionc_5" ) -- Potion of Illusion
	AddSpell( "professions", "ALCHEMY", 80477, nil, 450, 0, nil, 150000, "Interface\\Icons\\inv_potiond_5" ) -- Ghost Elixir
	AddSpell( "professions", "ALCHEMY", 80478, nil, 450, 0, nil, 150000, "Interface\\Icons\\INV_Alchemy_Elixir_Empty" ) -- Earthen Potion
	AddSpell( "professions", "ALCHEMY", 80479, nil, 455, 0, nil, 150000, "Interface\\Icons\\inv_potionf_3" ) -- Deathblood Venom
	AddSpell( "professions", "ALCHEMY", 80480, nil, 455, 0, nil, 150000, "Interface\\Icons\\INV_Potion_164" ) -- Elixir of the Naga
	AddSpell( "professions", "ALCHEMY", 80481, nil, 460, 0, nil, 160000, "Interface\\Icons\\inv_potiond_3" ) -- Volcanic Potion
	AddSpell( "professions", "ALCHEMY", 80482, nil, 465, 0, nil, 160000, "Interface\\Icons\\inv_potionc_3" ) -- Potion of Concentration
	AddSpell( "professions", "ALCHEMY", 80484, nil, 465, 0, nil, 160000, "Interface\\Icons\\inv_misc_potiona3" ) -- Elixir of the Cobra
	AddSpell( "professions", "ALCHEMY", 80486, nil, 470, 0, nil, 160000, "Interface\\Icons\\inv_potionf_1" ) -- Deepstone Oil
	AddSpell( "professions", "ALCHEMY", 80487, nil, 470, 0, nil, 160000, "Interface\\Icons\\inv_potiond_6" ) -- Mysterious Potion
	AddSpell( "professions", "ALCHEMY", 80488, nil, 475, 0, nil, 160000, "Interface\\Icons\\inv_potionf_5" ) -- Elixir of Deep Earth
	AddSpell( "professions", "ALCHEMY", 80490, nil, 475, 0, nil, 160000, "Interface\\Icons\\inv_misc_potionsetd" ) -- Mighty Rejuvenation Potion
	AddSpell( "professions", "ALCHEMY", 80491, nil, 480, 0, nil, 175000, "Interface\\Icons\\inv_potionf_6" ) -- Elixir of Impossible Accuracy
	AddSpell( "professions", "ALCHEMY", 80492, nil, 480, 0, nil, 175000, "Interface\\Icons\\inv_potionf_4" ) -- Prismatic Elixir
	AddSpell( "professions", "ALCHEMY", 80493, nil, 490, 0, nil, 175000, "Interface\\Icons\\inv_potionf_2" ) -- Elixir of Mighty Speed
	AddSpell( "professions", "ALCHEMY", 80494, nil, 485, 0, nil, 175000, "Interface\\Icons\\inv_misc_potionsetc" ) -- Mythical Mana Potion
	AddSpell( "professions", "ALCHEMY", 80495, nil, 485, 0, nil, 175000, "Interface\\Icons\\inv_potiond_4" ) -- Potion of the Tol'vir
	AddSpell( "professions", "ALCHEMY", 80496, nil, 490, 0, nil, 175000, "Interface\\Icons\\inv_potiond_1" ) -- Golemblood Potion
	AddSpell( "professions", "ALCHEMY", 80497, nil, 495, 0, nil, 175000, "Interface\\Icons\\inv_potiond_2" ) -- Elixir of the Master
	AddSpell( "professions", "ALCHEMY", 80498, nil, 495, 0, nil, 175000, "Interface\\Icons\\inv_misc_potionsetf" ) -- Mythical Healing Potion
	AddSpell( "professions", "ALCHEMY", 80508, nil, 500, 0, nil, 100000, "Interface\\Icons\\Spell_Holy_Aspiration" ) -- Lifebound Alchemist Stone
	AddSpell( "professions", "ALCHEMY", 80719, nil, 500, 0, nil, 200000, "Interface\\Icons\\inv_potione_1" ) -- Flask of Steelskin
	AddSpell( "professions", "ALCHEMY", 80720, nil, 505, 0, nil, 200000, "Interface\\Icons\\inv_potione_5" ) -- Flask of the Draconic Mind
	AddSpell( "professions", "ALCHEMY", 80721, nil, 510, 0, nil, 200000, "Interface\\Icons\\inv_potione_2" ) -- Flask of the Winds
	AddSpell( "professions", "ALCHEMY", 80723, nil, 510, 0, nil, 200000, "Interface\\Icons\\inv_potione_6" ) -- Flask of Titanic Strength
	AddSpell( "professions", "ALCHEMY", 80724, nil, 500, 0, nil, 200000, "Interface\\Icons\\inv_misc_endlesspotion" ) -- Flask of Enhancement
	AddSpell( "professions", "ALCHEMY", 80725, nil, 525, 0, nil, 250000, "Interface\\Icons\\inv_potionc_1" ) -- Potion of Deepholm
	AddSpell( "professions", "ALCHEMY", 80726, nil, 525, 0, nil, 250000, "Interface\\Icons\\inv_misc_potionsete" ) -- Potion of Treasure Finding
	AddSpell( "professions", "ALCHEMY", 80731, 75, 425, 0, nil, 500000, nil ) -- Illustrious Grand Master Alchemist
	AddSpell( "professions", "ALCHEMY", 93935, nil, 425, 0, nil, 150000, "Interface\\Icons\\inv_misc_potiona4" ) -- Draught of War
	AddSpell( "professions", "ALCHEMY", 94162, nil, 500, 0, nil, 200000, "Interface\\Icons\\inv_potione_4" ) -- Flask of Flowing Water
	AddSpell( "professions", "ALCHEMY", 96252, nil, 500, 0, nil, 100000, "Interface\\Icons\\item_alchemiststoneb" ) -- Volatile Alchemist Stone
	AddSpell( "professions", "ALCHEMY", 96253, nil, 500, 0, nil, 100000, "Interface\\Icons\\item_alchemiststone" ) -- Quicksilver Alchemist Stone
	AddSpell( "professions", "ALCHEMY", 96254, nil, 500, 0, nil, 100000, "Interface\\Icons\\item_alchemiststonec" ) -- Vibrant Alchemist Stone
	AddSpell( "professions", "ARCHAEOLOGY", 78670, 20, nil, 0, nil, 1000, nil ) -- Apprentice Archaeology
	AddSpell( "professions", "ARCHAEOLOGY", 88961, 20, 50, 0, nil, 1000, nil ) -- Journeyman Archaeology
	AddSpell( "professions", "ARCHAEOLOGY", 89718, 20, 125, 0, nil, 1000, nil ) -- Expert Archaeology
	AddSpell( "professions", "ARCHAEOLOGY", 89719, 35, 200, 0, nil, 25000, nil ) -- Artisan Archaeology
	AddSpell( "professions", "ARCHAEOLOGY", 89720, 50, 275, 0, nil, 100000, nil ) -- Master Archaeology
	AddSpell( "professions", "ARCHAEOLOGY", 89721, 65, 350, 0, nil, 150000, nil ) -- Grand Master Archaeology
	AddSpell( "professions", "ARCHAEOLOGY", 89722, 75, 425, 0, nil, 250000, nil ) -- Illustrious Grand Master Archaeology
	AddSpell( "professions", "BLACKSMITHING",  2018, 5, nil, 0, nil, 10, nil ) -- Apprentice Blacksmith
	AddSpell( "professions", "BLACKSMITHING",  2661, nil, 35, 0, nil, 100, "Interface\\Icons\\INV_Belt_02" ) -- Copper Chain Belt
	AddSpell( "professions", "BLACKSMITHING",  2662, nil, 1, 0, nil, 50, "Interface\\Icons\\INV_Pants_03" ) -- Copper Chain Pants
	AddSpell( "professions", "BLACKSMITHING",  2664, nil, 90, 0, nil, 500, "Interface\\Icons\\INV_Bracer_03" ) -- Runed Copper Bracers
	AddSpell( "professions", "BLACKSMITHING",  2665, nil, 65, 0, nil, 100, "Interface\\Icons\\INV_Stone_SharpeningStone_02" ) -- Coarse Sharpening Stone
	AddSpell( "professions", "BLACKSMITHING",  2666, nil, 70, 0, nil, 200, "Interface\\Icons\\INV_Belt_03" ) -- Runed Copper Belt
	AddSpell( "professions", "BLACKSMITHING",  2668, nil, 105, 0, nil, 300, "Interface\\Icons\\INV_Pants_03" ) -- Rough Bronze Leggings
	AddSpell( "professions", "BLACKSMITHING",  2670, nil, 105, 0, nil, 500, "Interface\\Icons\\INV_Chest_Chain_08" ) -- Rough Bronze Cuirass
	AddSpell( "professions", "BLACKSMITHING",  2672, nil, 120, 0, nil, 500, "Interface\\Icons\\INV_Bracer_07" ) -- Patterned Bronze Bracers
	AddSpell( "professions", "BLACKSMITHING",  2674, nil, 125, 0, nil, 1000, "Interface\\Icons\\INV_Stone_SharpeningStone_03" ) -- Heavy Sharpening Stone
	AddSpell( "professions", "BLACKSMITHING",  2675, nil, 145, 0, nil, 1000, "Interface\\Icons\\INV_Chest_Plate15" ) -- Shining Silver Breastplate
	AddSpell( "professions", "BLACKSMITHING",  2737, nil, 15, 0, nil, 50, "Interface\\Icons\\INV_Mace_01" ) -- Copper Mace
	AddSpell( "professions", "BLACKSMITHING",  2738, nil, 20, 0, nil, 50, "Interface\\Icons\\INV_Axe_23" ) -- Copper Axe
	AddSpell( "professions", "BLACKSMITHING",  2739, nil, 25, 0, nil, 50, "Interface\\Icons\\INV_Sword_26" ) -- Copper Shortsword
	AddSpell( "professions", "BLACKSMITHING",  2740, nil, 110, 0, nil, 200, "Interface\\Icons\\INV_Mace_08" ) -- Bronze Mace
	AddSpell( "professions", "BLACKSMITHING",  2741, nil, 115, 0, nil, 200, "Interface\\Icons\\INV_Axe_17" ) -- Bronze Axe
	AddSpell( "professions", "BLACKSMITHING",  2742, nil, 120, 0, nil, 200, "Interface\\Icons\\INV_Sword_04" ) -- Bronze Shortsword
	AddSpell( "professions", "BLACKSMITHING",  3100, 10, 50, 0, nil, 500, nil ) -- Journeyman Blacksmith
	AddSpell( "professions", "BLACKSMITHING",  3116, nil, 65, 0, nil, 100, "Interface\\Icons\\INV_Stone_WeightStone_02" ) -- Coarse Weightstone
	AddSpell( "professions", "BLACKSMITHING",  3117, nil, 125, 0, nil, 1000, "Interface\\Icons\\INV_Stone_WeightStone_03" ) -- Heavy Weightstone
	AddSpell( "professions", "BLACKSMITHING",  3292, nil, 95, 0, nil, 500, "Interface\\Icons\\INV_Sword_14" ) -- Heavy Copper Broadsword
	AddSpell( "professions", "BLACKSMITHING",  3293, nil, 35, 0, nil, 250, "Interface\\Icons\\INV_ThrowingAxe_02" ) -- Copper Battle Axe
	AddSpell( "professions", "BLACKSMITHING",  3294, nil, 70, 0, nil, 500, "Interface\\Icons\\INV_ThrowingAxe_01" ) -- Thick War Axe
	AddSpell( "professions", "BLACKSMITHING",  3296, nil, 130, 0, nil, 1000, "Interface\\Icons\\INV_Mace_08" ) -- Heavy Bronze Mace
	AddSpell( "professions", "BLACKSMITHING",  3319, nil, 20, 0, nil, 50, "Interface\\Icons\\INV_Boots_01" ) -- Copper Chain Boots
	AddSpell( "professions", "BLACKSMITHING",  3320, nil, 25, 0, nil, 100, "Interface\\Icons\\INV_Stone_GrindingStone_01" ) -- Rough Grinding Stone
	AddSpell( "professions", "BLACKSMITHING",  3323, nil, 40, 0, nil, 100, "Interface\\Icons\\INV_Gauntlets_04" ) -- Runed Copper Gauntlets
	AddSpell( "professions", "BLACKSMITHING",  3324, nil, 45, 0, nil, 200, "Interface\\Icons\\INV_Pants_03" ) -- Runed Copper Pants
	AddSpell( "professions", "BLACKSMITHING",  3326, nil, 75, 0, nil, 250, "Interface\\Icons\\INV_Stone_GrindingStone_02" ) -- Coarse Grinding Stone
	AddSpell( "professions", "BLACKSMITHING",  3328, nil, 110, 0, nil, 500, "Interface\\Icons\\INV_Shoulder_05" ) -- Rough Bronze Shoulders
	AddSpell( "professions", "BLACKSMITHING",  3331, nil, 130, 0, nil, 500, "Interface\\Icons\\INV_Boots_01" ) -- Silvered Bronze Boots
	AddSpell( "professions", "BLACKSMITHING",  3333, nil, 135, 0, nil, 1000, "Interface\\Icons\\INV_Gauntlets_05" ) -- Silvered Bronze Gauntlets
	AddSpell( "professions", "BLACKSMITHING",  3337, nil, 125, 0, nil, 1000, "Interface\\Icons\\INV_Stone_GrindingStone_03" ) -- Heavy Grinding Stone
	AddSpell( "professions", "BLACKSMITHING",  3491, nil, 105, 0, nil, 600, "Interface\\Icons\\INV_Weapon_ShortBlade_04" ) -- Big Bronze Knife
	AddSpell( "professions", "BLACKSMITHING",  3501, nil, 165, 0, nil, 1000, "Interface\\Icons\\INV_Bracer_06" ) -- Green Iron Bracers
	AddSpell( "professions", "BLACKSMITHING",  3502, nil, 170, 0, nil, 1250, "Interface\\Icons\\INV_Helmet_03" ) -- Green Iron Helm
	AddSpell( "professions", "BLACKSMITHING",  3506, nil, 155, 0, nil, 5000, "Interface\\Icons\\INV_Pants_05" ) -- Green Iron Leggings
	AddSpell( "professions", "BLACKSMITHING",  3508, nil, 180, 0, nil, 7500, "Interface\\Icons\\INV_Chest_Chain" ) -- Green Iron Hauberk
	AddSpell( "professions", "BLACKSMITHING",  3538, 20, 125, 0, nil, 5000, nil ) -- Expert Blacksmith
	AddSpell( "professions", "BLACKSMITHING",  6517, nil, 110, 0, nil, 800, "Interface\\Icons\\INV_Weapon_ShortBlade_05" ) -- Pearl-handled Dagger
	AddSpell( "professions", "BLACKSMITHING",  7223, nil, 185, 0, nil, 1000, "Interface\\Icons\\INV_Bracer_10" ) -- Golden Scale Bracers
	AddSpell( "professions", "BLACKSMITHING",  7408, nil, 65, 0, nil, 300, "Interface\\Icons\\INV_Hammer_18" ) -- Heavy Copper Maul
	AddSpell( "professions", "BLACKSMITHING",  7817, nil, 95, 0, nil, 200, "Interface\\Icons\\INV_Boots_01" ) -- Rough Bronze Boots
	AddSpell( "professions", "BLACKSMITHING",  7818, nil, 100, 0, nil, 100, "Interface\\Icons\\INV_Staff_01" ) -- Silver Rod
	AddSpell( "professions", "BLACKSMITHING",  8768, nil, 150, 0, nil, 250, "Interface\\Icons\\INV_Misc_ArmorKit_12" ) -- Iron Buckle
	AddSpell( "professions", "BLACKSMITHING",  8880, nil, 30, 0, nil, 100, "Interface\\Icons\\INV_Weapon_ShortBlade_14" ) -- Copper Dagger
	AddSpell( "professions", "BLACKSMITHING",  9785, 35, 200, 0, nil, 50000, nil ) -- Artisan Blacksmith
	AddSpell( "professions", "BLACKSMITHING",  9916, nil, 200, 0, nil, 2500, "Interface\\Icons\\INV_Chest_Plate05" ) -- Steel Breastplate
	AddSpell( "professions", "BLACKSMITHING",  9918, nil, 200, 0, nil, 2500, "Interface\\Icons\\INV_Stone_SharpeningStone_04" ) -- Solid Sharpening Stone
	AddSpell( "professions", "BLACKSMITHING",  9920, nil, 200, 0, nil, 2500, "Interface\\Icons\\INV_Stone_GrindingStone_04" ) -- Solid Grinding Stone
	AddSpell( "professions", "BLACKSMITHING",  9921, nil, 200, 0, nil, 2500, "Interface\\Icons\\INV_Stone_WeightStone_04" ) -- Solid Weightstone
	AddSpell( "professions", "BLACKSMITHING",  9926, nil, 205, 0, nil, 5000, "Interface\\Icons\\INV_Shoulder_22" ) -- Heavy Mithril Shoulder
	AddSpell( "professions", "BLACKSMITHING",  9928, nil, 205, 0, nil, 5000, "Interface\\Icons\\INV_Gauntlets_27" ) -- Heavy Mithril Gauntlet
	AddSpell( "professions", "BLACKSMITHING",  9931, nil, 210, 0, nil, 5000, "Interface\\Icons\\INV_Pants_03" ) -- Mithril Scale Pants
	AddSpell( "professions", "BLACKSMITHING",  9935, nil, 215, 0, nil, 5000, "Interface\\Icons\\INV_Helmet_03" ) -- Steel Plate Helm
	AddSpell( "professions", "BLACKSMITHING",  9959, nil, 230, 0, nil, 15000, "Interface\\Icons\\INV_Chest_Plate10" ) -- Heavy Mithril Breastplate
	AddSpell( "professions", "BLACKSMITHING",  9961, nil, 230, 0, nil, 15000, "Interface\\Icons\\INV_Helmet_35" ) -- Mithril Coif
	AddSpell( "professions", "BLACKSMITHING",  9968, nil, 235, 0, nil, 20000, "Interface\\Icons\\INV_Boots_Plate_01" ) -- Heavy Mithril Boots
	AddSpell( "professions", "BLACKSMITHING",  9983, nil, 30, 0, nil, 100, "Interface\\Icons\\INV_Sword_21" ) -- Copper Claymore
	AddSpell( "professions", "BLACKSMITHING",  9985, nil, 125, 0, nil, 250, "Interface\\Icons\\INV_Hammer_18" ) -- Bronze Warhammer
	AddSpell( "professions", "BLACKSMITHING",  9986, nil, 130, 0, nil, 500, "Interface\\Icons\\INV_Sword_20" ) -- Bronze Greatsword
	AddSpell( "professions", "BLACKSMITHING",  9987, nil, 135, 0, nil, 500, "Interface\\Icons\\INV_Axe_21" ) -- Bronze Battle Axe
	AddSpell( "professions", "BLACKSMITHING",  9993, nil, 210, 0, nil, 10000, "Interface\\Icons\\INV_Axe_14" ) -- Heavy Mithril Axe
	AddSpell( "professions", "BLACKSMITHING", 10001, nil, 230, 0, nil, 15000, "Interface\\Icons\\INV_Mace_15" ) -- Big Black Mace
	AddSpell( "professions", "BLACKSMITHING", 14379, nil, 150, 0, nil, 250, "Interface\\Icons\\INV_Staff_10" ) -- Golden Rod
	AddSpell( "professions", "BLACKSMITHING", 14380, nil, 200, 0, nil, 2500, "Interface\\Icons\\INV_Staff_11" ) -- Truesilver Rod
	AddSpell( "professions", "BLACKSMITHING", 15972, nil, 180, 0, nil, 7500, "Interface\\Icons\\INV_Weapon_ShortBlade_05" ) -- Glinting Steel Dagger
	AddSpell( "professions", "BLACKSMITHING", 16639, nil, 250, 0, nil, 10000, "Interface\\Icons\\INV_Stone_GrindingStone_05" ) -- Dense Grinding Stone
	AddSpell( "professions", "BLACKSMITHING", 16640, nil, 250, 0, nil, 10000, "Interface\\Icons\\INV_Stone_WeightStone_05" ) -- Dense Weightstone
	AddSpell( "professions", "BLACKSMITHING", 16641, nil, 250, 0, nil, 10000, "Interface\\Icons\\INV_Stone_SharpeningStone_05" ) -- Dense Sharpening Stone
	AddSpell( "professions", "BLACKSMITHING", 16642, nil, 250, 0, nil, 10000, "Interface\\Icons\\INV_Chest_Plate08" ) -- Thorium Armor
	AddSpell( "professions", "BLACKSMITHING", 16643, nil, 250, 0, nil, 10000, "Interface\\Icons\\INV_Belt_30" ) -- Thorium Belt
	AddSpell( "professions", "BLACKSMITHING", 16644, nil, 255, 0, nil, 10000, "Interface\\Icons\\INV_Bracer_13" ) -- Thorium Bracers
	AddSpell( "professions", "BLACKSMITHING", 16646, nil, 265, 0, nil, 10000, "Interface\\Icons\\INV_Shoulder_02" ) -- Imperial Plate Shoulders
	AddSpell( "professions", "BLACKSMITHING", 16647, nil, 265, 0, nil, 10000, "Interface\\Icons\\INV_Belt_01" ) -- Imperial Plate Belt
	AddSpell( "professions", "BLACKSMITHING", 16649, nil, 270, 0, nil, 10000, "Interface\\Icons\\INV_Bracer_19" ) -- Imperial Plate Bracers
	AddSpell( "professions", "BLACKSMITHING", 16652, nil, 280, 0, nil, 10000, "Interface\\Icons\\INV_Boots_Plate_08" ) -- Thorium Boots
	AddSpell( "professions", "BLACKSMITHING", 16653, nil, 280, 0, nil, 10000, "Interface\\Icons\\INV_Helmet_23" ) -- Thorium Helm
	AddSpell( "professions", "BLACKSMITHING", 16657, nil, 295, 0, nil, 10000, "Interface\\Icons\\INV_Boots_Plate_01" ) -- Imperial Plate Boots
	AddSpell( "professions", "BLACKSMITHING", 16658, nil, 295, 0, nil, 10000, "Interface\\Icons\\INV_Helmet_22" ) -- Imperial Plate Helm
	AddSpell( "professions", "BLACKSMITHING", 16662, nil, 300, 0, nil, 12000, "Interface\\Icons\\INV_Pants_04" ) -- Thorium Leggings
	AddSpell( "professions", "BLACKSMITHING", 16663, nil, 300, 0, nil, 12000, "Interface\\Icons\\INV_Chest_Plate10" ) -- Imperial Plate Chest
	AddSpell( "professions", "BLACKSMITHING", 16730, nil, 300, 0, nil, 12000, "Interface\\Icons\\INV_Pants_04" ) -- Imperial Plate Leggings
	AddSpell( "professions", "BLACKSMITHING", 16969, nil, 275, 0, nil, 15000, "Interface\\Icons\\INV_Axe_12" ) -- Ornate Thorium Handaxe
	AddSpell( "professions", "BLACKSMITHING", 16971, nil, 280, 0, nil, 15000, "Interface\\Icons\\INV_Weapon_Halberd_11" ) -- Huge Thorium Battleaxe
	AddSpell( "professions", "BLACKSMITHING", 19666, nil, 100, 0, nil, 100, "Interface\\Icons\\INV_Misc_Key_03" ) -- Silver Skeleton Key
	AddSpell( "professions", "BLACKSMITHING", 19667, nil, 150, 0, nil, 250, "Interface\\Icons\\INV_Misc_Key_13" ) -- Golden Skeleton Key
	AddSpell( "professions", "BLACKSMITHING", 19668, nil, 200, 0, nil, 2500, "Interface\\Icons\\INV_Misc_Key_11" ) -- Truesilver Skeleton Key
	AddSpell( "professions", "BLACKSMITHING", 19669, nil, 275, 0, nil, 10000, "Interface\\Icons\\INV_Misc_Key_08" ) -- Arcanite Skeleton Key
	AddSpell( "professions", "BLACKSMITHING", 20201, nil, 275, 0, nil, 10000, "Interface\\Icons\\INV_Staff_19" ) -- Arcanite Rod
	AddSpell( "professions", "BLACKSMITHING", 29545, nil, 300, 0, nil, 15000, "Interface\\Icons\\INV_Gauntlets_03" ) -- Fel Iron Plate Gloves
	AddSpell( "professions", "BLACKSMITHING", 29547, nil, 305, 0, nil, 15000, "Interface\\Icons\\INV_Belt_21" ) -- Fel Iron Plate Belt
	AddSpell( "professions", "BLACKSMITHING", 29548, nil, 315, 0, nil, 20000, "Interface\\Icons\\INV_Boots_Chain_11" ) -- Fel Iron Plate Boots
	AddSpell( "professions", "BLACKSMITHING", 29549, nil, 315, 0, nil, 20000, "Interface\\Icons\\INV_Pants_Plate_18" ) -- Fel Iron Plate Pants
	AddSpell( "professions", "BLACKSMITHING", 29550, nil, 325, 0, nil, 25000, "Interface\\Icons\\INV_Chest_Plate07" ) -- Fel Iron Breastplate
	AddSpell( "professions", "BLACKSMITHING", 29551, nil, 300, 0, nil, 15000, "Interface\\Icons\\INV_Helmet_35" ) -- Fel Iron Chain Coif
	AddSpell( "professions", "BLACKSMITHING", 29552, nil, 310, 0, nil, 18000, "Interface\\Icons\\INV_Gauntlets_11" ) -- Fel Iron Chain Gloves
	AddSpell( "professions", "BLACKSMITHING", 29553, nil, 315, 0, nil, 20000, "Interface\\Icons\\INV_Bracer_13" ) -- Fel Iron Chain Bracers
	AddSpell( "professions", "BLACKSMITHING", 29556, nil, 320, 0, nil, 22000, "Interface\\Icons\\INV_Chest_Chain_14" ) -- Fel Iron Chain Tunic
	AddSpell( "professions", "BLACKSMITHING", 29557, nil, 310, 0, nil, 18000, "Interface\\Icons\\INV_Axe_11" ) -- Fel Iron Hatchet
	AddSpell( "professions", "BLACKSMITHING", 29558, nil, 315, 0, nil, 20000, "Interface\\Icons\\INV_Hammer_06" ) -- Fel Iron Hammer
	AddSpell( "professions", "BLACKSMITHING", 29565, nil, 320, 0, nil, 22000, "Interface\\Icons\\INV_Sword_26" ) -- Fel Iron Greatsword
	AddSpell( "professions", "BLACKSMITHING", 29654, nil, 300, 0, nil, 15000, "Interface\\Icons\\INV_Stone_SharpeningStone_06" ) -- Fel Sharpening Stone
	AddSpell( "professions", "BLACKSMITHING", 29844, 50, 275, 0, nil, 100000, nil ) -- Master Blacksmith
	AddSpell( "professions", "BLACKSMITHING", 32284, nil, 325, 0, nil, 25000, "Interface\\Icons\\INV_Misc_Rune_11" ) -- Lesser Rune of Warding
	AddSpell( "professions", "BLACKSMITHING", 32655, nil, 300, 0, nil, 10000, "Interface\\Icons\\INV_Rod_Felsteel" ) -- Fel Iron Rod
	AddSpell( "professions", "BLACKSMITHING", 34607, nil, 300, 0, nil, 15000, "Interface\\Icons\\INV_Stone_WeightStone_06" ) -- Fel Weightstone
	AddSpell( "professions", "BLACKSMITHING", 34979, nil, 100, 0, nil, 600, "Interface\\Icons\\INV_Spear_05" ) -- Thick Bronze Darts
	AddSpell( "professions", "BLACKSMITHING", 34981, nil, 200, 0, nil, 7500, "Interface\\Icons\\INV_Axe_05" ) -- Whirling Steel Axes
	AddSpell( "professions", "BLACKSMITHING", 34982, nil, 300, 0, nil, 10000, "Interface\\Icons\\INV_Weapon_ShortBlade_26" ) -- Enchanted Thorium Blades
	AddSpell( "professions", "BLACKSMITHING", 34983, nil, 350, 0, nil, 50000, "Interface\\Icons\\INV_Weapon_ShortBlade_26" ) -- Felsteel Whisper Knives
	AddSpell( "professions", "BLACKSMITHING", 51300, 65, 350, 0, nil, 350000, nil ) -- Grand Master Blacksmith
	AddSpell( "professions", "BLACKSMITHING", 52567, nil, 370, 0, nil, 30000, "Interface\\Icons\\INV_Pants_Plate_03" ) -- Cobalt Legplates
	AddSpell( "professions", "BLACKSMITHING", 52568, nil, 350, 0, nil, 30000, "Interface\\Icons\\INV_Belt_31" ) -- Cobalt Belt
	AddSpell( "professions", "BLACKSMITHING", 52569, nil, 350, 0, nil, 30000, "Interface\\Icons\\INV_Boots_Plate_05" ) -- Cobalt Boots
	AddSpell( "professions", "BLACKSMITHING", 52570, nil, 375, 0, nil, 30000, "Interface\\Icons\\INV_Chest_Plate09" ) -- Cobalt Chestpiece
	AddSpell( "professions", "BLACKSMITHING", 52571, nil, 370, 0, nil, 30000, "Interface\\Icons\\INV_Helmet_06" ) -- Cobalt Helm
	AddSpell( "professions", "BLACKSMITHING", 52572, nil, 360, 0, nil, 30000, "Interface\\Icons\\INV_Shoulder_31" ) -- Cobalt Shoulders
	AddSpell( "professions", "BLACKSMITHING", 54550, nil, 360, 0, nil, 30000, "Interface\\Icons\\INV_Shield_46" ) -- Cobalt Triangle Shield
	AddSpell( "professions", "BLACKSMITHING", 54551, nil, 395, 0, nil, 40000, "Interface\\Icons\\INV_Belt_22" ) -- Tempered Saronite Belt
	AddSpell( "professions", "BLACKSMITHING", 54552, nil, 400, 0, nil, 40000, "Interface\\Icons\\INV_Boots_Plate_01" ) -- Tempered Saronite Boots
	AddSpell( "professions", "BLACKSMITHING", 54553, nil, 400, 0, nil, 40000, "Interface\\Icons\\INV_Chest_Plate06" ) -- Tempered Saronite Breastplate
	AddSpell( "professions", "BLACKSMITHING", 54554, nil, 395, 0, nil, 40000, "Interface\\Icons\\INV_Pants_Plate_20" ) -- Tempered Saronite Legplates
	AddSpell( "professions", "BLACKSMITHING", 54555, nil, 405, 0, nil, 40000, "Interface\\Icons\\INV_Helmet_123" ) -- Tempered Saronite Helm
	AddSpell( "professions", "BLACKSMITHING", 54556, nil, 405, 0, nil, 40000, "Interface\\Icons\\INV_Shoulder_70" ) -- Tempered Saronite Shoulders
	AddSpell( "professions", "BLACKSMITHING", 54557, nil, 390, 0, nil, 40000, "Interface\\Icons\\INV_Shield_45" ) -- Saronite Defender
	AddSpell( "professions", "BLACKSMITHING", 54917, nil, 375, 0, nil, 30000, "Interface\\Icons\\INV_Helmet_06" ) -- Spiked Cobalt Helm
	AddSpell( "professions", "BLACKSMITHING", 54918, nil, 380, 0, nil, 30000, "Interface\\Icons\\INV_Boots_Plate_05" ) -- Spiked Cobalt Boots
	AddSpell( "professions", "BLACKSMITHING", 54941, nil, 385, 0, nil, 30000, "Interface\\Icons\\INV_Shoulder_31" ) -- Spiked Cobalt Shoulders
	AddSpell( "professions", "BLACKSMITHING", 54944, nil, 385, 0, nil, 30000, "Interface\\Icons\\INV_Chest_Plate09" ) -- Spiked Cobalt Chestpiece
	AddSpell( "professions", "BLACKSMITHING", 54945, nil, 390, 0, nil, 35000, "Interface\\Icons\\INV_Gauntlets_26" ) -- Spiked Cobalt Gauntlets
	AddSpell( "professions", "BLACKSMITHING", 54946, nil, 395, 0, nil, 30000, "Interface\\Icons\\INV_Belt_31" ) -- Spiked Cobalt Belt
	AddSpell( "professions", "BLACKSMITHING", 54947, nil, 395, 0, nil, 35000, "Interface\\Icons\\INV_Pants_Plate_03" ) -- Spiked Cobalt Legplates
	AddSpell( "professions", "BLACKSMITHING", 54948, nil, 400, 0, nil, 30000, "Interface\\Icons\\INV_Bracer_03" ) -- Spiked Cobalt Bracers
	AddSpell( "professions", "BLACKSMITHING", 54949, nil, 400, 0, nil, 30000, "Interface\\Icons\\INV_Helmet_06" ) -- Horned Cobalt Helm
	AddSpell( "professions", "BLACKSMITHING", 55013, nil, 390, 0, nil, 40000, "Interface\\Icons\\INV_Shield_45" ) -- Saronite Protector
	AddSpell( "professions", "BLACKSMITHING", 55014, nil, 410, 0, nil, 35000, "Interface\\Icons\\INV_Shield_46" ) -- Saronite Bulwark
	AddSpell( "professions", "BLACKSMITHING", 55015, nil, 415, 0, nil, 40000, "Interface\\Icons\\INV_Gauntlets_28" ) -- Tempered Saronite Gauntlets
	AddSpell( "professions", "BLACKSMITHING", 55017, nil, 410, 0, nil, 40000, "Interface\\Icons\\INV_Bracer_18" ) -- Tempered Saronite Bracers
	AddSpell( "professions", "BLACKSMITHING", 55055, nil, 395, 0, nil, 40000, "Interface\\Icons\\INV_Pants_Plate_12" ) -- Brilliant Saronite Legplates
	AddSpell( "professions", "BLACKSMITHING", 55056, nil, 400, 0, nil, 40000, "Interface\\Icons\\INV_Gauntlets_28" ) -- Brilliant Saronite Gauntlets
	AddSpell( "professions", "BLACKSMITHING", 55057, nil, 405, 0, nil, 40000, "Interface\\Icons\\INV_Boots_Plate_05" ) -- Brilliant Saronite Boots
	AddSpell( "professions", "BLACKSMITHING", 55058, nil, 415, 0, nil, 45000, "Interface\\Icons\\INV_Chest_Plate11" ) -- Brilliant Saronite Breastplate
	AddSpell( "professions", "BLACKSMITHING", 55174, nil, 390, 0, nil, 50000, "Interface\\Icons\\INV_Axe_87" ) -- Honed Cobalt Cleaver
	AddSpell( "professions", "BLACKSMITHING", 55177, nil, 395, 0, nil, 50000, "Interface\\Icons\\INV_Sword_111" ) -- Savage Cobalt Slicer
	AddSpell( "professions", "BLACKSMITHING", 55179, nil, 400, 0, nil, 50000, "Interface\\Icons\\INV_Weapon_Shortblade_68" ) -- Saronite Ambusher
	AddSpell( "professions", "BLACKSMITHING", 55181, nil, 405, 0, nil, 50000, "Interface\\Icons\\INV_Weapon_Shortblade_68" ) -- Saronite Shiv
	AddSpell( "professions", "BLACKSMITHING", 55182, nil, 410, 0, nil, 40000, "Interface\\Icons\\INV_Mace_69" ) -- Furious Saronite Beatstick
	AddSpell( "professions", "BLACKSMITHING", 55185, nil, 415, 0, nil, 45000, "Interface\\Icons\\INV_Mace_63" ) -- Saronite Mindcrusher
	AddSpell( "professions", "BLACKSMITHING", 55200, nil, 380, 0, nil, 35000, "Interface\\Icons\\INV_Sword_94" ) -- Sturdy Cobalt Quickblade
	AddSpell( "professions", "BLACKSMITHING", 55201, nil, 380, 0, nil, 35000, "Interface\\Icons\\INV_Mace_69" ) -- Cobalt Tenderizer
	AddSpell( "professions", "BLACKSMITHING", 55202, nil, 385, 0, nil, 35000, "Interface\\Icons\\INV_ThrowingKnife_07" ) -- Sure-fire Shuriken
	AddSpell( "professions", "BLACKSMITHING", 55203, nil, 385, 0, nil, 35000, "Interface\\Icons\\INV_Sword_96" ) -- Forged Cobalt Claymore
	AddSpell( "professions", "BLACKSMITHING", 55204, nil, 390, 0, nil, 35000, "Interface\\Icons\\INV_Axe_88" ) -- Notched Cobalt War Axe
	AddSpell( "professions", "BLACKSMITHING", 55206, nil, 405, 0, nil, 40000, "Interface\\Icons\\INV_Weapon_ShortBlade_06" ) -- Deadly Saronite Dirk
	AddSpell( "professions", "BLACKSMITHING", 55298, nil, 420, 0, nil, 45000, "Interface\\Icons\\INV_Bracer_09" ) -- Vengeance Bindings
	AddSpell( "professions", "BLACKSMITHING", 55300, nil, 420, 0, nil, 45000, "Interface\\Icons\\INV_Gauntlets_26" ) -- Righteous Gauntlets
	AddSpell( "professions", "BLACKSMITHING", 55301, nil, 420, 0, nil, 45000, "Interface\\Icons\\INV_Gauntlets_26" ) -- Daunting Handguards
	AddSpell( "professions", "BLACKSMITHING", 55302, nil, 425, 0, nil, 45000, "Interface\\Icons\\INV_Helmet_130" ) -- Helm of Command
	AddSpell( "professions", "BLACKSMITHING", 55303, nil, 425, 0, nil, 45000, "Interface\\Icons\\INV_Pants_Plate_16" ) -- Daunting Legplates
	AddSpell( "professions", "BLACKSMITHING", 55304, nil, 425, 0, nil, 45000, "Interface\\Icons\\INV_Pants_Plate_16" ) -- Righteous Greaves
	AddSpell( "professions", "BLACKSMITHING", 55305, nil, 420, 0, nil, 45000, "Interface\\Icons\\INV_Bracer_09" ) -- Savage Saronite Bracers
	AddSpell( "professions", "BLACKSMITHING", 55306, nil, 420, 0, nil, 45000, "Interface\\Icons\\INV_Shoulder_92" ) -- Savage Saronite Pauldrons
	AddSpell( "professions", "BLACKSMITHING", 55307, nil, 420, 0, nil, 45000, "Interface\\Icons\\INV_Belt_23" ) -- Savage Saronite Waistguard
	AddSpell( "professions", "BLACKSMITHING", 55308, nil, 420, 0, nil, 45000, "Interface\\Icons\\INV_Boots_Chain_08" ) -- Savage Saronite Walkers
	AddSpell( "professions", "BLACKSMITHING", 55309, nil, 420, 0, nil, 45000, "Interface\\Icons\\INV_Gauntlets_26" ) -- Savage Saronite Gauntlets
	AddSpell( "professions", "BLACKSMITHING", 55310, nil, 425, 0, nil, 45000, "Interface\\Icons\\INV_Pants_Plate_20" ) -- Savage Saronite Legplates
	AddSpell( "professions", "BLACKSMITHING", 55311, nil, 425, 0, nil, 45000, "Interface\\Icons\\INV_Chest_Chain_15" ) -- Savage Saronite Hauberk
	AddSpell( "professions", "BLACKSMITHING", 55312, nil, 425, 0, nil, 45000, "Interface\\Icons\\INV_Helmet_130" ) -- Savage Saronite Skullshield
	AddSpell( "professions", "BLACKSMITHING", 55369, nil, 440, 0, nil, 180000, "Interface\\Icons\\INV_Mace_84" ) -- Titansteel Destroyer
	AddSpell( "professions", "BLACKSMITHING", 55370, nil, 440, 0, nil, 150000, "Interface\\Icons\\INV_Mace_87" ) -- Titansteel Bonecrusher
	AddSpell( "professions", "BLACKSMITHING", 55371, nil, 440, 0, nil, 150000, "Interface\\Icons\\INV_Mace_87" ) -- Titansteel Guardian
	AddSpell( "professions", "BLACKSMITHING", 55372, nil, 440, 0, nil, 120000, "Interface\\Icons\\INV_Helmet_134" ) -- Spiked Titansteel Helm
	AddSpell( "professions", "BLACKSMITHING", 55373, nil, 440, 0, nil, 120000, "Interface\\Icons\\INV_Helmet_134" ) -- Tempered Titansteel Helm
	AddSpell( "professions", "BLACKSMITHING", 55374, nil, 440, 0, nil, 120000, "Interface\\Icons\\INV_Helmet_134" ) -- Brilliant Titansteel Helm
	AddSpell( "professions", "BLACKSMITHING", 55375, nil, 440, 0, nil, 120000, "Interface\\Icons\\INV_Boots_Plate_08" ) -- Spiked Titansteel Treads
	AddSpell( "professions", "BLACKSMITHING", 55376, nil, 440, 0, nil, 120000, "Interface\\Icons\\INV_Boots_Plate_08" ) -- Tempered Titansteel Treads
	AddSpell( "professions", "BLACKSMITHING", 55377, nil, 440, 0, nil, 120000, "Interface\\Icons\\INV_Boots_Plate_08" ) -- Brilliant Titansteel Treads
	AddSpell( "professions", "BLACKSMITHING", 55628, nil, 400, 0, nil, 45000, nil ) -- Socket Bracer
	AddSpell( "professions", "BLACKSMITHING", 55641, nil, 400, 0, nil, 45000, nil ) -- Socket Gloves
	AddSpell( "professions", "BLACKSMITHING", 55656, nil, 415, 0, nil, 50000, "Interface\\Icons\\INV_Belt_36" ) -- Eternal Belt Buckle
	AddSpell( "professions", "BLACKSMITHING", 55732, nil, 420, 0, nil, 42000, "Interface\\Icons\\INV_Rod_Platinum" ) -- Titanium Rod
	AddSpell( "professions", "BLACKSMITHING", 55834, nil, 360, 0, nil, 30000, "Interface\\Icons\\INV_Bracer_07" ) -- Cobalt Bracers
	AddSpell( "professions", "BLACKSMITHING", 55835, nil, 370, 0, nil, 30000, "Interface\\Icons\\INV_Gauntlets_09" ) -- Cobalt Gauntlets
	AddSpell( "professions", "BLACKSMITHING", 55839, nil, 420, 0, nil, 42000, "Interface\\Icons\\INV_Belt_18" ) -- Titanium Weapon Chain
	AddSpell( "professions", "BLACKSMITHING", 56234, nil, 440, 0, nil, 150000, "Interface\\Icons\\INV_Weapon_Shortblade_76" ) -- Titansteel Shanker
	AddSpell( "professions", "BLACKSMITHING", 56280, nil, 410, 0, nil, 40000, "Interface\\Icons\\INV_Mace_67" ) -- Cudgel of Saronite Justice
	AddSpell( "professions", "BLACKSMITHING", 56357, nil, 420, 0, nil, 42000, "Interface\\Icons\\INV_Titanium_Shield_Spike" ) -- Titanium Shield Spike
	AddSpell( "professions", "BLACKSMITHING", 56400, nil, 440, 0, nil, 150000, "Interface\\Icons\\INV_Shield_60" ) -- Titansteel Shield Wall
	AddSpell( "professions", "BLACKSMITHING", 56549, nil, 420, 0, nil, 45000, "Interface\\Icons\\INV_Bracer_09" ) -- Ornate Saronite Bracers
	AddSpell( "professions", "BLACKSMITHING", 56550, nil, 420, 0, nil, 45000, "Interface\\Icons\\INV_Shoulder_92" ) -- Ornate Saronite Pauldrons
	AddSpell( "professions", "BLACKSMITHING", 56551, nil, 420, 0, nil, 45000, "Interface\\Icons\\INV_Belt_23" ) -- Ornate Saronite Waistguard
	AddSpell( "professions", "BLACKSMITHING", 56552, nil, 420, 0, nil, 45000, "Interface\\Icons\\INV_Boots_Chain_08" ) -- Ornate Saronite Walkers
	AddSpell( "professions", "BLACKSMITHING", 56553, nil, 420, 0, nil, 45000, "Interface\\Icons\\INV_Gauntlets_26" ) -- Ornate Saronite Gauntlets
	AddSpell( "professions", "BLACKSMITHING", 56554, nil, 425, 0, nil, 45000, "Interface\\Icons\\INV_Pants_Plate_20" ) -- Ornate Saronite Legplates
	AddSpell( "professions", "BLACKSMITHING", 56555, nil, 425, 0, nil, 45000, "Interface\\Icons\\INV_Chest_Chain_15" ) -- Ornate Saronite Hauberk
	AddSpell( "professions", "BLACKSMITHING", 56556, nil, 425, 0, nil, 45000, "Interface\\Icons\\INV_Helmet_130" ) -- Ornate Saronite Skullshield
	AddSpell( "professions", "BLACKSMITHING", 59405, nil, 350, 0, nil, 30000, "Interface\\Icons\\INV_Misc_Key_07" ) -- Cobalt Skeleton Key
	AddSpell( "professions", "BLACKSMITHING", 59406, nil, 430, 0, nil, 45000, "Interface\\Icons\\INV_Misc_Key_11" ) -- Titanium Skeleton Key
	AddSpell( "professions", "BLACKSMITHING", 59436, nil, 395, 0, nil, 40000, "Interface\\Icons\\INV_Belt_20" ) -- Brilliant Saronite Belt
	AddSpell( "professions", "BLACKSMITHING", 59438, nil, 400, 0, nil, 40000, "Interface\\Icons\\INV_Bracer_17" ) -- Brilliant Saronite Bracers
	AddSpell( "professions", "BLACKSMITHING", 59440, nil, 405, 0, nil, 40000, "Interface\\Icons\\INV_Shoulder_71" ) -- Brilliant Saronite Pauldrons
	AddSpell( "professions", "BLACKSMITHING", 59441, nil, 415, 0, nil, 45000, "Interface\\Icons\\INV_Helmet_105" ) -- Brilliant Saronite Helm
	AddSpell( "professions", "BLACKSMITHING", 59442, nil, 410, 0, nil, 40000, "Interface\\Icons\\INV_Sword_94" ) -- Saronite Spellblade
	AddSpell( "professions", "BLACKSMITHING", 61008, nil, 425, 0, nil, 120000, "Interface\\Icons\\INV_Chest_Chain_11" ) -- Icebane Chestguard
	AddSpell( "professions", "BLACKSMITHING", 61009, nil, 420, 0, nil, 120000, "Interface\\Icons\\INV_Belt_33" ) -- Icebane Girdle
	AddSpell( "professions", "BLACKSMITHING", 61010, nil, 420, 0, nil, 120000, "Interface\\Icons\\INV_Boots_Plate_08" ) -- Icebane Treads
	AddSpell( "professions", "BLACKSMITHING", 63182, nil, 440, 0, nil, 150000, "Interface\\Icons\\INV_Sword_73" ) -- Titansteel Spellblade
	AddSpell( "professions", "BLACKSMITHING", 76178, nil, 425, 0, nil, 15000, "Interface\\Icons\\INV_Weapon_ShortBlade_21" ) -- Folded Obsidium
	AddSpell( "professions", "BLACKSMITHING", 76179, nil, 440, 0, nil, 40000, "Interface\\Icons\\inv_bracer_plate_cataclysm_b_02" ) -- Hardened Obsidium Bracers
	AddSpell( "professions", "BLACKSMITHING", 76180, nil, 450, 0, nil, 50000, "Interface\\Icons\\inv_gauntlets_plate_cataclysm_b_02" ) -- Hardened Obsidium Gauntlets
	AddSpell( "professions", "BLACKSMITHING", 76181, nil, 460, 0, nil, 55000, "Interface\\Icons\\inv_belt_plate_cataclysm_b_02" ) -- Hardened Obsidium Belt
	AddSpell( "professions", "BLACKSMITHING", 76182, nil, 470, 0, nil, 60000, "Interface\\Icons\\inv_boots_plate_cataclysm_b_02" ) -- Hardened Obsidium Boots
	AddSpell( "professions", "BLACKSMITHING", 76258, nil, 480, 0, nil, 65000, "Interface\\Icons\\inv_shoulder_plate_cataclysm_b_02" ) -- Hardened Obsidium Shoulders
	AddSpell( "professions", "BLACKSMITHING", 76259, nil, 490, 0, nil, 65000, "Interface\\Icons\\inv_pants_plate_cataclysm_b_02" ) -- Hardened Obsidium Legguards
	AddSpell( "professions", "BLACKSMITHING", 76260, nil, 490, 0, nil, 65000, "Interface\\Icons\\inv_helmet_plate_cataclysm_b_02" ) -- Hardened Obsidium Helm
	AddSpell( "professions", "BLACKSMITHING", 76261, nil, 500, 0, nil, 75000, "Interface\\Icons\\inv_chest_plate_cataclysm_b_02" ) -- Hardened Obsidium Breastplate
	AddSpell( "professions", "BLACKSMITHING", 76262, nil, 440, 0, nil, 40000, "Interface\\Icons\\inv_bracer_63v1" ) -- Redsteel Bracers
	AddSpell( "professions", "BLACKSMITHING", 76263, nil, 450, 0, nil, 50000, "Interface\\Icons\\inv_gauntlets_107v1" ) -- Redsteel Gauntlets
	AddSpell( "professions", "BLACKSMITHING", 76264, nil, 460, 0, nil, 55000, "Interface\\Icons\\inv_belt_86v1" ) -- Redsteel Belt
	AddSpell( "professions", "BLACKSMITHING", 76265, nil, 470, 0, nil, 60000, "Interface\\Icons\\inv_boots_plate_19v1" ) -- Redsteel Boots
	AddSpell( "professions", "BLACKSMITHING", 76266, nil, 480, 0, nil, 65000, "Interface\\Icons\\inv_shoulder_plate_dungeonplate_c_03" ) -- Redsteel Shoulders
	AddSpell( "professions", "BLACKSMITHING", 76267, nil, 490, 0, nil, 65000, "Interface\\Icons\\inv_pants_plate_38v1" ) -- Redsteel Legguards
	AddSpell( "professions", "BLACKSMITHING", 76269, nil, 500, 0, nil, 75000, "Interface\\Icons\\inv_helmet_178v1" ) -- Redsteel Helm
	AddSpell( "professions", "BLACKSMITHING", 76270, nil, 500, 0, nil, 75000, "Interface\\Icons\\inv_chest_plate27v1" ) -- Redsteel Breastplate
	AddSpell( "professions", "BLACKSMITHING", 76280, nil, 440, 0, nil, 40000, "Interface\\Icons\\inv_bracer_79" ) -- Stormforged Bracers
	AddSpell( "professions", "BLACKSMITHING", 76281, nil, 450, 0, nil, 50000, "Interface\\Icons\\inv_gauntlets_122" ) -- Stormforged Gauntlets
	AddSpell( "professions", "BLACKSMITHING", 76283, nil, 460, 0, nil, 55000, "Interface\\Icons\\inv_belt_100" ) -- Stormforged Belt
	AddSpell( "professions", "BLACKSMITHING", 76285, nil, 470, 0, nil, 60000, "Interface\\Icons\\inv_boots_plate_23" ) -- Stormforged Boots
	AddSpell( "professions", "BLACKSMITHING", 76286, nil, 480, 0, nil, 65000, "Interface\\Icons\\inv_shoulder_149" ) -- Stormforged Shoulders
	AddSpell( "professions", "BLACKSMITHING", 76287, nil, 480, 0, nil, 65000, "Interface\\Icons\\inv_pants_plate_26" ) -- Stormforged Legguards
	AddSpell( "professions", "BLACKSMITHING", 76288, nil, 490, 0, nil, 65000, "Interface\\Icons\\inv_helmet_189" ) -- Stormforged Helm
	AddSpell( "professions", "BLACKSMITHING", 76289, nil, 500, 0, nil, 75000, "Interface\\Icons\\inv_chest_plate_31" ) -- Stormforged Breastplate
	AddSpell( "professions", "BLACKSMITHING", 76291, nil, 450, 0, nil, 50000, "Interface\\Icons\\inv_shield_cataclysm_b_01" ) -- Hardened Obsidium Shield
	AddSpell( "professions", "BLACKSMITHING", 76293, nil, 470, 0, nil, 60000, "Interface\\Icons\\inv_shield_cataclysm_b_02" ) -- Stormforged Shield
	AddSpell( "professions", "BLACKSMITHING", 76433, nil, 460, 0, nil, 50000, "Interface\\Icons\\inv_axe_1h_cataclysm_b_01" ) -- Decapitator's Razor
	AddSpell( "professions", "BLACKSMITHING", 76434, nil, 470, 0, nil, 60000, "Interface\\Icons\\inv_knife_1h_cataclysm_b_02" ) -- Cold-Forged Shank
	AddSpell( "professions", "BLACKSMITHING", 76435, nil, 480, 0, nil, 65000, "Interface\\Icons\\inv_knife_1h_cataclysm_b_01" ) -- Fire-Etched Dagger
	AddSpell( "professions", "BLACKSMITHING", 76436, nil, 480, 0, nil, 65000, "Interface\\Icons\\INV_Hammer_29" ) -- Lifeforce Hammer
	AddSpell( "professions", "BLACKSMITHING", 76437, nil, 480, 0, nil, 65000, "Interface\\Icons\\inv_sword_2h_cataclysm_b_01" ) -- Obsidium Executioner
	AddSpell( "professions", "BLACKSMITHING", 76438, nil, 475, 0, nil, 60000, "Interface\\Icons\\item_pyriumkey" ) -- Obsidium Skeleton Key
	AddSpell( "professions", "BLACKSMITHING", 76441, nil, 490, 0, nil, 65000, "Interface\\Icons\\inv_qiraj_hiltspiked" ) -- Elementium Shield Spike
	AddSpell( "professions", "BLACKSMITHING", 76474, nil, 470, 0, nil, 60000, "Interface\\Icons\\inv_polearm_2h_cataclysm_c_01" ) -- Obsidium Bladespear
	AddSpell( "professions", "BLACKSMITHING", 76666, 75, 425, 0, nil, 500000, nil ) -- Illustrious Grand Master Blacksmith
	AddSpell( "professions", "BLACKSMITHING", 92375, nil, 475, 0, nil, 60000, "Interface\\Icons\\INV_Rod_Adamantite" ) -- Elementium Rod
	AddSpell( "professions", "COOKING",  2539, nil, 10, 0, nil, 50, "Interface\\Icons\\INV_Misc_Food_65" ) -- Spiced Wolf Meat
	AddSpell( "professions", "COOKING",  2541, nil, 50, 0, nil, 100, "Interface\\Icons\\INV_Misc_Food_65" ) -- Coyote Steak
	AddSpell( "professions", "COOKING",  2544, nil, 75, 0, nil, 200, "Interface\\Icons\\INV_Misc_Food_08" ) -- Crab Cake
	AddSpell( "professions", "COOKING",  2546, nil, 80, 0, nil, 150, "Interface\\Icons\\INV_Misc_Food_48" ) -- Dry Pork Ribs
	AddSpell( "professions", "COOKING",  2550, nil, nil, 0, nil, 100, nil ) -- Apprentice Cook
	AddSpell( "professions", "COOKING",  3102, nil, 50, 0, nil, 500, nil ) -- Journeyman Cook
	AddSpell( "professions", "COOKING",  3399, nil, 150, 0, nil, 450, "Interface\\Icons\\INV_Misc_Food_14" ) -- Tasty Lion Steak
	AddSpell( "professions", "COOKING",  3400, nil, 175, 0, nil, 500, "Interface\\Icons\\INV_Misc_Bowl_01" ) -- Soothing Turtle Bisque
	AddSpell( "professions", "COOKING",  3413, nil, 125, 0, nil, 10000, nil ) -- Expert Cook
	AddSpell( "professions", "COOKING",  4094, nil, 175, 0, nil, 500, nil ) -- Barbecued Buzzard Wing
	AddSpell( "professions", "COOKING",  6412, nil, 10, 0, nil, 50, "Interface\\Icons\\INV_Misc_Food_68" ) -- Kaldorei Spider Kabob
	AddSpell( "professions", "COOKING",  6415, nil, 50, 0, nil, 100, "Interface\\Icons\\INV_Misc_Fish_05" ) -- Fillet of Frenzy
	AddSpell( "professions", "COOKING",  6499, nil, 50, 0, nil, 100, "Interface\\Icons\\INV_Misc_Shell_02" ) -- Boiled Clams
	AddSpell( "professions", "COOKING",  6500, nil, 125, 0, nil, 300, "Interface\\Icons\\INV_Misc_Shell_01" ) -- Goblin Deviled Clams
	AddSpell( "professions", "COOKING", 18238, nil, 225, 0, nil, 5000, "Interface\\Icons\\INV_Misc_Fish_01" ) -- Spotted Yellowtail
	AddSpell( "professions", "COOKING", 18240, nil, 240, 0, nil, 6000, "Interface\\Icons\\INV_Misc_Fish_13" ) -- Grilled Squid
	AddSpell( "professions", "COOKING", 18243, nil, 250, 0, nil, 6500, "Interface\\Icons\\INV_Drink_17" ) -- Nightfin Soup
	AddSpell( "professions", "COOKING", 18244, nil, 250, 0, nil, 6500, "Interface\\Icons\\INV_Misc_Fish_19" ) -- Poached Sunscale Salmon
	AddSpell( "professions", "COOKING", 18260, nil, 200, 0, nil, 25000, nil ) -- Artisan Cook
	AddSpell( "professions", "COOKING", 21175, nil, 200, 0, nil, 4000, "Interface\\Icons\\INV_Misc_Food_66" ) -- Spider Sausage
	AddSpell( "professions", "COOKING", 33359, nil, 275, 0, nil, 100000, nil ) -- Master Cook
	AddSpell( "professions", "COOKING", 37836, nil, 1, 0, nil, 10, "Interface\\Icons\\INV_Misc_Food_95_Grainbread" ) -- Spice Bread
	AddSpell( "professions", "COOKING", 42296, nil, 320, 0, nil, 15000, "Interface\\Icons\\INV_Misc_Food_64" ) -- Stewed Trout
	AddSpell( "professions", "COOKING", 42302, nil, 350, 0, nil, 20000, nil ) -- Fisherman's Feast
	AddSpell( "professions", "COOKING", 42305, nil, 350, 0, nil, 20000, nil ) -- Hot Buttered Trout
	AddSpell( "professions", "COOKING", 45549, nil, 350, 0, nil, 20000, "Interface\\Icons\\INV_Misc_Food_116_CondorLeg" ) -- Mammoth Meal
	AddSpell( "professions", "COOKING", 45550, nil, 350, 0, nil, 20000, "Interface\\Icons\\INV_Misc_Food_89" ) -- Shoveltusk Steak
	AddSpell( "professions", "COOKING", 45551, nil, 350, 0, nil, 20000, "Interface\\Icons\\INV_Misc_Food_124_Skewer" ) -- Worm Delight
	AddSpell( "professions", "COOKING", 45552, nil, 350, 0, nil, 20000, "Interface\\Icons\\INV_Misc_Food_86_Basilisk" ) -- Roasted Worg
	AddSpell( "professions", "COOKING", 45553, nil, 350, 0, nil, 20000, "Interface\\Icons\\INV_Misc_Food_53" ) -- Rhino Dogs
	AddSpell( "professions", "COOKING", 45554, nil, 375, 0, nil, 50000, "Interface\\Icons\\Ability_Hunter_Pet_Boar" ) -- Great Feast
	AddSpell( "professions", "COOKING", 45560, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Misc_Food_131_Fish" ) -- Smoked Rockfin
	AddSpell( "professions", "COOKING", 45561, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Misc_Food_143_Fish" ) -- Grilled Bonescale
	AddSpell( "professions", "COOKING", 45562, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Misc_Food_125_FishChunk" ) -- Sauteed Goby
	AddSpell( "professions", "COOKING", 45563, nil, 350, 0, nil, 20000, "Interface\\Icons\\INV_Misc_Food_79" ) -- Grilled Sculpin
	AddSpell( "professions", "COOKING", 45564, nil, 350, 0, nil, 20000, "Interface\\Icons\\INV_Misc_Food_130_Fish" ) -- Smoked Salmon
	AddSpell( "professions", "COOKING", 45565, nil, 350, 0, nil, 20000, "Interface\\Icons\\INV_Misc_Food_138_Fish" ) -- Poached Nettlefish
	AddSpell( "professions", "COOKING", 45566, nil, 350, 0, nil, 20000, "Interface\\Icons\\INV_Misc_Food_76" ) -- Pickled Fangtooth
	AddSpell( "professions", "COOKING", 45569, nil, 350, 0, nil, 20000, "Interface\\Icons\\INV_Misc_Food_140_Fish" ) -- Baked Manta Ray
	AddSpell( "professions", "COOKING", 46684, nil, 250, 0, nil, 6500, "Interface\\Icons\\INV_Misc_Food_68" ) -- Charred Bear Kabobs
	AddSpell( "professions", "COOKING", 46688, nil, 250, 0, nil, 6500, "Interface\\Icons\\INV_Misc_Food_65" ) -- Juicy Bear Burger
	AddSpell( "professions", "COOKING", 51296, nil, 350, 0, nil, 350000, nil ) -- Grand Master Cook
	AddSpell( "professions", "COOKING", 58065, nil, 350, 0, nil, 20000, "Interface\\Icons\\INV_Misc_Cauldron_Frost" ) -- Dalaran Clam Chowder
	AddSpell( "professions", "COOKING", 64358, nil, 400, 0, nil, 50000, "Interface\\Icons\\INV_Misc_Slime_02" ) -- Black Jelly
	AddSpell( "professions", "COOKING", 88006, nil, 425, 0, nil, 35000, "Interface\\Icons\\INV_Misc_Food_108_MeadCaribou" ) -- Blackened Surprise
	AddSpell( "professions", "COOKING", 88015, nil, 415, 0, nil, 30000, nil ) -- Darkbrew Lager
	AddSpell( "professions", "COOKING", 88053, nil, 425, 0, nil, 500000, nil ) -- Illustrious Grand Master Cook
	AddSpell( "professions", "COOKING", 93741, nil, 40, 0, nil, 80, "Interface\\Icons\\INV_Misc_Food_13" ) -- Venison Jerky
	AddSpell( "professions", "ENCHANTING",  7411, 5, nil, 0, nil, 10, nil ) -- Apprentice Enchanter
	AddSpell( "professions", "ENCHANTING",  7412, 10, 50, 0, nil, 500, nil ) -- Journeyman Enchanter
	AddSpell( "professions", "ENCHANTING",  7413, 20, 125, 0, nil, 5000, nil ) -- Expert Enchanter
	AddSpell( "professions", "ENCHANTING",  7420, nil, 15, 0, nil, 50, nil ) -- Enchant Chest - Minor Health
	AddSpell( "professions", "ENCHANTING",  7426, nil, 40, 0, nil, 100, nil ) -- Enchant Chest - Minor Absorption
	AddSpell( "professions", "ENCHANTING",  7454, nil, 45, 0, nil, 100, nil ) -- Enchant Cloak - Minor Resistance
	AddSpell( "professions", "ENCHANTING",  7457, nil, 50, 0, nil, 250, nil ) -- Enchant Bracer - Minor Stamina
	AddSpell( "professions", "ENCHANTING",  7745, nil, 100, 0, nil, 500, nil ) -- Enchant 2H Weapon - Minor Impact
	AddSpell( "professions", "ENCHANTING",  7748, nil, 60, 0, nil, 250, nil ) -- Enchant Chest - Lesser Health
	AddSpell( "professions", "ENCHANTING",  7771, nil, 70, 0, nil, 200, nil ) -- Enchant Cloak - Minor Protection
	AddSpell( "professions", "ENCHANTING",  7779, nil, 80, 0, nil, 400, nil ) -- Enchant Bracer - Minor Agility
	AddSpell( "professions", "ENCHANTING",  7788, nil, 90, 0, nil, 500, nil ) -- Enchant Weapon - Minor Striking
	AddSpell( "professions", "ENCHANTING",  7795, nil, 100, 0, nil, 1000, nil ) -- Runed Silver Rod
	AddSpell( "professions", "ENCHANTING",  7857, nil, 120, 0, nil, 1000, nil ) -- Enchant Chest - Health
	AddSpell( "professions", "ENCHANTING",  7861, nil, 125, 0, nil, 1250, nil ) -- Enchant Cloak - Lesser Fire Resistance
	AddSpell( "professions", "ENCHANTING",  7863, nil, 125, 0, nil, 1400, nil ) -- Enchant Boots - Minor Stamina
	AddSpell( "professions", "ENCHANTING", 13378, nil, 105, 0, nil, 600, nil ) -- Enchant Shield - Minor Stamina
	AddSpell( "professions", "ENCHANTING", 13421, nil, 115, 0, nil, 800, nil ) -- Enchant Cloak - Lesser Protection
	AddSpell( "professions", "ENCHANTING", 13485, nil, 130, 0, nil, 1500, nil ) -- Enchant Shield - Lesser Spirit
	AddSpell( "professions", "ENCHANTING", 13501, nil, 130, 0, nil, 1500, nil ) -- Enchant Bracer - Lesser Stamina
	AddSpell( "professions", "ENCHANTING", 13503, nil, 140, 0, nil, 2000, nil ) -- Enchant Weapon - Lesser Striking
	AddSpell( "professions", "ENCHANTING", 13529, nil, 145, 0, nil, 2400, nil ) -- Enchant 2H Weapon - Lesser Impact
	AddSpell( "professions", "ENCHANTING", 13538, nil, 140, 0, nil, 2500, nil ) -- Enchant Chest - Lesser Absorption
	AddSpell( "professions", "ENCHANTING", 13607, nil, 145, 0, nil, 2400, nil ) -- Enchant Chest - Mana
	AddSpell( "professions", "ENCHANTING", 13622, nil, 150, 0, nil, 2500, nil ) -- Enchant Bracer - Lesser Intellect
	AddSpell( "professions", "ENCHANTING", 13626, nil, 150, 0, nil, 2500, nil ) -- Enchant Chest - Minor Stats
	AddSpell( "professions", "ENCHANTING", 13628, nil, 150, 0, nil, 2500, nil ) -- Runed Golden Rod
	AddSpell( "professions", "ENCHANTING", 13631, nil, 155, 0, nil, 2600, nil ) -- Enchant Shield - Lesser Stamina
	AddSpell( "professions", "ENCHANTING", 13635, nil, 155, 0, nil, 2600, nil ) -- Enchant Cloak - Defense
	AddSpell( "professions", "ENCHANTING", 13637, nil, 160, 0, nil, 2800, nil ) -- Enchant Boots - Lesser Agility
	AddSpell( "professions", "ENCHANTING", 13640, nil, 160, 0, nil, 2700, nil ) -- Enchant Chest - Greater Health
	AddSpell( "professions", "ENCHANTING", 13642, nil, 165, 0, nil, 2800, nil ) -- Enchant Bracer - Spirit
	AddSpell( "professions", "ENCHANTING", 13644, nil, 170, 0, nil, 2800, nil ) -- Enchant Boots - Lesser Stamina
	AddSpell( "professions", "ENCHANTING", 13646, nil, 170, 0, nil, 2800, nil ) -- Enchant Bracer - Lesser Deflection
	AddSpell( "professions", "ENCHANTING", 13648, nil, 170, 0, nil, 2800, nil ) -- Enchant Bracer - Stamina
	AddSpell( "professions", "ENCHANTING", 13657, nil, 175, 0, nil, 3000, nil ) -- Enchant Cloak - Fire Resistance
	AddSpell( "professions", "ENCHANTING", 13659, nil, 180, 0, nil, 3200, nil ) -- Enchant Shield - Spirit
	AddSpell( "professions", "ENCHANTING", 13661, nil, 180, 0, nil, 3600, nil ) -- Enchant Bracer - Strength
	AddSpell( "professions", "ENCHANTING", 13663, nil, 185, 0, nil, 3800, nil ) -- Enchant Chest - Greater Mana
	AddSpell( "professions", "ENCHANTING", 13693, nil, 195, 0, nil, 4000, nil ) -- Enchant Weapon - Striking
	AddSpell( "professions", "ENCHANTING", 13695, nil, 200, 0, nil, 4000, nil ) -- Enchant 2H Weapon - Impact
	AddSpell( "professions", "ENCHANTING", 13700, nil, 200, 0, nil, 4000, nil ) -- Enchant Chest - Lesser Stats
	AddSpell( "professions", "ENCHANTING", 13702, nil, 200, 0, nil, 4000, nil ) -- Runed Truesilver Rod
	AddSpell( "professions", "ENCHANTING", 13746, nil, 205, 0, nil, 4200, nil ) -- Enchant Cloak - Greater Defense
	AddSpell( "professions", "ENCHANTING", 13794, nil, 205, 0, nil, 4200, nil ) -- Enchant Cloak - Resistance
	AddSpell( "professions", "ENCHANTING", 13815, nil, 210, 0, nil, 4400, nil ) -- Enchant Gloves - Agility
	AddSpell( "professions", "ENCHANTING", 13822, nil, 210, 0, nil, 4400, nil ) -- Enchant Bracer - Intellect
	AddSpell( "professions", "ENCHANTING", 13836, nil, 215, 0, nil, 4600, nil ) -- Enchant Boots - Stamina
	AddSpell( "professions", "ENCHANTING", 13858, nil, 220, 0, nil, 4800, nil ) -- Enchant Chest - Superior Health
	AddSpell( "professions", "ENCHANTING", 13887, nil, 225, 0, nil, 5000, nil ) -- Enchant Gloves - Strength
	AddSpell( "professions", "ENCHANTING", 13890, nil, 225, 0, nil, 5000, nil ) -- Enchant Boots - Minor Speed
	AddSpell( "professions", "ENCHANTING", 13905, nil, 230, 0, nil, 5400, nil ) -- Enchant Shield - Greater Spirit
	AddSpell( "professions", "ENCHANTING", 13917, nil, 230, 0, nil, 5400, nil ) -- Enchant Chest - Superior Mana
	AddSpell( "professions", "ENCHANTING", 13920, 35, 200, 0, nil, 50000, nil ) -- Artisan Enchanter
	AddSpell( "professions", "ENCHANTING", 13935, nil, 235, 0, nil, 5800, nil ) -- Enchant Boots - Agility
	AddSpell( "professions", "ENCHANTING", 13937, nil, 240, 0, nil, 6200, nil ) -- Enchant 2H Weapon - Greater Impact
	AddSpell( "professions", "ENCHANTING", 13939, nil, 240, 0, nil, 6200, nil ) -- Enchant Bracer - Greater Strength
	AddSpell( "professions", "ENCHANTING", 13941, nil, 245, 0, nil, 6200, nil ) -- Enchant Chest - Stats
	AddSpell( "professions", "ENCHANTING", 13943, nil, 245, 0, nil, 6200, nil ) -- Enchant Weapon - Greater Striking
	AddSpell( "professions", "ENCHANTING", 13948, nil, 250, 0, nil, 6500, nil ) -- Enchant Gloves - Minor Haste
	AddSpell( "professions", "ENCHANTING", 14293, nil, 10, 0, nil, 50, nil ) -- Lesser Magic Wand
	AddSpell( "professions", "ENCHANTING", 14807, nil, 70, 0, nil, 200, nil ) -- Greater Magic Wand
	AddSpell( "professions", "ENCHANTING", 14809, nil, 155, 0, nil, 2600, nil ) -- Lesser Mystic Wand
	AddSpell( "professions", "ENCHANTING", 14810, nil, 175, 0, nil, 3000, nil ) -- Greater Mystic Wand
	AddSpell( "professions", "ENCHANTING", 17180, nil, 250, 0, nil, 10000, nil ) -- Enchanted Thorium Bar
	AddSpell( "professions", "ENCHANTING", 17181, nil, 250, 0, nil, 10000, nil ) -- Enchanted Leather
	AddSpell( "professions", "ENCHANTING", 20008, nil, 255, 0, nil, 10000, nil ) -- Enchant Bracer - Greater Intellect
	AddSpell( "professions", "ENCHANTING", 20012, nil, 270, 0, nil, 10000, nil ) -- Enchant Gloves - Greater Agility
	AddSpell( "professions", "ENCHANTING", 20013, nil, 295, 0, nil, 20000, nil ) -- Enchant Gloves - Greater Strength
	AddSpell( "professions", "ENCHANTING", 20014, nil, 265, 0, nil, 10000, nil ) -- Enchant Cloak - Greater Resistance
	AddSpell( "professions", "ENCHANTING", 20016, nil, 280, 0, nil, 15000, nil ) -- Enchant Shield - Vitality
	AddSpell( "professions", "ENCHANTING", 20023, nil, 295, 0, nil, 20000, nil ) -- Enchant Boots - Greater Agility
	AddSpell( "professions", "ENCHANTING", 20028, nil, 290, 0, nil, 15000, nil ) -- Enchant Chest - Major Mana
	AddSpell( "professions", "ENCHANTING", 20051, nil, 290, 0, nil, 15000, nil ) -- Runed Arcanite Rod
	AddSpell( "professions", "ENCHANTING", 27899, nil, 305, 0, nil, 12500, nil ) -- Enchant Bracer - Brawn
	AddSpell( "professions", "ENCHANTING", 27905, nil, 315, 0, nil, 12500, nil ) -- Enchant Bracer - Stats
	AddSpell( "professions", "ENCHANTING", 27944, nil, 310, 0, nil, 15000, nil ) -- Enchant Shield - Tough Shield
	AddSpell( "professions", "ENCHANTING", 27957, nil, 315, 0, nil, 17500, nil ) -- Enchant Chest - Exceptional Health
	AddSpell( "professions", "ENCHANTING", 27958, nil, 350, 0, nil, 50000, nil ) -- Enchant Chest - Exceptional Mana
	AddSpell( "professions", "ENCHANTING", 27961, nil, 310, 0, nil, 15000, nil ) -- Enchant Cloak - Major Armor
	AddSpell( "professions", "ENCHANTING", 28027, nil, 325, 0, nil, 40000, nil ) -- Prismatic Sphere
	AddSpell( "professions", "ENCHANTING", 28028, nil, 350, 0, nil, 80000, nil ) -- Void Sphere
	AddSpell( "professions", "ENCHANTING", 28029, 50, 275, 0, nil, 100000, nil ) -- Master Enchanter
	AddSpell( "professions", "ENCHANTING", 32664, nil, 300, 0, nil, 10000, nil ) -- Runed Fel Iron Rod
	AddSpell( "professions", "ENCHANTING", 32665, nil, 350, 0, nil, 80000, nil ) -- Runed Adamantite Rod
	AddSpell( "professions", "ENCHANTING", 32667, nil, 375, 0, nil, 50000, nil ) -- Runed Eternium Rod
	AddSpell( "professions", "ENCHANTING", 33990, nil, 320, 0, nil, 20000, nil ) -- Enchant Chest - Major Spirit
	AddSpell( "professions", "ENCHANTING", 33991, nil, 300, 0, nil, 20000, nil ) -- Enchant Chest - Restore Mana Prime
	AddSpell( "professions", "ENCHANTING", 33993, nil, 305, 0, nil, 12500, nil ) -- Enchant Gloves - Blasting
	AddSpell( "professions", "ENCHANTING", 33995, nil, 340, 0, nil, 25000, nil ) -- Enchant Gloves - Major Strength
	AddSpell( "professions", "ENCHANTING", 33996, nil, 310, 0, nil, 15000, nil ) -- Enchant Gloves - Assault
	AddSpell( "professions", "ENCHANTING", 34001, nil, 305, 0, nil, 12500, nil ) -- Enchant Bracer - Major Intellect
	AddSpell( "professions", "ENCHANTING", 34002, nil, 300, 0, nil, 12500, nil ) -- Enchant Bracer - Assault
	AddSpell( "professions", "ENCHANTING", 34004, nil, 310, 0, nil, 15000, nil ) -- Enchant Cloak - Greater Agility
	AddSpell( "professions", "ENCHANTING", 42613, 35, 300, 0, nil, 10000, nil ) -- Nexus Transformation
	AddSpell( "professions", "ENCHANTING", 42615, nil, 335, 0, nil, 40000, nil ) -- Small Prismatic Shard
	AddSpell( "professions", "ENCHANTING", 44383, nil, 330, 0, nil, 25000, nil ) -- Enchant Shield - Resilience
	AddSpell( "professions", "ENCHANTING", 44484, nil, 405, 0, nil, 150000, nil ) -- Enchant Gloves - Expertise
	AddSpell( "professions", "ENCHANTING", 44488, nil, 410, 0, nil, 150000, nil ) -- Enchant Gloves - Precision
	AddSpell( "professions", "ENCHANTING", 44489, nil, 420, 0, nil, 150000, nil ) -- Enchant Shield - Dodge
	AddSpell( "professions", "ENCHANTING", 44492, nil, 395, 0, nil, 100000, nil ) -- Enchant Chest - Mighty Health
	AddSpell( "professions", "ENCHANTING", 44500, nil, 395, 0, nil, 100000, nil ) -- Enchant Cloak - Superior Agility
	AddSpell( "professions", "ENCHANTING", 44506, nil, 375, 0, nil, 50000, nil ) -- Enchant Gloves - Gatherer
	AddSpell( "professions", "ENCHANTING", 44508, nil, 410, 0, nil, 150000, nil ) -- Enchant Boots - Greater Spirit
	AddSpell( "professions", "ENCHANTING", 44509, nil, 420, 0, nil, 150000, nil ) -- Enchant Chest - Greater Mana Restoration
	AddSpell( "professions", "ENCHANTING", 44510, nil, 410, 0, nil, 150000, nil ) -- Enchant Weapon - Exceptional Spirit
	AddSpell( "professions", "ENCHANTING", 44513, nil, 395, 0, nil, 100000, nil ) -- Enchant Gloves - Greater Assault
	AddSpell( "professions", "ENCHANTING", 44528, nil, 385, 0, nil, 90000, nil ) -- Enchant Boots - Greater Fortitude
	AddSpell( "professions", "ENCHANTING", 44529, nil, 415, 0, nil, 150000, nil ) -- Enchant Gloves - Major Agility
	AddSpell( "professions", "ENCHANTING", 44555, nil, 375, 0, nil, 50000, nil ) -- Enchant Bracers - Exceptional Intellect
	AddSpell( "professions", "ENCHANTING", 44582, nil, 395, 0, nil, 100000, nil ) -- Enchant Cloak - Spell Piercing
	AddSpell( "professions", "ENCHANTING", 44584, nil, 405, 0, nil, 150000, nil ) -- Enchant Boots - Greater Vitality
	AddSpell( "professions", "ENCHANTING", 44589, nil, 415, 0, nil, 150000, nil ) -- Enchant Boots - Superior Agility
	AddSpell( "professions", "ENCHANTING", 44592, nil, 360, 0, nil, 50000, nil ) -- Enchant Gloves - Exceptional Spellpower
	AddSpell( "professions", "ENCHANTING", 44593, nil, 420, 0, nil, 150000, nil ) -- Enchant Bracers - Major Spirit
	AddSpell( "professions", "ENCHANTING", 44598, nil, 415, 0, nil, 150000, nil ) -- Enchant Bracers - Expertise
	AddSpell( "professions", "ENCHANTING", 44616, nil, 400, 0, nil, 100000, nil ) -- Enchant Bracers - Greater Stats
	AddSpell( "professions", "ENCHANTING", 44623, nil, 370, 0, nil, 50000, nil ) -- Enchant Chest - Super Stats
	AddSpell( "professions", "ENCHANTING", 44629, nil, 395, 0, nil, 100000, nil ) -- Enchant Weapon - Exceptional Spellpower
	AddSpell( "professions", "ENCHANTING", 44630, nil, 390, 0, nil, 80000, nil ) -- Enchant 2H Weapon - Greater Savagery
	AddSpell( "professions", "ENCHANTING", 44633, nil, 410, 0, nil, 150000, nil ) -- Enchant Weapon - Exceptional Agility
	AddSpell( "professions", "ENCHANTING", 44635, nil, 395, 0, nil, 100000, nil ) -- Enchant Bracers - Greater Spellpower
	AddSpell( "professions", "ENCHANTING", 44636, nil, 400, 0, nil, 100000, nil ) -- Enchant Ring - Greater Spellpower
	AddSpell( "professions", "ENCHANTING", 44645, nil, 400, 0, nil, 100000, nil ) -- Enchant Ring - Assault
	AddSpell( "professions", "ENCHANTING", 47766, nil, 400, 0, nil, 100000, nil ) -- Enchant Chest - Greater Dodge
	AddSpell( "professions", "ENCHANTING", 47900, nil, 425, 0, nil, 150000, nil ) -- Enchant Chest - Super Health
	AddSpell( "professions", "ENCHANTING", 51313, 65, 350, 0, nil, 350000, nil ) -- Grand Master Enchanter
	AddSpell( "professions", "ENCHANTING", 59636, nil, 400, 0, nil, 100000, nil ) -- Enchant Ring - Stamina
	AddSpell( "professions", "ENCHANTING", 60606, nil, 375, 0, nil, 50000, nil ) -- Enchant Boots - Assault
	AddSpell( "professions", "ENCHANTING", 60609, nil, 350, 0, nil, 50000, nil ) -- Enchant Cloak - Speed
	AddSpell( "professions", "ENCHANTING", 60616, nil, 360, 0, nil, 50000, nil ) -- Enchant Bracers - Striking
	AddSpell( "professions", "ENCHANTING", 60619, nil, 425, 0, nil, 150000, "Interface\\Icons\\INV_Rod_Titanium" ) -- Runed Titanium Rod
	AddSpell( "professions", "ENCHANTING", 60621, nil, 380, 0, nil, 80000, nil ) -- Enchant Weapon - Greater Potency
	AddSpell( "professions", "ENCHANTING", 60623, nil, 385, 0, nil, 90000, nil ) -- Enchant Boots - Icewalker
	AddSpell( "professions", "ENCHANTING", 60653, nil, 395, 0, nil, 100000, nil ) -- Enchant Shield - Greater Intellect
	AddSpell( "professions", "ENCHANTING", 60663, nil, 420, 0, nil, 150000, nil ) -- Enchant Cloak - Major Agility
	AddSpell( "professions", "ENCHANTING", 60668, nil, 425, 0, nil, 150000, nil ) -- Enchant Gloves - Crusher
	AddSpell( "professions", "ENCHANTING", 62959, nil, 385, 0, nil, 90000, nil ) -- Enchant Staff - Spellpower
	AddSpell( "professions", "ENCHANTING", 63746, nil, 225, 0, nil, 5000, nil ) -- Enchant Boots - Lesser Accuracy
	AddSpell( "professions", "ENCHANTING", 69412, nil, 445, 0, nil, 150000, nil ) -- Abyssal Shatter
	AddSpell( "professions", "ENCHANTING", 74132, nil, 425, 0, nil, 30000, nil ) -- Enchant Gloves - Mastery
	AddSpell( "professions", "ENCHANTING", 74189, nil, 425, 0, nil, 30000, nil ) -- Enchant Boots - Earthen Vitality
	AddSpell( "professions", "ENCHANTING", 74191, nil, 425, 0, nil, 30000, nil ) -- Enchant Chest - Mighty Stats
	AddSpell( "professions", "ENCHANTING", 74192, nil, 435, 0, nil, 30000, nil ) -- Enchant Cloak - Greater Spell Piercing
	AddSpell( "professions", "ENCHANTING", 74193, nil, 435, 0, nil, 30000, nil ) -- Enchant Bracer - Speed
	AddSpell( "professions", "ENCHANTING", 74195, nil, 450, 0, nil, 30000, nil ) -- Enchant Weapon - Mending
	AddSpell( "professions", "ENCHANTING", 74197, nil, 450, 0, nil, 30000, nil ) -- Enchant Weapon - Avalanche
	AddSpell( "professions", "ENCHANTING", 74198, nil, 455, 0, nil, 30000, nil ) -- Enchant Gloves - Haste
	AddSpell( "professions", "ENCHANTING", 74199, nil, 455, 0, nil, 30000, nil ) -- Enchant Boots - Haste
	AddSpell( "professions", "ENCHANTING", 74200, nil, 460, 0, nil, 30000, nil ) -- Enchant Chest - Stamina
	AddSpell( "professions", "ENCHANTING", 74201, nil, 460, 0, nil, 30000, nil ) -- Enchant Bracer - Critical Strike
	AddSpell( "professions", "ENCHANTING", 74202, nil, 465, 0, nil, 30000, nil ) -- Enchant Cloak - Intellect
	AddSpell( "professions", "ENCHANTING", 74207, nil, 465, 0, nil, 30000, nil ) -- Enchant Shield - Protection
	AddSpell( "professions", "ENCHANTING", 74211, nil, 470, 0, nil, 30000, nil ) -- Enchant Weapon - Elemental Slayer
	AddSpell( "professions", "ENCHANTING", 74212, nil, 470, 0, nil, 30000, nil ) -- Enchant Gloves - Exceptional Strength
	AddSpell( "professions", "ENCHANTING", 74213, nil, 475, 0, nil, 30000, nil ) -- Enchant Boots - Major Agility
	AddSpell( "professions", "ENCHANTING", 74214, nil, 475, 0, nil, 30000, nil ) -- Enchant Chest - Mighty Resilience
	AddSpell( "professions", "ENCHANTING", 74215, nil, 475, 0, nil, 30000, nil ) -- Enchant Ring - Strength
	AddSpell( "professions", "ENCHANTING", 74216, nil, 475, 0, nil, 30000, nil ) -- Enchant Ring - Agility
	AddSpell( "professions", "ENCHANTING", 74217, nil, 475, 0, nil, 30000, nil ) -- Enchant Ring - Intellect
	AddSpell( "professions", "ENCHANTING", 74218, nil, 475, 0, nil, 30000, nil ) -- Enchant Ring - Greater Stamina
	AddSpell( "professions", "ENCHANTING", 74220, nil, 480, 0, nil, 30000, nil ) -- Enchant Gloves - Greater Expertise
	AddSpell( "professions", "ENCHANTING", 74223, nil, 480, 0, nil, 30000, nil ) -- Enchant Weapon - Hurricane
	AddSpell( "professions", "ENCHANTING", 74225, nil, 485, 0, nil, 30000, nil ) -- Enchant Weapon - Heartsong
	AddSpell( "professions", "ENCHANTING", 74226, nil, 485, 0, nil, 30000, nil ) -- Enchant Shield - Mastery
	AddSpell( "professions", "ENCHANTING", 74229, nil, 490, 0, nil, 30000, nil ) -- Enchant Bracer - Dodge
	AddSpell( "professions", "ENCHANTING", 74230, nil, 490, 0, nil, 30000, nil ) -- Enchant Cloak - Critical Strike
	AddSpell( "professions", "ENCHANTING", 74231, nil, 495, 0, nil, 30000, nil ) -- Enchant Chest - Exceptional Spirit
	AddSpell( "professions", "ENCHANTING", 74232, nil, 495, 0, nil, 30000, nil ) -- Enchant Bracer - Precision
	AddSpell( "professions", "ENCHANTING", 74234, nil, 500, 0, nil, 30000, nil ) -- Enchant Cloak - Protection
	AddSpell( "professions", "ENCHANTING", 74235, nil, 500, 0, nil, 30000, nil ) -- Enchant Off-Hand - Superior Intellect
	AddSpell( "professions", "ENCHANTING", 74236, nil, 505, 0, nil, 30000, nil ) -- Enchant Boots - Precision
	AddSpell( "professions", "ENCHANTING", 74237, nil, 505, 0, nil, 30000, nil ) -- Enchant Bracer - Exceptional Spirit
	AddSpell( "professions", "ENCHANTING", 74238, nil, 510, 0, nil, 30000, nil ) -- Enchant Boots - Mastery
	AddSpell( "professions", "ENCHANTING", 74239, nil, 510, 0, nil, 30000, nil ) -- Enchant Bracer - Greater Expertise
	AddSpell( "professions", "ENCHANTING", 74240, nil, 510, 0, nil, 30000, nil ) -- Enchant Cloak - Greater Intellect
	AddSpell( "professions", "ENCHANTING", 74258, 75, 425, 0, nil, 500000, nil ) -- Illustrious Grand Master Enchanter
	AddSpell( "professions", "ENCHANTING", 95471, nil, 470, 0, nil, 30000, nil ) -- Enchant 2H Weapon - Mighty Agility
	AddSpell( "professions", "ENGINEERING",  3922, nil, 30, 0, nil, 115, "Interface\\Icons\\INV_Misc_Gear_06" ) -- Handful of Copper Bolts
	AddSpell( "professions", "ENGINEERING",  3923, nil, 30, 0, nil, 130, "Interface\\Icons\\INV_Misc_Bomb_09" ) -- Rough Copper Bomb
	AddSpell( "professions", "ENGINEERING",  3924, nil, 50, 0, nil, 150, "Interface\\Icons\\INV_Gizmo_Pipe_02" ) -- Copper Tube
	AddSpell( "professions", "ENGINEERING",  3925, nil, 50, 0, nil, 150, "Interface\\Icons\\INV_Weapon_Rifle_03" ) -- Rough Boomstick
	AddSpell( "professions", "ENGINEERING",  3926, nil, 65, 0, nil, 225, "Interface\\Icons\\INV_Gizmo_03" ) -- Copper Modulator
	AddSpell( "professions", "ENGINEERING",  3929, nil, 75, 0, nil, 250, "Interface\\Icons\\INV_Misc_Dust_02" ) -- Coarse Blasting Powder
	AddSpell( "professions", "ENGINEERING",  3931, nil, 75, 0, nil, 250, "Interface\\Icons\\INV_Misc_Bomb_06" ) -- Coarse Dynamite
	AddSpell( "professions", "ENGINEERING",  3932, nil, 85, 0, nil, 300, "Interface\\Icons\\INV_Crate_06" ) -- Target Dummy
	AddSpell( "professions", "ENGINEERING",  3934, nil, 100, 0, nil, 400, "Interface\\Icons\\INV_Helmet_47" ) -- Flying Tiger Goggles
	AddSpell( "professions", "ENGINEERING",  3936, nil, 105, 0, nil, 420, "Interface\\Icons\\INV_Weapon_Rifle_07" ) -- Deadly Blunderbuss
	AddSpell( "professions", "ENGINEERING",  3937, nil, 105, 0, nil, 450, "Interface\\Icons\\INV_Misc_Bomb_01" ) -- Large Copper Bomb
	AddSpell( "professions", "ENGINEERING",  3938, nil, 105, 0, nil, 450, "Interface\\Icons\\INV_Gizmo_Pipe_01" ) -- Bronze Tube
	AddSpell( "professions", "ENGINEERING",  3939, nil, 120, 0, nil, 500, "Interface\\Icons\\INV_Weapon_Rifle_07" ) -- Lovingly Crafted Boomstick
	AddSpell( "professions", "ENGINEERING",  3941, nil, 120, 0, nil, 500, "Interface\\Icons\\INV_Misc_Bomb_09" ) -- Small Bronze Bomb
	AddSpell( "professions", "ENGINEERING",  3942, nil, 125, 0, nil, 500, "Interface\\Icons\\INV_Gizmo_02" ) -- Whirring Bronze Gizmo
	AddSpell( "professions", "ENGINEERING",  3945, nil, 125, 0, nil, 500, "Interface\\Icons\\INV_Misc_Dust_06" ) -- Heavy Blasting Powder
	AddSpell( "professions", "ENGINEERING",  3946, nil, 125, 0, nil, 500, "Interface\\Icons\\INV_Misc_Bomb_06" ) -- Heavy Dynamite
	AddSpell( "professions", "ENGINEERING",  3949, nil, 130, 0, nil, 550, "Interface\\Icons\\INV_Weapon_Rifle_07" ) -- Silver-plated Shotgun
	AddSpell( "professions", "ENGINEERING",  3950, nil, 140, 0, nil, 600, "Interface\\Icons\\INV_Misc_Bomb_05" ) -- Big Bronze Bomb
	AddSpell( "professions", "ENGINEERING",  3953, nil, 145, 0, nil, 600, "Interface\\Icons\\INV_Gizmo_BronzeFramework_01" ) -- Bronze Framework
	AddSpell( "professions", "ENGINEERING",  3955, nil, 150, 0, nil, 750, "Interface\\Icons\\Spell_Nature_Polymorph" ) -- Explosive Sheep
	AddSpell( "professions", "ENGINEERING",  3956, nil, 150, 0, nil, 750, "Interface\\Icons\\INV_Helmet_47" ) -- Green Tinted Goggles
	AddSpell( "professions", "ENGINEERING",  3958, nil, 160, 0, nil, 800, "Interface\\Icons\\INV_Spear_05" ) -- Iron Strut
	AddSpell( "professions", "ENGINEERING",  3961, nil, 170, 0, nil, 900, "Interface\\Icons\\INV_Misc_PocketWatch_02" ) -- Gyrochronatom
	AddSpell( "professions", "ENGINEERING",  3962, nil, 175, 0, nil, 1000, "Interface\\Icons\\INV_Misc_Bomb_08" ) -- Iron Grenade
	AddSpell( "professions", "ENGINEERING",  3963, nil, 175, 0, nil, 1000, "Interface\\Icons\\INV_Helmet_08" ) -- Compact Harvest Reaper Kit
	AddSpell( "professions", "ENGINEERING",  3965, nil, 185, 0, nil, 1200, "Interface\\Icons\\INV_Crate_05" ) -- Advanced Target Dummy
	AddSpell( "professions", "ENGINEERING",  3967, nil, 190, 0, nil, 1400, "Interface\\Icons\\INV_Misc_Bomb_01" ) -- Big Iron Bomb
	AddSpell( "professions", "ENGINEERING",  3973, nil, 90, 0, nil, 300, "Interface\\Icons\\INV_Ingot_04" ) -- Silver Contact
	AddSpell( "professions", "ENGINEERING",  3977, nil, 60, 0, nil, 200, "Interface\\Icons\\INV_Misc_Spyglass_02" ) -- Crude Scope
	AddSpell( "professions", "ENGINEERING",  3978, nil, 110, 0, nil, 475, "Interface\\Icons\\INV_Misc_Spyglass_02" ) -- Standard Scope
	AddSpell( "professions", "ENGINEERING",  4036, 5, nil, 0, nil, 10, nil ) -- Apprentice Engineer
	AddSpell( "professions", "ENGINEERING",  4037, 10, 50, 0, nil, 500, nil ) -- Journeyman Engineer
	AddSpell( "professions", "ENGINEERING",  4038, 20, 125, 0, nil, 5000, nil ) -- Expert Engineer
	AddSpell( "professions", "ENGINEERING",  6458, nil, 135, 0, nil, 400, "Interface\\Icons\\INV_Misc_Spyglass_01" ) -- Ornate Spyglass
	AddSpell( "professions", "ENGINEERING",  7430, nil, 50, 0, nil, 150, "Interface\\Icons\\INV_Misc_Wrench_01" ) -- Arclight Spanner
	AddSpell( "professions", "ENGINEERING",  8334, nil, 100, 0, nil, 300, "Interface\\Icons\\INV_Box_01" ) -- Practice Lock
	AddSpell( "professions", "ENGINEERING",  8895, nil, 225, 1, 20222, 2200, "Interface\\Icons\\INV_Gizmo_RocketBoot_01" ) -- Goblin Rocket Boots
	AddSpell( "professions", "ENGINEERING",  9271, nil, 150, 0, nil, 500, "Interface\\Icons\\INV_Misc_Food_26" ) -- Aquadynamic Fish Attractor
	AddSpell( "professions", "ENGINEERING", 12584, nil, 150, 0, nil, 1000, "Interface\\Icons\\INV_Battery_02" ) -- Gold Power Core
	AddSpell( "professions", "ENGINEERING", 12585, nil, 175, 0, nil, 1000, "Interface\\Icons\\INV_Misc_Powder_Black" ) -- Solid Blasting Powder
	AddSpell( "professions", "ENGINEERING", 12586, nil, 175, 0, nil, 1000, "Interface\\Icons\\INV_Misc_Bomb_06" ) -- Solid Dynamite
	AddSpell( "professions", "ENGINEERING", 12589, nil, 195, 0, nil, 1300, "Interface\\Icons\\INV_Musket_01" ) -- Mithril Tube
	AddSpell( "professions", "ENGINEERING", 12590, nil, 175, 0, nil, 1000, "Interface\\Icons\\INV_Misc_ScrewDriver_02" ) -- Gyromatic Micro-Adjustor
	AddSpell( "professions", "ENGINEERING", 12591, nil, 200, 0, nil, 1500, "Interface\\Icons\\INV_Battery_01" ) -- Unstable Trigger
	AddSpell( "professions", "ENGINEERING", 12594, nil, 205, 0, nil, 1600, "Interface\\Icons\\INV_Helmet_47" ) -- Fire Goggles
	AddSpell( "professions", "ENGINEERING", 12595, nil, 205, 0, nil, 1600, "Interface\\Icons\\INV_Weapon_Rifle_07" ) -- Mithril Blunderbuss
	AddSpell( "professions", "ENGINEERING", 12599, nil, 215, 0, nil, 1800, "Interface\\Icons\\INV_Gizmo_MithrilCasing_01" ) -- Mithril Casing
	AddSpell( "professions", "ENGINEERING", 12603, nil, 215, 0, nil, 1800, "Interface\\Icons\\INV_Misc_Bomb_02" ) -- Mithril Frag Bomb
	AddSpell( "professions", "ENGINEERING", 12615, nil, 225, 0, nil, 2500, "Interface\\Icons\\INV_Helmet_47" ) -- Spellpower Goggles Xtreme
	AddSpell( "professions", "ENGINEERING", 12617, nil, 230, 0, nil, 2200, "Interface\\Icons\\INV_Helmet_49" ) -- Deepdive Helmet
	AddSpell( "professions", "ENGINEERING", 12618, nil, 230, 0, nil, 2200, "Interface\\Icons\\INV_Helmet_47" ) -- Rose Colored Goggles
	AddSpell( "professions", "ENGINEERING", 12619, nil, 235, 0, nil, 2400, "Interface\\Icons\\INV_Misc_Bomb_07" ) -- Hi-Explosive Bomb
	AddSpell( "professions", "ENGINEERING", 12622, nil, 245, 0, nil, 2800, "Interface\\Icons\\INV_Helmet_44" ) -- Green Lens
	AddSpell( "professions", "ENGINEERING", 12656, 35, 200, 0, nil, 50000, nil ) -- Artisan Engineer
	AddSpell( "professions", "ENGINEERING", 12715, nil, 205, 1, 20222, 1000, "Interface\\Icons\\INV_Scroll_03" ) -- Goblin Rocket Fuel Recipe
	AddSpell( "professions", "ENGINEERING", 12716, nil, 205, 1, 20222, 1500, nil ) -- Goblin Mortar
	AddSpell( "professions", "ENGINEERING", 12717, nil, 205, 1, 20222, 1500, "Interface\\Icons\\INV_Helmet_25" ) -- Goblin Mining Helmet
	AddSpell( "professions", "ENGINEERING", 12718, nil, 205, 1, 20222, 1500, "Interface\\Icons\\INV_Helmet_60" ) -- Goblin Construction Helmet
	AddSpell( "professions", "ENGINEERING", 12754, nil, 235, 1, 20222, 2600, "Interface\\Icons\\INV_Misc_Bomb_04" ) -- The Big One
	AddSpell( "professions", "ENGINEERING", 12755, nil, 230, 1, 20222, 2400, "Interface\\Icons\\INV_Gizmo_06" ) -- Goblin Bomb Dispenser
	AddSpell( "professions", "ENGINEERING", 12758, nil, 245, 1, 20222, 3000, "Interface\\Icons\\INV_Helmet_49" ) -- Goblin Rocket Helmet
	AddSpell( "professions", "ENGINEERING", 12759, nil, 240, 1, 20219, 2800, "Interface\\Icons\\INV_Gizmo_08" ) -- Gnomish Death Ray
	AddSpell( "professions", "ENGINEERING", 12760, nil, 205, 1, 20222, 1500, "Interface\\Icons\\Spell_Fire_SelfDestruct" ) -- Goblin Sapper Charge
	AddSpell( "professions", "ENGINEERING", 12895, nil, 205, 1, 20219, 1500, "Interface\\Icons\\INV_Scroll_05" ) -- Inlaid Mithril Cylinder Plans
	AddSpell( "professions", "ENGINEERING", 12897, nil, 215, 1, 20219, 2200, "Interface\\Icons\\INV_Helmet_47" ) -- Gnomish Goggles
	AddSpell( "professions", "ENGINEERING", 12899, nil, 205, 1, 20219, 1500, "Interface\\Icons\\INV_Gizmo_09" ) -- Gnomish Shrink Ray
	AddSpell( "professions", "ENGINEERING", 12902, nil, 210, 1, 20219, 1800, "Interface\\Icons\\INV_Misc_Net_01" ) -- Gnomish Net-o-Matic Projector
	AddSpell( "professions", "ENGINEERING", 12903, nil, 215, 1, 20219, 2000, "Interface\\Icons\\INV_Belt_06" ) -- Gnomish Harm Prevention Belt
	AddSpell( "professions", "ENGINEERING", 12905, nil, 210, 1, 20219, 1500, "Interface\\Icons\\INV_Boots_02" ) -- Gnomish Rocket Boots
	AddSpell( "professions", "ENGINEERING", 12906, nil, 230, 1, 20219, 2400, "Interface\\Icons\\Spell_Magic_PolymorphChicken" ) -- Gnomish Battle Chicken
	AddSpell( "professions", "ENGINEERING", 12907, nil, 235, 1, 20219, 2600, "Interface\\Icons\\INV_Helmet_49" ) -- Gnomish Mind Control Cap
	AddSpell( "professions", "ENGINEERING", 12908, nil, 240, 1, 20222, 2800, "Interface\\Icons\\Spell_Fire_FlameBolt" ) -- Goblin Dragon Gun
	AddSpell( "professions", "ENGINEERING", 15255, nil, 200, 0, nil, 1500, "Interface\\Icons\\INV_Gizmo_03" ) -- Mechanical Repair Kit
	AddSpell( "professions", "ENGINEERING", 19567, nil, 250, 0, nil, 4000, "Interface\\Icons\\INV_Egg_05" ) -- Salt Shaker
	AddSpell( "professions", "ENGINEERING", 19788, nil, 250, 0, nil, 4000, "Interface\\Icons\\INV_Misc_Ammo_Gunpowder_01" ) -- Dense Blasting Powder
	AddSpell( "professions", "ENGINEERING", 19790, nil, 260, 0, nil, 10000, "Interface\\Icons\\INV_Misc_Bomb_08" ) -- Thorium Grenade
	AddSpell( "professions", "ENGINEERING", 19791, nil, 260, 0, nil, 5000, "Interface\\Icons\\INV_Gizmo_04" ) -- Thorium Widget
	AddSpell( "professions", "ENGINEERING", 19792, nil, 260, 0, nil, 10000, "Interface\\Icons\\INV_Weapon_Rifle_07" ) -- Thorium Rifle
	AddSpell( "professions", "ENGINEERING", 19794, nil, 270, 0, nil, 20000, "Interface\\Icons\\INV_Helmet_47" ) -- Spellpower Goggles Xtreme Plus
	AddSpell( "professions", "ENGINEERING", 19795, nil, 275, 0, nil, 10000, "Interface\\Icons\\INV_Gizmo_Pipe_04" ) -- Thorium Tube
	AddSpell( "professions", "ENGINEERING", 19825, nil, 290, 0, nil, 20000, "Interface\\Icons\\INV_Helmet_47" ) -- Master Engineer's Goggles
	AddSpell( "professions", "ENGINEERING", 23070, nil, 250, 0, nil, 5000, "Interface\\Icons\\INV_Misc_Bomb_06" ) -- Dense Dynamite
	AddSpell( "professions", "ENGINEERING", 23071, nil, 260, 0, nil, 5000, "Interface\\Icons\\INV_Staff_18" ) -- Truesilver Transformer
	AddSpell( "professions", "ENGINEERING", 30303, nil, 300, 0, nil, 10000, "Interface\\Icons\\Inv_Misc_ammo_Gunpowder_07" ) -- Elemental Blasting Powder
	AddSpell( "professions", "ENGINEERING", 30304, nil, 300, 0, nil, 10000, "Interface\\Icons\\INV_Gizmo_FelIronCasing" ) -- Fel Iron Casing
	AddSpell( "professions", "ENGINEERING", 30305, nil, 300, 0, nil, 10000, "Interface\\Icons\\INV_Gizmo_FelIronBolts" ) -- Handful of Fel Iron Bolts
	AddSpell( "professions", "ENGINEERING", 30306, nil, 325, 0, nil, 20000, "Interface\\Icons\\INV_Gizmo_AdamantiteFrame" ) -- Adamantite Frame
	AddSpell( "professions", "ENGINEERING", 30307, nil, 340, 0, nil, 50000, "Interface\\Icons\\INV_Gizmo_HardenedAdamantiteTube" ) -- Hardened Adamantite Tube
	AddSpell( "professions", "ENGINEERING", 30308, nil, 340, 0, nil, 50000, "Interface\\Icons\\INV_Gizmo_KhoriumPowerCore" ) -- Khorium Power Core
	AddSpell( "professions", "ENGINEERING", 30309, nil, 340, 0, nil, 50000, "Interface\\Icons\\INV_Gizmo_FelStabilizer" ) -- Felsteel Stabilizer
	AddSpell( "professions", "ENGINEERING", 30310, nil, 300, 0, nil, 15000, "Interface\\Icons\\INV_Gizmo_FelIronBomb" ) -- Fel Iron Bomb
	AddSpell( "professions", "ENGINEERING", 30311, nil, 325, 0, nil, 25000, "Interface\\Icons\\INV_Misc_Bomb_08" ) -- Adamantite Grenade
	AddSpell( "professions", "ENGINEERING", 30312, nil, 320, 0, nil, 20000, "Interface\\Icons\\INV_Weapon_Rifle_04" ) -- Fel Iron Musket
	AddSpell( "professions", "ENGINEERING", 30350, 50, 275, 0, nil, 100000, nil ) -- Master Engineer
	AddSpell( "professions", "ENGINEERING", 30558, nil, 325, 1, 20222, 25000, "Interface\\Icons\\INV_Gizmo_TheBiggerOne" ) -- The Bigger One
	AddSpell( "professions", "ENGINEERING", 30560, nil, 340, 1, 20222, 35000, "Interface\\Icons\\INV_Gizmo_SuperSapperCharge" ) -- Super Sapper Charge
	AddSpell( "professions", "ENGINEERING", 30563, nil, 350, 1, 20222, 50000, "Interface\\Icons\\INV_Gizmo_RocketLauncher" ) -- Goblin Rocket Launcher
	AddSpell( "professions", "ENGINEERING", 30565, nil, 375, 1, 20222, 100000, "Interface\\Icons\\INV_Helmet_60" ) -- Foreman's Enchanted Helmet
	AddSpell( "professions", "ENGINEERING", 30566, nil, 375, 1, 20222, 100000, "Interface\\Icons\\INV_Helmet_60" ) -- Foreman's Reinforced Helmet
	AddSpell( "professions", "ENGINEERING", 30568, nil, 325, 1, 20219, 25000, "Interface\\Icons\\INV_Gizmo_GnomishFlameTurret" ) -- Gnomish Flame Turret
	AddSpell( "professions", "ENGINEERING", 30569, nil, 340, 1, 20219, 35000, "Interface\\Icons\\INV_Misc_EngGizmos_06" ) -- Gnomish Poultryizer
	AddSpell( "professions", "ENGINEERING", 30570, nil, 350, 1, 20219, 50000, "Interface\\Icons\\INV_Belt_27" ) -- Nigh-Invulnerability Belt
	AddSpell( "professions", "ENGINEERING", 30574, nil, 375, 1, 20219, 100000, "Interface\\Icons\\INV_Helmet_47" ) -- Gnomish Power Goggles
	AddSpell( "professions", "ENGINEERING", 30575, nil, 375, 1, 20219, 100000, "Interface\\Icons\\INV_Gizmo_NewGoggles" ) -- Gnomish Battle Goggles
	AddSpell( "professions", "ENGINEERING", 39971, nil, 335, 0, nil, 20000, "Interface\\Icons\\INV_Misc_EngGizmos_15" ) -- Icy Blasting Primers
	AddSpell( "professions", "ENGINEERING", 39973, nil, 335, 0, nil, 50000, "Interface\\Icons\\INV_Misc_EngGizmos_31" ) -- Frost Grenade
	AddSpell( "professions", "ENGINEERING", 40274, nil, 350, 0, nil, 45000, "Interface\\Icons\\INV_Gizmo_NewGoggles" ) -- Furious Gizmatic Goggles
	AddSpell( "professions", "ENGINEERING", 41307, nil, 375, 0, nil, 50000, "Interface\\Icons\\INV_Weapon_Rifle_13" ) -- Gyro-balanced Khorium Destroyer
	AddSpell( "professions", "ENGINEERING", 41311, nil, 350, 0, nil, 50000, "Interface\\Icons\\INV_Gizmo_NewGoggles" ) -- Justicebringer 2000 Specs
	AddSpell( "professions", "ENGINEERING", 41312, nil, 350, 0, nil, 45000, "Interface\\Icons\\INV_Gizmo_NewGoggles" ) -- Tankatronic Goggles
	AddSpell( "professions", "ENGINEERING", 41314, nil, 350, 0, nil, 50000, "Interface\\Icons\\INV_Gizmo_NewGoggles" ) -- Surestrike Goggles v2.0
	AddSpell( "professions", "ENGINEERING", 41315, nil, 350, 0, nil, 50000, "Interface\\Icons\\INV_Gizmo_NewGoggles" ) -- Gadgetstorm Goggles
	AddSpell( "professions", "ENGINEERING", 41316, nil, 350, 0, nil, 50000, "Interface\\Icons\\INV_Gizmo_NewGoggles" ) -- Living Replicator Specs
	AddSpell( "professions", "ENGINEERING", 41317, nil, 350, 0, nil, 50000, "Interface\\Icons\\INV_Gizmo_NewGoggles" ) -- Deathblow X11 Goggles
	AddSpell( "professions", "ENGINEERING", 41318, nil, 350, 0, nil, 50000, "Interface\\Icons\\INV_Gizmo_NewGoggles" ) -- Wonderheal XT40 Shades
	AddSpell( "professions", "ENGINEERING", 41319, nil, 350, 0, nil, 50000, "Interface\\Icons\\INV_Gizmo_NewGoggles" ) -- Magnified Moon Specs
	AddSpell( "professions", "ENGINEERING", 41320, nil, 350, 0, nil, 50000, "Interface\\Icons\\INV_Gizmo_NewGoggles" ) -- Destruction Holo-gogs
	AddSpell( "professions", "ENGINEERING", 41321, nil, 350, 0, nil, 50000, "Interface\\Icons\\INV_Gizmo_NewGoggles" ) -- Powerheal 4000 Lens
	AddSpell( "professions", "ENGINEERING", 44155, nil, 300, 0, nil, 60000, "Interface\\Icons\\Ability_Mount_Gyrocoptor" ) -- Flying Machine
	AddSpell( "professions", "ENGINEERING", 44157, 70, 375, 0, nil, 180000, "Interface\\Icons\\Ability_Mount_GyrocoptorElite" ) -- Turbo-Charged Flying Machine
	AddSpell( "professions", "ENGINEERING", 51306, 65, 350, 0, nil, 350000, nil ) -- Grand Master Engineer
	AddSpell( "professions", "ENGINEERING", 53281, nil, 350, 0, nil, 50000, "Interface\\Icons\\INV_Misc_EngGizmos_04" ) -- Volatile Blasting Trigger
	AddSpell( "professions", "ENGINEERING", 54353, nil, 400, 0, nil, 125000, "Interface\\Icons\\INV_Weapon_Rifle_08" ) -- Mark \"S\" Boomstick
	AddSpell( "professions", "ENGINEERING", 54736, nil, 390, 0, nil, 100000, nil ) -- Personal Electromagnetic Pulse Generator
	AddSpell( "professions", "ENGINEERING", 54793, nil, 380, 0, nil, 100000, nil ) -- Frag Belt
	AddSpell( "professions", "ENGINEERING", 54998, nil, 400, 0, nil, 125000, nil ) -- Hand-Mounted Pyro Rocket
	AddSpell( "professions", "ENGINEERING", 54999, nil, 400, 0, nil, 125000, nil ) -- Hyperspeed Accelerators
	AddSpell( "professions", "ENGINEERING", 55002, nil, 380, 0, nil, 100000, nil ) -- Flexweave Underlay
	AddSpell( "professions", "ENGINEERING", 55016, nil, 405, 0, nil, 125000, nil ) -- Nitro Boosts
	AddSpell( "professions", "ENGINEERING", 56349, nil, 350, 0, nil, 50000, "Interface\\Icons\\INV_Misc_EngGizmos_29" ) -- Handful of Cobalt Bolts
	AddSpell( "professions", "ENGINEERING", 56459, nil, 375, 0, nil, 100000, "Interface\\Icons\\INV_Pick_05" ) -- Hammer Pick
	AddSpell( "professions", "ENGINEERING", 56460, nil, 350, 0, nil, 50000, "Interface\\Icons\\INV_Misc_EngGizmos_31" ) -- Cobalt Frag Bomb
	AddSpell( "professions", "ENGINEERING", 56461, nil, 375, 0, nil, 100000, "Interface\\Icons\\INV_Pick_03" ) -- Bladed Pickaxe
	AddSpell( "professions", "ENGINEERING", 56462, nil, 435, 0, nil, 150000, "Interface\\Icons\\INV_Misc_EngGizmos_swissArmy" ) -- Gnomish Army Knife
	AddSpell( "professions", "ENGINEERING", 56463, nil, 375, 0, nil, 100000, "Interface\\Icons\\ABILITY_SEAL" ) -- Explosive Decoy
	AddSpell( "professions", "ENGINEERING", 56464, nil, 375, 0, nil, 100000, "Interface\\Icons\\INV_Misc_EngGizmos_27" ) -- Overcharged Capacitor
	AddSpell( "professions", "ENGINEERING", 56465, nil, 420, 0, nil, 125000, "Interface\\Icons\\INV_Gizmo_NewGoggles" ) -- Mechanized Snow Goggles
	AddSpell( "professions", "ENGINEERING", 56466, nil, 420, 0, nil, 125000, "Interface\\Icons\\INV_Gizmo_GoblinBoomBox_01" ) -- Sonic Booster
	AddSpell( "professions", "ENGINEERING", 56467, nil, 420, 0, nil, 125000, "Interface\\Icons\\INV_Gizmo_GoblinBoomBox_01" ) -- Noise Machine
	AddSpell( "professions", "ENGINEERING", 56468, nil, 405, 0, nil, 125000, "Interface\\Icons\\INV_Crate_01" ) -- Box of Bombs
	AddSpell( "professions", "ENGINEERING", 56469, nil, 425, 0, nil, 150000, "Interface\\Icons\\Spell_Nature_LightningOverload" ) -- Gnomish Lightning Generator
	AddSpell( "professions", "ENGINEERING", 56470, nil, 425, 0, nil, 150000, "Interface\\Icons\\INV_Misc_Spyglass_03" ) -- Sun Scope
	AddSpell( "professions", "ENGINEERING", 56471, nil, 390, 0, nil, 100000, "Interface\\Icons\\INV_Misc_EngGizmos_28" ) -- Froststeel Tube
	AddSpell( "professions", "ENGINEERING", 56472, nil, 425, 0, nil, 150000, "Interface\\Icons\\inv_misc_molle" ) -- MOLL-E
	AddSpell( "professions", "ENGINEERING", 56473, nil, 425, 1, 20219, 150000, "Interface\\Icons\\INV_Helmet_44" ) -- Gnomish X-Ray Specs
	AddSpell( "professions", "ENGINEERING", 56476, nil, 410, 0, nil, 125000, "Interface\\Icons\\INV_Gizmo_05" ) -- Healing Injector Kit
	AddSpell( "professions", "ENGINEERING", 56477, nil, 415, 0, nil, 125000, "Interface\\Icons\\INV_Gizmo_04" ) -- Mana Injector Kit
	AddSpell( "professions", "ENGINEERING", 56478, nil, 430, 0, nil, 200000, "Interface\\Icons\\INV_Misc_Spyglass_02" ) -- Heartseeker Scope
	AddSpell( "professions", "ENGINEERING", 56479, nil, 450, 0, nil, 200000, "Interface\\Icons\\INV_Weapon_Rifle_19" ) -- Armor Plated Combat Shotgun
	AddSpell( "professions", "ENGINEERING", 56480, nil, 440, 0, nil, 135000, "Interface\\Icons\\INV_Gizmo_NewGoggles" ) -- Armored Titanium Goggles
	AddSpell( "professions", "ENGINEERING", 56481, nil, 440, 0, nil, 150000, "Interface\\Icons\\INV_Gizmo_NewGoggles" ) -- Weakness Spectralizers
	AddSpell( "professions", "ENGINEERING", 56483, nil, 440, 0, nil, 135000, "Interface\\Icons\\INV_Gizmo_NewGoggles" ) -- Charged Titanium Specs
	AddSpell( "professions", "ENGINEERING", 56484, nil, 440, 0, nil, 150000, "Interface\\Icons\\INV_Gizmo_NewGoggles" ) -- Visage Liquification Goggles
	AddSpell( "professions", "ENGINEERING", 56486, nil, 440, 0, nil, 150000, "Interface\\Icons\\INV_Gizmo_NewGoggles" ) -- Greensight Gogs
	AddSpell( "professions", "ENGINEERING", 56487, nil, 440, 0, nil, 150000, "Interface\\Icons\\INV_Gizmo_NewGoggles" ) -- Electroflux Sight Enhancers
	AddSpell( "professions", "ENGINEERING", 56514, nil, 425, 1, 20222, 150000, "Interface\\Icons\\INV_Gizmo_SuperSapperCharge" ) -- Global Thermal Sapper Charge
	AddSpell( "professions", "ENGINEERING", 56574, nil, 440, 0, nil, 150000, "Interface\\Icons\\INV_Gizmo_NewGoggles" ) -- Truesight Ice Blinders
	AddSpell( "professions", "ENGINEERING", 60874, nil, 450, 0, nil, 200000, "Interface\\Icons\\INV_Weapon_Rifle_06" ) -- Nesingwary 4000
	AddSpell( "professions", "ENGINEERING", 61471, nil, 390, 0, nil, 100000, "Interface\\Icons\\Ability_Hunter_RapidRegeneration" ) -- Diamond-cut Refractor Scope
	AddSpell( "professions", "ENGINEERING", 61481, nil, 420, 0, nil, 125000, "Interface\\Icons\\INV_Gizmo_NewGoggles" ) -- Mechanized Snow Goggles
	AddSpell( "professions", "ENGINEERING", 61482, nil, 420, 0, nil, 125000, "Interface\\Icons\\INV_Gizmo_NewGoggles" ) -- Mechanized Snow Goggles
	AddSpell( "professions", "ENGINEERING", 61483, nil, 420, 0, nil, 112500, "Interface\\Icons\\INV_Gizmo_NewGoggles" ) -- Mechanized Snow Goggles
	AddSpell( "professions", "ENGINEERING", 62271, nil, 440, 0, nil, 150000, "Interface\\Icons\\INV_Gizmo_NewGoggles" ) -- Unbreakable Healing Amplifiers
	AddSpell( "professions", "ENGINEERING", 63750, nil, 250, 0, nil, 5000, "Interface\\Icons\\INV_Misc_Spyglass_03" ) -- High-powered Flashlight
	AddSpell( "professions", "ENGINEERING", 63765, nil, 380, 0, nil, 100000, nil ) -- Springy Arachnoweave
	AddSpell( "professions", "ENGINEERING", 63770, nil, 400, 0, nil, 125000, nil ) -- Reticulated Armor Webbing
	AddSpell( "professions", "ENGINEERING", 67326, nil, 410, 0, nil, 100000, "Interface\\Icons\\spell_nature_elementalprecision_1" ) -- Goblin Beam Welder
	AddSpell( "professions", "ENGINEERING", 67839, nil, 410, 0, nil, 100000, nil ) -- Mind Amplification Dish
	AddSpell( "professions", "ENGINEERING", 67920, nil, 435, 0, nil, 150000, "Interface\\Icons\\spell_fire_bluefirenova" ) -- Wormhole Generator: Northrend
	AddSpell( "professions", "ENGINEERING", 81714, nil, 525, 0, nil, 216000, "Interface\\Icons\\INV_Gizmo_NewGoggles" ) -- Reinforced Bio-Optic Killshades
	AddSpell( "professions", "ENGINEERING", 81715, nil, 525, 0, nil, 240000, "Interface\\Icons\\INV_Gizmo_NewGoggles" ) -- Specialized Bio-Optic Killshades
	AddSpell( "professions", "ENGINEERING", 81716, nil, 525, 0, nil, 240000, "Interface\\Icons\\INV_Gizmo_NewGoggles" ) -- Deadly Bio-Optic Killshades
	AddSpell( "professions", "ENGINEERING", 81720, nil, 525, 0, nil, 240000, "Interface\\Icons\\INV_Gizmo_NewGoggles" ) -- Energized Bio-Optic Killshades
	AddSpell( "professions", "ENGINEERING", 81722, nil, 525, 0, nil, 240000, "Interface\\Icons\\INV_Gizmo_NewGoggles" ) -- Agile Bio-Optic Killshades
	AddSpell( "professions", "ENGINEERING", 81725, nil, 525, 0, nil, 240000, "Interface\\Icons\\INV_Gizmo_NewGoggles" ) -- Lightweight Bio-Optic Killshades
	AddSpell( "professions", "ENGINEERING", 82774, 75, 425, 0, nil, 500000, nil ) -- Illustrious Grand Master Engineer
	AddSpell( "professions", "ENGINEERING", 84403, nil, 425, 0, nil, 150000, "Interface\\Icons\\inv_misc_enggizmos_33" ) -- Handful of Obsidium Bolts
	AddSpell( "professions", "ENGINEERING", 84406, nil, 440, 0, nil, 150000, "Interface\\Icons\\inv_helmet_47" ) -- Authentic Jr. Engineer Goggles
	AddSpell( "professions", "ENGINEERING", 84408, nil, 450, 0, nil, 150000, "Interface\\Icons\\inv_misc_scopec" ) -- R19 Threatfinder
	AddSpell( "professions", "ENGINEERING", 84409, nil, 455, 0, nil, 160000, "Interface\\Icons\\inv_misc_bomb_07" ) -- Volatile Seaforium Blastpack
	AddSpell( "professions", "ENGINEERING", 84410, nil, 450, 0, nil, 150000, "Interface\\Icons\\inv_misc_enggizmos_37" ) -- Safety Catch Removal Kit
	AddSpell( "professions", "ENGINEERING", 84411, nil, 465, 0, nil, 160000, "Interface\\Icons\\INV_Musket_02" ) -- High-Powered Bolt Gun
	AddSpell( "professions", "ENGINEERING", 84412, nil, 475, 1, 20222, 160000, "Interface\\Icons\\achievement_dungeon_ulduarraid_irongolem_01" ) -- Personal World Destroyer
	AddSpell( "professions", "ENGINEERING", 84413, nil, 475, 1, 20219, 160000, "Interface\\Icons\\inv_pet_deweaonizedmechcompanion" ) -- De-Weaponized Mechanical Companion
	AddSpell( "professions", "ENGINEERING", 84415, nil, 475, 0, nil, 170000, "Interface\\Icons\\inv_misc_enggizmos_39" ) -- Lure Master Tackle Box
	AddSpell( "professions", "ENGINEERING", 84416, nil, 475, 0, nil, 170000, "Interface\\Icons\\inv_misc_enggizmos_34" ) -- Elementium Toolbox
	AddSpell( "professions", "ENGINEERING", 84417, nil, 495, 0, nil, 170000, "Interface\\Icons\\inv_weapon_rifle_43" ) -- Volatile Thunderstick
	AddSpell( "professions", "ENGINEERING", 84418, nil, 475, 0, nil, 170000, "Interface\\Icons\\inv_misc_head_dragon_bronze" ) -- Elementium Dragonling
	AddSpell( "professions", "ENGINEERING", 84420, nil, 490, 0, nil, 170000, "Interface\\Icons\\inv_bow_2h_crossbow_cataclysm_b_02" ) -- Finely-Tuned Throat Needler
	AddSpell( "professions", "ENGINEERING", 84421, nil, 490, 0, nil, 170000, "Interface\\Icons\\ability_hunter_beastcall02" ) -- Loot-a-Rang
	AddSpell( "professions", "ENGINEERING", 84428, nil, 515, 0, nil, 200000, "Interface\\Icons\\inv_misc_scopea" ) -- Gnomish X-Ray Scope
	AddSpell( "professions", "ENGINEERING", 84429, nil, 505, 0, nil, 200000, "Interface\\Icons\\inv_gizmo_fuelcell" ) -- Goblin Barbecue
	AddSpell( "professions", "ENGINEERING", 84430, nil, 510, 0, nil, 200000, "Interface\\Icons\\spell_fire_flameblades" ) -- Heat-Treated Spinning Lure
	AddSpell( "professions", "ENGINEERING", 84431, nil, 525, 0, nil, 240000, "Interface\\Icons\\inv_weapon_bow_60" ) -- Overpowered Chicken Splitter
	AddSpell( "professions", "ENGINEERING", 84432, nil, 525, 0, nil, 240000, "Interface\\Icons\\inv_weapon_rifle_44" ) -- Kickback 5000
	AddSpell( "professions", "ENGINEERING", 94748, nil, 445, 0, nil, 150000, "Interface\\Icons\\inv_gizmo_electrifiedether" ) -- Electrified Ether
	AddSpell( "professions", "ENGINEERING", 95703, nil, 440, 0, nil, 150000, "Interface\\Icons\\inv_misc_enggizmos_35" ) -- Electrostatic Condenser
	AddSpell( "professions", "ENGINEERING", 95705, nil, 500, 1, 20219, 200000, "Interface\\Icons\\INV_Gizmo_03" ) -- Gnomish Gravity Well
	AddSpell( "professions", "ENGINEERING", 95707, nil, 500, 1, 20222, 200000, "Interface\\Icons\\inv_misc_enggizmos_38" ) -- Big Daddy
	AddSpell( "professions", "FIRSTAID",  3273, nil, nil, 0, nil, 100, nil ) -- Apprentice First Aid
	AddSpell( "professions", "FIRSTAID",  3274, nil, 50, 0, nil, 500, nil ) -- Journeyman First Aid
	AddSpell( "professions", "FIRSTAID",  3276, nil, 40, 0, nil, 100, "Interface\\Icons\\INV_Misc_Bandage_18" ) -- Heavy Linen Bandage
	AddSpell( "professions", "FIRSTAID",  3277, nil, 80, 0, nil, 250, "Interface\\Icons\\INV_Misc_Bandage_14" ) -- Wool Bandage
	AddSpell( "professions", "FIRSTAID",  3278, nil, 115, 0, nil, 1000, "Interface\\Icons\\INV_Misc_Bandage_17" ) -- Heavy Wool Bandage
	AddSpell( "professions", "FIRSTAID",  7924, nil, 125, 0, nil, 1000, nil ) -- Expert First Aid
	AddSpell( "professions", "FIRSTAID",  7928, nil, 150, 0, nil, 5000, "Interface\\Icons\\INV_Misc_Bandage_01" ) -- Silk Bandage
	AddSpell( "professions", "FIRSTAID",  7929, nil, 180, 0, nil, 5000, "Interface\\Icons\\INV_Misc_Bandage_02" ) -- Heavy Silk Bandage
	AddSpell( "professions", "FIRSTAID",  7934, nil, 80, 0, nil, 250, "Interface\\Icons\\INV_Misc_Slime_01" ) -- Anti-Venom
	AddSpell( "professions", "FIRSTAID", 10840, nil, 210, 0, nil, 10000, "Interface\\Icons\\INV_Misc_Bandage_19" ) -- Mageweave Bandage
	AddSpell( "professions", "FIRSTAID", 10841, nil, 240, 0, nil, 10000, "Interface\\Icons\\INV_Misc_Bandage_20" ) -- Heavy Mageweave Bandage
	AddSpell( "professions", "FIRSTAID", 10846, 35, 200, 0, nil, 25000, nil ) -- Artisan First Aid
	AddSpell( "professions", "FIRSTAID", 18629, nil, 260, 0, nil, 20000, "Interface\\Icons\\INV_Misc_Bandage_11" ) -- Runecloth Bandage
	AddSpell( "professions", "FIRSTAID", 18630, nil, 290, 0, nil, 20000, "Interface\\Icons\\INV_Misc_Bandage_12" ) -- Heavy Runecloth Bandage
	AddSpell( "professions", "FIRSTAID", 27028, 50, 275, 0, nil, 100000, nil ) -- Master First Aid
	AddSpell( "professions", "FIRSTAID", 27032, nil, 300, 0, nil, 20000, "Interface\\Icons\\INV_Misc_Bandage_Netherweave" ) -- Netherweave Bandage
	AddSpell( "professions", "FIRSTAID", 27033, nil, 330, 0, nil, 40000, "Interface\\Icons\\INV_Misc_Bandage_Netherweave_Heavy" ) -- Heavy Netherweave Bandage
	AddSpell( "professions", "FIRSTAID", 45542, 65, 350, 0, nil, 150000, nil ) -- Grand Master First Aid
	AddSpell( "professions", "FIRSTAID", 45545, nil, 350, 0, nil, 40000, "Interface\\Icons\\INV_Misc_Bandage_Frostweave" ) -- Frostweave Bandage
	AddSpell( "professions", "FIRSTAID", 45546, nil, 400, 0, nil, 60000, "Interface\\Icons\\INV_Misc_Bandage_Frostweave_Heavy" ) -- Heavy Frostweave Bandage
	AddSpell( "professions", "FIRSTAID", 74556, nil, 425, 0, nil, 60000, "Interface\\Icons\\INV_Misc_Bandage_16" ) -- Embersilk Bandage
	AddSpell( "professions", "FIRSTAID", 74557, nil, 475, 0, nil, 80000, "Interface\\Icons\\inv_emberweavebandage2" ) -- Heavy Embersilk Bandage
	AddSpell( "professions", "FIRSTAID", 74558, nil, 525, 0, nil, 15000, "Interface\\Icons\\inv_emberweavebandage1" ) -- Field Bandage: Dense Embersilk
	AddSpell( "professions", "FIRSTAID", 74559, 75, 425, 0, nil, 250000, nil ) -- Illustrious Grand Master First Aid
	AddSpell( "professions", "FIRSTAID", 88893, nil, 525, 1, 74558, 80000, "Interface\\Icons\\inv_emberweavebandage1" ) -- Dense Embersilk Bandage
	AddSpell( "professions", "FISHING",  7620, 5, nil, 0, nil, 100, nil ) -- Apprentice Fishing
	AddSpell( "professions", "FISHING",  7731, 1, 50, 0, nil, 500, nil ) -- Journeyman Fishing
	AddSpell( "professions", "FISHING",  7732, 1, 125, 0, nil, 10000, nil ) -- Expert Fishing
	AddSpell( "professions", "FISHING", 18248, 1, 200, 0, nil, 25000, nil ) -- Artisan Fishing
	AddSpell( "professions", "FISHING", 33095, 1, 275, 0, nil, 100000, nil ) -- Master Fishing
	AddSpell( "professions", "FISHING", 51294, 1, 350, 0, nil, 150000, nil ) -- Grand Master Fishing
	AddSpell( "professions", "FISHING", 88868, 1, 425, 0, nil, 500000, nil ) -- Illustrious Grand Master Fishing
	AddSpell( "professions", "HERBALISM",  2366, nil, nil, 0, nil, 10, "Interface\\Icons\\Trade_Herbalism" ) -- Apprentice Herbalist
	AddSpell( "professions", "HERBALISM",  2368, nil, 50, 0, nil, 500, "Interface\\Icons\\Trade_Herbalism" ) -- Journeyman Herbalist
	AddSpell( "professions", "HERBALISM",  3570, 10, 125, 0, nil, 5000, "Interface\\Icons\\Trade_Herbalism" ) -- Expert Herbalist
	AddSpell( "professions", "HERBALISM", 11993, 25, 200, 0, nil, 50000, "Interface\\Icons\\Trade_Herbalism" ) -- Artisan Herbalist
	AddSpell( "professions", "HERBALISM", 28695, 40, 275, 0, nil, 100000, "Interface\\Icons\\Trade_Herbalism" ) -- Master Herbalist
	AddSpell( "professions", "HERBALISM", 50300, 55, 350, 0, nil, 350000, "Interface\\Icons\\Trade_Herbalism" ) -- Grand Master Herbalist
	AddSpell( "professions", "HERBALISM", 74519, 75, 425, 0, nil, 500000, "Interface\\Icons\\Trade_Herbalism" ) -- Illustrious Grand Master Herbalist
	AddSpell( "professions", "INSCRIPTION", 45357, 5, nil, 0, nil, 10, nil ) -- Apprentice Scribe
	AddSpell( "professions", "INSCRIPTION", 45358, 10, 50, 0, nil, 500, nil ) -- Journeyman Scribe
	AddSpell( "professions", "INSCRIPTION", 45359, 20, 125, 0, nil, 5000, nil ) -- Expert Scribe
	AddSpell( "professions", "INSCRIPTION", 45360, 35, 200, 0, nil, 50000, nil ) -- Artisan Scribe
	AddSpell( "professions", "INSCRIPTION", 45361, 50, 275, 0, nil, 100000, nil ) -- Master Scribe
	AddSpell( "professions", "INSCRIPTION", 45363, 65, 350, 0, nil, 350000, nil ) -- Grand Master Scribe
	AddSpell( "professions", "INSCRIPTION", 48121, nil, 100, 0, nil, 400, "Interface\\Icons\\INV_Glyph_MajorDruid" ) -- Glyph of Entangling Roots
	AddSpell( "professions", "INSCRIPTION", 48247, nil, 85, 0, nil, 500, "Interface\\Icons\\INV_Misc_Ticket_Tarot_Furies" ) -- Mysterious Tarot
	AddSpell( "professions", "INSCRIPTION", 48248, nil, 35, 0, nil, 50, "Interface\\Icons\\INV_Scroll_15" ) -- Scroll of Recall
	AddSpell( "professions", "INSCRIPTION", 50598, nil, 75, 0, nil, 400, "Interface\\Icons\\INV_Scroll_01" ) -- Scroll of Intellect II
	AddSpell( "professions", "INSCRIPTION", 50599, nil, 165, 0, nil, 750, "Interface\\Icons\\INV_Scroll_01" ) -- Scroll of Intellect III
	AddSpell( "professions", "INSCRIPTION", 50600, nil, 215, 0, nil, 4500, "Interface\\Icons\\INV_Scroll_01" ) -- Scroll of Intellect IV
	AddSpell( "professions", "INSCRIPTION", 50601, nil, 260, 0, nil, 10000, "Interface\\Icons\\INV_Scroll_01" ) -- Scroll of Intellect V
	AddSpell( "professions", "INSCRIPTION", 50602, nil, 300, 0, nil, 20000, "Interface\\Icons\\INV_Scroll_01" ) -- Scroll of Intellect VI
	AddSpell( "professions", "INSCRIPTION", 50603, nil, 360, 0, nil, 50000, "Interface\\Icons\\INV_Scroll_01" ) -- Scroll of Intellect VII
	AddSpell( "professions", "INSCRIPTION", 50604, nil, 410, 0, nil, 60000, "Interface\\Icons\\INV_Scroll_01" ) -- Scroll of Intellect VIII
	AddSpell( "professions", "INSCRIPTION", 50605, nil, 75, 0, nil, 400, "Interface\\Icons\\INV_Scroll_01" ) -- Scroll of Spirit II
	AddSpell( "professions", "INSCRIPTION", 50606, nil, 160, 0, nil, 750, "Interface\\Icons\\INV_Scroll_01" ) -- Scroll of Spirit III
	AddSpell( "professions", "INSCRIPTION", 50607, nil, 210, 0, nil, 4500, "Interface\\Icons\\INV_Scroll_01" ) -- Scroll of Spirit IV
	AddSpell( "professions", "INSCRIPTION", 50608, nil, 255, 0, nil, 10000, "Interface\\Icons\\INV_Scroll_01" ) -- Scroll of Spirit V
	AddSpell( "professions", "INSCRIPTION", 50609, nil, 295, 0, nil, 20000, "Interface\\Icons\\INV_Scroll_01" ) -- Scroll of Spirit VI
	AddSpell( "professions", "INSCRIPTION", 50610, nil, 355, 0, nil, 50000, "Interface\\Icons\\INV_Scroll_01" ) -- Scroll of Spirit VII
	AddSpell( "professions", "INSCRIPTION", 50611, nil, 405, 0, nil, 60000, "Interface\\Icons\\INV_Scroll_01" ) -- Scroll of Spirit VIII
	AddSpell( "professions", "INSCRIPTION", 50612, nil, 75, 0, nil, 400, "Interface\\Icons\\INV_Scroll_07" ) -- Scroll of Stamina II
	AddSpell( "professions", "INSCRIPTION", 50614, nil, 155, 0, nil, 750, "Interface\\Icons\\INV_Scroll_07" ) -- Scroll of Stamina III
	AddSpell( "professions", "INSCRIPTION", 50616, nil, 205, 0, nil, 4500, "Interface\\Icons\\INV_Scroll_07" ) -- Scroll of Stamina IV
	AddSpell( "professions", "INSCRIPTION", 50617, nil, 250, 0, nil, 10000, "Interface\\Icons\\INV_Scroll_07" ) -- Scroll of Stamina V
	AddSpell( "professions", "INSCRIPTION", 50618, nil, 290, 0, nil, 20000, "Interface\\Icons\\INV_Scroll_07" ) -- Scroll of Stamina VI
	AddSpell( "professions", "INSCRIPTION", 50619, nil, 350, 0, nil, 50000, "Interface\\Icons\\INV_Scroll_07" ) -- Scroll of Stamina VII
	AddSpell( "professions", "INSCRIPTION", 50620, nil, 400, 0, nil, 60000, "Interface\\Icons\\INV_Scroll_07" ) -- Scroll of Stamina VIII
	AddSpell( "professions", "INSCRIPTION", 52739, nil, 35, 0, nil, 150, "Interface\\Icons\\INV_Inscription_ArmorScroll01" ) -- Enchanting Vellum
	AddSpell( "professions", "INSCRIPTION", 52843, nil, 35, 0, nil, 50, "Interface\\Icons\\INV_Inscription_InkWhite02" ) -- Moonglow Ink
	AddSpell( "professions", "INSCRIPTION", 53462, nil, 75, 0, nil, 300, "Interface\\Icons\\INV_Inscription_InkBlack01" ) -- Midnight Ink
	AddSpell( "professions", "INSCRIPTION", 56943, nil, 350, 0, nil, 30000, "Interface\\Icons\\INV_Glyph_MajorDruid" ) -- Glyph of Frenzied Regeneration
	AddSpell( "professions", "INSCRIPTION", 56945, nil, 115, 0, nil, 500, "Interface\\Icons\\INV_Glyph_MajorDruid" ) -- Glyph of Healing Touch
	AddSpell( "professions", "INSCRIPTION", 56948, nil, 150, 0, nil, 750, "Interface\\Icons\\inv_glyph_primedruid" ) -- Glyph of Insect Swarm
	AddSpell( "professions", "INSCRIPTION", 56951, nil, 130, 0, nil, 750, "Interface\\Icons\\inv_glyph_primedruid" ) -- Glyph of Moonfire
	AddSpell( "professions", "INSCRIPTION", 56952, nil, 310, 0, nil, 20000, "Interface\\Icons\\INV_Glyph_MajorDruid" ) -- Glyph of Pounce
	AddSpell( "professions", "INSCRIPTION", 56953, nil, 170, 0, nil, 1000, "Interface\\Icons\\INV_Glyph_MajorDruid" ) -- Glyph of Rebirth
	AddSpell( "professions", "INSCRIPTION", 56955, nil, 80, 0, nil, 300, "Interface\\Icons\\inv_glyph_primedruid" ) -- Glyph of Rejuvenation
	AddSpell( "professions", "INSCRIPTION", 56956, nil, 200, 0, nil, 3000, "Interface\\Icons\\inv_glyph_primedruid" ) -- Glyph of Rip
	AddSpell( "professions", "INSCRIPTION", 56957, nil, 260, 0, nil, 10000, "Interface\\Icons\\inv_glyph_primedruid" ) -- Glyph of Shred
	AddSpell( "professions", "INSCRIPTION", 56959, nil, 220, 0, nil, 4500, "Interface\\Icons\\inv_glyph_primedruid" ) -- Glyph of Starfire
	AddSpell( "professions", "INSCRIPTION", 56961, nil, 90, 0, nil, 400, "Interface\\Icons\\INV_Glyph_MajorDruid" ) -- Glyph of Maul
	AddSpell( "professions", "INSCRIPTION", 56963, nil, 85, 0, nil, 300, "Interface\\Icons\\inv_glyph_primedruid" ) -- Glyph of Wrath
	AddSpell( "professions", "INSCRIPTION", 56971, nil, 115, 0, nil, 500, "Interface\\Icons\\inv_glyph_primemage" ) -- Glyph of Arcane Missiles
	AddSpell( "professions", "INSCRIPTION", 56972, nil, 335, 0, nil, 30000, "Interface\\Icons\\INV_Glyph_MajorMage" ) -- Glyph of Arcane Power
	AddSpell( "professions", "INSCRIPTION", 56973, nil, 130, 0, nil, 750, "Interface\\Icons\\INV_Glyph_MajorMage" ) -- Glyph of Blink
	AddSpell( "professions", "INSCRIPTION", 56974, nil, 155, 0, nil, 750, "Interface\\Icons\\INV_Glyph_MajorMage" ) -- Glyph of Evocation
	AddSpell( "professions", "INSCRIPTION", 56976, nil, 80, 0, nil, 300, "Interface\\Icons\\INV_Glyph_MajorMage" ) -- Glyph of Frost Nova
	AddSpell( "professions", "INSCRIPTION", 56978, nil, 90, 0, nil, 400, "Interface\\Icons\\inv_glyph_primemage" ) -- Glyph of Pyroblast
	AddSpell( "professions", "INSCRIPTION", 56979, nil, 225, 0, nil, 6000, "Interface\\Icons\\INV_Glyph_MajorMage" ) -- Glyph of Ice Block
	AddSpell( "professions", "INSCRIPTION", 56980, nil, 375, 0, nil, 50000, "Interface\\Icons\\inv_glyph_primemage" ) -- Glyph of Ice Lance
	AddSpell( "professions", "INSCRIPTION", 56981, nil, 175, 0, nil, 1000, "Interface\\Icons\\INV_Glyph_MajorMage" ) -- Glyph of Icy Veins
	AddSpell( "professions", "INSCRIPTION", 56984, nil, 325, 0, nil, 30000, "Interface\\Icons\\inv_glyph_primemage" ) -- Glyph of Mage Armor
	AddSpell( "professions", "INSCRIPTION", 56987, nil, 400, 0, nil, 60000, "Interface\\Icons\\INV_Glyph_MajorMage" ) -- Glyph of Polymorph
	AddSpell( "professions", "INSCRIPTION", 56991, nil, 315, 0, nil, 20000, "Interface\\Icons\\inv_glyph_primemage" ) -- Glyph of Arcane Blast
	AddSpell( "professions", "INSCRIPTION", 56994, nil, 175, 0, nil, 1000, "Interface\\Icons\\inv_glyph_primehunter" ) -- Glyph of Aimed Shot
	AddSpell( "professions", "INSCRIPTION", 56995, nil, 100, 0, nil, 400, "Interface\\Icons\\inv_glyph_primehunter" ) -- Glyph of Arcane Shot
	AddSpell( "professions", "INSCRIPTION", 56997, nil, 115, 0, nil, 500, "Interface\\Icons\\INV_Glyph_MajorHunter" ) -- Glyph of Mending
	AddSpell( "professions", "INSCRIPTION", 57000, nil, 200, 0, nil, 3000, "Interface\\Icons\\INV_Glyph_MajorHunter" ) -- Glyph of Deterrence
	AddSpell( "professions", "INSCRIPTION", 57001, nil, 225, 0, nil, 6000, "Interface\\Icons\\INV_Glyph_MajorHunter" ) -- Glyph of Disengage
	AddSpell( "professions", "INSCRIPTION", 57002, nil, 260, 0, nil, 10000, "Interface\\Icons\\INV_Glyph_MajorHunter" ) -- Glyph of Freezing Trap
	AddSpell( "professions", "INSCRIPTION", 57003, nil, 350, 0, nil, 30000, "Interface\\Icons\\INV_Glyph_MajorHunter" ) -- Glyph of Ice Trap
	AddSpell( "professions", "INSCRIPTION", 57004, nil, 80, 0, nil, 300, "Interface\\Icons\\INV_Glyph_MajorHunter" ) -- Glyph of Misdirection
	AddSpell( "professions", "INSCRIPTION", 57005, nil, 130, 0, nil, 750, "Interface\\Icons\\INV_Glyph_MajorHunter" ) -- Glyph of Immolation Trap
	AddSpell( "professions", "INSCRIPTION", 57006, nil, 375, 0, nil, 50000, "Interface\\Icons\\inv_glyph_primehunter" ) -- Glyph of the Dazzled Prey
	AddSpell( "professions", "INSCRIPTION", 57007, nil, 150, 0, nil, 750, "Interface\\Icons\\INV_Glyph_MajorHunter" ) -- Glyph of Silencing Shot
	AddSpell( "professions", "INSCRIPTION", 57008, nil, 315, 0, nil, 20000, "Interface\\Icons\\inv_glyph_primehunter" ) -- Glyph of Rapid Fire
	AddSpell( "professions", "INSCRIPTION", 57009, nil, 90, 0, nil, 400, "Interface\\Icons\\inv_glyph_primehunter" ) -- Glyph of Serpent Sting
	AddSpell( "professions", "INSCRIPTION", 57020, nil, 180, 0, nil, 1000, "Interface\\Icons\\INV_Glyph_MajorPaladin" ) -- Glyph of Cleansing
	AddSpell( "professions", "INSCRIPTION", 57022, nil, 80, 0, nil, 300, "Interface\\Icons\\INV_Glyph_MajorPaladin" ) -- Glyph of Divine Protection
	AddSpell( "professions", "INSCRIPTION", 57023, nil, 205, 0, nil, 4500, "Interface\\Icons\\INV_Glyph_MajorPaladin" ) -- Glyph of Consecration
	AddSpell( "professions", "INSCRIPTION", 57024, nil, 230, 0, nil, 6000, "Interface\\Icons\\inv_glyph_primepaladin" ) -- Glyph of Crusader Strike
	AddSpell( "professions", "INSCRIPTION", 57025, nil, 265, 0, nil, 10000, "Interface\\Icons\\inv_glyph_primepaladin" ) -- Glyph of Exorcism
	AddSpell( "professions", "INSCRIPTION", 57026, nil, 300, 0, nil, 20000, "Interface\\Icons\\inv_glyph_primepaladin" ) -- Glyph of Word of Glory
	AddSpell( "professions", "INSCRIPTION", 57027, nil, 90, 0, nil, 400, "Interface\\Icons\\INV_Glyph_MajorPaladin" ) -- Glyph of Hammer of Justice
	AddSpell( "professions", "INSCRIPTION", 57029, nil, 105, 0, nil, 500, "Interface\\Icons\\inv_glyph_primepaladin" ) -- Glyph of Divine Favor
	AddSpell( "professions", "INSCRIPTION", 57030, nil, 120, 0, nil, 500, "Interface\\Icons\\inv_glyph_primepaladin" ) -- Glyph of Judgement
	AddSpell( "professions", "INSCRIPTION", 57031, nil, 135, 0, nil, 750, "Interface\\Icons\\INV_Glyph_MajorPaladin" ) -- Glyph of Divinity
	AddSpell( "professions", "INSCRIPTION", 57033, nil, 335, 0, nil, 30000, "Interface\\Icons\\INV_Glyph_MajorPaladin" ) -- Glyph of Rebuke
	AddSpell( "professions", "INSCRIPTION", 57036, nil, 375, 0, nil, 50000, "Interface\\Icons\\INV_Glyph_MajorPaladin" ) -- Glyph of Turn Evil
	AddSpell( "professions", "INSCRIPTION", 57113, nil, 340, 0, nil, 30000, "Interface\\Icons\\INV_Glyph_MajorRogue" ) -- Glyph of Ambush
	AddSpell( "professions", "INSCRIPTION", 57114, nil, 80, 0, nil, 300, "Interface\\Icons\\inv_glyph_primerogue" ) -- Glyph of Backstab
	AddSpell( "professions", "INSCRIPTION", 57119, nil, 95, 0, nil, 400, "Interface\\Icons\\INV_Glyph_MajorRogue" ) -- Glyph of Evasion
	AddSpell( "professions", "INSCRIPTION", 57120, nil, 105, 0, nil, 500, "Interface\\Icons\\inv_glyph_primerogue" ) -- Glyph of Eviscerate
	AddSpell( "professions", "INSCRIPTION", 57121, nil, 120, 0, nil, 500, "Interface\\Icons\\INV_Glyph_MajorRogue" ) -- Glyph of Expose Armor
	AddSpell( "professions", "INSCRIPTION", 57122, nil, 305, 0, nil, 20000, "Interface\\Icons\\INV_Glyph_MajorRogue" ) -- Glyph of Feint
	AddSpell( "professions", "INSCRIPTION", 57123, nil, 135, 0, nil, 750, "Interface\\Icons\\INV_Glyph_MajorRogue" ) -- Glyph of Garrote
	AddSpell( "professions", "INSCRIPTION", 57125, nil, 160, 0, nil, 750, "Interface\\Icons\\INV_Glyph_MajorRogue" ) -- Glyph of Gouge
	AddSpell( "professions", "INSCRIPTION", 57129, nil, 185, 0, nil, 3000, "Interface\\Icons\\INV_Glyph_MajorRogue" ) -- Glyph of Sap
	AddSpell( "professions", "INSCRIPTION", 57131, nil, 210, 0, nil, 4500, "Interface\\Icons\\inv_glyph_primerogue" ) -- Glyph of Sinister Strike
	AddSpell( "professions", "INSCRIPTION", 57132, nil, 235, 0, nil, 6000, "Interface\\Icons\\inv_glyph_primerogue" ) -- Glyph of Slice and Dice
	AddSpell( "professions", "INSCRIPTION", 57133, nil, 285, 0, nil, 15000, "Interface\\Icons\\INV_Glyph_MajorRogue" ) -- Glyph of Sprint
	AddSpell( "professions", "INSCRIPTION", 57154, nil, 240, 0, nil, 7500, "Interface\\Icons\\INV_Glyph_MajorWarrior" ) -- Glyph of Cleaving
	AddSpell( "professions", "INSCRIPTION", 57156, nil, 285, 0, nil, 15000, "Interface\\Icons\\inv_glyph_primewarrior" ) -- Glyph of Bloodthirst
	AddSpell( "professions", "INSCRIPTION", 57157, nil, 125, 0, nil, 750, "Interface\\Icons\\INV_Glyph_MajorWarrior" ) -- Glyph of Piercing Howl
	AddSpell( "professions", "INSCRIPTION", 57158, nil, 95, 0, nil, 400, "Interface\\Icons\\INV_Glyph_MajorWarrior" ) -- Glyph of Heroic Throw
	AddSpell( "professions", "INSCRIPTION", 57161, nil, 170, 0, nil, 1000, "Interface\\Icons\\inv_glyph_primewarrior" ) -- Glyph of Overpower
	AddSpell( "professions", "INSCRIPTION", 57162, nil, 85, 0, nil, 300, "Interface\\Icons\\INV_Glyph_MajorWarrior" ) -- Glyph of Rapid Charge
	AddSpell( "professions", "INSCRIPTION", 57163, nil, 110, 0, nil, 500, "Interface\\Icons\\inv_glyph_primewarrior" ) -- Glyph of Slam
	AddSpell( "professions", "INSCRIPTION", 57165, nil, 190, 0, nil, 3000, "Interface\\Icons\\inv_glyph_primewarrior" ) -- Glyph of Revenge
	AddSpell( "professions", "INSCRIPTION", 57167, nil, 140, 0, nil, 750, "Interface\\Icons\\INV_Glyph_MajorWarrior" ) -- Glyph of Sunder Armor
	AddSpell( "professions", "INSCRIPTION", 57168, nil, 320, 0, nil, 20000, "Interface\\Icons\\INV_Glyph_MajorWarrior" ) -- Glyph of Sweeping Strikes
	AddSpell( "professions", "INSCRIPTION", 57172, nil, 345, 0, nil, 30000, "Interface\\Icons\\inv_glyph_primewarrior" ) -- Glyph of Raging Blow
	AddSpell( "professions", "INSCRIPTION", 57183, nil, 230, 0, nil, 6000, "Interface\\Icons\\INV_Glyph_MajorPriest" ) -- Glyph of Dispel Magic
	AddSpell( "professions", "INSCRIPTION", 57184, nil, 105, 0, nil, 500, "Interface\\Icons\\INV_Glyph_MajorPriest" ) -- Glyph of Fade
	AddSpell( "professions", "INSCRIPTION", 57185, nil, 270, 0, nil, 10000, "Interface\\Icons\\INV_Glyph_MajorPriest" ) -- Glyph of Fear Ward
	AddSpell( "professions", "INSCRIPTION", 57186, nil, 120, 0, nil, 500, "Interface\\Icons\\inv_glyph_primepriest" ) -- Glyph of Flash Heal
	AddSpell( "professions", "INSCRIPTION", 57187, nil, 315, 0, nil, 20000, "Interface\\Icons\\INV_Glyph_MajorPriest" ) -- Glyph of Holy Nova
	AddSpell( "professions", "INSCRIPTION", 57188, nil, 135, 0, nil, 750, "Interface\\Icons\\INV_Glyph_MajorPriest" ) -- Glyph of Inner Fire
	AddSpell( "professions", "INSCRIPTION", 57192, nil, 350, 0, nil, 30000, "Interface\\Icons\\inv_glyph_primepriest" ) -- Glyph of Shadow Word: Pain
	AddSpell( "professions", "INSCRIPTION", 57194, nil, 80, 0, nil, 300, "Interface\\Icons\\inv_glyph_primepriest" ) -- Glyph of Power Word: Shield
	AddSpell( "professions", "INSCRIPTION", 57196, nil, 95, 0, nil, 400, "Interface\\Icons\\INV_Glyph_MajorPriest" ) -- Glyph of Psychic Scream
	AddSpell( "professions", "INSCRIPTION", 57197, nil, 160, 0, nil, 750, "Interface\\Icons\\inv_glyph_primepriest" ) -- Glyph of Renew
	AddSpell( "professions", "INSCRIPTION", 57198, nil, 375, 0, nil, 50000, "Interface\\Icons\\INV_Glyph_MajorPriest" ) -- Glyph of Scourge Imprisonment
	AddSpell( "professions", "INSCRIPTION", 57200, nil, 180, 0, nil, 1000, "Interface\\Icons\\inv_glyph_primepriest" ) -- Glyph of Mind Flay
	AddSpell( "professions", "INSCRIPTION", 57201, nil, 210, 0, nil, 4500, "Interface\\Icons\\INV_Glyph_MajorPriest" ) -- Glyph of Smite
	AddSpell( "professions", "INSCRIPTION", 57210, nil, 265, 0, nil, 10000, "Interface\\Icons\\INV_Glyph_MajorDeathKnight" ) -- Glyph of Bone Shield
	AddSpell( "professions", "INSCRIPTION", 57213, nil, 285, 0, nil, 15000, "Interface\\Icons\\INV_Glyph_MajorDeathKnight" ) -- Glyph of Death Grip
	AddSpell( "professions", "INSCRIPTION", 57216, nil, 270, 0, nil, 10000, "Interface\\Icons\\inv_glyph_primedeathknight" ) -- Glyph of Frost Strike
	AddSpell( "professions", "INSCRIPTION", 57219, nil, 280, 0, nil, 10000, "Interface\\Icons\\inv_glyph_primedeathknight" ) -- Glyph of Icy Touch
	AddSpell( "professions", "INSCRIPTION", 57221, nil, 300, 0, nil, 20000, "Interface\\Icons\\INV_Glyph_MajorDeathKnight" ) -- Glyph of Pestilence
	AddSpell( "professions", "INSCRIPTION", 57222, nil, 350, 0, nil, 30000, "Interface\\Icons\\inv_glyph_primedeathknight" ) -- Glyph of Raise Dead
	AddSpell( "professions", "INSCRIPTION", 57224, nil, 330, 0, nil, 30000, "Interface\\Icons\\inv_glyph_primedeathknight" ) -- Glyph of Scourge Strike
	AddSpell( "professions", "INSCRIPTION", 57225, nil, 375, 0, nil, 50000, "Interface\\Icons\\INV_Glyph_MajorDeathKnight" ) -- Glyph of Strangulate
	AddSpell( "professions", "INSCRIPTION", 57226, nil, 305, 0, nil, 20000, "Interface\\Icons\\INV_Glyph_MajorDeathKnight" ) -- Glyph of Pillar of Frost
	AddSpell( "professions", "INSCRIPTION", 57227, nil, 345, 0, nil, 30000, "Interface\\Icons\\INV_Glyph_MajorDeathKnight" ) -- Glyph of Vampiric Blood
	AddSpell( "professions", "INSCRIPTION", 57236, nil, 300, 0, nil, 20000, "Interface\\Icons\\inv_glyph_primeshaman" ) -- Glyph of Earthliving Weapon
	AddSpell( "professions", "INSCRIPTION", 57238, nil, 110, 0, nil, 500, "Interface\\Icons\\INV_Glyph_MajorShaman" ) -- Glyph of Fire Nova
	AddSpell( "professions", "INSCRIPTION", 57239, nil, 85, 0, nil, 300, "Interface\\Icons\\inv_glyph_primeshaman" ) -- Glyph of Flame Shock
	AddSpell( "professions", "INSCRIPTION", 57240, nil, 125, 0, nil, 750, "Interface\\Icons\\inv_glyph_primeshaman" ) -- Glyph of Flametongue Weapon
	AddSpell( "professions", "INSCRIPTION", 57241, nil, 185, 0, nil, 3000, "Interface\\Icons\\INV_Glyph_MajorShaman" ) -- Glyph of Frost Shock
	AddSpell( "professions", "INSCRIPTION", 57242, nil, 215, 0, nil, 4500, "Interface\\Icons\\INV_Glyph_MajorShaman" ) -- Glyph of Healing Stream Totem
	AddSpell( "professions", "INSCRIPTION", 57244, nil, 235, 0, nil, 6000, "Interface\\Icons\\INV_Glyph_MajorShaman" ) -- Glyph of Totemic Recall
	AddSpell( "professions", "INSCRIPTION", 57245, nil, 140, 0, nil, 750, "Interface\\Icons\\inv_glyph_primeshaman" ) -- Glyph of Lightning Bolt
	AddSpell( "professions", "INSCRIPTION", 57246, nil, 95, 0, nil, 400, "Interface\\Icons\\INV_Glyph_MajorShaman" ) -- Glyph of Lightning Shield
	AddSpell( "professions", "INSCRIPTION", 57248, nil, 375, 0, nil, 50000, "Interface\\Icons\\inv_glyph_primeshaman" ) -- Glyph of Stormstrike
	AddSpell( "professions", "INSCRIPTION", 57249, nil, 165, 0, nil, 750, "Interface\\Icons\\inv_glyph_primeshaman" ) -- Glyph of Lava Lash
	AddSpell( "professions", "INSCRIPTION", 57251, nil, 275, 0, nil, 10000, "Interface\\Icons\\inv_glyph_primeshaman" ) -- Glyph of Water Shield
	AddSpell( "professions", "INSCRIPTION", 57252, nil, 330, 0, nil, 30000, "Interface\\Icons\\inv_glyph_primeshaman" ) -- Glyph of Windfury Weapon
	AddSpell( "professions", "INSCRIPTION", 57257, nil, 350, 0, nil, 30000, "Interface\\Icons\\inv_glyph_primewarlock" ) -- Glyph of Incinerate
	AddSpell( "professions", "INSCRIPTION", 57259, nil, 85, 0, nil, 300, "Interface\\Icons\\inv_glyph_primewarlock" ) -- Glyph of Corruption
	AddSpell( "professions", "INSCRIPTION", 57262, nil, 125, 0, nil, 750, "Interface\\Icons\\INV_Glyph_MajorWarlock" ) -- Glyph of Fear
	AddSpell( "professions", "INSCRIPTION", 57265, nil, 110, 0, nil, 500, "Interface\\Icons\\INV_Glyph_MinorWarlock" ) -- Glyph of Health Funnel
	AddSpell( "professions", "INSCRIPTION", 57266, nil, 95, 0, nil, 400, "Interface\\Icons\\INV_Glyph_MajorWarlock" ) -- Glyph of Healthstone
	AddSpell( "professions", "INSCRIPTION", 57269, nil, 140, 0, nil, 750, "Interface\\Icons\\inv_glyph_primewarlock" ) -- Glyph of Imp
	AddSpell( "professions", "INSCRIPTION", 57270, nil, 215, 0, nil, 4500, "Interface\\Icons\\INV_Glyph_MajorWarlock" ) -- Glyph of Soul Swap
	AddSpell( "professions", "INSCRIPTION", 57271, nil, 165, 0, nil, 750, "Interface\\Icons\\INV_Glyph_MajorWarlock" ) -- Glyph of Shadow Bolt
	AddSpell( "professions", "INSCRIPTION", 57272, nil, 275, 0, nil, 10000, "Interface\\Icons\\inv_glyph_primewarlock" ) -- Glyph of Shadowburn
	AddSpell( "professions", "INSCRIPTION", 57274, nil, 240, 0, nil, 7500, "Interface\\Icons\\INV_Glyph_MajorWarlock" ) -- Glyph of Soulstone
	AddSpell( "professions", "INSCRIPTION", 57275, nil, 325, 0, nil, 30000, "Interface\\Icons\\INV_Glyph_MajorWarlock" ) -- Glyph of Seduction
	AddSpell( "professions", "INSCRIPTION", 57277, nil, 190, 0, nil, 3000, "Interface\\Icons\\INV_Glyph_MajorWarlock" ) -- Glyph of Voidwalker
	AddSpell( "professions", "INSCRIPTION", 57703, nil, 85, 0, nil, 400, "Interface\\Icons\\INV_Inscription_InkGreen02" ) -- Hunter's Ink
	AddSpell( "professions", "INSCRIPTION", 57704, nil, 100, 0, nil, 400, "Interface\\Icons\\INV_Inscription_InkYellow02" ) -- Lion's Ink
	AddSpell( "professions", "INSCRIPTION", 57706, nil, 125, 0, nil, 750, "Interface\\Icons\\INV_Inscription_InkYellow04" ) -- Dawnstar Ink
	AddSpell( "professions", "INSCRIPTION", 57707, nil, 150, 0, nil, 750, "Interface\\Icons\\INV_Inscription_InkGreen03" ) -- Jadefire Ink
	AddSpell( "professions", "INSCRIPTION", 57708, nil, 175, 0, nil, 750, "Interface\\Icons\\INV_Inscription_InkPurple04" ) -- Royal Ink
	AddSpell( "professions", "INSCRIPTION", 57709, nil, 200, 0, nil, 3000, "Interface\\Icons\\INV_Inscription_InkPurple03" ) -- Celestial Ink
	AddSpell( "professions", "INSCRIPTION", 57710, nil, 225, 0, nil, 6000, "Interface\\Icons\\INV_Inscription_InkRed01" ) -- Fiery Ink
	AddSpell( "professions", "INSCRIPTION", 57711, nil, 250, 0, nil, 10000, "Interface\\Icons\\INV_Inscription_InkSilver01" ) -- Shimmering Ink
	AddSpell( "professions", "INSCRIPTION", 57712, nil, 275, 0, nil, 10000, "Interface\\Icons\\INV_Inscription_InkBlueWhite03" ) -- Ink of the Sky
	AddSpell( "professions", "INSCRIPTION", 57713, nil, 290, 0, nil, 20000, "Interface\\Icons\\INV_Inscription_InkBlack02" ) -- Ethereal Ink
	AddSpell( "professions", "INSCRIPTION", 57714, nil, 325, 0, nil, 20000, "Interface\\Icons\\INV_Inscription_InkBlack04" ) -- Darkflame Ink
	AddSpell( "professions", "INSCRIPTION", 57715, nil, 350, 0, nil, 50000, "Interface\\Icons\\INV_Inscription_InkPurple01" ) -- Ink of the Sea
	AddSpell( "professions", "INSCRIPTION", 57716, nil, 375, 0, nil, 50000, "Interface\\Icons\\INV_Inscription_InkBlueWhite01" ) -- Snowfall Ink
	AddSpell( "professions", "INSCRIPTION", 58344, nil, 80, 0, nil, 300, "Interface\\Icons\\INV_Glyph_MajorWarrior" ) -- Glyph of Long Charge
	AddSpell( "professions", "INSCRIPTION", 58346, nil, 80, 0, nil, 300, "Interface\\Icons\\INV_Glyph_MajorWarrior" ) -- Glyph of Thunder Clap
	AddSpell( "professions", "INSCRIPTION", 58472, nil, 15, 0, nil, 50, "Interface\\Icons\\INV_Scroll_02" ) -- Scroll of Agility
	AddSpell( "professions", "INSCRIPTION", 58473, nil, 85, 0, nil, 400, "Interface\\Icons\\INV_Scroll_02" ) -- Scroll of Agility II
	AddSpell( "professions", "INSCRIPTION", 58476, nil, 175, 0, nil, 750, "Interface\\Icons\\INV_Scroll_02" ) -- Scroll of Agility III
	AddSpell( "professions", "INSCRIPTION", 58478, nil, 225, 0, nil, 4500, "Interface\\Icons\\INV_Scroll_02" ) -- Scroll of Agility IV
	AddSpell( "professions", "INSCRIPTION", 58480, nil, 270, 0, nil, 10000, "Interface\\Icons\\INV_Scroll_02" ) -- Scroll of Agility V
	AddSpell( "professions", "INSCRIPTION", 58481, nil, 310, 0, nil, 20000, "Interface\\Icons\\INV_Scroll_02" ) -- Scroll of Agility VI
	AddSpell( "professions", "INSCRIPTION", 58482, nil, 370, 0, nil, 50000, "Interface\\Icons\\INV_Scroll_02" ) -- Scroll of Agility VII
	AddSpell( "professions", "INSCRIPTION", 58483, nil, 420, 0, nil, 60000, "Interface\\Icons\\INV_Scroll_02" ) -- Scroll of Agility VIII
	AddSpell( "professions", "INSCRIPTION", 58484, nil, 15, 0, nil, 50, "Interface\\Icons\\INV_Scroll_02" ) -- Scroll of Strength
	AddSpell( "professions", "INSCRIPTION", 58485, nil, 80, 0, nil, 400, "Interface\\Icons\\INV_Scroll_02" ) -- Scroll of Strength II
	AddSpell( "professions", "INSCRIPTION", 58486, nil, 170, 0, nil, 750, "Interface\\Icons\\INV_Scroll_02" ) -- Scroll of Strength III
	AddSpell( "professions", "INSCRIPTION", 58487, nil, 220, 0, nil, 4500, "Interface\\Icons\\INV_Scroll_02" ) -- Scroll of Strength IV
	AddSpell( "professions", "INSCRIPTION", 58488, nil, 265, 0, nil, 10000, "Interface\\Icons\\INV_Scroll_02" ) -- Scroll of Strength V
	AddSpell( "professions", "INSCRIPTION", 58489, nil, 305, 0, nil, 20000, "Interface\\Icons\\INV_Scroll_02" ) -- Scroll of Strength VI
	AddSpell( "professions", "INSCRIPTION", 58490, nil, 365, 0, nil, 50000, "Interface\\Icons\\INV_Scroll_02" ) -- Scroll of Strength VII
	AddSpell( "professions", "INSCRIPTION", 58491, nil, 415, 0, nil, 60000, "Interface\\Icons\\INV_Scroll_02" ) -- Scroll of Strength VIII
	AddSpell( "professions", "INSCRIPTION", 58565, nil, 85, 0, nil, 500, "Interface\\Icons\\INV_Misc_Book_11" ) -- Mystic Tome
	AddSpell( "professions", "INSCRIPTION", 59326, nil, 100, 0, nil, 400, "Interface\\Icons\\INV_Glyph_MajorShaman" ) -- Glyph of Ghost Wolf
	AddSpell( "professions", "INSCRIPTION", 59338, nil, 310, 0, nil, 20000, "Interface\\Icons\\INV_Glyph_MajorDeathKnight" ) -- Glyph of Rune Tap
	AddSpell( "professions", "INSCRIPTION", 59339, nil, 320, 0, nil, 20000, "Interface\\Icons\\INV_Glyph_MajorDeathKnight" ) -- Glyph of Blood Boil
	AddSpell( "professions", "INSCRIPTION", 59340, nil, 340, 0, nil, 30000, "Interface\\Icons\\inv_glyph_primedeathknight" ) -- Glyph of Death Strike
	AddSpell( "professions", "INSCRIPTION", 59387, nil, 200, 0, nil, 3000, "Interface\\Icons\\INV_Scroll_11" ) -- Certificate of Ownership
	AddSpell( "professions", "INSCRIPTION", 59475, nil, 125, 0, nil, 750, "Interface\\Icons\\INV_Misc_Book_07" ) -- Tome of the Dawn
	AddSpell( "professions", "INSCRIPTION", 59478, nil, 125, 0, nil, 750, "Interface\\Icons\\INV_Misc_Book_01" ) -- Book of Survival
	AddSpell( "professions", "INSCRIPTION", 59480, nil, 125, 0, nil, 750, "Interface\\Icons\\INV_Misc_Ticket_Tarot_Furies" ) -- Strange Tarot
	AddSpell( "professions", "INSCRIPTION", 59484, nil, 175, 0, nil, 750, "Interface\\Icons\\INV_Misc_Book_11" ) -- Tome of Kings
	AddSpell( "professions", "INSCRIPTION", 59486, nil, 175, 0, nil, 750, "Interface\\Icons\\INV_Misc_Book_09" ) -- Royal Guide of Escape Routes
	AddSpell( "professions", "INSCRIPTION", 59487, nil, 175, 0, nil, 750, "Interface\\Icons\\INV_Misc_Ticket_Tarot_Furies" ) -- Arcane Tarot
	AddSpell( "professions", "INSCRIPTION", 59489, nil, 225, 0, nil, 6000, "Interface\\Icons\\INV_Misc_Book_10" ) -- Fire Eater's Guide
	AddSpell( "professions", "INSCRIPTION", 59490, nil, 225, 0, nil, 6000, "Interface\\Icons\\INV_Misc_Book_05" ) -- Book of Stars
	AddSpell( "professions", "INSCRIPTION", 59491, nil, 225, 0, nil, 6000, "Interface\\Icons\\INV_Misc_Ticket_Tarot_Furies" ) -- Shadowy Tarot
	AddSpell( "professions", "INSCRIPTION", 59493, nil, 275, 0, nil, 10000, "Interface\\Icons\\INV_Misc_Book_05" ) -- Stormbound Tome
	AddSpell( "professions", "INSCRIPTION", 59494, nil, 275, 0, nil, 10000, "Interface\\Icons\\INV_Misc_Book_08" ) -- Manual of Clouds
	AddSpell( "professions", "INSCRIPTION", 59495, nil, 325, 0, nil, 20000, "Interface\\Icons\\INV_Misc_Book_10" ) -- Hellfire Tome
	AddSpell( "professions", "INSCRIPTION", 59496, nil, 325, 0, nil, 20000, "Interface\\Icons\\INV_Misc_Book_07" ) -- Book of Clever Tricks
	AddSpell( "professions", "INSCRIPTION", 59497, nil, 400, 0, nil, 60000, "Interface\\Icons\\INV_Misc_Book_09" ) -- Iron-bound Tome
	AddSpell( "professions", "INSCRIPTION", 59498, nil, 400, 0, nil, 60000, "Interface\\Icons\\INV_Misc_Book_09" ) -- Faces of Doom
	AddSpell( "professions", "INSCRIPTION", 59502, nil, 275, 0, nil, 10000, "Interface\\Icons\\INV_Misc_Ticket_Tarot_Furies" ) -- Darkmoon Card
	AddSpell( "professions", "INSCRIPTION", 59503, nil, 325, 0, nil, 20000, "Interface\\Icons\\INV_Misc_Ticket_Tarot_Furies" ) -- Greater Darkmoon Card
	AddSpell( "professions", "INSCRIPTION", 59504, nil, 400, 0, nil, 60000, "Interface\\Icons\\INV_Misc_Ticket_Tarot_Furies" ) -- Darkmoon Card of the North
	AddSpell( "professions", "INSCRIPTION", 60336, nil, 200, 0, nil, 3000, "Interface\\Icons\\INV_Scroll_12" ) -- Scroll of Recall II
	AddSpell( "professions", "INSCRIPTION", 60337, nil, 350, 0, nil, 50000, "Interface\\Icons\\INV_Scroll_16" ) -- Scroll of Recall III
	AddSpell( "professions", "INSCRIPTION", 61117, nil, 400, 0, nil, 75000, nil ) -- Master's Inscription of the Axe
	AddSpell( "professions", "INSCRIPTION", 61118, nil, 400, 0, nil, 75000, nil ) -- Master's Inscription of the Crag
	AddSpell( "professions", "INSCRIPTION", 61119, nil, 400, 0, nil, 75000, nil ) -- Master's Inscription of the Pinnacle
	AddSpell( "professions", "INSCRIPTION", 61120, nil, 400, 0, nil, 75000, nil ) -- Master's Inscription of the Storm
	AddSpell( "professions", "INSCRIPTION", 61177, nil, 385, 0, nil, 100000, nil ) -- Northrend Inscription Research
	AddSpell( "professions", "INSCRIPTION", 61288, nil, 75, 0, nil, 1000, nil ) -- Minor Inscription Research
	AddSpell( "professions", "INSCRIPTION", 62162, nil, 375, 0, nil, 50000, "Interface\\Icons\\INV_Glyph_MajorDruid" ) -- Glyph of Focus
	AddSpell( "professions", "INSCRIPTION", 64053, nil, 350, 0, nil, 50000, "Interface\\Icons\\INV_Misc_Book_11" ) -- Twilight Tome
	AddSpell( "professions", "INSCRIPTION", 64258, nil, 250, 0, nil, 10000, "Interface\\Icons\\INV_Glyph_MajorDruid" ) -- Glyph of Monsoon
	AddSpell( "professions", "INSCRIPTION", 64259, nil, 255, 0, nil, 10000, "Interface\\Icons\\INV_Glyph_MajorPriest" ) -- Glyph of Desperation
	AddSpell( "professions", "INSCRIPTION", 64260, nil, 255, 0, nil, 10000, "Interface\\Icons\\inv_glyph_primerogue" ) -- Glyph of Mutilate
	AddSpell( "professions", "INSCRIPTION", 64261, nil, 250, 0, nil, 10000, "Interface\\Icons\\inv_glyph_primeshaman" ) -- Glyph of Earth Shield
	AddSpell( "professions", "INSCRIPTION", 64262, nil, 255, 0, nil, 10000, "Interface\\Icons\\INV_Glyph_MajorShaman" ) -- Glyph of Shamanistic Rage
	AddSpell( "professions", "INSCRIPTION", 64266, nil, 275, 0, nil, 10000, "Interface\\Icons\\inv_glyph_primedeathknight" ) -- Glyph of Death Coil
	AddSpell( "professions", "INSCRIPTION", 67600, nil, 100, 0, nil, 400, "Interface\\Icons\\INV_Glyph_MajorDruid" ) -- Glyph of Ferocious Bite
	AddSpell( "professions", "INSCRIPTION", 69385, nil, 440, 0, nil, 120000, "Interface\\Icons\\INV_Scroll_14" ) -- Runescroll of Fortitude
	AddSpell( "professions", "INSCRIPTION", 85785, nil, 500, 0, nil, 120000, "Interface\\Icons\\INV_Scroll_14" ) -- Runescroll of Fortitude II
	AddSpell( "professions", "INSCRIPTION", 86004, nil, 425, 0, nil, 80000, "Interface\\Icons\\inv_inscription_inkblack03" ) -- Blackfallow Ink
	AddSpell( "professions", "INSCRIPTION", 86005, nil, 475, 0, nil, 90000, "Interface\\Icons\\inv_inscription_inkred03" ) -- Inferno Ink
	AddSpell( "professions", "INSCRIPTION", 86008, 75, 425, 0, nil, 500000, nil ) -- Illustrious Grand Master Scribe
	AddSpell( "professions", "INSCRIPTION", 86375, nil, 500, 0, nil, 75000, nil ) -- Swiftsteel Inscription
	AddSpell( "professions", "INSCRIPTION", 86401, nil, 500, 0, nil, 75000, nil ) -- Lionsmane Inscription
	AddSpell( "professions", "INSCRIPTION", 86402, nil, 500, 0, nil, 75000, nil ) -- Inscription of the Earth Prince
	AddSpell( "professions", "INSCRIPTION", 86403, nil, 500, 0, nil, 75000, nil ) -- Felfire Inscription
	AddSpell( "professions", "INSCRIPTION", 86609, nil, 450, 0, nil, 80000, "Interface\\Icons\\INV_Misc_Ticket_Tarot_Stack_01" ) -- Mysterious Fortune Card
	AddSpell( "professions", "INSCRIPTION", 86615, nil, 525, 0, nil, 200000, "Interface\\Icons\\INV_Misc_Ticket_Tarot_Furies" ) -- Darkmoon Card of Destruction
	AddSpell( "professions", "INSCRIPTION", 86616, nil, 475, 0, nil, 90000, "Interface\\Icons\\INV_Misc_Book_05" ) -- Book of Blood
	AddSpell( "professions", "INSCRIPTION", 86640, nil, 475, 0, nil, 90000, "Interface\\Icons\\INV_Misc_Book_11" ) -- Lord Rottington's Pressed Wisp Book
	AddSpell( "professions", "INSCRIPTION", 86641, nil, 510, 0, nil, 120000, "Interface\\Icons\\inv_misc_book_17" ) -- Dungeoneering Guide
	AddSpell( "professions", "INSCRIPTION", 86642, nil, 510, 0, nil, 120000, "Interface\\Icons\\inv_misc_book_16" ) -- Divine Companion
	AddSpell( "professions", "INSCRIPTION", 86643, nil, 510, 0, nil, 120000, "Interface\\Icons\\inv_misc_book_18" ) -- Battle Tome
	AddSpell( "professions", "INSCRIPTION", 86647, nil, 480, 0, nil, 90000, "Interface\\Icons\\inv_misc_monsterhorn_01" ) -- Etched Horn
	AddSpell( "professions", "INSCRIPTION", 86648, nil, 480, 0, nil, 90000, "Interface\\Icons\\inv_misc_book_16" ) -- Manual of the Planes
	AddSpell( "professions", "INSCRIPTION", 86649, nil, 505, 0, nil, 120000, "Interface\\Icons\\inv_misc_monsterscales_07" ) -- Runed Dragonscale
	AddSpell( "professions", "INSCRIPTION", 86650, nil, 515, 0, nil, 150000, "Interface\\Icons\\inv_jewelry_trinket_06" ) -- Notched Jawbone
	AddSpell( "professions", "INSCRIPTION", 86652, nil, 515, 0, nil, 150000, "Interface\\Icons\\inv_misc_eye_02" ) -- Tattooed Eyeball
	AddSpell( "professions", "INSCRIPTION", 86653, nil, 515, 0, nil, 150000, "Interface\\Icons\\inv_relics_idolofrejuvenation" ) -- Silver Inlaid Leaf
	AddSpell( "professions", "INSCRIPTION", 86654, nil, 500, 0, nil, 100000, "Interface\\Icons\\inv_scroll_11" ) -- Forged Documents
	AddSpell( "professions", "INSCRIPTION", 89244, nil, 500, 0, nil, 100000, "Interface\\Icons\\inv_scroll_11" ) -- Forged Documents
	AddSpell( "professions", "INSCRIPTION", 89367, nil, 460, 0, nil, 80000, "Interface\\Icons\\INV_Misc_Book_11" ) -- Adventurer's Journal
	AddSpell( "professions", "INSCRIPTION", 89368, nil, 445, 0, nil, 80000, "Interface\\Icons\\INV_Scroll_01" ) -- Scroll of Intellect IX
	AddSpell( "professions", "INSCRIPTION", 89369, nil, 465, 0, nil, 80000, "Interface\\Icons\\INV_Scroll_02" ) -- Scroll of Strength IX
	AddSpell( "professions", "INSCRIPTION", 89370, nil, 470, 0, nil, 80000, "Interface\\Icons\\INV_Scroll_02" ) -- Scroll of Agility IX
	AddSpell( "professions", "INSCRIPTION", 89371, nil, 455, 0, nil, 80000, "Interface\\Icons\\INV_Scroll_01" ) -- Scroll of Spirit IX
	AddSpell( "professions", "INSCRIPTION", 89372, nil, 460, 0, nil, 80000, "Interface\\Icons\\INV_Scroll_07" ) -- Scroll of Stamina IX
	AddSpell( "professions", "INSCRIPTION", 89373, nil, 450, 0, nil, 80000, "Interface\\Icons\\INV_Scroll_07" ) -- Scroll of Protection IX
	AddSpell( "professions", "INSCRIPTION", 92026, nil, 75, 0, nil, 400, "Interface\\Icons\\INV_Misc_Dust_02" ) -- Vanishing Powder
	AddSpell( "professions", "INSCRIPTION", 92027, nil, 475, 0, nil, 90000, "Interface\\Icons\\achievement_zone_dustwallowmarsh" ) -- Dust of Disappearance
	AddSpell( "professions", "INSCRIPTION", 92579, nil, 180, 0, nil, 1000, "Interface\\Icons\\INV_Glyph_MajorRogue" ) -- Glyph of Blind
	AddSpell( "professions", "INSCRIPTION", 94401, nil, 120, 0, nil, 500, "Interface\\Icons\\inv_glyph_primedruid" ) -- Glyph of Tiger's Fury
	AddSpell( "professions", "INSCRIPTION", 94402, nil, 330, 0, nil, 30000, "Interface\\Icons\\inv_glyph_primedruid" ) -- Glyph of Lacerate
	AddSpell( "professions", "INSCRIPTION", 94403, nil, 120, 0, nil, 500, "Interface\\Icons\\INV_Glyph_MajorDruid" ) -- Glyph of Faerie Fire
	AddSpell( "professions", "INSCRIPTION", 94404, nil, 150, 0, nil, 750, "Interface\\Icons\\INV_Glyph_MajorDruid" ) -- Glyph of Feral Charge
	AddSpell( "professions", "INSCRIPTION", 94405, nil, 150, 0, nil, 750, "Interface\\Icons\\INV_Glyph_MajorWarrior" ) -- Glyph of Death Wish
	AddSpell( "professions", "INSCRIPTION", 94406, nil, 250, 0, nil, 10000, "Interface\\Icons\\INV_Glyph_MajorWarrior" ) -- Glyph of Intercept
	AddSpell( "professions", "INSCRIPTION", 96284, nil, 275, 0, nil, 10000, "Interface\\Icons\\INV_Glyph_MajorDeathKnight" ) -- Glyph of Dark Succor
	AddSpell( "professions", "JEWELCRAFTING", 25229, 5, nil, 0, nil, 10, nil ) -- Apprentice Jewelcrafter
	AddSpell( "professions", "JEWELCRAFTING", 25230, 10, 50, 0, nil, 500, "Interface\\Icons\\INV_Misc_Gem_03" ) -- Journeyman Jewelcrafter
	AddSpell( "professions", "JEWELCRAFTING", 25278, nil, 50, 0, nil, 200, "Interface\\Icons\\INV_Jewelcrafting_BronzeSetting" ) -- Bronze Setting
	AddSpell( "professions", "JEWELCRAFTING", 25280, nil, 50, 0, nil, 200, "Interface\\Icons\\INV_Jewelry_Ring_01" ) -- Elegant Silver Ring
	AddSpell( "professions", "JEWELCRAFTING", 25283, nil, 30, 0, nil, 100, "Interface\\Icons\\INV_Jewelry_Ring_23" ) -- Inlaid Malachite Ring
	AddSpell( "professions", "JEWELCRAFTING", 25284, nil, 60, 0, nil, 400, "Interface\\Icons\\INV_Jewelry_Ring_28" ) -- Simple Pearl Ring
	AddSpell( "professions", "JEWELCRAFTING", 25287, nil, 70, 0, nil, 400, "Interface\\Icons\\INV_Jewelry_Ring_16" ) -- Gloom Band
	AddSpell( "professions", "JEWELCRAFTING", 25305, nil, 90, 0, nil, 1000, "Interface\\Icons\\INV_Jewelry_Ring_26" ) -- Heavy Silver Ring
	AddSpell( "professions", "JEWELCRAFTING", 25317, nil, 80, 0, nil, 600, "Interface\\Icons\\INV_Jewelry_Ring_05" ) -- Ring of Silver Might
	AddSpell( "professions", "JEWELCRAFTING", 25318, nil, 100, 0, nil, 800, "Interface\\Icons\\INV_Jewelry_Ring_34" ) -- Ring of Twilight Shadows
	AddSpell( "professions", "JEWELCRAFTING", 25321, nil, 120, 0, nil, 1500, "Interface\\Icons\\INV_Crown_15" ) -- Moonsoul Crown
	AddSpell( "professions", "JEWELCRAFTING", 25490, nil, 50, 0, nil, 300, "Interface\\Icons\\INV_Jewelry_Ring_14" ) -- Solid Bronze Ring
	AddSpell( "professions", "JEWELCRAFTING", 25498, nil, 110, 0, nil, 600, "Interface\\Icons\\INV_Jewelry_Necklace_22" ) -- Barbaric Iron Collar
	AddSpell( "professions", "JEWELCRAFTING", 25610, nil, 120, 0, nil, 1500, "Interface\\Icons\\INV_Shield_21" ) -- Pendant of the Agate Shield
	AddSpell( "professions", "JEWELCRAFTING", 25612, nil, 125, 0, nil, 1500, "Interface\\Icons\\INV_Gauntlets_04" ) -- Heavy Iron Knuckles
	AddSpell( "professions", "JEWELCRAFTING", 25613, nil, 135, 0, nil, 1200, "Interface\\Icons\\INV_Jewelry_Ring_40" ) -- Golden Dragon Ring
	AddSpell( "professions", "JEWELCRAFTING", 25615, nil, 150, 0, nil, 1500, "Interface\\Icons\\INV_Jewelcrafting_MithrilFiligree" ) -- Mithril Filigree
	AddSpell( "professions", "JEWELCRAFTING", 25617, nil, 150, 0, nil, 1500, "Interface\\Icons\\INV_Jewelry_Ring_20" ) -- Blazing Citrine Ring
	AddSpell( "professions", "JEWELCRAFTING", 25620, nil, 170, 0, nil, 2000, "Interface\\Icons\\INV_Jewelry_Ring_35" ) -- Engraved Truesilver Ring
	AddSpell( "professions", "JEWELCRAFTING", 25621, nil, 180, 0, nil, 2000, "Interface\\Icons\\INV_Jewelry_Ring_29" ) -- Citrine Ring of Rapid Healing
	AddSpell( "professions", "JEWELCRAFTING", 26872, nil, 200, 0, nil, 2500, "Interface\\Icons\\INV_Jewelcrafting_JadeOwl" ) -- Figurine - Jade Owl
	AddSpell( "professions", "JEWELCRAFTING", 26874, nil, 210, 0, nil, 5000, "Interface\\Icons\\INV_Jewelry_Ring_05" ) -- Aquamarine Signet
	AddSpell( "professions", "JEWELCRAFTING", 26876, nil, 220, 0, nil, 3000, "Interface\\Icons\\INV_Jewelry_Necklace_16" ) -- Aquamarine Pendant of the Warrior
	AddSpell( "professions", "JEWELCRAFTING", 26880, nil, 225, 0, nil, 3500, "Interface\\Icons\\INV_Jewelcrafting_ThoriumSetting" ) -- Thorium Setting
	AddSpell( "professions", "JEWELCRAFTING", 26883, nil, 235, 0, nil, 4000, "Interface\\Icons\\INV_Jewelry_Necklace_15" ) -- Ruby Pendant of Fire
	AddSpell( "professions", "JEWELCRAFTING", 26885, nil, 240, 0, nil, 5000, "Interface\\Icons\\INV_Jewelry_Ring_26" ) -- Truesilver Healing Ring
	AddSpell( "professions", "JEWELCRAFTING", 26902, nil, 260, 0, nil, 10000, "Interface\\Icons\\INV_Jewelry_Ring_17" ) -- Simple Opal Ring
	AddSpell( "professions", "JEWELCRAFTING", 26903, nil, 275, 0, nil, 10000, "Interface\\Icons\\INV_Jewelry_Ring_29" ) -- Sapphire Signet
	AddSpell( "professions", "JEWELCRAFTING", 26907, nil, 280, 0, nil, 10000, "Interface\\Icons\\INV_Jewelry_Ring_27" ) -- Onslaught Ring
	AddSpell( "professions", "JEWELCRAFTING", 26908, nil, 280, 0, nil, 12000, "Interface\\Icons\\INV_Jewelry_Necklace_11" ) -- Sapphire Pendant of Winter Night
	AddSpell( "professions", "JEWELCRAFTING", 26911, nil, 290, 0, nil, 15000, "Interface\\Icons\\INV_Jewelry_Necklace_01" ) -- Living Emerald Pendant
	AddSpell( "professions", "JEWELCRAFTING", 26916, nil, 310, 0, nil, 20000, "Interface\\Icons\\INV_Jewelry_Ring_41" ) -- Band of Natural Fire
	AddSpell( "professions", "JEWELCRAFTING", 26926, nil, 5, 0, nil, 50, "Interface\\Icons\\INV_Jewelry_Ring_12" ) -- Heavy Copper Ring
	AddSpell( "professions", "JEWELCRAFTING", 26927, nil, 50, 0, nil, 300, "Interface\\Icons\\INV_Belt_19" ) -- Thick Bronze Necklace
	AddSpell( "professions", "JEWELCRAFTING", 26928, nil, 30, 0, nil, 100, "Interface\\Icons\\INV_Jewelry_Necklace_02" ) -- Ornate Tigerseye Necklace
	AddSpell( "professions", "JEWELCRAFTING", 28894, 20, 125, 0, nil, 5000, "Interface\\Icons\\INV_Misc_Gem_03" ) -- Expert Jewelcrafter
	AddSpell( "professions", "JEWELCRAFTING", 28895, 35, 200, 0, nil, 50000, "Interface\\Icons\\INV_Misc_Gem_03" ) -- Artisan Jewelcrafter
	AddSpell( "professions", "JEWELCRAFTING", 28897, 50, 275, 0, nil, 100000, "Interface\\Icons\\INV_Misc_Gem_03" ) -- Master Jewelcrafter
	AddSpell( "professions", "JEWELCRAFTING", 28905, nil, 300, 0, nil, 10000, "Interface\\Icons\\INV_Misc_Gem_BloodGem_02" ) -- Bold Blood Garnet
	AddSpell( "professions", "JEWELCRAFTING", 28910, nil, 300, 0, nil, 10000, "Interface\\Icons\\INV_Misc_Gem_FlameSpessarite_02" ) -- Inscribed Flame Spessarite
	AddSpell( "professions", "JEWELCRAFTING", 28914, nil, 315, 0, nil, 10000, "Interface\\Icons\\INV_Misc_Gem_EbonDraenite_02" ) -- Glinting Shadow Draenite
	AddSpell( "professions", "JEWELCRAFTING", 28916, nil, 300, 0, nil, 10000, "Interface\\Icons\\INV_Misc_Gem_DeepPeridot_02" ) -- Radiant Deep Peridot
	AddSpell( "professions", "JEWELCRAFTING", 28917, nil, 300, 0, nil, 10000, "Interface\\Icons\\INV_Misc_Gem_DeepPeridot_02" ) -- Jagged Deep Peridot
	AddSpell( "professions", "JEWELCRAFTING", 28925, nil, 300, 0, nil, 10000, "Interface\\Icons\\INV_Misc_Gem_EbonDraenite_02" ) -- Timeless Shadow Draenite
	AddSpell( "professions", "JEWELCRAFTING", 28936, nil, 325, 0, nil, 10000, "Interface\\Icons\\INV_Misc_Gem_EbonDraenite_02" ) -- Sovereign Shadow Draenite
	AddSpell( "professions", "JEWELCRAFTING", 28948, nil, 325, 0, nil, 10000, "Interface\\Icons\\INV_Misc_Gem_AzureDraenite_02" ) -- Rigid Azure Moonstone
	AddSpell( "professions", "JEWELCRAFTING", 28950, nil, 300, 0, nil, 10000, "Interface\\Icons\\INV_Misc_Gem_AzureDraenite_02" ) -- Solid Azure Moonstone
	AddSpell( "professions", "JEWELCRAFTING", 28953, nil, 300, 0, nil, 10000, "Interface\\Icons\\INV_Misc_Gem_AzureDraenite_02" ) -- Sparkling Azure Moonstone
	AddSpell( "professions", "JEWELCRAFTING", 31048, nil, 305, 0, nil, 20000, "Interface\\Icons\\INV_Jewelry_Ring_39" ) -- Fel Iron Blood Ring
	AddSpell( "professions", "JEWELCRAFTING", 31049, nil, 305, 0, nil, 20000, "Interface\\Icons\\INV_Jewelry_Ring_60" ) -- Golden Draenite Ring
	AddSpell( "professions", "JEWELCRAFTING", 31050, nil, 320, 0, nil, 25000, "Interface\\Icons\\INV_Jewelry_Ring_50Naxxramas" ) -- Azure Moonstone Ring
	AddSpell( "professions", "JEWELCRAFTING", 31051, nil, 335, 0, nil, 30000, "Interface\\Icons\\INV_Jewelry_Necklace_29Naxxramas" ) -- Thick Adamantite Necklace
	AddSpell( "professions", "JEWELCRAFTING", 31052, nil, 335, 0, nil, 30000, "Interface\\Icons\\INV_Jewelry_Ring_59" ) -- Heavy Adamantite Ring
	AddSpell( "professions", "JEWELCRAFTING", 31252, 5, 20, 0, nil, 100, nil ) -- Prospecting
	AddSpell( "professions", "JEWELCRAFTING", 32178, nil, 20, 0, nil, 100, "Interface\\Icons\\INV_Jewelry_Necklace_01" ) -- Malachite Pendant
	AddSpell( "professions", "JEWELCRAFTING", 32179, nil, 20, 0, nil, 100, "Interface\\Icons\\INV_Jewelry_Ring_21" ) -- Tigerseye Band
	AddSpell( "professions", "JEWELCRAFTING", 32801, nil, 50, 0, nil, 200, "Interface\\Icons\\INV_Misc_Statue_05" ) -- Coarse Stone Statue
	AddSpell( "professions", "JEWELCRAFTING", 32807, nil, 110, 0, nil, 600, "Interface\\Icons\\INV_Misc_Statue_09" ) -- Heavy Stone Statue
	AddSpell( "professions", "JEWELCRAFTING", 32808, nil, 175, 0, nil, 2000, "Interface\\Icons\\INV_Misc_Statue_06" ) -- Solid Stone Statue
	AddSpell( "professions", "JEWELCRAFTING", 32809, nil, 225, 0, nil, 3500, "Interface\\Icons\\INV_Misc_Statue_10" ) -- Dense Stone Statue
	AddSpell( "professions", "JEWELCRAFTING", 34590, nil, 300, 0, nil, 10000, "Interface\\Icons\\INV_Misc_Gem_BloodGem_02" ) -- Delicate Blood Garnet
	AddSpell( "professions", "JEWELCRAFTING", 34955, nil, 180, 0, nil, 2500, "Interface\\Icons\\INV_Jewelry_Ring_46" ) -- Golden Ring of Power
	AddSpell( "professions", "JEWELCRAFTING", 34959, nil, 200, 0, nil, 3000, "Interface\\Icons\\INV_Jewelry_Ring_30" ) -- Truesilver Commander's Ring
	AddSpell( "professions", "JEWELCRAFTING", 34960, nil, 280, 0, nil, 10000, "Interface\\Icons\\INV_Jewelry_Ring_35" ) -- Glowing Thorium Band
	AddSpell( "professions", "JEWELCRAFTING", 34961, nil, 290, 0, nil, 10000, "Interface\\Icons\\INV_Jewelry_Ring_18" ) -- Emerald Lion Ring
	AddSpell( "professions", "JEWELCRAFTING", 36523, nil, 75, 0, nil, 600, "Interface\\Icons\\INV_Jewelry_Necklace_01" ) -- Brilliant Necklace
	AddSpell( "professions", "JEWELCRAFTING", 36524, nil, 105, 0, nil, 800, "Interface\\Icons\\INV_Jewelry_Ring_11" ) -- Heavy Jade Ring
	AddSpell( "professions", "JEWELCRAFTING", 36525, nil, 230, 0, nil, 4000, "Interface\\Icons\\INV_Jewelry_Ring_25" ) -- Red Ring of Destruction
	AddSpell( "professions", "JEWELCRAFTING", 36526, nil, 265, 0, nil, 10000, "Interface\\Icons\\INV_Jewelry_Ring_42" ) -- Diamond Focus Ring
	AddSpell( "professions", "JEWELCRAFTING", 37818, nil, 65, 0, nil, 500, "Interface\\Icons\\INV_Jewelry_Ring_34" ) -- Bronze Band of Force
	AddSpell( "professions", "JEWELCRAFTING", 38068, nil, 325, 0, nil, 20000, nil ) -- Mercurial Adamantite
	AddSpell( "professions", "JEWELCRAFTING", 38175, nil, 80, 0, nil, 650, "Interface\\Icons\\INV_Jewelry_Necklace_29Naxxramas" ) -- Bronze Torc
	AddSpell( "professions", "JEWELCRAFTING", 40514, nil, 340, 0, nil, 8500, "Interface\\Icons\\INV_Jewelry_Necklace_03" ) -- Necklace of the Deep
	AddSpell( "professions", "JEWELCRAFTING", 41414, nil, 325, 0, nil, 10000, "Interface\\Icons\\INV_Jewelry_Ring_05" ) -- Brilliant Pearl Band
	AddSpell( "professions", "JEWELCRAFTING", 41415, nil, 330, 0, nil, 10000, "Interface\\Icons\\INV_Jewelry_Ring_16" ) -- The Black Pearl
	AddSpell( "professions", "JEWELCRAFTING", 41418, nil, 365, 0, nil, 30000, "Interface\\Icons\\INV_Crown_01" ) -- Crown of the Sea Witch
	AddSpell( "professions", "JEWELCRAFTING", 41420, nil, 325, 0, nil, 8500, "Interface\\Icons\\INV_Misc_Gem_Pearl_08" ) -- Purified Jaggal Pearl
	AddSpell( "professions", "JEWELCRAFTING", 41429, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Misc_Gem_Pearl_07" ) -- Purified Shadow Pearl
	AddSpell( "professions", "JEWELCRAFTING", 47280, nil, 350, 0, nil, 30000, "Interface\\Icons\\INV_Misc_Gem_Diamond_03" ) -- Brilliant Glass
	AddSpell( "professions", "JEWELCRAFTING", 51311, 65, 350, 0, nil, 350000, nil ) -- Grand Master Jewelcrafter
	AddSpell( "professions", "JEWELCRAFTING", 53831, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Jewelcrafting_Gem_22" ) -- Bold Bloodstone
	AddSpell( "professions", "JEWELCRAFTING", 53832, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Jewelcrafting_Gem_22" ) -- Delicate Bloodstone
	AddSpell( "professions", "JEWELCRAFTING", 53843, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Jewelcrafting_Gem_21" ) -- Subtle Sun Crystal
	AddSpell( "professions", "JEWELCRAFTING", 53844, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Jewelcrafting_Gem_22" ) -- Flashing Bloodstone
	AddSpell( "professions", "JEWELCRAFTING", 53845, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Jewelcrafting_Gem_21" ) -- Smooth Sun Crystal
	AddSpell( "professions", "JEWELCRAFTING", 53852, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Jewelcrafting_Gem_22" ) -- Brilliant Bloodstone
	AddSpell( "professions", "JEWELCRAFTING", 53854, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Jewelcrafting_Gem_24" ) -- Rigid Chalcedony
	AddSpell( "professions", "JEWELCRAFTING", 53856, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Jewelcrafting_Gem_21" ) -- Quick Sun Crystal
	AddSpell( "professions", "JEWELCRAFTING", 53859, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Jewelcrafting_Gem_23" ) -- Sovereign Shadow Crystal
	AddSpell( "professions", "JEWELCRAFTING", 53860, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Jewelcrafting_Gem_23" ) -- Shifting Shadow Crystal
	AddSpell( "professions", "JEWELCRAFTING", 53861, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Jewelcrafting_Gem_23" ) -- Glinting Shadow Crystal
	AddSpell( "professions", "JEWELCRAFTING", 53870, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Jewelcrafting_Gem_19" ) -- Jagged Dark Jade
	AddSpell( "professions", "JEWELCRAFTING", 53871, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Jewelcrafting_Gem_23" ) -- Guardian's Shadow Crystal
	AddSpell( "professions", "JEWELCRAFTING", 53872, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Jewelcrafting_Gem_20" ) -- Inscribed Huge Citrine
	AddSpell( "professions", "JEWELCRAFTING", 53873, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Jewelcrafting_Gem_23" ) -- Etched Shadow Crystal
	AddSpell( "professions", "JEWELCRAFTING", 53874, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Jewelcrafting_Gem_20" ) -- Champion's Huge Citrine
	AddSpell( "professions", "JEWELCRAFTING", 53876, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Jewelcrafting_Gem_20" ) -- Fierce Huge Citrine
	AddSpell( "professions", "JEWELCRAFTING", 53880, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Jewelcrafting_Gem_20" ) -- Deft Huge Citrine
	AddSpell( "professions", "JEWELCRAFTING", 53882, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Jewelcrafting_Gem_20" ) -- Potent Huge Citrine
	AddSpell( "professions", "JEWELCRAFTING", 53883, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Jewelcrafting_Gem_23" ) -- Veiled Shadow Crystal
	AddSpell( "professions", "JEWELCRAFTING", 53891, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Jewelcrafting_Gem_20" ) -- Stalwart Huge Citrine
	AddSpell( "professions", "JEWELCRAFTING", 53892, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Jewelcrafting_Gem_23" ) -- Accurate Shadow Crystal
	AddSpell( "professions", "JEWELCRAFTING", 53893, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Jewelcrafting_Gem_20" ) -- Resolute Huge Citrine
	AddSpell( "professions", "JEWELCRAFTING", 53894, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Jewelcrafting_Gem_23" ) -- Timeless Shadow Crystal
	AddSpell( "professions", "JEWELCRAFTING", 53918, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Jewelcrafting_Gem_19" ) -- Regal Dark Jade
	AddSpell( "professions", "JEWELCRAFTING", 53920, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Jewelcrafting_Gem_19" ) -- Forceful Dark Jade
	AddSpell( "professions", "JEWELCRAFTING", 53922, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Jewelcrafting_Gem_19" ) -- Misty Dark Jade
	AddSpell( "professions", "JEWELCRAFTING", 53923, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Jewelcrafting_Gem_19" ) -- Lightning Dark Jade
	AddSpell( "professions", "JEWELCRAFTING", 53925, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Jewelcrafting_Gem_19" ) -- Energized Dark Jade
	AddSpell( "professions", "JEWELCRAFTING", 53934, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Jewelcrafting_Gem_24" ) -- Solid Chalcedony
	AddSpell( "professions", "JEWELCRAFTING", 53941, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Jewelcrafting_Gem_24" ) -- Sparkling Chalcedony
	AddSpell( "professions", "JEWELCRAFTING", 54017, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Jewelcrafting_Gem_22" ) -- Precise Bloodstone
	AddSpell( "professions", "JEWELCRAFTING", 55386, nil, 420, 0, nil, 120000, "Interface\\Icons\\INV_Jewelcrafting_IceDiamond_02" ) -- Tireless Skyflare Diamond
	AddSpell( "professions", "JEWELCRAFTING", 55394, nil, 420, 0, nil, 120000, "Interface\\Icons\\INV_Jewelcrafting_IceDiamond_02" ) -- Swift Skyflare Diamond
	AddSpell( "professions", "JEWELCRAFTING", 55399, nil, 420, 0, nil, 120000, "Interface\\Icons\\INV_Jewelcrafting_ShadowSpirit_02" ) -- Powerful Earthsiege Diamond
	AddSpell( "professions", "JEWELCRAFTING", 55402, nil, 420, 0, nil, 120000, "Interface\\Icons\\INV_Jewelcrafting_ShadowSpirit_02" ) -- Persistent Earthsiege Diamond
	AddSpell( "professions", "JEWELCRAFTING", 56193, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Jewelry_Ring_25" ) -- Bloodstone Band
	AddSpell( "professions", "JEWELCRAFTING", 56194, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Jewelry_Ring_21" ) -- Sun Rock Ring
	AddSpell( "professions", "JEWELCRAFTING", 56195, nil, 380, 0, nil, 120000, "Interface\\Icons\\INV_Weapon_ShortBlade_22" ) -- Jade Dagger Pendant
	AddSpell( "professions", "JEWELCRAFTING", 56196, nil, 380, 0, nil, 80000, "Interface\\Icons\\INV_Jewelry_Necklace_15" ) -- Blood Sun Necklace
	AddSpell( "professions", "JEWELCRAFTING", 56197, nil, 420, 0, nil, 100000, "Interface\\Icons\\INV_Jewelry_Ring_49Naxxramas" ) -- Dream Signet
	AddSpell( "professions", "JEWELCRAFTING", 56199, nil, 400, 0, nil, 150000, "Interface\\Icons\\INV_Jewelcrafting_CrimsonHare" ) -- Figurine - Ruby Hare
	AddSpell( "professions", "JEWELCRAFTING", 56201, nil, 400, 0, nil, 150000, "Interface\\Icons\\INV_Jewelcrafting_PurpleSerpent" ) -- Figurine - Twilight Serpent
	AddSpell( "professions", "JEWELCRAFTING", 56202, nil, 400, 0, nil, 150000, "Interface\\Icons\\INV_Jewelcrafting_AzureOwl" ) -- Figurine - Sapphire Owl
	AddSpell( "professions", "JEWELCRAFTING", 56203, nil, 400, 0, nil, 150000, "Interface\\Icons\\INV_Jewelcrafting_EmeraldBoar" ) -- Figurine - Emerald Boar
	AddSpell( "professions", "JEWELCRAFTING", 56205, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Misc_Gem_03" ) -- Dark Jade Focusing Lens
	AddSpell( "professions", "JEWELCRAFTING", 56206, nil, 350, 0, nil, 10000, nil ) -- Shadow Crystal Focusing Lens
	AddSpell( "professions", "JEWELCRAFTING", 56208, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Misc_Gem_02" ) -- Shadow Jade Focusing Lens
	AddSpell( "professions", "JEWELCRAFTING", 56530, nil, 350, 0, nil, 10000, "Interface\\Icons\\INV_Misc_Gem_Pearl_10" ) -- Enchanted Pearl
	AddSpell( "professions", "JEWELCRAFTING", 56531, nil, 390, 0, nil, 100000, "Interface\\Icons\\INV_Misc_Gem_Pearl_12" ) -- Enchanted Tear
	AddSpell( "professions", "JEWELCRAFTING", 58141, nil, 350, 0, nil, 30000, "Interface\\Icons\\INV_Jewelry_Necklace_03" ) -- Crystal Citrine Necklace
	AddSpell( "professions", "JEWELCRAFTING", 58142, nil, 350, 0, nil, 30000, "Interface\\Icons\\INV_Jewelry_Necklace_16" ) -- Crystal Chalcedony Amulet
	AddSpell( "professions", "JEWELCRAFTING", 58143, nil, 350, 0, nil, 30000, "Interface\\Icons\\INV_Jewelry_Ring_35" ) -- Earthshadow Ring
	AddSpell( "professions", "JEWELCRAFTING", 58144, nil, 350, 0, nil, 30000, "Interface\\Icons\\INV_Jewelry_Ring_34" ) -- Jade Ring of Slaying
	AddSpell( "professions", "JEWELCRAFTING", 58145, nil, 390, 0, nil, 50000, "Interface\\Icons\\INV_Jewelry_Ring_02" ) -- Stoneguard Band
	AddSpell( "professions", "JEWELCRAFTING", 58146, nil, 390, 0, nil, 50000, "Interface\\Icons\\INV_Jewelry_Ring_14" ) -- Shadowmight Ring
	AddSpell( "professions", "JEWELCRAFTING", 59759, nil, 400, 0, nil, 150000, "Interface\\Icons\\INV_Jewelcrafting_GoldenCrab" ) -- Figurine - Monarch Crab
	AddSpell( "professions", "JEWELCRAFTING", 62242, nil, 425, 0, nil, 150000, "Interface\\Icons\\INV_Misc_Gem_Diamond_02" ) -- Icy Prism
	AddSpell( "professions", "JEWELCRAFTING", 62941, nil, 300, 0, nil, 10000, "Interface\\Icons\\INV_Misc_Gem_01" ) -- Prismatic Black Diamond
	AddSpell( "professions", "JEWELCRAFTING", 63743, nil, 200, 0, nil, 3000, "Interface\\Icons\\INV_Jewelry_Necklace_04" ) -- Amulet of Truesight
	AddSpell( "professions", "JEWELCRAFTING", 64725, nil, 420, 0, nil, 100000, "Interface\\Icons\\INV_Jewelry_Necklace_24" ) -- Emerald Choker
	AddSpell( "professions", "JEWELCRAFTING", 64726, nil, 420, 0, nil, 100000, "Interface\\Icons\\INV_Jewelry_Necklace_16" ) -- Sky Sapphire Amulet
	AddSpell( "professions", "JEWELCRAFTING", 64727, nil, 420, 0, nil, 100000, "Interface\\Icons\\INV_Jewelry_Ring_34" ) -- Runed Mana Band
	AddSpell( "professions", "JEWELCRAFTING", 64728, nil, 420, 0, nil, 100000, "Interface\\Icons\\INV_Jewelry_Ring_72" ) -- Scarlet Signet
	AddSpell( "professions", "JEWELCRAFTING", 73222, nil, 425, 0, nil, 30000, "Interface\\Icons\\inv_misc_cutgemnormala" ) -- Bold Carnelian
	AddSpell( "professions", "JEWELCRAFTING", 73223, nil, 425, 0, nil, 30000, "Interface\\Icons\\inv_misc_cutgemnormala" ) -- Delicate Carnelian
	AddSpell( "professions", "JEWELCRAFTING", 73225, nil, 425, 0, nil, 30000, "Interface\\Icons\\inv_misc_cutgemnormala" ) -- Brilliant Carnelian
	AddSpell( "professions", "JEWELCRAFTING", 73226, nil, 425, 0, nil, 30000, "Interface\\Icons\\inv_misc_cutgemnormala" ) -- Precise Carnelian
	AddSpell( "professions", "JEWELCRAFTING", 73227, nil, 425, 0, nil, 30000, "Interface\\Icons\\inv_misc_cutgemnormal4a" ) -- Solid Zephyrite
	AddSpell( "professions", "JEWELCRAFTING", 73228, nil, 425, 0, nil, 30000, "Interface\\Icons\\inv_misc_cutgemnormal4a" ) -- Sparkling Zephyrite
	AddSpell( "professions", "JEWELCRAFTING", 73230, nil, 425, 0, nil, 30000, "Interface\\Icons\\inv_misc_cutgemnormal4a" ) -- Rigid Zephyrite
	AddSpell( "professions", "JEWELCRAFTING", 73232, nil, 425, 0, nil, 30000, "Interface\\Icons\\inv_misc_cutgemnormal6a" ) -- Smooth Alicite
	AddSpell( "professions", "JEWELCRAFTING", 73234, nil, 425, 0, nil, 30000, "Interface\\Icons\\inv_misc_cutgemnormal6a" ) -- Quick Alicite
	AddSpell( "professions", "JEWELCRAFTING", 73239, nil, 425, 0, nil, 30000, "Interface\\Icons\\inv_misc_cutgemnormal6a" ) -- Fractured Alicite
	AddSpell( "professions", "JEWELCRAFTING", 73240, nil, 425, 0, nil, 30000, "Interface\\Icons\\inv_misc_cutgemnormal2a" ) -- Sovereign Nightstone
	AddSpell( "professions", "JEWELCRAFTING", 73241, nil, 425, 0, nil, 30000, "Interface\\Icons\\inv_misc_cutgemnormal2a" ) -- Shifting Nightstone
	AddSpell( "professions", "JEWELCRAFTING", 73243, nil, 425, 0, nil, 30000, "Interface\\Icons\\inv_misc_cutgemnormal2a" ) -- Timeless Nightstone
	AddSpell( "professions", "JEWELCRAFTING", 73246, nil, 425, 0, nil, 30000, "Interface\\Icons\\inv_misc_cutgemnormal2a" ) -- Etched Nightstone
	AddSpell( "professions", "JEWELCRAFTING", 73247, nil, 425, 0, nil, 30000, "Interface\\Icons\\inv_misc_cutgemnormal2a" ) -- Glinting Nightstone
	AddSpell( "professions", "JEWELCRAFTING", 73249, nil, 425, 0, nil, 30000, "Interface\\Icons\\inv_misc_cutgemnormal2a" ) -- Veiled Nightstone
	AddSpell( "professions", "JEWELCRAFTING", 73250, nil, 425, 0, nil, 30000, "Interface\\Icons\\inv_misc_cutgemnormal2a" ) -- Accurate Nightstone
	AddSpell( "professions", "JEWELCRAFTING", 73266, nil, 425, 0, nil, 30000, "Interface\\Icons\\inv_misc_cutgemnormal3a" ) -- Reckless Hessonite
	AddSpell( "professions", "JEWELCRAFTING", 73267, nil, 425, 0, nil, 30000, "Interface\\Icons\\inv_misc_cutgemnormal3a" ) -- Skillful Hessonite
	AddSpell( "professions", "JEWELCRAFTING", 73268, nil, 425, 0, nil, 30000, "Interface\\Icons\\inv_misc_cutgemnormal3a" ) -- Adept Hessonite
	AddSpell( "professions", "JEWELCRAFTING", 73270, nil, 425, 0, nil, 30000, "Interface\\Icons\\inv_misc_cutgemnormal3a" ) -- Artful Hessonite
	AddSpell( "professions", "JEWELCRAFTING", 73274, nil, 425, 0, nil, 30000, "Interface\\Icons\\inv_misc_cutgemnormal5a" ) -- Jagged Jasper
	AddSpell( "professions", "JEWELCRAFTING", 73279, nil, 425, 0, nil, 30000, "Interface\\Icons\\inv_misc_cutgemnormal5a" ) -- Puissant Jasper
	AddSpell( "professions", "JEWELCRAFTING", 73281, nil, 425, 0, nil, 30000, "Interface\\Icons\\inv_misc_cutgemnormal5a" ) -- Sensei's Jasper
	AddSpell( "professions", "JEWELCRAFTING", 73318, 75, 425, 0, nil, 500000, nil ) -- Illustrious Grand Master Jewelcrafter
	AddSpell( "professions", "JEWELCRAFTING", 73478, nil, 500, 0, nil, 30000, "Interface\\Icons\\INV_Misc_Gem_Ruby_01" ) -- Fire Prism
	AddSpell( "professions", "JEWELCRAFTING", 73494, nil, 425, 0, nil, 30000, "Interface\\Icons\\inv_misc_stonering1" ) -- Jasper Ring
	AddSpell( "professions", "JEWELCRAFTING", 73495, nil, 450, 0, nil, 30000, "Interface\\Icons\\inv_misc_diamondring2" ) -- Hessonite Band
	AddSpell( "professions", "JEWELCRAFTING", 73496, nil, 435, 0, nil, 30000, "Interface\\Icons\\inv_misc_necklacea3" ) -- Alicite Pendant
	AddSpell( "professions", "JEWELCRAFTING", 73497, nil, 460, 0, nil, 30000, "Interface\\Icons\\inv_misc_stonenecklace" ) -- Nightstone Choker
	AddSpell( "professions", "JEWELCRAFTING", 73620, nil, 460, 0, nil, 30000, "Interface\\Icons\\inv_hand_1h_cataclysm_b_02 " ) -- Carnelian Spikes
	AddSpell( "professions", "JEWELCRAFTING", 73621, nil, 490, 0, nil, 30000, "Interface\\Icons\\inv_hand_1h_cataclysm_b_01" ) -- The Perforator
	AddSpell( "professions", "LEATHERWORKING",  2108, 5, nil, 0, nil, 10, nil ) -- Apprentice Leatherworker
	AddSpell( "professions", "LEATHERWORKING",  2153, nil, 15, 0, nil, 50, "Interface\\Icons\\INV_Pants_Wolf" ) -- Handstitched Leather Pants
	AddSpell( "professions", "LEATHERWORKING",  2159, nil, 85, 0, nil, 250, "Interface\\Icons\\INV_Misc_Cape_10" ) -- Fine Leather Cloak
	AddSpell( "professions", "LEATHERWORKING",  2160, nil, 40, 0, nil, 100, "Interface\\Icons\\INV_Chest_Leather_09" ) -- Embossed Leather Vest
	AddSpell( "professions", "LEATHERWORKING",  2161, nil, 55, 0, nil, 100, "Interface\\Icons\\INV_Boots_05" ) -- Embossed Leather Boots
	AddSpell( "professions", "LEATHERWORKING",  2162, nil, 60, 0, nil, 100, "Interface\\Icons\\INV_Helmet_48" ) -- Embossed Leather Cloak
	AddSpell( "professions", "LEATHERWORKING",  2165, nil, 100, 0, nil, 250, "Interface\\Icons\\INV_Misc_ArmorKit_15" ) -- Medium Armor Kit
	AddSpell( "professions", "LEATHERWORKING",  2166, nil, 120, 0, nil, 450, "Interface\\Icons\\INV_Chest_Leather_10" ) -- Toughened Leather Armor
	AddSpell( "professions", "LEATHERWORKING",  2167, nil, 100, 0, nil, 350, "Interface\\Icons\\INV_Boots_05" ) -- Dark Leather Boots
	AddSpell( "professions", "LEATHERWORKING",  2168, nil, 110, 0, nil, 350, "Interface\\Icons\\INV_Misc_Cape_10" ) -- Dark Leather Cloak
	AddSpell( "professions", "LEATHERWORKING",  3104, 10, 50, 0, nil, 500, nil ) -- Journeyman Leatherworker
	AddSpell( "professions", "LEATHERWORKING",  3753, nil, 25, 0, nil, 75, "Interface\\Icons\\INV_Belt_04" ) -- Handstitched Leather Belt
	AddSpell( "professions", "LEATHERWORKING",  3756, nil, 55, 0, nil, 150, "Interface\\Icons\\INV_Gauntlets_05" ) -- Embossed Leather Gloves
	AddSpell( "professions", "LEATHERWORKING",  3759, nil, 75, 0, nil, 200, "Interface\\Icons\\INV_Pants_02" ) -- Embossed Leather Pants
	AddSpell( "professions", "LEATHERWORKING",  3760, nil, 150, 0, nil, 600, "Interface\\Icons\\INV_Misc_Cape_07" ) -- Hillman's Cloak
	AddSpell( "professions", "LEATHERWORKING",  3761, nil, 85, 0, nil, 350, "Interface\\Icons\\INV_Chest_Leather_09" ) -- Fine Leather Tunic
	AddSpell( "professions", "LEATHERWORKING",  3763, nil, 80, 0, nil, 300, "Interface\\Icons\\INV_Belt_04" ) -- Fine Leather Belt
	AddSpell( "professions", "LEATHERWORKING",  3764, nil, 145, 0, nil, 500, "Interface\\Icons\\INV_Gauntlets_05" ) -- Hillman's Leather Gloves
	AddSpell( "professions", "LEATHERWORKING",  3766, nil, 125, 0, nil, 400, "Interface\\Icons\\INV_Belt_03" ) -- Dark Leather Belt
	AddSpell( "professions", "LEATHERWORKING",  3768, nil, 130, 0, nil, 500, "Interface\\Icons\\INV_Shoulder_08" ) -- Hillman's Shoulders
	AddSpell( "professions", "LEATHERWORKING",  3770, nil, 135, 0, nil, 500, "Interface\\Icons\\INV_Gauntlets_24" ) -- Toughened Leather Gloves
	AddSpell( "professions", "LEATHERWORKING",  3774, nil, 160, 0, nil, 1000, "Interface\\Icons\\INV_Belt_17" ) -- Green Leather Belt
	AddSpell( "professions", "LEATHERWORKING",  3776, nil, 180, 0, nil, 1200, "Interface\\Icons\\INV_Bracer_12" ) -- Green Leather Bracers
	AddSpell( "professions", "LEATHERWORKING",  3780, nil, 150, 0, nil, 750, "Interface\\Icons\\INV_Misc_ArmorKit_16" ) -- Heavy Armor Kit
	AddSpell( "professions", "LEATHERWORKING",  3811, 20, 125, 0, nil, 5000, nil ) -- Expert Leatherworker
	AddSpell( "professions", "LEATHERWORKING",  3816, nil, 35, 0, nil, 50, "Interface\\Icons\\INV_Misc_Pelt_Wolf_01" ) -- Cured Light Hide
	AddSpell( "professions", "LEATHERWORKING",  3817, nil, 100, 0, nil, 200, "Interface\\Icons\\INV_Misc_Pelt_Bear_02" ) -- Cured Medium Hide
	AddSpell( "professions", "LEATHERWORKING",  3818, nil, 150, 0, nil, 500, "Interface\\Icons\\INV_Misc_Pelt_Wolf_02" ) -- Cured Heavy Hide
	AddSpell( "professions", "LEATHERWORKING",  6661, nil, 190, 0, nil, 2000, "Interface\\Icons\\INV_Chest_Leather_04" ) -- Barbaric Harness
	AddSpell( "professions", "LEATHERWORKING",  7135, nil, 115, 0, nil, 400, "Interface\\Icons\\INV_Pants_09" ) -- Dark Leather Pants
	AddSpell( "professions", "LEATHERWORKING",  7147, nil, 160, 0, nil, 1000, "Interface\\Icons\\INV_Pants_02" ) -- Guardian Pants
	AddSpell( "professions", "LEATHERWORKING",  7151, nil, 175, 0, nil, 1200, "Interface\\Icons\\INV_Shoulder_08" ) -- Barbaric Shoulders
	AddSpell( "professions", "LEATHERWORKING",  7156, nil, 190, 0, nil, 2400, "Interface\\Icons\\INV_Gauntlets_05" ) -- Guardian Gloves
	AddSpell( "professions", "LEATHERWORKING",  9065, nil, 70, 0, nil, 150, "Interface\\Icons\\INV_Bracer_04" ) -- Light Leather Bracers
	AddSpell( "professions", "LEATHERWORKING",  9068, nil, 95, 0, nil, 400, "Interface\\Icons\\INV_Pants_02" ) -- Light Leather Pants
	AddSpell( "professions", "LEATHERWORKING",  9074, nil, 120, 0, nil, 500, "Interface\\Icons\\INV_Gauntlets_05" ) -- Nimble Leather Gloves
	AddSpell( "professions", "LEATHERWORKING",  9145, nil, 125, 0, nil, 500, "Interface\\Icons\\INV_Gauntlets_05" ) -- Fletcher's Gloves
	AddSpell( "professions", "LEATHERWORKING",  9196, nil, 175, 0, nil, 1500, "Interface\\Icons\\INV_Chest_Leather_03" ) -- Dusky Leather Armor
	AddSpell( "professions", "LEATHERWORKING",  9198, nil, 180, 0, nil, 2000, "Interface\\Icons\\INV_Misc_Cape_04" ) -- Frost Leather Cloak
	AddSpell( "professions", "LEATHERWORKING",  9201, nil, 185, 0, nil, 2000, "Interface\\Icons\\INV_Bracer_07" ) -- Dusky Bracers
	AddSpell( "professions", "LEATHERWORKING",  9206, nil, 195, 0, nil, 2500, "Interface\\Icons\\INV_Belt_06" ) -- Dusky Belt
	AddSpell( "professions", "LEATHERWORKING", 10482, nil, 200, 0, nil, 2000, "Interface\\Icons\\INV_Misc_Pelt_Bear_01" ) -- Cured Thick Hide
	AddSpell( "professions", "LEATHERWORKING", 10487, nil, 200, 0, nil, 2000, "Interface\\Icons\\INV_Misc_ArmorKit_07" ) -- Thick Armor Kit
	AddSpell( "professions", "LEATHERWORKING", 10499, nil, 205, 0, nil, 3000, "Interface\\Icons\\INV_Chest_Leather_03" ) -- Nightscape Tunic
	AddSpell( "professions", "LEATHERWORKING", 10507, nil, 205, 0, nil, 3000, "Interface\\Icons\\INV_Belt_24" ) -- Nightscape Headband
	AddSpell( "professions", "LEATHERWORKING", 10511, nil, 210, 0, nil, 3000, "Interface\\Icons\\INV_Chest_Chain_12" ) -- Turtle Scale Breastplate
	AddSpell( "professions", "LEATHERWORKING", 10518, nil, 210, 0, nil, 3500, "Interface\\Icons\\INV_Bracer_06" ) -- Turtle Scale Bracers
	AddSpell( "professions", "LEATHERWORKING", 10548, nil, 230, 0, nil, 4000, "Interface\\Icons\\INV_Pants_11" ) -- Nightscape Pants
	AddSpell( "professions", "LEATHERWORKING", 10552, nil, 230, 0, nil, 4000, "Interface\\Icons\\INV_Helmet_40" ) -- Turtle Scale Helm
	AddSpell( "professions", "LEATHERWORKING", 10556, nil, 235, 0, nil, 4500, "Interface\\Icons\\INV_Pants_02" ) -- Turtle Scale Leggings
	AddSpell( "professions", "LEATHERWORKING", 10558, nil, 235, 0, nil, 4500, "Interface\\Icons\\INV_Boots_05" ) -- Nightscape Boots
	AddSpell( "professions", "LEATHERWORKING", 10630, nil, 230, 0, nil, 10000, "Interface\\Icons\\INV_Gauntlets_30" ) -- Gauntlets of the Sea
	AddSpell( "professions", "LEATHERWORKING", 10632, nil, 250, 0, nil, 10000, "Interface\\Icons\\INV_Helmet_08" ) -- Helm of Fire
	AddSpell( "professions", "LEATHERWORKING", 10647, nil, 250, 0, nil, 10000, "Interface\\Icons\\INV_Chest_Leather_06" ) -- Feathered Breastplate
	AddSpell( "professions", "LEATHERWORKING", 10650, nil, 255, 0, nil, 10000, "Interface\\Icons\\INV_Chest_Chain_07" ) -- Dragonscale Breastplate
	AddSpell( "professions", "LEATHERWORKING", 10662, 35, 200, 0, nil, 50000, nil ) -- Artisan Leatherworker
	AddSpell( "professions", "LEATHERWORKING", 19047, nil, 250, 0, nil, 5000, "Interface\\Icons\\INV_Misc_Pelt_Bear_03" ) -- Cured Rugged Hide
	AddSpell( "professions", "LEATHERWORKING", 19052, nil, 265, 0, nil, 10000, "Interface\\Icons\\INV_Bracer_07" ) -- Wicked Leather Bracers
	AddSpell( "professions", "LEATHERWORKING", 19055, nil, 270, 0, nil, 10000, "Interface\\Icons\\INV_Gauntlets_31" ) -- Runic Leather Gauntlets
	AddSpell( "professions", "LEATHERWORKING", 19058, nil, 250, 0, nil, 5000, "Interface\\Icons\\INV_Misc_ArmorKit_09" ) -- Rugged Armor Kit
	AddSpell( "professions", "LEATHERWORKING", 19065, nil, 275, 0, nil, 10000, "Interface\\Icons\\INV_Bracer_11" ) -- Runic Leather Bracers
	AddSpell( "professions", "LEATHERWORKING", 19071, nil, 280, 0, nil, 10000, "Interface\\Icons\\INV_Misc_Bandage_13" ) -- Wicked Leather Headband
	AddSpell( "professions", "LEATHERWORKING", 19072, nil, 280, 0, nil, 10000, "Interface\\Icons\\INV_Belt_23" ) -- Runic Leather Belt
	AddSpell( "professions", "LEATHERWORKING", 19082, nil, 290, 0, nil, 15000, "Interface\\Icons\\INV_Misc_Bandage_11" ) -- Runic Leather Headband
	AddSpell( "professions", "LEATHERWORKING", 19083, nil, 290, 0, nil, 15000, "Interface\\Icons\\INV_Pants_12" ) -- Wicked Leather Pants
	AddSpell( "professions", "LEATHERWORKING", 19091, nil, 300, 0, nil, 15000, "Interface\\Icons\\INV_Pants_02" ) -- Runic Leather Pants
	AddSpell( "professions", "LEATHERWORKING", 19092, nil, 300, 0, nil, 15000, "Interface\\Icons\\INV_Belt_03" ) -- Wicked Leather Belt
	AddSpell( "professions", "LEATHERWORKING", 19098, nil, 300, 0, nil, 15000, "Interface\\Icons\\INV_Chest_Plate06" ) -- Wicked Leather Armor
	AddSpell( "professions", "LEATHERWORKING", 19102, nil, 300, 0, nil, 15000, "Interface\\Icons\\INV_Chest_Leather_07" ) -- Runic Leather Armor
	AddSpell( "professions", "LEATHERWORKING", 19103, nil, 300, 0, nil, 15000, "Interface\\Icons\\INV_Shoulder_15" ) -- Runic Leather Shoulders
	AddSpell( "professions", "LEATHERWORKING", 20648, nil, 100, 0, nil, 500, "Interface\\Icons\\INV_Misc_LeatherScrap_05" ) -- Medium Leather
	AddSpell( "professions", "LEATHERWORKING", 20649, nil, 150, 0, nil, 1000, "Interface\\Icons\\INV_Misc_LeatherScrap_07" ) -- Heavy Leather
	AddSpell( "professions", "LEATHERWORKING", 20650, nil, 200, 0, nil, 4000, "Interface\\Icons\\INV_Misc_LeatherScrap_08" ) -- Thick Leather
	AddSpell( "professions", "LEATHERWORKING", 22331, nil, 250, 0, nil, 5000, "Interface\\Icons\\INV_Misc_LeatherScrap_02" ) -- Rugged Leather
	AddSpell( "professions", "LEATHERWORKING", 24654, nil, 300, 0, nil, 50000, "Interface\\Icons\\INV_Pants_Mail_15" ) -- Blue Dragonscale Leggings
	AddSpell( "professions", "LEATHERWORKING", 24655, nil, 280, 0, nil, 30000, "Interface\\Icons\\INV_Gauntlets_12" ) -- Green Dragonscale Gauntlets
	AddSpell( "professions", "LEATHERWORKING", 32454, nil, 300, 0, nil, 10000, "Interface\\Icons\\INV_Misc_LeatherScrap_10" ) -- Knothide Leather
	AddSpell( "professions", "LEATHERWORKING", 32455, nil, 325, 0, nil, 20000, "Interface\\Icons\\INV_Misc_LeatherScrap_11" ) -- Heavy Knothide Leather
	AddSpell( "professions", "LEATHERWORKING", 32456, nil, 300, 0, nil, 15000, "Interface\\Icons\\INV_Misc_ArmorKit_24" ) -- Knothide Armor Kit
	AddSpell( "professions", "LEATHERWORKING", 32462, nil, 300, 0, nil, 15000, "Interface\\Icons\\INV_Gauntlets_04" ) -- Felscale Gloves
	AddSpell( "professions", "LEATHERWORKING", 32463, nil, 310, 0, nil, 18000, "Interface\\Icons\\INV_Boots_Chain_08" ) -- Felscale Boots
	AddSpell( "professions", "LEATHERWORKING", 32464, nil, 320, 0, nil, 20000, "Interface\\Icons\\INV_Pants_Mail_08" ) -- Felscale Pants
	AddSpell( "professions", "LEATHERWORKING", 32465, nil, 335, 0, nil, 25000, "Interface\\Icons\\INV_Chest_Chain_13" ) -- Felscale Breastplate
	AddSpell( "professions", "LEATHERWORKING", 32466, nil, 300, 0, nil, 15000, "Interface\\Icons\\INV_Pants_Mail_07" ) -- Scaled Draenic Pants
	AddSpell( "professions", "LEATHERWORKING", 32467, nil, 310, 0, nil, 18000, "Interface\\Icons\\INV_Gauntlets_04" ) -- Scaled Draenic Gloves
	AddSpell( "professions", "LEATHERWORKING", 32468, nil, 325, 0, nil, 20000, "Interface\\Icons\\INV_Chest_Chain_16" ) -- Scaled Draenic Vest
	AddSpell( "professions", "LEATHERWORKING", 32469, nil, 335, 0, nil, 25000, "Interface\\Icons\\INV_Boots_Chain_01" ) -- Scaled Draenic Boots
	AddSpell( "professions", "LEATHERWORKING", 32470, nil, 300, 0, nil, 15000, "Interface\\Icons\\INV_Gauntlets_04" ) -- Thick Draenic Gloves
	AddSpell( "professions", "LEATHERWORKING", 32471, nil, 315, 0, nil, 18000, "Interface\\Icons\\INV_Pants_Leather_07" ) -- Thick Draenic Pants
	AddSpell( "professions", "LEATHERWORKING", 32472, nil, 320, 0, nil, 20000, "Interface\\Icons\\INV_Boots_Chain_01" ) -- Thick Draenic Boots
	AddSpell( "professions", "LEATHERWORKING", 32473, nil, 330, 0, nil, 25000, "Interface\\Icons\\INV_Chest_Leather_07" ) -- Thick Draenic Vest
	AddSpell( "professions", "LEATHERWORKING", 32478, nil, 300, 0, nil, 15000, "Interface\\Icons\\INV_Boots_Chain_01" ) -- Wild Draenish Boots
	AddSpell( "professions", "LEATHERWORKING", 32479, nil, 310, 0, nil, 18000, "Interface\\Icons\\INV_Gauntlets_04" ) -- Wild Draenish Gloves
	AddSpell( "professions", "LEATHERWORKING", 32480, nil, 320, 0, nil, 20000, "Interface\\Icons\\INV_Pants_Leather_07" ) -- Wild Draenish Leggings
	AddSpell( "professions", "LEATHERWORKING", 32481, nil, 330, 0, nil, 25000, "Interface\\Icons\\INV_Chest_Leather_07" ) -- Wild Draenish Vest
	AddSpell( "professions", "LEATHERWORKING", 32549, 50, 275, 0, nil, 100000, nil ) -- Master Leatherworker
	AddSpell( "professions", "LEATHERWORKING", 35540, nil, 340, 0, nil, 20000, "Interface\\Icons\\INV_Misc_Drum_03" ) -- Drums of War
	AddSpell( "professions", "LEATHERWORKING", 36074, nil, 260, 0, nil, 10000, "Interface\\Icons\\INV_Pants_Leather_03" ) -- Blackstorm Leggings
	AddSpell( "professions", "LEATHERWORKING", 36075, nil, 260, 0, nil, 10000, "Interface\\Icons\\INV_Pants_Leather_03" ) -- Wildfeather Leggings
	AddSpell( "professions", "LEATHERWORKING", 36076, nil, 260, 0, nil, 10000, "Interface\\Icons\\INV_Pants_Plate_20" ) -- Dragonstrike Leggings
	AddSpell( "professions", "LEATHERWORKING", 36077, nil, 330, 0, nil, 40000, "Interface\\Icons\\INV_Chest_Cloth_07" ) -- Primalstorm Breastplate
	AddSpell( "professions", "LEATHERWORKING", 36078, nil, 330, 0, nil, 40000, "Interface\\Icons\\INV_Chest_Cloth_06" ) -- Living Crystal Breastplate
	AddSpell( "professions", "LEATHERWORKING", 36079, nil, 330, 0, nil, 40000, "Interface\\Icons\\INV_Chest_Plate06" ) -- Golden Dragonstrike Breastplate
	AddSpell( "professions", "LEATHERWORKING", 44770, nil, 350, 0, nil, 50000, "Interface\\Icons\\INV_Misc_ArmorKit_08" ) -- Glove Reinforcements
	AddSpell( "professions", "LEATHERWORKING", 44970, nil, 350, 0, nil, 50000, "Interface\\Icons\\INV_Misc_ArmorKit_25" ) -- Heavy Knothide Armor Kit
	AddSpell( "professions", "LEATHERWORKING", 45100, nil, 300, 0, nil, 15000, "Interface\\Icons\\INV_Misc_Bag_20" ) -- Leatherworker's Satchel
	AddSpell( "professions", "LEATHERWORKING", 50936, nil, 390, 0, nil, 80000, "Interface\\Icons\\INV_Misc_LeatherScrap_19" ) -- Heavy Borean Leather
	AddSpell( "professions", "LEATHERWORKING", 50938, nil, 375, 0, nil, 30000, "Interface\\Icons\\INV_Chest_Fur" ) -- Iceborne Chestguard
	AddSpell( "professions", "LEATHERWORKING", 50939, nil, 370, 0, nil, 30000, "Interface\\Icons\\INV_Pants_06" ) -- Iceborne Leggings
	AddSpell( "professions", "LEATHERWORKING", 50940, nil, 380, 0, nil, 30000, "Interface\\Icons\\INV_Shoulder_74" ) -- Iceborne Shoulderpads
	AddSpell( "professions", "LEATHERWORKING", 50941, nil, 370, 0, nil, 30000, "Interface\\Icons\\INV_Gauntlets_05" ) -- Iceborne Gloves
	AddSpell( "professions", "LEATHERWORKING", 50942, nil, 375, 0, nil, 30000, "Interface\\Icons\\INV_Boots_04" ) -- Iceborne Boots
	AddSpell( "professions", "LEATHERWORKING", 50943, nil, 380, 0, nil, 30000, "Interface\\Icons\\INV_Belt_02" ) -- Iceborne Belt
	AddSpell( "professions", "LEATHERWORKING", 50944, nil, 370, 0, nil, 30000, "Interface\\Icons\\INV_Chest_Fur" ) -- Arctic Chestpiece
	AddSpell( "professions", "LEATHERWORKING", 50945, nil, 375, 0, nil, 30000, "Interface\\Icons\\INV_Pants_06" ) -- Arctic Leggings
	AddSpell( "professions", "LEATHERWORKING", 50946, nil, 380, 0, nil, 30000, "Interface\\Icons\\INV_Shoulder_73" ) -- Arctic Shoulderpads
	AddSpell( "professions", "LEATHERWORKING", 50947, nil, 375, 0, nil, 30000, "Interface\\Icons\\INV_Gauntlets_05" ) -- Arctic Gloves
	AddSpell( "professions", "LEATHERWORKING", 50948, nil, 370, 0, nil, 30000, "Interface\\Icons\\INV_Boots_04" ) -- Arctic Boots
	AddSpell( "professions", "LEATHERWORKING", 50949, nil, 380, 0, nil, 30000, "Interface\\Icons\\INV_Belt_02" ) -- Arctic Belt
	AddSpell( "professions", "LEATHERWORKING", 50950, nil, 375, 0, nil, 30000, "Interface\\Icons\\INV_Chest_Chain_13" ) -- Frostscale Chestguard
	AddSpell( "professions", "LEATHERWORKING", 50951, nil, 370, 0, nil, 30000, "Interface\\Icons\\INV_Pants_Mail_15" ) -- Frostscale Leggings
	AddSpell( "professions", "LEATHERWORKING", 50952, nil, 375, 0, nil, 30000, "Interface\\Icons\\INV_Shoulder_76" ) -- Frostscale Shoulders
	AddSpell( "professions", "LEATHERWORKING", 50953, nil, 380, 0, nil, 30000, "Interface\\Icons\\INV_Gauntlets_30" ) -- Frostscale Gloves
	AddSpell( "professions", "LEATHERWORKING", 50954, nil, 380, 0, nil, 30000, "Interface\\Icons\\INV_Boots_Chain_06" ) -- Frostscale Boots
	AddSpell( "professions", "LEATHERWORKING", 50955, nil, 370, 0, nil, 30000, "Interface\\Icons\\INV_Belt_02" ) -- Frostscale Belt
	AddSpell( "professions", "LEATHERWORKING", 50956, nil, 375, 0, nil, 30000, "Interface\\Icons\\INV_Chest_Chain_13" ) -- Nerubian Chestguard
	AddSpell( "professions", "LEATHERWORKING", 50957, nil, 370, 0, nil, 30000, "Interface\\Icons\\INV_Pants_Leather_09" ) -- Nerubian Legguards
	AddSpell( "professions", "LEATHERWORKING", 50958, nil, 380, 0, nil, 30000, "Interface\\Icons\\INV_Shoulder_16" ) -- Nerubian Shoulders
	AddSpell( "professions", "LEATHERWORKING", 50959, nil, 370, 0, nil, 30000, "Interface\\Icons\\INV_Gauntlets_05" ) -- Nerubian Gloves
	AddSpell( "professions", "LEATHERWORKING", 50960, nil, 380, 0, nil, 30000, "Interface\\Icons\\INV_Boots_Chain_07" ) -- Nerubian Boots
	AddSpell( "professions", "LEATHERWORKING", 50961, nil, 375, 0, nil, 30000, "Interface\\Icons\\INV_Belt_02" ) -- Nerubian Belt
	AddSpell( "professions", "LEATHERWORKING", 50962, nil, 350, 0, nil, 50000, "Interface\\Icons\\INV_Misc_ArmorKit_28" ) -- Borean Armor Kit
	AddSpell( "professions", "LEATHERWORKING", 50963, nil, 395, 0, nil, 80000, "Interface\\Icons\\INV_Misc_ArmorKit_30" ) -- Heavy Borean Armor Kit
	AddSpell( "professions", "LEATHERWORKING", 50964, nil, 405, 0, nil, 50000, "Interface\\Icons\\INV_Misc_ArmorKit_31" ) -- Jormungar Leg Armor
	AddSpell( "professions", "LEATHERWORKING", 50965, nil, 425, 0, nil, 80000, "Interface\\Icons\\INV_Misc_ArmorKit_32" ) -- Frosthide Leg Armor
	AddSpell( "professions", "LEATHERWORKING", 50966, nil, 400, 0, nil, 50000, "Interface\\Icons\\INV_Misc_ArmorKit_29" ) -- Nerubian Leg Armor
	AddSpell( "professions", "LEATHERWORKING", 50967, nil, 425, 0, nil, 80000, "Interface\\Icons\\INV_Misc_ArmorKit_33" ) -- Icescale Leg Armor
	AddSpell( "professions", "LEATHERWORKING", 51302, 65, 350, 0, nil, 350000, nil ) -- Grand Master Leatherworker
	AddSpell( "professions", "LEATHERWORKING", 51568, nil, 400, 0, nil, 100000, "Interface\\Icons\\INV_Boots_07" ) -- Black Chitinguard Boots
	AddSpell( "professions", "LEATHERWORKING", 51569, nil, 395, 0, nil, 80000, "Interface\\Icons\\INV_Pants_Leather_09" ) -- Dark Arctic Leggings
	AddSpell( "professions", "LEATHERWORKING", 51570, nil, 395, 0, nil, 80000, "Interface\\Icons\\INV_Chest_Leather_01" ) -- Dark Arctic Chestpiece
	AddSpell( "professions", "LEATHERWORKING", 51571, nil, 385, 0, nil, 30000, "Interface\\Icons\\INV_Bracer_08" ) -- Arctic Wristguards
	AddSpell( "professions", "LEATHERWORKING", 51572, nil, 385, 0, nil, 30000, "Interface\\Icons\\INV_Helmet_110" ) -- Arctic Helm
	AddSpell( "professions", "LEATHERWORKING", 55199, nil, 395, 0, nil, 80000, "Interface\\Icons\\INV_Misc_Cape_14" ) -- Cloak of Tormented Skies
	AddSpell( "professions", "LEATHERWORKING", 57683, nil, 400, 0, nil, 70000, nil ) -- Fur Lining - Attack Power
	AddSpell( "professions", "LEATHERWORKING", 57690, nil, 400, 0, nil, 70000, nil ) -- Fur Lining - Stamina
	AddSpell( "professions", "LEATHERWORKING", 57691, nil, 400, 0, nil, 70000, nil ) -- Fur Lining - Spell Power
	AddSpell( "professions", "LEATHERWORKING", 60583, nil, 405, 0, nil, 50000, nil ) -- Jormungar Leg Reinforcements
	AddSpell( "professions", "LEATHERWORKING", 60584, nil, 400, 0, nil, 50000, nil ) -- Nerubian Leg Reinforcements
	AddSpell( "professions", "LEATHERWORKING", 60599, nil, 385, 0, nil, 30000, "Interface\\Icons\\INV_Bracer_15" ) -- Frostscale Bracers
	AddSpell( "professions", "LEATHERWORKING", 60600, nil, 385, 0, nil, 30000, "Interface\\Icons\\INV_Helmet_11" ) -- Frostscale Helm
	AddSpell( "professions", "LEATHERWORKING", 60601, nil, 395, 0, nil, 80000, "Interface\\Icons\\INV_Pants_Mail_15" ) -- Dark Frostscale Leggings
	AddSpell( "professions", "LEATHERWORKING", 60604, nil, 395, 0, nil, 80000, "Interface\\Icons\\INV_Chest_Chain_13" ) -- Dark Frostscale Breastplate
	AddSpell( "professions", "LEATHERWORKING", 60605, nil, 400, 0, nil, 100000, "Interface\\Icons\\INV_Boots_Chain_06" ) -- Dragonstompers
	AddSpell( "professions", "LEATHERWORKING", 60607, nil, 385, 0, nil, 30000, "Interface\\Icons\\INV_Bracer_10" ) -- Iceborne Wristguards
	AddSpell( "professions", "LEATHERWORKING", 60608, nil, 385, 0, nil, 30000, "Interface\\Icons\\INV_Helmet_109" ) -- Iceborne Helm
	AddSpell( "professions", "LEATHERWORKING", 60611, nil, 395, 0, nil, 80000, "Interface\\Icons\\INV_Pants_06" ) -- Dark Iceborne Leggings
	AddSpell( "professions", "LEATHERWORKING", 60613, nil, 395, 0, nil, 80000, "Interface\\Icons\\INV_Chest_Fur" ) -- Dark Iceborne Chestguard
	AddSpell( "professions", "LEATHERWORKING", 60620, nil, 400, 0, nil, 100000, "Interface\\Icons\\INV_Boots_04" ) -- Bugsquashers
	AddSpell( "professions", "LEATHERWORKING", 60622, nil, 385, 0, nil, 30000, "Interface\\Icons\\INV_Bracer_10" ) -- Nerubian Bracers
	AddSpell( "professions", "LEATHERWORKING", 60624, nil, 385, 0, nil, 30000, "Interface\\Icons\\INV_Helmet_110" ) -- Nerubian Helm
	AddSpell( "professions", "LEATHERWORKING", 60627, nil, 395, 0, nil, 80000, "Interface\\Icons\\INV_Pants_Mail_14" ) -- Dark Nerubian Leggings
	AddSpell( "professions", "LEATHERWORKING", 60629, nil, 395, 0, nil, 80000, "Interface\\Icons\\INV_Chest_Chain_13" ) -- Dark Nerubian Chestpiece
	AddSpell( "professions", "LEATHERWORKING", 60630, nil, 400, 0, nil, 80000, "Interface\\Icons\\INV_Boots_Chain_07" ) -- Scaled Icewalkers
	AddSpell( "professions", "LEATHERWORKING", 60631, nil, 380, 0, nil, 80000, "Interface\\Icons\\INV_Misc_Cape_14" ) -- Cloak of Harsh Winds
	AddSpell( "professions", "LEATHERWORKING", 60637, nil, 440, 0, nil, 200000, "Interface\\Icons\\INV_Misc_Cape_13" ) -- Ice Striker's Cloak
	AddSpell( "professions", "LEATHERWORKING", 60640, nil, 440, 0, nil, 200000, "Interface\\Icons\\INV_Misc_Cape_14" ) -- Durable Nerubhide Cape
	AddSpell( "professions", "LEATHERWORKING", 60643, nil, 415, 0, nil, 50000, "Interface\\Icons\\INV_Misc_Bag_13" ) -- Pack of Endless Pockets
	AddSpell( "professions", "LEATHERWORKING", 60649, nil, 425, 0, nil, 100000, "Interface\\Icons\\INV_Chest_Chain_15" ) -- Razorstrike Breastplate
	AddSpell( "professions", "LEATHERWORKING", 60651, nil, 420, 0, nil, 100000, "Interface\\Icons\\INV_Shoulder_69" ) -- Virulent Spaulders
	AddSpell( "professions", "LEATHERWORKING", 60652, nil, 420, 0, nil, 100000, "Interface\\Icons\\INV_Bracer_06" ) -- Eaglebane Bracers
	AddSpell( "professions", "LEATHERWORKING", 60655, nil, 425, 0, nil, 200000, "Interface\\Icons\\INV_Helmet_121" ) -- Nightshock Hood
	AddSpell( "professions", "LEATHERWORKING", 60658, nil, 420, 0, nil, 200000, "Interface\\Icons\\INV_Belt_22" ) -- Nightshock Girdle
	AddSpell( "professions", "LEATHERWORKING", 60660, nil, 425, 0, nil, 100000, "Interface\\Icons\\INV_Pants_Leather_09" ) -- Leggings of Visceral Strikes
	AddSpell( "professions", "LEATHERWORKING", 60665, nil, 420, 0, nil, 100000, "Interface\\Icons\\INV_Gauntlets_30" ) -- Seafoam Gauntlets
	AddSpell( "professions", "LEATHERWORKING", 60666, nil, 420, 0, nil, 80000, "Interface\\Icons\\INV_Boots_07" ) -- Jormscale Footpads
	AddSpell( "professions", "LEATHERWORKING", 60669, nil, 425, 0, nil, 100000, "Interface\\Icons\\INV_Chest_Leather_14" ) -- Wildscale Breastplate
	AddSpell( "professions", "LEATHERWORKING", 60671, nil, 420, 0, nil, 100000, "Interface\\Icons\\INV_Shoulder_75" ) -- Purehorn Spaulders
	AddSpell( "professions", "LEATHERWORKING", 62448, nil, 425, 0, nil, 80000, "Interface\\Icons\\INV_Misc_ArmorKit_18" ) -- Earthen Leg Armor
	AddSpell( "professions", "LEATHERWORKING", 64661, nil, 350, 0, nil, 50000, "Interface\\Icons\\INV_Misc_LeatherScrap_15" ) -- Borean Leather
	AddSpell( "professions", "LEATHERWORKING", 69386, nil, 450, 0, nil, 200000, "Interface\\Icons\\INV_Misc_Drum_03" ) -- Drums of Forgotten Kings
	AddSpell( "professions", "LEATHERWORKING", 69388, nil, 450, 0, nil, 200000, "Interface\\Icons\\INV_Misc_Drum_07" ) -- Drums of the Wild
	AddSpell( "professions", "LEATHERWORKING", 78379, nil, 425, 0, nil, 75000, "Interface\\Icons\\inv_misc_armorkit_28" ) -- Savage Armor Kit
	AddSpell( "professions", "LEATHERWORKING", 78380, nil, 460, 0, nil, 75000, "Interface\\Icons\\inv_misc_cape_07" ) -- Savage Cloak
	AddSpell( "professions", "LEATHERWORKING", 78388, nil, 460, 0, nil, 75000, "Interface\\Icons\\inv_bracer_leather_cataclysm_b_01" ) -- Tsunami Bracers
	AddSpell( "professions", "LEATHERWORKING", 78396, nil, 470, 0, nil, 75000, "Interface\\Icons\\inv_belt_leather_cataclysm_b_01" ) -- Tsunami Belt
	AddSpell( "professions", "LEATHERWORKING", 78398, nil, 450, 0, nil, 75000, "Interface\\Icons\\inv_bracer_leather_cataclysm_b_01" ) -- Darkbrand Bracers
	AddSpell( "professions", "LEATHERWORKING", 78399, nil, 465, 0, nil, 75000, "Interface\\Icons\\inv_gauntlets_leather_cataclysm_b_01" ) -- Darkbrand Gloves
	AddSpell( "professions", "LEATHERWORKING", 78405, nil, 470, 0, nil, 75000, "Interface\\Icons\\inv_misc_cape_cataclysm_tank_b_01" ) -- Hardened Scale Cloak
	AddSpell( "professions", "LEATHERWORKING", 78406, nil, 475, 0, nil, 85000, "Interface\\Icons\\inv_gauntlets_leather_cataclysm_b_01" ) -- Tsunami Gloves
	AddSpell( "professions", "LEATHERWORKING", 78407, nil, 465, 0, nil, 75000, "Interface\\Icons\\inv_boots_leather_cataclysm_b_01" ) -- Darkbrand Boots
	AddSpell( "professions", "LEATHERWORKING", 78410, nil, 450, 0, nil, 75000, "Interface\\Icons\\inv_boots_leather_cataclysm_b_01" ) -- Tsunami Boots
	AddSpell( "professions", "LEATHERWORKING", 78411, nil, 475, 0, nil, 85000, "Interface\\Icons\\inv_shoulder_leather_cataclysm_b_01" ) -- Darkbrand Shoulders
	AddSpell( "professions", "LEATHERWORKING", 78415, nil, 455, 0, nil, 75000, "Interface\\Icons\\inv_shoulder_leather_cataclysm_b_01" ) -- Tsunami Shoulders
	AddSpell( "professions", "LEATHERWORKING", 78416, nil, 455, 0, nil, 75000, "Interface\\Icons\\inv_belt_leather_cataclysm_b_01" ) -- Darkbrand Belt
	AddSpell( "professions", "LEATHERWORKING", 78419, nil, 475, 0, nil, 85000, "Interface\\Icons\\INV_Misc_ArmorKit_26" ) -- Scorched Leg Armor
	AddSpell( "professions", "LEATHERWORKING", 78420, nil, 480, 0, nil, 85000, "Interface\\Icons\\INV_Misc_ArmorKit_29" ) -- Twilight Leg Armor
	AddSpell( "professions", "LEATHERWORKING", 78423, nil, 490, 0, nil, 85000, "Interface\\Icons\\inv_chest_leather_cataclysm_b_01" ) -- Tsunami Chestguard
	AddSpell( "professions", "LEATHERWORKING", 78424, nil, 490, 0, nil, 85000, "Interface\\Icons\\inv_helmet_leather_cataclysm_b_01" ) -- Darkbrand Helm
	AddSpell( "professions", "LEATHERWORKING", 78427, nil, 480, 0, nil, 85000, "Interface\\Icons\\inv_pants_leather_cataclysm_b_01" ) -- Tsunami Leggings
	AddSpell( "professions", "LEATHERWORKING", 78428, nil, 480, 0, nil, 85000, "Interface\\Icons\\inv_chest_leather_cataclysm_b_01" ) -- Darkbrand Chestguard
	AddSpell( "professions", "LEATHERWORKING", 78432, nil, 485, 0, nil, 85000, "Interface\\Icons\\inv_helmet_leather_cataclysm_b_01" ) -- Tsunami Helm
	AddSpell( "professions", "LEATHERWORKING", 78433, nil, 485, 0, nil, 85000, "Interface\\Icons\\inv_pants_leather_cataclysm_b_01" ) -- Darkbrand Leggings
	AddSpell( "professions", "LEATHERWORKING", 78436, nil, 485, 0, nil, 85000, "Interface\\Icons\\item_savageleatherhide" ) -- Heavy Savage Leather
	AddSpell( "professions", "LEATHERWORKING", 78437, nil, 485, 0, nil, 85000, "Interface\\Icons\\inv_misc_armorkit_30" ) -- Heavy Savage Armor Kit
	AddSpell( "professions", "LEATHERWORKING", 78438, nil, 495, 0, nil, 85000, "Interface\\Icons\\inv_misc_cape_cataclysm_melee_c_01" ) -- Cloak of Beasts
	AddSpell( "professions", "LEATHERWORKING", 78439, nil, 495, 0, nil, 85000, "Interface\\Icons\\inv_misc_cape_cataclysm_tank_c_01" ) -- Cloak of War
	AddSpell( "professions", "LEATHERWORKING", 81199, 75, 425, 0, nil, 500000, nil ) -- Illustrious Grand Master Leatherworker
	AddSpell( "professions", "LEATHERWORKING", 84950, nil, 425, 0, nil, 75000, "Interface\\Icons\\item_savageleather" ) -- Savage Leather
	AddSpell( "professions", "LEATHERWORKING", 85007, nil, 500, 0, nil, 100000, nil ) -- Draconic Embossment - Stamina
	AddSpell( "professions", "LEATHERWORKING", 85008, nil, 500, 0, nil, 100000, nil ) -- Draconic Embossment - Agility
	AddSpell( "professions", "LEATHERWORKING", 85009, nil, 500, 0, nil, 100000, nil ) -- Draconic Embossment - Strength
	AddSpell( "professions", "LEATHERWORKING", 85010, nil, 500, 0, nil, 100000, nil ) -- Draconic Embossment - Intellect
	AddSpell( "professions", "LEATHERWORKING", 85067, nil, 465, 0, nil, 75000, nil ) -- Dragonbone Leg Reinforcements
	AddSpell( "professions", "LEATHERWORKING", 85068, nil, 465, 0, nil, 75000, nil ) -- Charscale Leg Reinforcements
	AddSpell( "professions", "MINING",  2575, nil, nil, 0, nil, 10, nil ) -- Apprentice Miner
	AddSpell( "professions", "MINING",  2576, nil, 50, 0, nil, 500, nil ) -- Journeyman Miner
	AddSpell( "professions", "MINING",  2658, nil, 75, 0, nil, 200, "Interface\\Icons\\INV_Ingot_01" ) -- Smelt Silver
	AddSpell( "professions", "MINING",  2659, nil, 65, 0, nil, 200, "Interface\\Icons\\INV_Ingot_Bronze" ) -- Smelt Bronze
	AddSpell( "professions", "MINING",  3304, nil, 65, 0, nil, 50, "Interface\\Icons\\INV_Ingot_05" ) -- Smelt Tin
	AddSpell( "professions", "MINING",  3307, nil, 125, 0, nil, 500, "Interface\\Icons\\INV_Ingot_Iron" ) -- Smelt Iron
	AddSpell( "professions", "MINING",  3308, nil, 155, 0, nil, 2500, "Interface\\Icons\\INV_Ingot_03" ) -- Smelt Gold
	AddSpell( "professions", "MINING",  3564, 10, 125, 0, nil, 5000, nil ) -- Expert Miner
	AddSpell( "professions", "MINING",  3569, nil, 165, 0, nil, 2500, "Interface\\Icons\\INV_Ingot_Steel" ) -- Smelt Steel
	AddSpell( "professions", "MINING", 10097, nil, 175, 0, nil, 5000, "Interface\\Icons\\INV_Ingot_06" ) -- Smelt Mithril
	AddSpell( "professions", "MINING", 10098, nil, 230, 0, nil, 10000, "Interface\\Icons\\INV_Ingot_08" ) -- Smelt Truesilver
	AddSpell( "professions", "MINING", 10248, 25, 200, 0, nil, 50000, nil ) -- Artisan Miner
	AddSpell( "professions", "MINING", 16153, nil, 230, 0, nil, 20000, "Interface\\Icons\\INV_Ingot_07" ) -- Smelt Thorium
	AddSpell( "professions", "MINING", 29354, 40, 275, 0, nil, 100000, nil ) -- Master Miner
	AddSpell( "professions", "MINING", 29356, nil, 275, 0, nil, 40000, "Interface\\Icons\\INV_Ingot_FelIron" ) -- Smelt Fel Iron
	AddSpell( "professions", "MINING", 29358, nil, 325, 0, nil, 40000, "Interface\\Icons\\INV_Ingot_10" ) -- Smelt Adamantite
	AddSpell( "professions", "MINING", 29359, nil, 350, 0, nil, 40000, "Interface\\Icons\\INV_Ingot_11" ) -- Smelt Eternium
	AddSpell( "professions", "MINING", 29360, nil, 350, 0, nil, 40000, "Interface\\Icons\\INV_Ingot_Felsteel" ) -- Smelt Felsteel
	AddSpell( "professions", "MINING", 29361, nil, 375, 0, nil, 100000, "Interface\\Icons\\INV_Ingot_09" ) -- Smelt Khorium
	AddSpell( "professions", "MINING", 29686, nil, 375, 0, nil, 100000, "Interface\\Icons\\INV_Ingot_Adamantite" ) -- Smelt Hardened Adamantite
	AddSpell( "professions", "MINING", 35750, nil, 300, 0, nil, 10000, nil ) -- Earth Shatter
	AddSpell( "professions", "MINING", 35751, nil, 300, 0, nil, 10000, nil ) -- Fire Sunder
	AddSpell( "professions", "MINING", 49252, nil, 350, 0, nil, 100000, "Interface\\Icons\\INV_Ingot_Cobalt" ) -- Smelt Cobalt
	AddSpell( "professions", "MINING", 49258, nil, 400, 0, nil, 150000, "Interface\\Icons\\INV_Ingot_Yoggthorite" ) -- Smelt Saronite
	AddSpell( "professions", "MINING", 50310, 55, 350, 0, nil, 350000, nil ) -- Grand Master Miner
	AddSpell( "professions", "MINING", 55208, nil, 450, 0, nil, 200000, "Interface\\Icons\\INV_Ingot_Titansteel_blue" ) -- Smelt Titansteel
	AddSpell( "professions", "MINING", 55211, nil, 450, 0, nil, 200000, "Interface\\Icons\\INV_Ingot_Platinum" ) -- Smelt Titanium
	AddSpell( "professions", "MINING", 70524, nil, 250, 0, nil, 10000, nil ) -- Enchanted Thorium Bar
	AddSpell( "professions", "MINING", 74517, 75, 425, 0, nil, 500000, nil ) -- Illustrious Grand Master Miner
	AddSpell( "professions", "MINING", 74529, nil, 525, 0, nil, 50000, "Interface\\Icons\\inv_misc_pyriumbar_02" ) -- Smelt Pyrite
	AddSpell( "professions", "MINING", 74530, nil, 475, 0, nil, 50000, "Interface\\Icons\\inv_misc_pyriumbar" ) -- Smelt Elementium
	AddSpell( "professions", "MINING", 74537, nil, 500, 0, nil, 50000, "Interface\\Icons\\inv_misc_ebonsteelbar" ) -- Smelt Hardened Elementium
	AddSpell( "professions", "MINING", 84038, nil, 425, 0, nil, 50000, "Interface\\Icons\\INV_Stone_15" ) -- Smelt Obsidium
	AddSpell( "professions", "SKINNING",  8613, nil, nil, 0, nil, 10, nil ) -- Apprentice Skinner
	AddSpell( "professions", "SKINNING",  8617, nil, 50, 0, nil, 500, nil ) -- Journeyman Skinner
	AddSpell( "professions", "SKINNING",  8618, 10, 125, 0, nil, 5000, nil ) -- Expert Skinner
	AddSpell( "professions", "SKINNING", 10768, 25, 200, 0, nil, 50000, nil ) -- Artisan Skinner
	AddSpell( "professions", "SKINNING", 32678, 40, 275, 0, nil, 100000, nil ) -- Master Skinner
	AddSpell( "professions", "SKINNING", 50305, 55, 350, 0, nil, 350000, nil ) -- Grand Master Skinner
	AddSpell( "professions", "SKINNING", 74522, 75, 425, 0, nil, 500000, nil ) -- Illustrious Grand Master Skinner
	AddSpell( "professions", "TAILORING",  2385, nil, 10, 0, nil, 50, "Interface\\Icons\\INV_Shirt_05" ) -- Brown Linen Vest
	AddSpell( "professions", "TAILORING",  2386, nil, 65, 0, nil, 200, "Interface\\Icons\\INV_Boots_09" ) -- Linen Boots
	AddSpell( "professions", "TAILORING",  2392, nil, 40, 0, nil, 50, "Interface\\Icons\\INV_Shirt_Red_01" ) -- Red Linen Shirt
	AddSpell( "professions", "TAILORING",  2393, nil, 1, 0, nil, 25, "Interface\\Icons\\INV_Shirt_White_01" ) -- White Linen Shirt
	AddSpell( "professions", "TAILORING",  2394, nil, 40, 0, nil, 50, "Interface\\Icons\\INV_Shirt_Blue_01" ) -- Blue Linen Shirt
	AddSpell( "professions", "TAILORING",  2395, nil, 70, 0, nil, 300, "Interface\\Icons\\INV_Chest_Fur" ) -- Barbaric Linen Vest
	AddSpell( "professions", "TAILORING",  2396, nil, 70, 0, nil, 200, "Interface\\Icons\\INV_Shirt_Green_01" ) -- Green Linen Shirt
	AddSpell( "professions", "TAILORING",  2397, nil, 60, 0, nil, 200, "Interface\\Icons\\INV_Misc_Cape_07" ) -- Reinforced Linen Cape
	AddSpell( "professions", "TAILORING",  2399, nil, 85, 0, nil, 300, "Interface\\Icons\\INV_Chest_Cloth_39" ) -- Green Woolen Vest
	AddSpell( "professions", "TAILORING",  2401, nil, 95, 0, nil, 300, "Interface\\Icons\\INV_Boots_09" ) -- Woolen Boots
	AddSpell( "professions", "TAILORING",  2402, nil, 75, 0, nil, 250, "Interface\\Icons\\INV_Misc_Cape_10" ) -- Woolen Cape
	AddSpell( "professions", "TAILORING",  2406, nil, 100, 0, nil, 200, "Interface\\Icons\\INV_Shirt_Grey_01" ) -- Gray Woolen Shirt
	AddSpell( "professions", "TAILORING",  2964, nil, 75, 0, nil, 100, "Interface\\Icons\\INV_Fabric_Wool_03" ) -- Bolt of Woolen Cloth
	AddSpell( "professions", "TAILORING",  3755, nil, 45, 0, nil, 100, "Interface\\Icons\\INV_Misc_Bag_01" ) -- Linen Bag
	AddSpell( "professions", "TAILORING",  3757, nil, 80, 0, nil, 200, "Interface\\Icons\\INV_Misc_Bag_10" ) -- Woolen Bag
	AddSpell( "professions", "TAILORING",  3813, nil, 150, 0, nil, 800, "Interface\\Icons\\INV_Misc_Bag_07" ) -- Small Silk Pack
	AddSpell( "professions", "TAILORING",  3839, nil, 125, 0, nil, 500, "Interface\\Icons\\INV_Fabric_Silk_03" ) -- Bolt of Silk Cloth
	AddSpell( "professions", "TAILORING",  3840, nil, 35, 0, nil, 100, "Interface\\Icons\\INV_Gauntlets_05" ) -- Heavy Linen Gloves
	AddSpell( "professions", "TAILORING",  3841, nil, 60, 0, nil, 200, "Interface\\Icons\\INV_Bracer_12" ) -- Green Linen Bracers
	AddSpell( "professions", "TAILORING",  3842, nil, 70, 0, nil, 300, "Interface\\Icons\\INV_Pants_07" ) -- Handstitched Linen Britches
	AddSpell( "professions", "TAILORING",  3843, nil, 85, 0, nil, 400, "Interface\\Icons\\INV_Gauntlets_05" ) -- Heavy Woolen Gloves
	AddSpell( "professions", "TAILORING",  3845, nil, 80, 0, nil, 300, "Interface\\Icons\\INV_Boots_09" ) -- Soft-soled Linen Boots
	AddSpell( "professions", "TAILORING",  3848, nil, 110, 0, nil, 500, "Interface\\Icons\\INV_Shoulder_06" ) -- Double-stitched Woolen Shoulders
	AddSpell( "professions", "TAILORING",  3850, nil, 110, 0, nil, 500, "Interface\\Icons\\INV_Pants_01" ) -- Heavy Woolen Pants
	AddSpell( "professions", "TAILORING",  3852, nil, 130, 0, nil, 750, "Interface\\Icons\\INV_Gauntlets_05" ) -- Gloves of Meditation
	AddSpell( "professions", "TAILORING",  3855, nil, 125, 0, nil, 750, "Interface\\Icons\\INV_Boots_05" ) -- Spidersilk Boots
	AddSpell( "professions", "TAILORING",  3859, nil, 150, 0, nil, 750, "Interface\\Icons\\INV_Chest_Cloth_37" ) -- Azure Silk Vest
	AddSpell( "professions", "TAILORING",  3861, nil, 185, 0, nil, 1000, "Interface\\Icons\\INV_Misc_Cape_02" ) -- Long Silken Cloak
	AddSpell( "professions", "TAILORING",  3865, nil, 175, 0, nil, 1000, "Interface\\Icons\\INV_Fabric_Mageweave_03" ) -- Bolt of Mageweave
	AddSpell( "professions", "TAILORING",  3866, nil, 110, 0, nil, 250, "Interface\\Icons\\INV_Shirt_Red_01" ) -- Stylish Red Shirt
	AddSpell( "professions", "TAILORING",  3871, nil, 170, 0, nil, 500, "Interface\\Icons\\INV_Shirt_08" ) -- Formal White Shirt
	AddSpell( "professions", "TAILORING",  3908, 5, nil, 0, nil, 10, nil ) -- Apprentice Tailor
	AddSpell( "professions", "TAILORING",  3909, 10, 50, 0, nil, 500, nil ) -- Journeyman Tailor
	AddSpell( "professions", "TAILORING",  3910, 20, 125, 0, nil, 5000, nil ) -- Expert Tailor
	AddSpell( "professions", "TAILORING",  3914, nil, 30, 0, nil, 50, "Interface\\Icons\\INV_Pants_06" ) -- Brown Linen Pants
	AddSpell( "professions", "TAILORING",  6521, nil, 90, 0, nil, 400, "Interface\\Icons\\INV_Misc_Cape_11" ) -- Pearl-clasped Cloak
	AddSpell( "professions", "TAILORING",  6690, nil, 135, 0, nil, 1000, "Interface\\Icons\\INV_Chest_Cloth_17" ) -- Lesser Wizard's Robe
	AddSpell( "professions", "TAILORING",  7623, nil, 30, 0, nil, 50, "Interface\\Icons\\INV_Chest_Cloth_21" ) -- Brown Linen Robe
	AddSpell( "professions", "TAILORING",  7624, nil, 30, 0, nil, 50, "Interface\\Icons\\INV_Chest_Cloth_04" ) -- White Linen Robe
	AddSpell( "professions", "TAILORING",  8465, nil, 40, 0, nil, 50, "Interface\\Icons\\INV_Shirt_12" ) -- Simple Dress
	AddSpell( "professions", "TAILORING",  8467, nil, 110, 0, nil, 250, "Interface\\Icons\\INV_Shirt_12" ) -- White Woolen Dress
	AddSpell( "professions", "TAILORING",  8483, nil, 160, 0, nil, 500, "Interface\\Icons\\INV_Shirt_White_01" ) -- White Swashbuckler's Shirt
	AddSpell( "professions", "TAILORING",  8489, nil, 175, 0, nil, 750, "Interface\\Icons\\INV_Shirt_Red_01" ) -- Red Swashbuckler's Shirt
	AddSpell( "professions", "TAILORING",  8758, nil, 140, 0, nil, 600, "Interface\\Icons\\INV_Pants_08" ) -- Azure Silk Pants
	AddSpell( "professions", "TAILORING",  8760, nil, 145, 0, nil, 600, "Interface\\Icons\\INV_Helmet_29" ) -- Azure Silk Hood
	AddSpell( "professions", "TAILORING",  8762, nil, 160, 0, nil, 750, "Interface\\Icons\\INV_Misc_Bandana_01" ) -- Silk Headband
	AddSpell( "professions", "TAILORING",  8764, nil, 170, 0, nil, 900, "Interface\\Icons\\INV_Shirt_04" ) -- Earthen Vest
	AddSpell( "professions", "TAILORING",  8766, nil, 175, 0, nil, 1000, "Interface\\Icons\\INV_Belt_22" ) -- Azure Silk Belt
	AddSpell( "professions", "TAILORING",  8770, nil, 190, 0, nil, 1000, "Interface\\Icons\\INV_Chest_Cloth_02" ) -- Robe of Power
	AddSpell( "professions", "TAILORING",  8772, nil, 175, 0, nil, 1000, "Interface\\Icons\\INV_Belt_04" ) -- Crimson Silk Belt
	AddSpell( "professions", "TAILORING",  8774, nil, 180, 0, nil, 1000, "Interface\\Icons\\INV_Shoulder_18" ) -- Green Silken Shoulders
	AddSpell( "professions", "TAILORING",  8776, nil, 15, 0, nil, 50, "Interface\\Icons\\INV_Belt_05" ) -- Linen Belt
	AddSpell( "professions", "TAILORING",  8791, nil, 185, 0, nil, 2500, "Interface\\Icons\\INV_Shirt_04" ) -- Crimson Silk Vest
	AddSpell( "professions", "TAILORING",  8799, nil, 195, 0, nil, 3000, "Interface\\Icons\\INV_Pants_06" ) -- Crimson Silk Pantaloons
	AddSpell( "professions", "TAILORING",  8804, nil, 210, 0, nil, 5000, "Interface\\Icons\\INV_Gauntlets_05" ) -- Crimson Silk Gloves
	AddSpell( "professions", "TAILORING", 12045, nil, 20, 0, nil, 50, "Interface\\Icons\\INV_Boots_05" ) -- Simple Linen Boots
	AddSpell( "professions", "TAILORING", 12046, nil, 75, 0, nil, 300, "Interface\\Icons\\INV_Pants_11" ) -- Simple Kilt
	AddSpell( "professions", "TAILORING", 12048, nil, 205, 0, nil, 4000, "Interface\\Icons\\INV_Chest_Leather_03" ) -- Black Mageweave Vest
	AddSpell( "professions", "TAILORING", 12049, nil, 205, 0, nil, 4000, "Interface\\Icons\\INV_Pants_09" ) -- Black Mageweave Leggings
	AddSpell( "professions", "TAILORING", 12050, nil, 210, 0, nil, 4000, "Interface\\Icons\\INV_Chest_Cloth_13" ) -- Black Mageweave Robe
	AddSpell( "professions", "TAILORING", 12052, nil, 210, 0, nil, 5000, "Interface\\Icons\\INV_Pants_11" ) -- Shadoweave Pants
	AddSpell( "professions", "TAILORING", 12053, nil, 215, 0, nil, 5000, "Interface\\Icons\\INV_Gauntlets_05" ) -- Black Mageweave Gloves
	AddSpell( "professions", "TAILORING", 12055, nil, 215, 0, nil, 5500, "Interface\\Icons\\INV_Chest_Cloth_38" ) -- Shadoweave Robe
	AddSpell( "professions", "TAILORING", 12061, nil, 215, 0, nil, 2500, "Interface\\Icons\\INV_Shirt_Orange_01" ) -- Orange Mageweave Shirt
	AddSpell( "professions", "TAILORING", 12065, nil, 225, 0, nil, 5000, "Interface\\Icons\\INV_Misc_Bag_10_Black" ) -- Mageweave Bag
	AddSpell( "professions", "TAILORING", 12067, nil, 225, 0, nil, 5000, "Interface\\Icons\\INV_Gauntlets_18" ) -- Dreamweave Gloves
	AddSpell( "professions", "TAILORING", 12069, nil, 225, 0, nil, 5000, "Interface\\Icons\\INV_Chest_Cloth_25" ) -- Cindercloth Robe
	AddSpell( "professions", "TAILORING", 12070, nil, 225, 0, nil, 5000, "Interface\\Icons\\INV_Chest_Cloth_42" ) -- Dreamweave Vest
	AddSpell( "professions", "TAILORING", 12071, nil, 225, 0, nil, 6000, "Interface\\Icons\\INV_Gauntlets_09" ) -- Shadoweave Gloves
	AddSpell( "professions", "TAILORING", 12072, nil, 230, 0, nil, 6000, "Interface\\Icons\\INV_Misc_Bandana_01" ) -- Black Mageweave Headband
	AddSpell( "professions", "TAILORING", 12073, nil, 230, 0, nil, 6000, "Interface\\Icons\\INV_Boots_05" ) -- Black Mageweave Boots
	AddSpell( "professions", "TAILORING", 12074, nil, 230, 0, nil, 6000, "Interface\\Icons\\INV_Shoulder_25" ) -- Black Mageweave Shoulders
	AddSpell( "professions", "TAILORING", 12076, nil, 235, 0, nil, 6500, "Interface\\Icons\\INV_Shoulder_25" ) -- Shadoweave Shoulders
	AddSpell( "professions", "TAILORING", 12077, nil, 235, 0, nil, 5000, "Interface\\Icons\\INV_Chest_Cloth_21" ) -- Simple Black Dress
	AddSpell( "professions", "TAILORING", 12079, nil, 235, 0, nil, 6500, "Interface\\Icons\\INV_Misc_Bag_10_Red" ) -- Red Mageweave Bag
	AddSpell( "professions", "TAILORING", 12082, nil, 240, 0, nil, 7000, "Interface\\Icons\\INV_Boots_05" ) -- Shadoweave Boots
	AddSpell( "professions", "TAILORING", 12088, nil, 245, 0, nil, 7500, "Interface\\Icons\\INV_Boots_05" ) -- Cindercloth Boots
	AddSpell( "professions", "TAILORING", 12092, nil, 250, 0, nil, 7500, "Interface\\Icons\\INV_Crown_01" ) -- Dreamweave Circlet
	AddSpell( "professions", "TAILORING", 12180, 35, 200, 0, nil, 50000, nil ) -- Artisan Tailor
	AddSpell( "professions", "TAILORING", 18401, nil, 250, 0, nil, 10000, "Interface\\Icons\\INV_Fabric_PurpleFire_02" ) -- Bolt of Runecloth
	AddSpell( "professions", "TAILORING", 18402, nil, 255, 0, nil, 10000, "Interface\\Icons\\INV_Belt_15" ) -- Runecloth Belt
	AddSpell( "professions", "TAILORING", 18403, nil, 255, 0, nil, 10000, "Interface\\Icons\\INV_Chest_Cloth_08" ) -- Frostweave Tunic
	AddSpell( "professions", "TAILORING", 18406, nil, 260, 0, nil, 10000, "Interface\\Icons\\INV_Chest_Cloth_04" ) -- Runecloth Robe
	AddSpell( "professions", "TAILORING", 18407, nil, 260, 0, nil, 10000, "Interface\\Icons\\INV_Chest_Cloth_04" ) -- Runecloth Tunic
	AddSpell( "professions", "TAILORING", 18409, nil, 265, 0, nil, 10000, "Interface\\Icons\\INV_Misc_Cape_10" ) -- Runecloth Cloak
	AddSpell( "professions", "TAILORING", 18410, nil, 265, 0, nil, 10000, "Interface\\Icons\\INV_Belt_16" ) -- Ghostweave Belt
	AddSpell( "professions", "TAILORING", 18411, nil, 265, 0, nil, 10000, "Interface\\Icons\\INV_Gauntlets_05" ) -- Frostweave Gloves
	AddSpell( "professions", "TAILORING", 18413, nil, 270, 0, nil, 10000, "Interface\\Icons\\INV_Gauntlets_05" ) -- Ghostweave Gloves
	AddSpell( "professions", "TAILORING", 18414, nil, 270, 0, nil, 10000, "Interface\\Icons\\INV_Chest_Cloth_26" ) -- Brightcloth Robe
	AddSpell( "professions", "TAILORING", 18415, nil, 270, 0, nil, 10000, "Interface\\Icons\\INV_Gauntlets_21" ) -- Brightcloth Gloves
	AddSpell( "professions", "TAILORING", 18416, nil, 275, 0, nil, 12500, "Interface\\Icons\\INV_Shirt_08" ) -- Ghostweave Vest
	AddSpell( "professions", "TAILORING", 18417, nil, 275, 0, nil, 12500, "Interface\\Icons\\INV_Gauntlets_25" ) -- Runecloth Gloves
	AddSpell( "professions", "TAILORING", 18420, nil, 275, 0, nil, 12500, "Interface\\Icons\\INV_Misc_Cape_11" ) -- Brightcloth Cloak
	AddSpell( "professions", "TAILORING", 18421, nil, 275, 0, nil, 12500, "Interface\\Icons\\INV_Pants_09" ) -- Wizardweave Leggings
	AddSpell( "professions", "TAILORING", 18423, nil, 280, 0, nil, 15000, "Interface\\Icons\\INV_Boots_05" ) -- Runecloth Boots
	AddSpell( "professions", "TAILORING", 18424, nil, 280, 0, nil, 15000, "Interface\\Icons\\INV_Pants_08" ) -- Frostweave Pants
	AddSpell( "professions", "TAILORING", 18437, nil, 285, 0, nil, 15000, "Interface\\Icons\\INV_Boots_05" ) -- Felcloth Boots
	AddSpell( "professions", "TAILORING", 18438, nil, 285, 0, nil, 15000, "Interface\\Icons\\INV_Pants_09" ) -- Runecloth Pants
	AddSpell( "professions", "TAILORING", 18441, nil, 290, 0, nil, 15000, "Interface\\Icons\\INV_Pants_01" ) -- Ghostweave Pants
	AddSpell( "professions", "TAILORING", 18442, nil, 290, 0, nil, 15000, "Interface\\Icons\\INV_Helmet_34" ) -- Felcloth Hood
	AddSpell( "professions", "TAILORING", 18444, nil, 295, 0, nil, 15000, "Interface\\Icons\\INV_Misc_Bandana_03" ) -- Runecloth Headband
	AddSpell( "professions", "TAILORING", 18446, nil, 300, 0, nil, 15000, "Interface\\Icons\\INV_Chest_Cloth_46" ) -- Wizardweave Robe
	AddSpell( "professions", "TAILORING", 18449, nil, 300, 0, nil, 15000, "Interface\\Icons\\INV_Shoulder_21" ) -- Runecloth Shoulders
	AddSpell( "professions", "TAILORING", 18450, nil, 300, 0, nil, 15000, "Interface\\Icons\\INV_Helmet_63" ) -- Wizardweave Turban
	AddSpell( "professions", "TAILORING", 18451, nil, 300, 0, nil, 15000, "Interface\\Icons\\INV_Chest_Cloth_09" ) -- Felcloth Robe
	AddSpell( "professions", "TAILORING", 18453, nil, 300, 0, nil, 15000, "Interface\\Icons\\INV_Shoulder_23" ) -- Felcloth Shoulders
	AddSpell( "professions", "TAILORING", 26745, nil, 300, 0, nil, 15000, "Interface\\Icons\\INV_Fabric_Netherweave_Bolt" ) -- Bolt of Netherweave
	AddSpell( "professions", "TAILORING", 26746, nil, 315, 0, nil, 15000, "Interface\\Icons\\INV_Misc_Bag_23_Netherweave" ) -- Netherweave Bag
	AddSpell( "professions", "TAILORING", 26764, nil, 310, 0, nil, 15000, "Interface\\Icons\\INV_Bracer_07" ) -- Netherweave Bracers
	AddSpell( "professions", "TAILORING", 26765, nil, 310, 0, nil, 15000, "Interface\\Icons\\INV_Belt_04" ) -- Netherweave Belt
	AddSpell( "professions", "TAILORING", 26770, nil, 320, 0, nil, 20000, "Interface\\Icons\\INV_Gauntlets_27" ) -- Netherweave Gloves
	AddSpell( "professions", "TAILORING", 26771, nil, 325, 0, nil, 20000, "Interface\\Icons\\INV_Pants_09" ) -- Netherweave Pants
	AddSpell( "professions", "TAILORING", 26772, nil, 335, 0, nil, 20000, "Interface\\Icons\\INV_Boots_05" ) -- Netherweave Boots
	AddSpell( "professions", "TAILORING", 26790, 50, 275, 0, nil, 100000, nil ) -- Master Tailor
	AddSpell( "professions", "TAILORING", 31460, nil, 300, 0, nil, 15000, "Interface\\Icons\\INV_Misc_Net_01" ) -- Netherweave Net
	AddSpell( "professions", "TAILORING", 51309, 65, 350, 0, nil, 350000, nil ) -- Grand Master Tailor
	AddSpell( "professions", "TAILORING", 55642, nil, 420, 0, nil, 125000, nil ) -- Lightweave Embroidery
	AddSpell( "professions", "TAILORING", 55769, nil, 420, 0, nil, 125000, nil ) -- Darkglow Embroidery
	AddSpell( "professions", "TAILORING", 55777, nil, 420, 0, nil, 125000, nil ) -- Swordguard Embroidery
	AddSpell( "professions", "TAILORING", 55898, nil, 360, 0, nil, 50000, "Interface\\Icons\\INV_Misc_Net_01" ) -- Frostweave Net
	AddSpell( "professions", "TAILORING", 55899, nil, 350, 0, nil, 50000, "Interface\\Icons\\INV_Fabric_Frostweave_Bolt" ) -- Bolt of Frostweave
	AddSpell( "professions", "TAILORING", 55900, nil, 400, 0, nil, 125000, "Interface\\Icons\\INV_Fabric_Frostweave_ImbuedBolt" ) -- Bolt of Imbued Frostweave
	AddSpell( "professions", "TAILORING", 55901, nil, 395, 0, nil, 50000, "Interface\\Icons\\INV_Pants_Cloth_11" ) -- Duskweave Leggings
	AddSpell( "professions", "TAILORING", 55902, nil, 350, 0, nil, 50000, "Interface\\Icons\\INV_Shoulder_72" ) -- Frostwoven Shoulders
	AddSpell( "professions", "TAILORING", 55903, nil, 360, 0, nil, 50000, "Interface\\Icons\\INV_Chest_Cloth_19" ) -- Frostwoven Robe
	AddSpell( "professions", "TAILORING", 55904, nil, 360, 0, nil, 50000, "Interface\\Icons\\INV_Gauntlets_06" ) -- Frostwoven Gloves
	AddSpell( "professions", "TAILORING", 55906, nil, 375, 0, nil, 50000, "Interface\\Icons\\INV_Boots_09" ) -- Frostwoven Boots
	AddSpell( "professions", "TAILORING", 55907, nil, 380, 0, nil, 50000, "Interface\\Icons\\INV_Helmet_125" ) -- Frostwoven Cowl
	AddSpell( "professions", "TAILORING", 55908, nil, 370, 0, nil, 50000, "Interface\\Icons\\INV_Belt_29" ) -- Frostwoven Belt
	AddSpell( "professions", "TAILORING", 55910, nil, 385, 0, nil, 80000, "Interface\\Icons\\INV_Shoulder_02" ) -- Mystic Frostwoven Shoulders
	AddSpell( "professions", "TAILORING", 55911, nil, 390, 0, nil, 80000, "Interface\\Icons\\INV_Chest_Cloth_19" ) -- Mystic Frostwoven Robe
	AddSpell( "professions", "TAILORING", 55913, nil, 385, 0, nil, 80000, "Interface\\Icons\\INV_Bracer_11" ) -- Mystic Frostwoven Wristwraps
	AddSpell( "professions", "TAILORING", 55914, nil, 395, 0, nil, 50000, "Interface\\Icons\\INV_Belt_29" ) -- Duskweave Belt
	AddSpell( "professions", "TAILORING", 55919, nil, 395, 0, nil, 100000, "Interface\\Icons\\INV_Helmet_125" ) -- Duskweave Cowl
	AddSpell( "professions", "TAILORING", 55920, nil, 400, 0, nil, 50000, "Interface\\Icons\\INV_Bracer_11" ) -- Duskweave Wristwraps
	AddSpell( "professions", "TAILORING", 55921, nil, 405, 0, nil, 100000, "Interface\\Icons\\INV_Chest_Cloth_19" ) -- Duskweave Robe
	AddSpell( "professions", "TAILORING", 55922, nil, 405, 0, nil, 100000, "Interface\\Icons\\INV_Gauntlets_06" ) -- Duskweave Gloves
	AddSpell( "professions", "TAILORING", 55923, nil, 410, 0, nil, 100000, "Interface\\Icons\\INV_Shoulder_72" ) -- Duskweave Shoulders
	AddSpell( "professions", "TAILORING", 55924, nil, 410, 0, nil, 125000, "Interface\\Icons\\INV_Boots_09" ) -- Duskweave Boots
	AddSpell( "professions", "TAILORING", 55925, nil, 415, 0, nil, 125000, "Interface\\Icons\\INV_Pants_Cloth_11" ) -- Black Duskweave Leggings
	AddSpell( "professions", "TAILORING", 55941, nil, 420, 0, nil, 125000, "Interface\\Icons\\INV_Chest_Cloth_19" ) -- Black Duskweave Robe
	AddSpell( "professions", "TAILORING", 55943, nil, 415, 0, nil, 125000, "Interface\\Icons\\INV_Bracer_11" ) -- Black Duskweave Wristwraps
	AddSpell( "professions", "TAILORING", 55995, nil, 400, 0, nil, 50000, "Interface\\Icons\\INV_Shirt_Yellow_01" ) -- Yellow Lumberjack Shirt
	AddSpell( "professions", "TAILORING", 56000, nil, 400, 0, nil, 50000, "Interface\\Icons\\INV_Shirt_Green_01" ) -- Green Workman's Shirt
	AddSpell( "professions", "TAILORING", 56001, nil, 415, 0, nil, 100000, "Interface\\Icons\\INV_Fabric_Moonshroud" ) -- Moonshroud
	AddSpell( "professions", "TAILORING", 56002, nil, 415, 0, nil, 100000, "Interface\\Icons\\INV_Fabric_Ebonweave" ) -- Ebonweave
	AddSpell( "professions", "TAILORING", 56003, nil, 415, 0, nil, 100000, "Interface\\Icons\\INV_Fabric_Spellweave" ) -- Spellweave
	AddSpell( "professions", "TAILORING", 56007, nil, 410, 0, nil, 80000, "Interface\\Icons\\INV_Misc_Bag_EnchantedMageweave" ) -- Frostweave Bag
	AddSpell( "professions", "TAILORING", 56008, nil, 400, 0, nil, 100000, "Interface\\Icons\\Spell_Nature_AstralRecal" ) -- Shining Spellthread
	AddSpell( "professions", "TAILORING", 56010, nil, 400, 0, nil, 100000, "Interface\\Icons\\Spell_Nature_AstralRecal" ) -- Azure Spellthread
	AddSpell( "professions", "TAILORING", 56014, nil, 390, 0, nil, 100000, "Interface\\Icons\\INV_Misc_Cape_16" ) -- Cloak of the Moon
	AddSpell( "professions", "TAILORING", 56015, nil, 395, 0, nil, 100000, "Interface\\Icons\\INV_Misc_Cape_16" ) -- Cloak of Frozen Spirits
	AddSpell( "professions", "TAILORING", 56018, nil, 425, 0, nil, 100000, "Interface\\Icons\\inv_helmet_120" ) -- Hat of Wintry Doom
	AddSpell( "professions", "TAILORING", 56019, nil, 420, 0, nil, 100000, "Interface\\Icons\\INV_Boots_Cloth_19" ) -- Silky Iceshard Boots
	AddSpell( "professions", "TAILORING", 56020, nil, 420, 0, nil, 100000, "Interface\\Icons\\INV_Belt_31" ) -- Deep Frozen Cord
	AddSpell( "professions", "TAILORING", 56021, nil, 425, 0, nil, 100000, "Interface\\Icons\\INV_Pants_Cloth_11" ) -- Frostmoon Pants
	AddSpell( "professions", "TAILORING", 56022, nil, 420, 0, nil, 100000, "Interface\\Icons\\INV_Gauntlets_06" ) -- Light Blessed Mittens
	AddSpell( "professions", "TAILORING", 56023, nil, 420, 0, nil, 100000, "Interface\\Icons\\INV_Boots_Cloth_01" ) -- Aurora Slippers
	AddSpell( "professions", "TAILORING", 56024, nil, 440, 0, nil, 200000, "Interface\\Icons\\INV_Chest_Cloth_04" ) -- Moonshroud Robe
	AddSpell( "professions", "TAILORING", 56025, nil, 435, 0, nil, 200000, "Interface\\Icons\\INV_Gauntlets_06" ) -- Moonshroud Gloves
	AddSpell( "professions", "TAILORING", 56026, nil, 440, 0, nil, 200000, "Interface\\Icons\\INV_Chest_Cloth_48" ) -- Ebonweave Robe
	AddSpell( "professions", "TAILORING", 56027, nil, 435, 0, nil, 200000, "Interface\\Icons\\INV_Gauntlets_06" ) -- Ebonweave Gloves
	AddSpell( "professions", "TAILORING", 56028, nil, 440, 0, nil, 200000, "Interface\\Icons\\INV_Chest_Cloth_41" ) -- Spellweave Robe
	AddSpell( "professions", "TAILORING", 56029, nil, 435, 0, nil, 200000, "Interface\\Icons\\INV_Gauntlets_06" ) -- Spellweave Gloves
	AddSpell( "professions", "TAILORING", 56030, nil, 380, 0, nil, 50000, "Interface\\Icons\\INV_Pants_Cloth_11" ) -- Frostwoven Leggings
	AddSpell( "professions", "TAILORING", 56031, nil, 350, 0, nil, 50000, "Interface\\Icons\\INV_Bracer_11" ) -- Frostwoven Wristwraps
	AddSpell( "professions", "TAILORING", 56034, nil, 405, 0, nil, 100000, nil ) -- Master's Spellthread
	AddSpell( "professions", "TAILORING", 56039, nil, 405, 0, nil, 100000, nil ) -- Sanctified Spellthread
	AddSpell( "professions", "TAILORING", 59582, nil, 415, 0, nil, 100000, "Interface\\Icons\\INV_Belt_16" ) -- Frostsavage Belt
	AddSpell( "professions", "TAILORING", 59583, nil, 415, 0, nil, 100000, "Interface\\Icons\\INV_Bracer_07" ) -- Frostsavage Bracers
	AddSpell( "professions", "TAILORING", 59584, nil, 420, 0, nil, 100000, "Interface\\Icons\\INV_Shoulder_72" ) -- Frostsavage Shoulders
	AddSpell( "professions", "TAILORING", 59585, nil, 420, 0, nil, 100000, "Interface\\Icons\\INV_Boots_09" ) -- Frostsavage Boots
	AddSpell( "professions", "TAILORING", 59586, nil, 420, 0, nil, 100000, "Interface\\Icons\\INV_Gauntlets_06" ) -- Frostsavage Gloves
	AddSpell( "professions", "TAILORING", 59587, nil, 420, 0, nil, 100000, "Interface\\Icons\\INV_Chest_Cloth_51" ) -- Frostsavage Robe
	AddSpell( "professions", "TAILORING", 59588, nil, 420, 0, nil, 120000, "Interface\\Icons\\INV_Pants_Cloth_24" ) -- Frostsavage Leggings
	AddSpell( "professions", "TAILORING", 59589, nil, 420, 0, nil, 120000, "Interface\\Icons\\INV_Helmet_125" ) -- Frostsavage Cowl
	AddSpell( "professions", "TAILORING", 60969, nil, 300, 0, nil, 15000, "Interface\\Icons\\ability_mount_flyingcarpet" ) -- Flying Carpet
	AddSpell( "professions", "TAILORING", 60971, nil, 425, 0, nil, 150000, "Interface\\Icons\\ability_mount_magnificentflyingcarpet" ) -- Magnificent Flying Carpet
	AddSpell( "professions", "TAILORING", 60990, nil, 420, 0, nil, 180000, "Interface\\Icons\\INV_Belt_31" ) -- Glacial Waistband
	AddSpell( "professions", "TAILORING", 60993, nil, 425, 0, nil, 180000, "Interface\\Icons\\INV_Chest_Cloth_08" ) -- Glacial Robe
	AddSpell( "professions", "TAILORING", 60994, nil, 420, 0, nil, 180000, "Interface\\Icons\\INV_Boots_Cloth_05" ) -- Glacial Slippers
	AddSpell( "professions", "TAILORING", 63742, nil, 125, 0, nil, 750, "Interface\\Icons\\INV_Misc_Cape_16" ) -- Spidersilk Drape
	AddSpell( "professions", "TAILORING", 64729, nil, 400, 0, nil, 100000, "Interface\\Icons\\INV_Misc_Cape_19" ) -- Frostguard Drape
	AddSpell( "professions", "TAILORING", 64730, nil, 405, 0, nil, 100000, "Interface\\Icons\\INV_Misc_Cape_19" ) -- Cloak of Crimson Snow
	AddSpell( "professions", "TAILORING", 74964, nil, 425, 0, nil, 100000, "Interface\\Icons\\inv_misc_emberweavecloth_01" ) -- Bolt of Embersilk Cloth
	AddSpell( "professions", "TAILORING", 75141, nil, 515, 0, nil, 150000, "Interface\\Icons\\INV_Chest_Cloth_57" ) -- Dream of Skywall
	AddSpell( "professions", "TAILORING", 75142, nil, 505, 0, nil, 150000, "Interface\\Icons\\INV_Chest_Cloth_57" ) -- Dream of Deepholm
	AddSpell( "professions", "TAILORING", 75144, nil, 500, 0, nil, 150000, "Interface\\Icons\\INV_Chest_Cloth_57" ) -- Dream of Hyjal
	AddSpell( "professions", "TAILORING", 75145, nil, 510, 0, nil, 150000, "Interface\\Icons\\INV_Chest_Cloth_57" ) -- Dream of Ragnaros
	AddSpell( "professions", "TAILORING", 75146, nil, 500, 0, nil, 150000, "Interface\\Icons\\INV_Chest_Cloth_57" ) -- Dream of Azshara
	AddSpell( "professions", "TAILORING", 75154, nil, 475, 1, 56034, 40000, nil ) -- Master's Spellthread
	AddSpell( "professions", "TAILORING", 75155, nil, 475, 1, 56039, 40000, nil ) -- Sanctified Spellthread
	AddSpell( "professions", "TAILORING", 75156, 75, 425, 0, nil, 500000, nil ) -- Illustrious Grand Master Tailor
	AddSpell( "professions", "TAILORING", 75172, nil, 500, 1, 55642, 60000, nil ) -- Lightweave Embroidery
	AddSpell( "professions", "TAILORING", 75175, nil, 500, 1, 55769, 60000, nil ) -- Darkglow Embroidery
	AddSpell( "professions", "TAILORING", 75178, nil, 500, 1, 55777, 60000, nil ) -- Swordguard Embroidery
	AddSpell( "professions", "TAILORING", 75247, nil, 425, 0, nil, 100000, "Interface\\Icons\\INV_Misc_Net_01" ) -- Embersilk Net
	AddSpell( "professions", "TAILORING", 75248, nil, 445, 0, nil, 120000, "Interface\\Icons\\inv_belt_cloth_cataclysm_b_01" ) -- Deathsilk Belt
	AddSpell( "professions", "TAILORING", 75249, nil, 445, 0, nil, 120000, "Interface\\Icons\\inv_bracer_cloth_cataclysm_b_01" ) -- Deathsilk Bracers
	AddSpell( "professions", "TAILORING", 75250, nil, 450, 0, nil, 120000, "Interface\\Icons\\item_spellcloththread" ) -- Enchanted Spellthread
	AddSpell( "professions", "TAILORING", 75251, nil, 455, 0, nil, 120000, "Interface\\Icons\\inv_shoulder_cloth_cataclysm_b_01" ) -- Deathsilk Shoulders
	AddSpell( "professions", "TAILORING", 75252, nil, 455, 0, nil, 120000, "Interface\\Icons\\inv_boots_cloth_cataclysm_b_01" ) -- Deathsilk Boots
	AddSpell( "professions", "TAILORING", 75253, nil, 460, 0, nil, 120000, "Interface\\Icons\\inv_gauntlets_cloth_cataclysm_b_01" ) -- Deathsilk Gloves
	AddSpell( "professions", "TAILORING", 75254, nil, 460, 0, nil, 120000, "Interface\\Icons\\inv_pants_cloth_cataclysm_b_01" ) -- Deathsilk Leggings
	AddSpell( "professions", "TAILORING", 75255, nil, 460, 0, nil, 120000, "Interface\\Icons\\Spell_Nature_AstralRecal" ) -- Ghostly Spellthread
	AddSpell( "professions", "TAILORING", 75256, nil, 465, 0, nil, 120000, "Interface\\Icons\\inv_helmet_cloth_cataclysm_b_01" ) -- Deathsilk Cowl
	AddSpell( "professions", "TAILORING", 75257, nil, 465, 0, nil, 120000, "Interface\\Icons\\inv_chest_cloth_cataclysm_b_01" ) -- Deathsilk Robe
	AddSpell( "professions", "TAILORING", 75258, nil, 470, 0, nil, 120000, "Interface\\Icons\\inv_belt_cloth_cataclysm_b_01" ) -- Spiritmend Belt
	AddSpell( "professions", "TAILORING", 75259, nil, 470, 0, nil, 120000, "Interface\\Icons\\inv_bracer_cloth_cataclysm_b_01" ) -- Spiritmend Bracers
	AddSpell( "professions", "TAILORING", 75260, nil, 475, 0, nil, 120000, "Interface\\Icons\\inv_shoulder_cloth_cataclysm_b_01" ) -- Spiritmend Shoulders
	AddSpell( "professions", "TAILORING", 75261, nil, 475, 0, nil, 120000, "Interface\\Icons\\inv_boots_cloth_cataclysm_b_01" ) -- Spiritmend Boots
	AddSpell( "professions", "TAILORING", 75262, nil, 480, 0, nil, 150000, "Interface\\Icons\\inv_gauntlets_cloth_cataclysm_b_01" ) -- Spiritmend Gloves
	AddSpell( "professions", "TAILORING", 75263, nil, 480, 0, nil, 150000, "Interface\\Icons\\inv_pants_cloth_cataclysm_b_01" ) -- Spiritmend Leggings
	AddSpell( "professions", "TAILORING", 75264, nil, 480, 0, nil, 150000, "Interface\\Icons\\inv_misc_bag_32" ) -- Embersilk Bag
	AddSpell( "professions", "TAILORING", 75265, nil, 480, 0, nil, 150000, "Interface\\Icons\\inv_misc_bag_31" ) -- Otherworldly Bag
	AddSpell( "professions", "TAILORING", 75266, nil, 485, 0, nil, 150000, "Interface\\Icons\\inv_helmet_cloth_cataclysm_b_01" ) -- Spiritmend Cowl
	AddSpell( "professions", "TAILORING", 75267, nil, 485, 0, nil, 150000, "Interface\\Icons\\inv_chest_cloth_cataclysm_b_01" ) -- Spiritmend Robe
	AddSpell( "professions", "TAILORING", 75268, nil, 490, 0, nil, 150000, "Interface\\Icons\\inv_misc_bag_30" ) -- Hyjal Expedition Bag
	AddSpell( "professions", "TAILORING", 75269, nil, 510, 0, nil, 180000, "Interface\\Icons\\inv_belt_robe_dungeonrobe_c_04" ) -- Fireweave Belt
	AddSpell( "professions", "TAILORING", 75270, nil, 500, 0, nil, 150000, "Interface\\Icons\\inv_bracer_robe_dungeonrobe_c_04" ) -- Emberfire Bracers
	AddSpell( "professions", "TAILORING", 75290, nil, 500, 0, nil, 150000, "Interface\\Icons\\inv_bracer_robe_dungeonrobe_c_04" ) -- Fireweave Bracers
	AddSpell( "professions", "TAILORING", 75291, nil, 505, 0, nil, 180000, "Interface\\Icons\\inv_shoulder_robe_dungeonrobe_c_04" ) -- Emberfire Shoulders
	AddSpell( "professions", "TAILORING", 75292, nil, 510, 0, nil, 180000, "Interface\\Icons\\inv_shoulder_robe_dungeonrobe_c_04" ) -- Fireweave Shoulders
	AddSpell( "professions", "TAILORING", 75293, nil, 510, 0, nil, 180000, "Interface\\Icons\\inv_belt_robe_dungeonrobe_c_04" ) -- Emberfire Belt
	AddSpell( "professions", "TAILORING", 75294, nil, 515, 0, nil, 180000, "Interface\\Icons\\inv_boots_robe_dungeonrobe_c_04" ) -- Fireweave Boots
	AddSpell( "professions", "TAILORING", 75295, nil, 515, 0, nil, 180000, "Interface\\Icons\\inv_gauntlets_robe_dungeonrobe_c_04" ) -- Emberfire Gloves
	AddSpell( "professions", "TAILORING", 75296, nil, 520, 0, nil, 180000, "Interface\\Icons\\inv_gauntlets_robe_dungeonrobe_c_04" ) -- Fireweave Gloves
	AddSpell( "professions", "TAILORING", 75297, nil, 520, 0, nil, 180000, "Interface\\Icons\\inv_boots_robe_dungeonrobe_c_04" ) -- Emberfire Boots
	AddSpell( "professions", "TAILORING", 94743, nil, 525, 0, nil, 240000, "Interface\\Icons\\INV_Chest_Cloth_57" ) -- Dream of Destruction

end

-------------------------------------------------------------------------------
-- Trainners
-------------------------------------------------------------------------------

function Syllabus:SaveTrainers()
	local trainers_db = Syllabus.db.global.trainers

	Syllabus.db.global.save_trainer = Syllabus.db.global.save_trainer or {}
	wipe(Syllabus.db.global.save_trainer)

	Syllabus.db.global.save_missing_mapid = Syllabus.db.global.save_missing_mapid or {}
	wipe(Syllabus.db.global.save_missing_mapid)

	Syllabus.db.global.save_invalid_trainer = Syllabus.db.global.save_invalid_trainer or {}
	wipe(Syllabus.db.global.save_invalid_trainer)

	FillZoneToMapTables()

	for trainer_id, trainer in pairs(trainers_db) do
		if not IsTableEmpty(trainer) then
			local id = type(trainer_id) == "number" and trainer_id or trainer.id
			local name = type(trainer_id) == "string" and trainer_id or trainer.name

			local x = trainer.x and trainer.x * 100 or 0
			local y = trainer.y and trainer.y * 100 or 0
			local faction = (trainer.is_alliance and 1 or 0) + (trainer.is_horde and 2 or 0)

			local zone_name = ZONE_NAMES[trainer.continent_id] and ZONE_NAMES[trainer.continent_id][trainer.zone_id]

			local map_id, floor = trainer.map_id, trainer.floor

			if not map_id and trainer.zone_id and trainer.continent_id then
				local id = ("%s;%s"):format(trainer.continent_id, trainer.zone_id)
				map_id = zone_to_mapid[id]
				floor = zone_to_floorid[id]

				if not map_id then
					map_id = name_to_mapid[zone_name]
					floor = map_id and (floor or 0)
				end

				if not map_id then
					Syllabus.db.global.save_missing_mapid[id] = zone_name
				end
			end

			local ident
			if trainer.rep and id and map_id then
				ident = "\t"
			else
				ident = "--\t"
				Syllabus.db.global.save_invalid_trainer[id or "nil"] = true
			end

			local add_string = ('%sAddTrainer( %s, [[%s]], %s, %s, %.1f, %.1f, %s, %s, [[%s]], %d ) -- zone: %s: %s'):format(
				ident,
				pad(id, 5),
				tostring(name),
				tostring(trainer.continent_id),
				tostring(trainer.zone_id),
				x,
				y,
				tostring(map_id),
				tostring(floor),
				tostring(BR[trainer.rep]),
				faction,
				tostring(zone_name),
				tostring(trainer.subzone)
			)

			tinsert(Syllabus.db.global.save_trainer, add_string)
		end
	end

	sort(Syllabus.db.global.save_trainer)

end

local function AddTrainer( id, name, continent_id, zone_id, x, y, map_id, floor, rep, faction )
	local trainers_db = Syllabus.db.global.trainers

	-- name and rep needs to be localized, rep can be done using LibBabble-Faction-3.0
	if not id then
		err("Missing trainer id for %s",name)
		return
	end

	if not (trainers_db[name] or trainers_db[id]) then
		err("New trainer: %s - %s", id, name)
	end

	if not IsTableEmpty(trainers_db[name]) then
		-- Check to see if there is a name entry
		trainers_db[id] = trainers_db[name]
		trainers_db[name] = nil
	end

	local trainer =  trainers_db[id]

	if trainer.id then
		if trainer.id ~= id then
			err("Trainer ID missmatch: existing ID = %s, new ID = %s", trainer.id, id)
			return
		end
	else
		trainer.id = id
	end

	if trainer.name then
		if trainer.name ~= name then
			err("Trainer name missmatch: existing name = %s, new name = %s", trainer.name, name)
			return
		end
	else
		trainer.name = name
	end

	-- If there is a map_id, we don't save the zone_id and continent_id information
	if not map_id then
		if trainer.continent_id then
			if trainer.continent_id ~= continent_id then
				err("Trainer continent_id missmatch: existing id = %s, new is = %s", trainer.continent_id, continent_id)
				return
			end
		else
			trainer.continent_id = continent_id
		end

		if trainer.zone_id then
			if trainer.zone_id ~= zone_id then
				err("Trainer zone_id missmatch: existing id = %s, new is = %s", trainer.zone_id, zone_id)
				return
			end
		else
			trainer.zone_id = zone_id
		end
	else
		trainer.continent_id = nil
		trainer.zone_id = nil
	end


	if trainer.map_id then
		if trainer.map_id ~= map_id then
			err("Trainer map_id missmatch: existing id = %s, new is = %s", trainer.map_id, map_id)
			return
		end
	else
		trainer.map_id = map_id
	end

	floor = floor ~= 0 and floor or nil
	if trainer.floor then
		if trainer.floor ~= floor then
			err("Trainer zone_id missmatch: existing id = %s, new is = %s", trainer.floor, floor)
			return
		end
	else
		trainer.floor = floor
	end

	if x == 0 then
		err("Invalid coordinates for %s - %s: %s, %s", id, name, x, y)
	else
		if not trainer.x or trainer.x == 0 then
			trainer.x = x / 100
			trainer.y = y / 100
		else
			local my_x = floor(trainer.x*1000 + .5)/10
			local my_y = floor(trainer.y*1000 + .5)/10

			if my_x ~= x then
				--err("Different x values for %s: (%s,%s) ~= (%s,%s)", tostring(name), tostring(my_x), tostring(my_y), tostring(x), tostring(y))
			end

			if my_y ~= y then
				--err("Different y values for %s: (%s,%s) ~= (%s,%s)", tostring(name), tostring(my_x), tostring(my_y), tostring(x), tostring(y))
			end
		end
	end

	if trainer.rep then
		if trainer.rep ~= BL[rep] then
			err("Trainer reputation missmatch: existing rep = %s, new rep = %s", trainer.rep, BL[rep])
			return
		end
	else
		if rep ~= 'nil' then
			trainer.rep = BL[rep]
		else
			err("Missing rep for %s (%s)",id,name)
		end
	end

	if faction == 3 then
		trainer.is_alliance = true
		trainer.is_horde = true
	elseif faction == 1 then
		trainer.is_alliance = true
	elseif faction == 2 then
		trainer.is_horde = true
	else
		err("Unknown faction for %s: %s", name, faction)
	end

end

function Syllabus:AddTrainers()

	AddTrainer( 17246, "\"Cookie\" McWeaksauce", 1, 4, 46.7, 70.5, 464, 0, "Stormwind", 1 ) -- zone: Azuremyst Isle: nil
	AddTrainer( 20914, "Aalun", 1, 23, 81.3, 52.8, 471, 0, "Exodar", 1 ) -- zone: The Exodar:
	AddTrainer(  3967, "Aayndia Floralwind", 1, 2, 35.9, 52.1, 43, 0, "Darnassus", 1 ) -- zone: Ashenvale: nil
	AddTrainer( 47382, "Adam Hossack", 2, 35, 75.8, 37.6, 382, 0, "Undercity", 2 ) -- zone: Undercity: Magic Quarter
	AddTrainer(  1632, "Adele Fielder", 2, 10, 46.4, 62.1, 30, 0, "Stormwind", 1 ) -- zone: Elwynn Forest: nil
	AddTrainer( 26977, "Adelene Sunlance", 4, 1, 41.2, 53.9, 486, 0, "Warsong Offensive", 2 ) -- zone: Borean Tundra: nil
	AddTrainer( 33630, "Aelthin", 3, 6, 38.5, 71.1, 481, 0, "The Scryers", 2 ) -- zone: Shattrath City: Scryer's Tier
	AddTrainer( 16771, "Ahonan", 1, 23, 55.2, 82.9, 471, 0, "Exodar", 1 ) -- zone: The Exodar: Trader's Tier
	AddTrainer(  4160, "Ainethil", 1, 7, 55.0, 23.8, 381, 0, "Darnassus", 1 ) -- zone: Darnassus: nil
	AddTrainer( 16728, "Akham", 1, 23, 67.3, 74.5, 471, 0, "Exodar", 1 ) -- zone: The Exodar: Trader's Tier
	AddTrainer(  3606, "Alanna Raveneye", 1, 22, 36.8, 34.2, 41, 0, "Darnassus", 1 ) -- zone: Teldrassil: nil
	AddTrainer( 28694, "Alard Schmied", 4, 3, 45.3, 28.0, 504, 1, "Kirin Tor", 3 ) -- zone: Dalaran: Tanks for Everything
	AddTrainer( 50010, "Alaressa", 3, 6, 51.9, 51.8, 481, 0, "The Scryers", 1 ) -- zone: Shattrath City: nil
	AddTrainer( 18802, "Alchemist Gribble", 3, 2, 53.9, 65.8, 465, 0, "Honor Hold", 1 ) -- zone: Hellfire Peninsula: Honor Hold
	AddTrainer( 33674, "Alchemist Kanhu", 3, 6, 38.6, 30.0, 481, 0, "The Aldor", 3 ) -- zone: Shattrath City:
	AddTrainer(  1215, "Alchemist Mallory", 2, 10, 39.8, 48.3, 30, 0, "Stormwind", 1 ) -- zone: Elwynn Forest: nil
--	AddTrainer(  4900, "Alchemist Narett", 1, 10, 64.0, 47.7, 141, 0, nil, 1 ) -- zone: Dustwallow Marsh: Theramore Isle
	AddTrainer( 33608, "Alchemy", 3, 6, 44.2, 90.3, 481, 0, "The Scryers", 3 ) -- zone: Shattrath City: The Seer's Library
	AddTrainer(  4210, "Alegorn", 1, 7, 50.1, 36.6, 381, 0, "Darnassus", 1 ) -- zone: Darnassus: Craftsmen's Terrace
	AddTrainer( 15501, "Aleinia", 2, 11, 48.5, 47.5, 462, 0, "Silvermoon City", 2 ) -- zone: Eversong Woods: nil
	AddTrainer( 26997, "Alestos", 4, 1, 57.5, 72.2, 486, 0, "Valiance Expedition", 1 ) -- zone: Borean Tundra: Valiance Keep
	AddTrainer( 16662, "Alestus", 2, 24, 77.6, 71.3, 480, 0, "Silvermoon City", 2 ) -- zone: Silvermoon City: Walk of Elders
	AddTrainer(  5173, "Alexander Calder", 2, 14, 50.1, 7.3, 341, 0, "Ironforge", 1 ) -- zone: Ironforge: The Forlorn Cavern
	AddTrainer( 26964, "Alexandra McQueen", 4, 6, 79.4, 30.7, 491, 0, "The Hand of Vengeance", 2 ) -- zone: Howling Fjord: nil
	AddTrainer( 26990, "Alexis Marlowe", 4, 1, 57.6, 71.7, 486, 0, "Valiance Expedition", 1 ) -- zone: Borean Tundra: Valiance Keep
--	AddTrainer( 34786, "Alice Rigsdale", 2, 11, 52.8, 56.1, 462, 0, nil, 2 ) -- zone: Eversong Woods:
--	AddTrainer( 34785, "Alnar Whitebough", 1, 23, 73.2, 56.4, 471, 0, nil, 1 ) -- zone: The Exodar:
	AddTrainer( 29194, "Amal'thazad", 2, 9, 80.4, 48.1, 23, 0, "Knights of the Ebon Blade", 3 ) -- zone: Eastern Plaguelands: Acherus: The Ebon Hold
	AddTrainer(  4568, "Anastasia Hartwell", 2, 35, 85.4, 10.8, 382, nil, "Undercity", 2 ) -- zone: Undercity: Magic Quarter
	AddTrainer( 22477, "Anchorite Ensham", 3, 7, 30.9, 76.0, 478, 0, "The Sha'tar", 3 ) -- zone: Terokkar Forest: Sha'tari Base Camp
	AddTrainer( 17214, "Anchorite Fateema", 1, 4, 48.5, 51.8, 464, 0, "Exodar", 1 ) -- zone: Azuremyst Isle: nil
	AddTrainer( 17424, "Anchorite Paetheus", 1, 5, 54.7, 54.0, 476, 0, "Exodar", 1 ) -- zone: Bloodmyst Isle: nil
	AddTrainer( 23734, "Anchorite Yazmina", 4, 6, 59.7, 62.2, 491, 0, "Valiance Expedition", 1 ) -- zone: Howling Fjord: Valgarde
	AddTrainer( 29508, "Andellion", 4, 3, 34.1, 27.8, 504, 1, "Kirin Tor", 3 ) -- zone: Dalaran: Legendary Leathers
	AddTrainer(   914, "Ander Germaine", 2, 26, 79.4, 69.0, 301, 0, "Stormwind", 1 ) -- zone: Stormwind City: Command Center
	AddTrainer(  3607, "Androl Oakhand", 1, 22, 54.0, 90.0, 41, 0, "Darnassus", 1 ) -- zone: Teldrassil: Rut'theran Village
	AddTrainer(  4215, "Anishar", 1, 7, 42.2, 36.8, 381, 0, "Darnassus", 1 ) -- zone: Darnassus: Cenarion Enclave
	AddTrainer( 16588, "Apothecary Antonivich", 3, 2, 52.4, 36.5, 465, 0, "Thrallmar", 2 ) -- zone: Hellfire Peninsula: nil
	AddTrainer( 27023, "Apothecary Bressa", 4, 4, 36.2, 48.7, 488, 0, "The Hand of Vengeance", 2 ) -- zone: Dragonblight: nil
	AddTrainer( 27029, "Apothecary Wormwick", 4, 4, 76.9, 62.2, 488, 0, "The Hand of Vengeance", 2 ) -- zone: Dragonblight: nil
	AddTrainer( 15400, "Arathel Sunforge", 2, 11, 59.6, 62.6, 462, 0, "Silvermoon City", 2 ) -- zone: Eversong Woods: nil
	AddTrainer( 16161, "Arcanist Sheynathren", 2, 11, 38.2, 72.5, 462, 0, "Silvermoon City", 2 ) -- zone: Eversong Woods: nil
	AddTrainer( 29156, "Archmage Celindra", 4, 3, 56.5, 47.1, 504, 1, "Kirin Tor", 1 ) -- zone: Dalaran: The Violet Gate
	AddTrainer(  3047, "Archmage Shymm", 1, 25, 22.7, 14.8, 362, nil, "Undercity", 2 ) -- zone: Thunder Bluff: The Pools of Vision
	AddTrainer( 18991, "Aresella", 3, 2, 26.3, 62.0, 465, 0, "Silvermoon City", 2 ) -- zone: Hellfire Peninsula: nil
	AddTrainer( 26988, "Argo Strongstout", 4, 1, 57.2, 66.6, 486, 0, "Valiance Expedition", 1 ) -- zone: Borean Tundra: Valiance Keep
	AddTrainer(  4087, "Arias'ta Bladesinger", 1, 7, 56.5, 46.3, 381, 0, "Darnassus", 1 ) -- zone: Darnassus:
	AddTrainer(  4573, "Armand Cromwell", 2, 35, 80.8, 31.1, 382, 0, "Undercity", 2 ) -- zone: Undercity: Magic Quarter
	--AddTrainer(  3373, "Arnok", 1, 17, 34.0, 84.5, 321, 2, "Orgrimmar", 2 ) -- zone: Orgrimmar: Valley of Spirits
	AddTrainer(  5493, "Arnold Leland", 2, 26, 55.0, 69.4, 301, nil, "Stormwind", 1 ) -- zone: Stormwind City: The Canals
	AddTrainer( 33603, "Arthur Denny", 4, 8, 71.8, 20.9, 492, 0, "Argent Crusade", 3 ) -- zone: Icecrown: Argent Tournament Grounds
	AddTrainer( 26975, "Arthur Henslowe", 4, 1, 41.8, 54.3, 486, 0, "Warsong Offensive", 2 ) -- zone: Borean Tundra: nil
	AddTrainer(  4588, "Arthur Moore", 2, 35, 70.2, 58.1, 382, 0, "Undercity", 2 ) -- zone: Undercity: Rogues' Quarter
	AddTrainer(  5491, "Arthur the Faithful", 2, 26, 52.7, 45.4, 301, nil, "Stormwind", 1 ) -- zone: Stormwind City: Cathedral of Light
	AddTrainer( 17222, "Artificer Daelo", 1, 4, 48.0, 51.0, 464, 0, "Exodar", 1 ) -- zone: Azuremyst Isle: nil
	AddTrainer( 46709, "Arugi", 1, 17, 56.3, 61.5, 321, 2, "Orgrimmar", 2 ) -- zone: Orgrimmar: The Drag
	AddTrainer( 19540, "Asarnan", 3, 4, 44.2, 33.7, 479, 0, "The Consortium", 3 ) -- zone: Netherstorm: nil
	AddTrainer(  3026, "Aska Mistrunner", 1, 25, 51.1, 52.9, 362, 0, "Thunder Bluff", 2 ) -- zone: Thunder Bluff: Thunder Bluff
	AddTrainer(  4156, "Astaia", 1, 7, 49.0, 61.1, 381, 0, "Darnassus", 1 ) -- zone: Darnassus: Tradesmen's Terrace
	AddTrainer( 26996, "Awan Iceborn", 4, 1, 76.3, 37.0, 486, 0, "The Taunka", 2 ) -- zone: Borean Tundra: nil
	AddTrainer( 29631, "Awilo Lon'gomba", 4, 3, 70.2, 38.7, 504, 1, "The Sunreavers", 2 ) -- zone: Dalaran: The Filthy Animal
	AddTrainer(  6291, "Balthus Stoneflayer", 2, 14, 39.8, 32.5, 341, 0, "Ironforge", 1 ) -- zone: Ironforge: The Great Forge
	AddTrainer( 33631, "Barien", 3, 6, 43.2, 64.7, 481, 0, "The Scryers", 3 ) -- zone: Shattrath City:
	AddTrainer( 18754, "Barim Spilthoof", 3, 2, 56.2, 38.6, 465, 0, "Orgrimmar", 2 ) -- zone: Hellfire Peninsula: nil
	AddTrainer( 17514, "Bati", 1, 23, 46.5, 63.1, 471, 0, "Exodar", 1 ) -- zone: The Exodar: The Vault of Lights
	AddTrainer( 18988, "Baxter", 3, 2, 56.8, 37.5, 465, 0, "Thrallmar", 2 ) -- zone: Hellfire Peninsula: nil
	AddTrainer( 17120, "Behomat", 1, 23, 55.4, 81.9, 471, 0, "Exodar", 1 ) -- zone: The Exodar: Trader's Tier
	AddTrainer( 16663, "Belil", 2, 24, 79.1, 42.9, 480, 0, "Silvermoon City", 2 ) -- zone: Silvermoon City: Farstriders' Square
	AddTrainer( 47571, "Belloc Brightblade", 1, 17, 49.0, 70.6, 321, 1, "Silvermoon City", 2 ) -- zone: Orgrimmar: Grommash Hold
	AddTrainer( 16669, "Bemarrin", 2, 24, 79.5, 39.0, 480, 0, "Silvermoon City", 2 ) -- zone: Silvermoon City: Farstriders' Square
	AddTrainer(  3009, "Bena Winterhoof", 1, 25, 46.8, 33.5, 362, 0, "Thunder Bluff", 2 ) -- zone: Thunder Bluff: Thunder Bluff
	AddTrainer(  4258, "Bengus Deepforge", 2, 14, 52.1, 41.7, 341, 0, "Ironforge", 1 ) -- zone: Ironforge: The Great Forge
	AddTrainer( 26914, "Benjamin Clegg", 4, 6, 58.6, 62.8, 491, 0, "Valiance Expedition", 1 ) -- zone: Howling Fjord: nil
	AddTrainer(  3032, "Beram Skychaser", 1, 25, 22.2, 19.3, 362, 0, "Thunder Bluff", 2 ) -- zone: Thunder Bluff: Spirit Rise
	AddTrainer( 26911, "Bernadette Dexter", 4, 6, 59.9, 63.5, 491, 0, "Valiance Expedition", 1 ) -- zone: Howling Fjord: Valgarde
	AddTrainer( 33587, "Bethany Cromwell", 4, 8, 72.4, 20.9, 492, 0, "Argent Crusade", 3 ) -- zone: Icecrown: Argent Tournament Grounds
	AddTrainer(  5114, "Bilban Tosslespanner", 2, 14, 66.3, 88.3, 341, 0, "Gnomeregan", 1 ) -- zone: Ironforge: Hall of Arms
	AddTrainer(  7954, "Binjy Featherwhistle", 2, 7, 56.3, 46.4, 27, 0, "Gnomeregan", 1 ) -- zone: Dun Morogh: Steelgrill's Depot
	AddTrainer(  5144, "Bink", 2, 14, 27.0, 8.2, 341, 0, "Gnomeregan", 1 ) -- zone: Ironforge: Hall of Mysteries
	AddTrainer( 33586, "Binkie Brightgear", 4, 8, 72.2, 20.9, 492, 0, "Argent Crusade", 3 ) -- zone: Icecrown: Argent Tournament Grounds
	AddTrainer( 42331, "Bipsi Frostflinger", 2, 7, 34.5, 35.1, 27, 0, "Gnomeregan", 1 ) -- zone: Dun Morogh: New Tinkertown
	AddTrainer(  5957, "Birgitte Cranston", 1, 25, 22.2, 16.9, 362, nil, "Undercity", 2 ) -- zone: Thunder Bluff: The Pools of Vision
	AddTrainer( 17245, "Blacksmith Calypso", 1, 4, 46.4, 71.1, 464, 0, "Ironforge", 1 ) -- zone: Azuremyst Isle: nil
	AddTrainer( 33609, "Blacksmithing", 3, 6, 43.9, 90.2, 481, 0, "The Scryers", 3 ) -- zone: Shattrath City: The Seer's Library
	AddTrainer( 47575, "Boduro the Seeker", 3, 6, 62.4, 70.4, 481, 0, "Lower City", 3 ) -- zone: Shattrath City: Lower City
	AddTrainer( 44393, "Bolner Hammerbeak", 2, 26, 65.8, 31.0, 301, nil, "Stormwind", 1 ) -- zone: Stormwind City: Dwarven District
	AddTrainer( 26959, "Booker Kells", 4, 6, 79.3, 29.3, 491, 0, "The Hand of Vengeance", 2 ) -- zone: Howling Fjord: Vengeance Landing
	AddTrainer( 11178, "Borgosh Corebender", 1, 17, 75.9, 33.7, 321, 2, "Orgrimmar", 2 ) -- zone: Orgrimmar: Valley of Honor
	AddTrainer(  7232, "Borgus Steelhand", 2, 26, 59.8, 34.8, 301, 0, "Ironforge", 1 ) -- zone: Stormwind City: nil
	AddTrainer( 26564, "Borus Ironbender", 4, 4, 36.6, 47.1, 488, 0, "Warsong Offensive", 2 ) -- zone: Dragonblight: nil
	AddTrainer( 33639, "Botanist Alaenra", 3, 6, 38.5, 71.1, 481, 0, "The Scryers", 2 ) -- zone: Shattrath City: Scryer's Tier
	AddTrainer( 16644, "Botanist Nathera", 2, 24, 67.4, 18.6, 480, 0, "Silvermoon City", 2 ) -- zone: Silvermoon City: Court of the Sun
	AddTrainer(  3523, "Bowen Brisboise", 2, 31, 52.6, 55.6, 20, 0, "Undercity", 2 ) -- zone: Tirisfal Glades: nil
	AddTrainer(  5142, "Braenna Flintcrag", 2, 14, 24.6, 8.8, 341, 0, "Ironforge", 1 ) -- zone: Ironforge: Hall of Mysteries
	AddTrainer( 43769, "Bralla Cloudwing", 2, 26, 70.3, 73.3, 301, nil, "Stormwind", 1 ) -- zone: Stormwind City: Gryphon Roost
--	AddTrainer( 29924, "Brandig", 4, 10, 28.9, 74.9, 495, 0, nil, 1 ) -- zone: The Storm Peaks: nil
	AddTrainer(  5149, "Brandur Ironhammer", 2, 14, 23.5, 6.1, 341, 0, "Ironforge", 1 ) -- zone: Ironforge: Hall of Mysteries
	AddTrainer(  7946, "Brannock", 1, 12, 45.3, 41.5, 121, 0, "Darnassus", 1 ) -- zone: Feralas: Feathermoon Stronghold
	AddTrainer( 50025, "Bratu", 3, 6, 56.1, 37.3, 481, 0, "The Aldor", 1 ) -- zone: Shattrath City: Terrace of Light
--	AddTrainer(  1385, "Brawn", 2, 27, 31.7, 28.8, 689, 0, nil, 2 ) -- zone: Stranglethorn Vale: nil
	AddTrainer(  3001, "Brek Stonehoof", 1, 25, 34.6, 57.6, 362, 0, "Thunder Bluff", 2 ) -- zone: Thunder Bluff: Thunder Bluff
	AddTrainer(  5172, "Briarthorn", 2, 14, 50.2, 5.6, 341, 0, "Gnomeregan", 1 ) -- zone: Ironforge: The Forlorn Cavern
	AddTrainer(  2836, "Brikk Keencraft", 2, 29, 44.1, 70.9, 673, 0, "Booty Bay", 3 ) -- zone: The Cape of Stranglethorn: Booty Bay
	AddTrainer(  1681, "Brock Stoneseeker", 2, 17, 37.1, 47.8, 35, 0, "Ironforge", 1 ) -- zone: Loch Modan: nil
	AddTrainer( 26905, "Brom Brewbaster", 4, 6, 58.2, 62.1, 491, 0, "Valiance Expedition", 1 ) -- zone: Howling Fjord: Valgarde
	AddTrainer(  4598, "Brom Killian", 2, 35, 55.8, 37.0, 382, 0, "Undercity", 2 ) -- zone: Undercity: War Quarter
	AddTrainer(  1702, "Bronk Guzzlegear", 2, 7, 57.3, 48.7, 27, 0, "Ironforge", 1 ) -- zone: Dun Morogh: Steelgrill's Depot
	AddTrainer(  5484, "Brother Benjamin", 2, 26, 50.8, 45.0, 301, nil, "Stormwind", 1 ) -- zone: Stormwind City: Cathedral of Light
	AddTrainer(  5489, "Brother Joshua", 2, 26, 49.6, 45.1, 301, nil, "Stormwind", 1 ) -- zone: Stormwind City: Cathedral of Light
	AddTrainer( 50022, "Brulla", 1, 16, 49.5, 60.8, 11, 0, "Orgrimmar", 2 ) -- zone: Northern Barrens: The Crossroads
	AddTrainer( 18771, "Brumman", 3, 2, 54.1, 64.0, 465, 0, "Honor Hold", 1 ) -- zone: Hellfire Peninsula: nil
	AddTrainer(  7869, "Brumn Winterhoof", 2, 2, 28.2, 45.0, 16, 0, "Thunder Bluff", 2 ) -- zone: Arathi Highlands: nil
	AddTrainer( 26976, "Brunna Ironaxe", 4, 1, 42.6, 53.2, 486, 0, "Warsong Offensive", 2 ) -- zone: Borean Tundra: nil
	AddTrainer( 26992, "Brynna Wilson", 4, 1, 57.9, 66.4, 486, 0, "Valiance Expedition", 1 ) -- zone: Borean Tundra: Valiance Keep
	AddTrainer( 18990, "Burko", 3, 2, 22.4, 39.4, 465, 0, "Exodar", 1 ) -- zone: Hellfire Peninsula: Temple of Telhamat
	AddTrainer(  8736, "Buzzek Bracketswing", 1, 21, 52.3, 27.7, 161, 0, "Gadgetzan", 3 ) -- zone: Tanaris: nil
	AddTrainer(  6094, "Byancie", 1, 22, 55.3, 56.8, 41, 0, "Darnassus", 1 ) -- zone: Teldrassil: nil
	AddTrainer( 26909, "Byron Welwick", 4, 6, 60.4, 64.1, 491, 0, "Valiance Expedition", 1 ) -- zone: Howling Fjord: Valgarde
	AddTrainer( 16642, "Camberon", 2, 24, 66.1, 17.4, 480, 0, "Silvermoon City", 2 ) -- zone: Silvermoon City: Court of the Sun
	AddTrainer(  2132, "Carolai Anise", 2, 31, 59.5, 52.2, 20, 0, "Undercity", 2 ) -- zone: Tirisfal Glades: nil
	AddTrainer( 26960, "Carter Tiffens", 4, 6, 79.3, 28.9, 491, 0, "The Hand of Vengeance", 2 ) -- zone: Howling Fjord: Vengeance Landing
--	AddTrainer(  7870, "Caryssia Moonhunter", 1, 12, 89.4, 46.5, 121, 0, nil, 1 ) -- zone: Feralas: nil
	AddTrainer( 30713, "Catarina Stanford", 2, 26, 49.8, 74.8, 301, nil, "Stormwind", 1 ) -- zone: Stormwind City: The Scribe of Stormwind
	AddTrainer( 44395, "Celestine of the Harvest", 2, 26, 57.7, 24.8, 301, 0, "Stormwind", 1 ) -- zone: Stormwind City:
--	AddTrainer( 19369, "Celie Steelwing", 3, 5, 37.2, 58.5, 473, 0, nil, 1 ) -- zone: Shadowmoon Valley: nil
	AddTrainer( 28699, "Charles Worth", 4, 3, 36.2, 33.9, 504, 1, "Kirin Tor", 3 ) -- zone: Dalaran: Talismanic Textiles
	AddTrainer(  3069, "Chaw Stronghide", 1, 15, 45.5, 57.9, 9, 0, "Thunder Bluff", 2 ) -- zone: Mulgore: nil
	AddTrainer( 25277, "Chief Engineer Leveny", 4, 1, 42.6, 53.7, 486, 0, "Warsong Offensive", 2 ) -- zone: Borean Tundra: nil
	AddTrainer( 45306, "Chief Surgeon Gashweld", 2, 26, 63.1, 34.2, 301, 0, "Gnomeregan", 1 ) -- zone: Stormwind City: Dwarven District
	AddTrainer(  3136, "Clarise Gnarltree", 2, 8, 74.0, 48.6, 34, 0, "Stormwind", 1 ) -- zone: Duskwood: Darkshire
	AddTrainer(  5690, "Clyde Kellen", 2, 31, 67.0, 51.0, 20, 0, "Undercity", 2 ) -- zone: Tirisfal Glades: Brightwater Lake
	AddTrainer( 50011, "Cona", 1, 9, 56.2, 75.2, 4, 0, "Darkspear Trolls", 2 ) -- zone: Durotar: Sen'jin Village
	AddTrainer( 45714, "Conjurer Mixli", 1, 17, 40.4, 80.3, 321, 2, "Bilgewater Cartel", 2 ) -- zone: Orgrimmar: Goblin Slums
	AddTrainer(  1355, "Cook Ghilm", 2, 7, 75.6, 52.8, 27, 0, "Ironforge", 1 ) -- zone: Dun Morogh: Gol'Bolar Quarry
	AddTrainer( 33619, "Cooking", 3, 6, 43.2, 91.4, 481, 0, "The Scryers", 3 ) -- zone: Shattrath City: The Seer's Library
	AddTrainer( 26981, "Crog Steelspine", 4, 1, 40.8, 55.3, 486, 0, "Warsong Offensive", 2 ) -- zone: Borean Tundra: nil
	AddTrainer(  3087, "Crystal Boughman", 2, 19, 22.8, 43.6, 36, 0, "Stormwind", 1 ) -- zone: Redridge Mountains: nil
	AddTrainer( 33588, "Crystal Brightspark", 4, 8, 71.6, 20.9, 492, 0, "Argent Crusade", 3 ) -- zone: Icecrown: Argent Tournament Grounds
	AddTrainer(  3603, "Cyndra Kindwhisper", 1, 22, 57.6, 60.7, 41, 0, "Darnassus", 1 ) -- zone: Teldrassil: nil
	AddTrainer( 17215, "Daedal", 1, 4, 48.5, 51.5, 464, 0, "Exodar", 1 ) -- zone: Azuremyst Isle: nil
	AddTrainer( 33635, "Daenril", 3, 6, 41.6, 63.4, 481, 0, "The Scryers", 3 ) -- zone: Shattrath City:
	AddTrainer( 44394, "Dalga Hammerbeak", 2, 26, 66.1, 31.2, 301, nil, "Stormwind", 1 ) -- zone: Stormwind City: Dwarven District
	AddTrainer( 18749, "Dalinna", 3, 2, 56.6, 37.1, 465, 0, "Thrallmar", 2 ) -- zone: Hellfire Peninsula: nil
	AddTrainer(  1701, "Dank Drizzlecut", 2, 7, 76.5, 53.7, 27, 0, "Ironforge", 1 ) -- zone: Dun Morogh: Gol'Bolar Quarry
	AddTrainer(  4211, "Dannelor", 1, 7, 51.7, 30.8, 381, 0, "Darnassus", 1 ) -- zone: Darnassus: Craftsmen's Terrace
	AddTrainer( 16667, "Danwe", 2, 24, 76.5, 40.9, 480, 0, "Silvermoon City", 2 ) -- zone: Silvermoon City: nil
	AddTrainer( 50729, "Darba the Crone", 2, 14, 50.0, 5.9, 341, 0, "Ironforge", 1 ) -- zone: Ironforge: The Forlorn Cavern
	AddTrainer( 52335, "Dareth", 2, 7, 59.6, 35.0, 27, 0, "Gilneas", 1 ) -- zone: Dun Morogh: Gates of Ironforge
	AddTrainer( 27001, "Darin Goodstitch", 4, 1, 57.4, 72.3, 486, 0, "Valiance Expedition", 1 ) -- zone: Borean Tundra: Valiance Keep
	AddTrainer( 47579, "Dariness the Learned", 4, 3, 48.1, 38.7, 504, 1, "Kirin Tor", 1 ) -- zone: Dalaran: The Legerdemain Lounge
	AddTrainer( 45339, "Dark Cleric Cecille", 1, 17, 48.2, 73.0, 321, 2, "Undercity", 2 ) -- zone: Orgrimmar: Grommash Hold
	AddTrainer( 43693, "Darlene Stokx", 2, 26, 77.4, 67.6, 301, nil, "Stormwind", 1 ) -- zone: Stormwind City:
	AddTrainer( 19187, "Darmari", 3, 6, 66.8, 67.1, 481, 0, "Lower City", 3 ) -- zone: Shattrath City: nil
	AddTrainer(  7315, "Darnath Bladesinger", 1, 7, 56.5, 46.3, 381, 0, "Darnassus", 1 ) -- zone: Darnassus:
	AddTrainer(  5159, "Daryl Riknussun", 2, 14, 60.1, 36.6, 341, 0, "Ironforge", 1 ) -- zone: Ironforge: The Great Forge
	AddTrainer(  2399, "Daryl Stack", 2, 13, 63.7, 20.8, 24, 0, "Undercity", 2 ) -- zone: Hillsbrad Foothills: nil
	AddTrainer(  3290, "Deek Fizzlebizz", 2, 17, 45.9, 13.6, 35, 0, "Gnomeregan", 1 ) -- zone: Loch Modan: nil
	AddTrainer(  5885, "Deino", 1, 17, 38.5, 85.9, 321, 2, "Orgrimmar", 2 ) -- zone: Orgrimmar: Valley of Spirits
--	AddTrainer(  6299, "Delfrum Flintbeard", 1, 6, 38.2, 41.0, 42, 0, nil, 1 ) -- zone: Darkshore: nil
	AddTrainer(   461, "Demisette Cloyce", 2, 26, 39.3, 84.9, 301, 0, "Stormwind", 1 ) -- zone: Stormwind City: The Slaughtered Lamb
	AddTrainer(  4218, "Denatharion", 1, 7, 40.1, 27.4, 381, 0, "Darnassus", 1 ) -- zone: Darnassus: Cenarion Enclave
	AddTrainer( 23103, "Derek the Undying", 2, 35, 56.6, 17.8, 382, 0, "Undercity", 2 ) -- zone: Undercity: War Quarter
	AddTrainer( 28696, "Derik Marks", 4, 3, 35.0, 28.6, 504, 1, "Kirin Tor", 3 ) -- zone: Dalaran: Legendary Leathers
	AddTrainer( 28700, "Diane Cannings", 4, 3, 35.0, 28.6, 504, 1, "Kirin Tor", 3 ) -- zone: Dalaran: Legendary Leathers
	AddTrainer( 29513, "Didi the Wrench", 4, 3, 39.5, 24.9, 504, 1, "Kirin Tor", 3 ) -- zone: Dalaran: Like Clockwork
	AddTrainer(  7312, "Dink", 2, 14, 27.0, 8.2, 341, 0, "Gnomeregan", 1 ) -- zone: Ironforge: Hall of Mysteries
	AddTrainer( 36615, "Doc Zapnozzle", 5, 3, 42.7, 16.3, 544, 0, "Bilgewater Cartel", 2 ) -- zone: The Lost Isles: Gallywix Docks
	AddTrainer( 12920, "Doctor Gregory Victor", 2, 2, 73.4, 36.8, 16, 0, "Undercity", 2 ) -- zone: Arathi Highlands: nil
--	AddTrainer( 12939, "Doctor Gustaf VanHowzen", 1, 10, 68.2, 47.9, 141, 0, nil, 1 ) -- zone: Dustwallow Marsh: nil
	AddTrainer(  4611, "Doctor Herbert Halsey", 2, 35, 47.7, 73.0, 382, 0, "Undercity", 2 ) -- zone: Undercity: The Apothecarium
	AddTrainer( 39718, "Doktor Professor Ironpants", 2, 14, 75.4, 11.2, 341, 0, "Ironforge", 1 ) -- zone: Ironforge: The Library
	AddTrainer( 43277, "Don Omar", 2, 26, 79.3, 71.0, 301, 0, "Stormwind", 1 ) -- zone: Stormwind City: Command Center
	AddTrainer( 28704, "Dorothy Egan", 4, 3, 43.1, 34.4, 504, 1, "Kirin Tor", 3 ) -- zone: Dalaran: Magus Commerce Exchange
--	AddTrainer( 11097, "Drakk Stonehand", 2, 30, 13.4, 43.4, 26, 0, nil, 1 ) -- zone: The Hinterlands: nil
	AddTrainer( 16780, "Drathen", 2, 24, 76.6, 68.6, 480, 0, "Silvermoon City", 2 ) -- zone: Silvermoon City: Walk of Elders
	AddTrainer( 33683, "Dremm", 3, 6, 37.2, 26.9, 481, 0, "The Aldor", 3 ) -- zone: Shattrath City:
	AddTrainer( 42324, "Drill Sergeant Steamcrank", 2, 7, 34.3, 37.4, 27, 0, "Gnomeregan", 1 ) -- zone: Dun Morogh: New Tinkertown
	AddTrainer( 17488, "Dulvi", 1, 4, 48.9, 51.1, 464, 0, "Exodar", 1 ) -- zone: Azuremyst Isle: nil
	AddTrainer( 33580, "Dustin Vail", 4, 8, 73.0, 20.8, 492, 0, "Argent Crusade", 3 ) -- zone: Icecrown: Argent Tournament Grounds
	AddTrainer(  3174, "Dwukk", 1, 9, 52.0, 40.8, 4, 0, "Orgrimmar", 2 ) -- zone: Durotar: Razor Hill
	AddTrainer( 50714, "Dyrhara", 1, 7, 37.5, 81.1, 381, 0, "Darnassus", 1 ) -- zone: Darnassus: nil
	AddTrainer( 16749, "Edirah", 1, 23, 47.2, 62.2, 471, 0, "Exodar", 1 ) -- zone: The Exodar: The Vault of Lights
	AddTrainer(  5515, "Einris Brightspear", 2, 26, 67.7, 36.5, 301, 0, "Stormwind", 1 ) -- zone: Stormwind City: Dwarven District
	AddTrainer(  1103, "Eldrin", 2, 10, 79.3, 69.0, 30, 0, "Stormwind", 1 ) -- zone: Elwynn Forest: nil
	AddTrainer( 30717, "Elise Brightletter", 2, 14, 60.7, 45.2, 341, 0, "Ironforge", 1 ) -- zone: Ironforge: The Great Forge
	AddTrainer(  4165, "Elissa Dumas", 1, 7, 43.9, 78.5, 381, 0, "Darnassus", 1 ) -- zone: Darnassus: Temple of the Moon
	AddTrainer( 26906, "Elizabeth Jackson", 4, 6, 58.6, 62.8, 491, 0, "Valiance Expedition", 1 ) -- zone: Howling Fjord: nil
	AddTrainer(  5498, "Elsharin", 2, 26, 48.4, 87.5, 301, 0, "Stormwind", 1 ) -- zone: Stormwind City: Wizard's Sanctum
	AddTrainer( 26954, "Emil Autumn", 4, 6, 78.6, 28.3, 491, 0, "The Hand of Vengeance", 2 ) -- zone: Howling Fjord: Vengeance Landing
	AddTrainer( 28693, "Enchanter Nalthanis", 4, 3, 38.8, 40.2, 504, 1, "Kirin Tor", 3 ) -- zone: Dalaran: Simply Enchanting
	AddTrainer( 33610, "Enchanting", 3, 6, 43.7, 90.1, 481, 0, "The Scryers", 3 ) -- zone: Shattrath City: The Seer's Library
	AddTrainer( 33633, "Enchantress Andiala", 3, 6, 55.8, 74.6, 481, 0, "The Scryers", 2 ) -- zone: Shattrath City:
	AddTrainer( 19251, "Enchantress Volali", 3, 6, 43.2, 92.3, 481, 0, "The Scryers", 3 ) -- zone: Shattrath City: nil
	AddTrainer( 33634, "Engineer Sinbei", 3, 6, 43.6, 65.0, 481, 0, "The Scryers", 3 ) -- zone: Shattrath City:
	AddTrainer( 33611, "Engineering", 3, 6, 43.7, 90.1, 481, 0, "The Scryers", 3 ) -- zone: Shattrath City: The Seer's Library
	AddTrainer( 45718, "Environmental Engineer Linza", 1, 17, 36.4, 85.0, 321, 2, "Bilgewater Cartel", 2 ) -- zone: Orgrimmar: Goblin Slums
--	AddTrainer(   nil, "Enyo", 1, 17, 38.7, 85.2, 321, 2, "Orgrimmar", 2 ) -- zone: Orgrimmar: Valley of Spirits
	AddTrainer( 26980, "Eorain Dawnstrike", 4, 1, 41.2, 53.9, 486, 0, "Warsong Offensive", 2 ) -- zone: Borean Tundra: nil
	AddTrainer( 16774, "Erett", 1, 23, 31.8, 14.4, 471, 0, "Exodar", 1 ) -- zone: The Exodar: The Crystal Hall
	AddTrainer( 17487, "Erin Kelly", 1, 4, 46.2, 70.5, 464, 0, "Stormwind", 1 ) -- zone: Azuremyst Isle: nil
	AddTrainer(  4214, "Erion Shadewhisper", 1, 7, 40.0, 39.7, 381, 0, "Darnassus", 1 ) -- zone: Darnassus: Cenarion Enclave
	AddTrainer(  4552, "Eunice Burch", 2, 35, 62.4, 44.8, 382, 0, "Undercity", 2 ) -- zone: Undercity: Trade Quarter
	AddTrainer( 33583, "Fael Morningsong", 4, 8, 73.0, 20.6, 492, 0, "Argent Crusade", 3 ) -- zone: Icecrown: Argent Tournament Grounds
	AddTrainer( 43428, "Faeyrin Willowmoon", 1, 6, 50.7, 20.8, 42, 0, "Darnassus", 1 ) -- zone: Darkshore: Lor'danel
	AddTrainer( 47576, "Falda Fardelve", 4, 1, 57.6, 71.7, 486, 0, "Valiance Expedition", 1 ) -- zone: Borean Tundra: Valiance Keep
	AddTrainer( 26987, "Falorn Nightwhisper", 4, 1, 57.7, 71.9, 486, 0, "Valiance Expedition", 1 ) -- zone: Borean Tundra: Valiance Keep
	AddTrainer( 19778, "Farii", 1, 23, 44.6, 24.3, 471, 0, "Exodar", 1 ) -- zone: The Exodar: The Crystal Hall
	AddTrainer( 23127, "Farseer Javad", 2, 14, 55.3, 29.1, 341, 0, "Exodar", 1 ) -- zone: Ironforge: The Great Forge
	AddTrainer( 50174, "Farseer Lopaa", 4, 3, 38.1, 65.1, 504, 1, "Exodar", 1 ) -- zone: Dalaran: The Silver Enclave
	AddTrainer( 20407, "Farseer Umbrua", 2, 26, 65.9, 31.1, 301, nil, "Exodar", 1 ) -- zone: Stormwind City: Dwarven District
	AddTrainer( 18753, "Felannia", 3, 2, 52.3, 36.1, 465, 0, "Thrallmar", 2 ) -- zone: Hellfire Peninsula: nil
	AddTrainer( 26999, "Fendrig Redbeard", 4, 1, 57.4, 66.2, 486, 0, "Valiance Expedition", 1 ) -- zone: Borean Tundra: Valiance Keep
	AddTrainer(  5167, "Fenthwick", 2, 14, 51.8, 15.3, 341, 0, "Gnomeregan", 1 ) -- zone: Ironforge: The Forlorn Cavern
--	AddTrainer( 19478, "Fera Palerunner", 3, 1, 53.7, 55.0, 475, 0, nil, 2 ) -- zone: Blade's Edge Mountains: nil
	AddTrainer( 30715, "Feyden Darkin", 1, 7, 58.9, 14.1, 381, 0, "Darnassus", 1 ) -- zone: Darnassus: nil
	AddTrainer(  5127, "Fimble Finespindle", 2, 14, 40.1, 33.5, 341, 0, "Gnomeregan", 1 ) -- zone: Ironforge: The Great Forge
	AddTrainer(  1676, "Finbus Geargrind", 2, 8, 77.4, 48.7, 34, 0, "Gnomeregan", 1 ) -- zone: Duskwood: Darkshire
	AddTrainer( 29514, "Findle Whistlesteam", 4, 3, 39.3, 24.9, 504, 1, "Kirin Tor", 3 ) -- zone: Dalaran: Like Clockwork
	AddTrainer( 33621, "First Aid", 3, 6, 43.6, 91.6, 481, 0, "The Scryers", 3 ) -- zone: Shattrath City: The Seer's Library
	AddTrainer( 33623, "Fishing", 3, 6, 43.5, 91.5, 481, 0, "The Scryers", 3 ) -- zone: Shattrath City: The Seer's Library
	AddTrainer(   908, "Flora Silverwind", 2, 29, 42.0, 74.6, 673, 0, "Booty Bay", 3 ) -- zone: The Cape of Stranglethorn: Booty Bay
	AddTrainer( 33682, "Fono", 3, 6, 36.1, 48.1, 481, 0, "The Aldor", 3 ) -- zone: Shattrath City:
	AddTrainer( 52642, "Foreman Pernic", 1, 7, 50.4, 33.7, 381, 0, "Gilneas", 1 ) -- zone: Darnassus:
	AddTrainer( 11031, "Franklin Lloyd", 2, 35, 75.9, 73.7, 382, 0, "Undercity", 2 ) -- zone: Undercity: nil
	AddTrainer( 26913, "Frederic Burrhus", 4, 6, 59.9, 63.8, 491, 0, "Valiance Expedition", 1 ) -- zone: Howling Fjord: Valgarde
	AddTrainer(  3181, "Fremal Doohickey", 2, 39, 10.5, 60.2, 40, 0, "Gnomeregan", 1 ) -- zone: Wetlands: Deepwater Tavern
	AddTrainer(  4219, "Fylerian Nightwing", 1, 7, 39.4, 27.6, 381, 0, "Darnassus", 1 ) -- zone: Darnassus: Cenarion Enclave
	AddTrainer( 18987, "Gaston", 3, 2, 54.0, 63.5, 465, 0, "Honor Hold", 1 ) -- zone: Hellfire Peninsula: Honor Hold
	AddTrainer( 26982, "Geba'li", 4, 1, 41.6, 53.4, 486, 0, "Warsong Offensive", 2 ) -- zone: Borean Tundra: nil
	AddTrainer(  5513, "Gelman Stonehand", 2, 26, 59.7, 37.7, 301, nil, "Stormwind", 1 ) -- zone: Stormwind City: Dwarven District
	AddTrainer(  4254, "Geofram Bouldertoe", 2, 14, 50.1, 26.2, 341, 0, "Ironforge", 1 ) -- zone: Ironforge: The Great Forge
	AddTrainer(  1346, "Georgio Bolero", 2, 26, 53.3, 81.4, 301, nil, "Stormwind", 1 ) -- zone: Stormwind City: Mage Quarter
	AddTrainer( 47574, "Gerdra Fardelve", 3, 2, 53.8, 66.0, 465, 0, "Honor Hold", 1 ) -- zone: Hellfire Peninsula: Honor Hold
	AddTrainer(  1470, "Ghak Healtouch", 2, 17, 37.0, 49.2, 35, 0, "Ironforge", 1 ) -- zone: Loch Modan: nil
	AddTrainer( 47248, "Gija", 1, 17, 49.6, 71.1, 321, 2, "Orgrimmar", 2 ) -- zone: Orgrimmar:
	AddTrainer(  5157, "Gimble Thistlefuzz", 2, 14, 60.4, 45.5, 341, 0, "Gnomeregan", 1 ) -- zone: Ironforge: The Great Forge
	AddTrainer(  3345, "Godan", 1, 17, 53.4, 49.4, 321, 2, "Orgrimmar", 2 ) -- zone: Orgrimmar: The Drag
	AddTrainer( 46357, "Gonto", 1, 17, 44.7, 78.4, 321, 2, "Orgrimmar", 2 ) -- zone: Orgrimmar: Valley of Strength
	AddTrainer(  1229, "Granis Swiftaxe", 2, 7, 54.5, 50.9, 27, 0, "Ironforge", 1 ) -- zone: Dun Morogh: Thunderbrew Distillery
	AddTrainer(  2627, "Grarnik Goodstitch", 2, 29, 43.6, 73.0, 673, 0, "Booty Bay", 3 ) -- zone: The Cape of Stranglethorn: Booty Bay
	AddTrainer(  1699, "Gremlock Pilsnor", 2, 7, 47.6, 52.3, 27, 0, "Ironforge", 1 ) -- zone: Dun Morogh: nil
	AddTrainer( 49781, "Grendin Swiftaxe", 2, 17, 34.0, 46.7, 35, 0, "Ironforge", 1 ) -- zone: Loch Modan: Thelsamar
	AddTrainer(  3353, "Grezz Ragefist", 1, 17, 79.9, 31.1, 321, 2, "Orgrimmar", 2 ) -- zone: Orgrimmar: Hall of the Brave
--	AddTrainer( 21087, "Grikka", 3, 1, 76.8, 65.5, 475, 0, nil, 2 ) -- zone: Blade's Edge Mountains: nil
	AddTrainer(  5161, "Grimnur Stonebrand", 2, 14, 48.2, 8.1, 341, 0, "Ironforge", 1 ) -- zone: Ironforge: The Forlorn Cavern
--	AddTrainer(  4193, "Grondal Moonbreeze", 1, 6, 38.2, 40.5, 42, 0, nil, 1 ) -- zone: Darkshore: nil
	AddTrainer( 26912, "Grumbol Stoutpick", 4, 6, 59.9, 63.9, 491, 0, "Valiance Expedition", 1 ) -- zone: Howling Fjord: Valgarde
	AddTrainer(  5164, "Grumnus Steelshaper", 2, 14, 49.7, 43.1, 341, 0, "Ironforge", 1 ) -- zone: Ironforge: The Great Forge
--	AddTrainer( 19341, "Grutah", 3, 5, 29.7, 31.5, 473, 0, nil, 2 ) -- zone: Shadowmoon Valley: nil
	AddTrainer(  3557, "Guillaume Sorouy", 2, 25, 43.2, 41.0, 21, 0, "Undercity", 2 ) -- zone: Silverpine Forest: nil
	AddTrainer( 26961, "Gunter Hansen", 4, 6, 78.3, 28.2, 491, 0, "The Hand of Vengeance", 2 ) -- zone: Howling Fjord: Vengeance Landing
	AddTrainer( 50152, "Hahna Moonscrest", 4, 3, 58.3, 27.2, 504, 1, "Thunder Bluff", 2 ) -- zone: Dalaran: Sunreaver's Sanctuary
	AddTrainer( 11098, "Hahrana Ironhide", 1, 12, 74.4, 43.1, 121, 0, "Thunder Bluff", 2 ) -- zone: Feralas: Camp Mojache
	AddTrainer( 18772, "Hama", 3, 2, 54.1, 63.6, 465, 0, "Honor Hold", 1 ) -- zone: Hellfire Peninsula: nil
	AddTrainer( 19063, "Hamanar", 3, 6, 35.8, 20.6, 481, 0, "The Aldor", 3 ) -- zone: Shattrath City: Aldor Rise
	AddTrainer( 47569, "Hammon the Jaded", 1, 7, 42.5, 83.3, 381, 0, "Darnassus", 1 ) -- zone: Darnassus: Temple of the Moon
	AddTrainer( 33640, "Hanlir", 3, 6, 58.4, 75.2, 481, 0, "The Scryers", 2 ) -- zone: Shattrath City:
	AddTrainer( 35100, "Hargen Bronzewing", 3, 2, 54.3, 62.7, 465, 0, "Stormwind", 1 ) -- zone: Hellfire Peninsula: Honor Hold
	AddTrainer( 17513, "Harnan", 1, 23, 47.1, 62.5, 471, 0, "Exodar", 1 ) -- zone: The Exodar: The Vault of Lights
	AddTrainer(  3179, "Harold Riggs", 2, 39, 8.1, 58.7, 40, 0, "Stormwind", 1 ) -- zone: Wetlands: Menethil Harbor
	AddTrainer( 44238, "Harrison Jones", 2, 26, 85.7, 25.9, 301, nil, "Stormwind", 1 ) -- zone: Stormwind City: Royal Library
	AddTrainer( 33616, "Herbalism", 3, 6, 44.0, 91.2, 481, 0, "The Scryers", 3 ) -- zone: Shattrath City: The Seer's Library
	AddTrainer( 11074, "Hgarth", 1, 20, 49.2, 57.2, 81, 0, "Orgrimmar", 2 ) -- zone: Stonetalon Mountains: nil
	AddTrainer( 19252, "High Enchanter Bardolan", 3, 6, 43.2, 92.2, 481, 0, "The Scryers", 3 ) -- zone: Shattrath City: nil
	AddTrainer( 11406, "High Priest Rohan", 2, 14, 25.1, 8.4, 341, 0, "Ironforge", 1 ) -- zone: Ironforge: Hall of Mysteries
	AddTrainer(   376, "High Priestess Laurena", 2, 26, 49.4, 44.8, 301, nil, "Stormwind", 1 ) -- zone: Stormwind City: Cathedral of Light
	AddTrainer( 31084, "Highlord Darion Mograine", 2, 9, 83.5, 49.5, 23, 0, "Knights of the Ebon Blade", 3 ) -- zone: Eastern Plaguelands: nil
	AddTrainer( 31238, "Hira Snowdawn", 4, 3, 70.1, 45.2, 504, 1, "Kirin Tor", 3 ) -- zone: Dalaran: Krasus' Landing
	AddTrainer( 44783, "Hiwahi Three-Feathers", 1, 17, 38.8, 50.3, 321, 2, "Thunder Bluff", 2 ) -- zone: Orgrimmar:
--	AddTrainer( 27704, "Horace Alder", 1, 10, 66.3, 48.9, 141, 0, nil, 1 ) -- zone: Dustwallow Marsh: Theramore Isle
	AddTrainer( 47578, "Hugen Goldwise", 4, 6, 58.3, 62.5, 491, 0, "Valiance Expedition", 1 ) -- zone: Howling Fjord: Valgarde
	AddTrainer(  5165, "Hulfdan Blackbeard", 2, 14, 51.7, 14.5, 341, 0, "Ironforge", 1 ) -- zone: Ironforge: The Forlorn Cavern
	AddTrainer( 16823, "Humphry", 3, 2, 56.8, 63.8, 465, 0, "Honor Hold", 1 ) -- zone: Hellfire Peninsula: Honor Hold
	AddTrainer( 18779, "Hurnak Grimmord", 3, 2, 56.7, 63.8, 465, 0, "Honor Hold", 1 ) -- zone: Hellfire Peninsula: Honor Hold
	AddTrainer( 47568, "Ian Thomas Wall", 4, 6, 79.4, 29.3, 491, 0, "Undercity", 2 ) -- zone: Howling Fjord: Vengeance Landing
	AddTrainer(  5480, "Ilsa Corbin", 2, 26, 80.0, 69.6, 301, 0, "Stormwind", 1 ) -- zone: Stormwind City: Command Center
	AddTrainer( 29505, "Imindril Spearsong", 4, 3, 45.0, 29.0, 504, 1, "Kirin Tor", 3 ) -- zone: Dalaran: Tanks for Everything
	AddTrainer( 16653, "Inethven", 2, 24, 59.1, 19.5, 480, nil, "Silvermoon City", 2 ) -- zone: Silvermoon City: Sunfury Spire
	AddTrainer( 33615, "Inscription", 3, 6, 43.5, 90.8, 481, 0, "The Scryers", 3 ) -- zone: Shattrath City: The Seer's Library
	AddTrainer( 20791, "Iorioa", 3, 6, 59.1, 47.2, 481, 0, "The Sha'tar", 1 ) -- zone: Shattrath City: nil
	AddTrainer( 33641, "Irduil", 3, 6, 40.9, 63.3, 481, 0, "The Scryers", 2 ) -- zone: Shattrath City:
	AddTrainer( 11146, "Ironus Coldsteel", 2, 14, 50.1, 42.8, 341, 0, "Ironforge", 1 ) -- zone: Ironforge: The Great Forge
--	AddTrainer( 19185, "Jack Trapper", 3, 6, 62.8, 67.9, 481, 0, nil, 3 ) -- zone: Shattrath City: Lower City
--	AddTrainer(  9584, "Jalane Ayrole", 2, 26, 40.6, 83.9, 301, 0, nil, 1 ) -- zone: Stormwind City: nil
	AddTrainer(  4596, "James Van Brunt", 2, 35, 61.2, 29.9, 382, 0, "Undercity", 2 ) -- zone: Undercity: War Quarter
	AddTrainer( 26955, "Jamesina Watterly", 4, 6, 78.4, 30.0, 491, 0, "The Hand of Vengeance", 2 ) -- zone: Howling Fjord: Vengeance Landing
	AddTrainer(  3404, "Jandi", 1, 17, 34.7, 63.1, 321, 2, "Darkspear Trolls", 2 ) -- zone: Orgrimmar: Valley of Spirits
	AddTrainer(  8142, "Jannos Lighthoof", 1, 12, 76.0, 42.2, 121, 0, "Thunder Bluff", 2 ) -- zone: Feralas: Camp Mojache
	AddTrainer(  4753, "Jartsam", 1, 7, 42.6, 33.0, 381, 0, "Darnassus", 1 ) -- zone: Darnassus: Cenarion Enclave
	AddTrainer(  2837, "Jaxin Chong", 2, 29, 42.6, 74.9, 673, 0, "Booty Bay", 3 ) -- zone: The Cape of Stranglethorn: Booty Bay
--	AddTrainer( 19539, "Jazdalaad", 3, 4, 44.5, 34.0, 479, 0, nil, 3 ) -- zone: Netherstorm: nil
	AddTrainer( 28698, "Jedidiah Handers", 4, 3, 41.4, 26.0, 504, 1, "Kirin Tor", 3 ) -- zone: Dalaran: All That Glitters Prospecting Co.
	AddTrainer( 18777, "Jelena Nightsky", 3, 2, 54.5, 63.3, 465, 0, "Honor Hold", 1 ) -- zone: Hellfire Peninsula: Honor Hold
--	AddTrainer( 11037, "Jenna Lemkenilli", 1, 6, 38.3, 41.1, 42, 0, nil, 1 ) -- zone: Darkshore: nil
	AddTrainer(  5497, "Jennea Cannon", 2, 26, 49.5, 86.1, 301, nil, "Stormwind", 1 ) -- zone: Stormwind City: Wizard's Sanctum
	AddTrainer( 28958, "Jessa Weaver", 4, 3, 55.1, 47.1, 504, 1, "Kirin Tor", 1 ) -- zone: Dalaran: nil
	AddTrainer( 33614, "Jewelcrafting", 3, 6, 43.7, 90.8, 481, 0, "The Scryers", 3 ) -- zone: Shattrath City: The Seer's Library
--	AddTrainer( 14743, "Jhordy Lapforge", 1, 21, 52.3, 26.9, 161, 0, nil, 3 ) -- zone: Tanaris: nil
	AddTrainer( 33678, "Jijia", 3, 6, 38.2, 30.0, 481, 0, "The Aldor", 3 ) -- zone: Shattrath City:
	AddTrainer( 30706, "Jo'mah", 1, 17, 35.7, 69.4, 321, 2, "Darkspear Trolls", 2 ) -- zone: Orgrimmar: Valley of Spirits
	AddTrainer( 18773, "Johan Barnes", 3, 2, 53.7, 66.1, 465, 0, "Honor Hold", 1 ) -- zone: Hellfire Peninsula: Honor Hold
--	AddTrainer(  3555, "Johan Focht", 2, 25, 43.4, 40.5, 21, 0, nil, 2 ) -- zone: Silverpine Forest: nil
--	AddTrainer( 25099, "Jonathan Garrett", 3, 5, 29.2, 28.5, 473, 0, nil, 2 ) -- zone: Shadowmoon Valley: nil
	AddTrainer( 26962, "Jonathan Lewis", 4, 6, 79.3, 29.0, 491, 0, "The Hand of Vengeance", 2 ) -- zone: Howling Fjord: Vengeance Landing
	AddTrainer(  5153, "Jormund Stonebrow", 2, 14, 43.2, 29.2, 341, 0, "Ironforge", 1 ) -- zone: Ironforge: The Great Forge
	AddTrainer(  4576, "Josef Gregorian", 2, 35, 70.7, 30.3, 382, 0, "Undercity", 2 ) -- zone: Undercity: Magic Quarter
	AddTrainer( 33589, "Joseph Wilson", 4, 8, 71.4, 22.5, 492, 0, "Argent Crusade", 3 ) -- zone: Icecrown: Argent Tournament Grounds
	AddTrainer(  4578, "Josephine Lister", 2, 35, 86.5, 22.3, 382, 0, "Undercity", 2 ) -- zone: Undercity: Magic Quarter
--	AddTrainer( 27034, "Josric Fame", 4, 4, 75.9, 63.2, 488, 0, nil, 2 ) -- zone: Dragonblight: nil
	AddTrainer(  5145, "Juli Stormkettle", 2, 14, 26.2, 6.8, 341, 0, "Gnomeregan", 1 ) -- zone: Ironforge: Hall of Mysteries
--	AddTrainer( 18911, "Juno Dufrain", 3, 8, 78.1, 65.9, 467, 0, nil, 1 ) -- zone: Zangarmarsh: Cenarion Refuge
--	AddTrainer( 17634, "K. Lee Smallfry", 3, 8, 68.6, 50.2, 467, 0, nil, 1 ) -- zone: Zangarmarsh: nil
--	AddTrainer( 21493, "Kablamm Farflinger", 3, 4, 32.9, 63.7, 479, 0, nil, 3 ) -- zone: Netherstorm: nil
	AddTrainer(  4566, "Kaelystia Hatebringer", 2, 35, 85.2, 14.3, 382, nil, "Undercity", 2 ) -- zone: Undercity: Magic Quarter
	AddTrainer(  3028, "Kah Mistrunner", 1, 25, 56.6, 47.6, 362, 0, "Thunder Bluff", 2 ) -- zone: Thunder Bluff: Thunder Bluff
--	AddTrainer( 18751, "Kalaen", 3, 2, 56.8, 37.7, 465, 0, nil, 2 ) -- zone: Hellfire Peninsula: nil
	AddTrainer( 19775, "Kalinda", 2, 24, 90.5, 74.1, 480, 0, "Silvermoon City", 2 ) -- zone: Silvermoon City:
--	AddTrainer( 16272, "Kanaria", 2, 11, 48.5, 47.6, 462, 0, nil, 2 ) -- zone: Eversong Woods: nil
	AddTrainer(  3344, "Kardris Dreamseeker", 1, 17, 39.0, 47.4, 321, 2, "Orgrimmar", 2 ) -- zone: Orgrimmar: Valley of Wisdom
	AddTrainer( 45548, "Kark Helmbreaker", 1, 17, 35.9, 82.9, 321, 2, "Thunder Bluff", 2 ) -- zone: Orgrimmar: Goblin Slums
--	AddTrainer(  2998, "Karn Stonehoof", 1, 25, 39.0, 56.5, 362, 0, nil, 2 ) -- zone: Thunder Bluff: nil
	AddTrainer(  3365, "Karolek", 1, 17, 61.0, 54.8, 321, 2, "Orgrimmar", 2 ) -- zone: Orgrimmar: The Drag
	AddTrainer( 28705, "Katherine Lee", 4, 3, 40.4, 65.9, 504, 1, "The Silver Covenant", 1 ) -- zone: Dalaran: A Hero's Welcome
	AddTrainer(  5492, "Katherine the Pure", 2, 26, 52.7, 45.0, 301, nil, "Stormwind", 1 ) -- zone: Stormwind City: Cathedral of Light
	AddTrainer( 17504, "Kazi", 1, 23, 56.8, 84.1, 471, 0, "Exodar", 1 ) -- zone: The Exodar: Trader's Tier
	AddTrainer( 16640, "Keelen Sheets", 2, 24, 57.0, 50.1, 480, 0, "Silvermoon City", 2 ) -- zone: Silvermoon City:
--	AddTrainer(  7231, "Kelgruk Bloodaxe", 1, 17, 81.9, 18.3, 321, 2, nil, 2 ) -- zone: Orgrimmar: nil
	AddTrainer(  1901, "Kelstrum Stonebreaker", 2, 14, 66.9, 89.7, 341, 0, "Ironforge", 1 ) -- zone: Ironforge: Hall of Arms
	AddTrainer(  5113, "Kelv Sternhammer", 2, 14, 70.0, 90.9, 341, 0, "Ironforge", 1 ) -- zone: Ironforge: Hall of Arms
	AddTrainer( 49939, "Kenral Nightwind", 1, 6, 50.7, 18.6, 42, 0, "Darnassus", 1 ) -- zone: Darkshore: Lor'danel
	AddTrainer(  4752, "Kildar", 1, 17, 61.2, 34.7, 321, 2, "Orgrimmar", 2 ) -- zone: Orgrimmar: Valley of Honor
	AddTrainer( 17505, "Killac", 1, 23, 46.3, 88.8, 471, 0, "Exodar", 1 ) -- zone: The Exodar: Trader's Tier
	AddTrainer(  7087, "Killian Hagey", 2, 35, 70.3, 59.9, 382, 0, "Undercity", 2 ) -- zone: Undercity: Rogues' Quarter
	AddTrainer( 26994, "Kirea Moondancer", 4, 1, 57.8, 71.9, 486, 0, "Valiance Expedition", 1 ) -- zone: Borean Tundra: Valiance Keep
	AddTrainer( 33637, "Kirembri Silvermane", 3, 6, 58.0, 75.0, 481, 0, "The Scryers", 2 ) -- zone: Shattrath City:
--	AddTrainer( 11072, "Kitta Firewind", 2, 10, 64.9, 70.6, 30, 0, nil, 1 ) -- zone: Elwynn Forest: nil
	AddTrainer(  3013, "Komin Winterhoof", 1, 25, 49.8, 39.8, 362, 0, "Thunder Bluff", 2 ) -- zone: Thunder Bluff: Thunder Bluff
	AddTrainer( 33681, "Korim", 3, 6, 37.4, 27.6, 481, 0, "The Aldor", 3 ) -- zone: Shattrath City:
	AddTrainer( 20124, "Kradu Grimblade", 3, 6, 69.7, 43.3, 481, 0, "Lower City", 3 ) -- zone: Shattrath City: Lower City
	AddTrainer( 45540, "Krenk Choplimb", 1, 17, 37.1, 87.4, 321, 2, "Bilgewater Cartel", 2 ) -- zone: Orgrimmar: Goblin Slums
	AddTrainer( 26952, "Kristen Smythe", 4, 6, 79.2, 28.9, 491, 0, "The Hand of Vengeance", 2 ) -- zone: Howling Fjord: Vengeance Landing
--	AddTrainer( 18747, "Krugosh", 3, 2, 55.5, 37.6, 465, 0, nil, 2 ) -- zone: Hellfire Peninsula: nil
--	AddTrainer(  3175, "Krunn", 1, 9, 51.9, 40.9, 4, 0, nil, 2 ) -- zone: Durotar: nil
--	AddTrainer( 45286, "KTC Train-a-Tron Deluxe", 5, 3, 53.2, 35.7, 544, 0, nil, 2 ) -- zone: The Lost Isles: Sky Falls
	AddTrainer( 33581, "Kul'de", 4, 8, 71.8, 20.8, 492, 0, "Argent Crusade", 3 ) -- zone: Icecrown: Argent Tournament Grounds
	AddTrainer(  8144, "Kulleg Stonehorn", 1, 12, 74.4, 43.0, 121, 0, "Thunder Bluff", 2 ) -- zone: Feralas: Camp Mojache
--	AddTrainer(  6297, "Kurdram Stonehammer", 1, 6, 38.2, 41.1, 42, 0, nil, 1 ) -- zone: Darkshore: nil
--	AddTrainer(  7948, "Kylanna Windwhisper", 1, 12, 32.6, 43.8, 121, 0, nil, 1 ) -- zone: Feralas: nil
--	AddTrainer(  3964, "Kylanna", 1, 2, 50.8, 67.1, 43, 0, nil, 1 ) -- zone: Ashenvale: nil
	AddTrainer( 19186, "Kylene", 3, 6, 75.3, 31.5, 481, 0, "Lower City", 3 ) -- zone: Shattrath City: World's End Tavern
	AddTrainer(  3036, "Kym Wildmane", 1, 25, 76.4, 31.4, 362, 0, "Thunder Bluff", 2 ) -- zone: Thunder Bluff: Elder Rise
	AddTrainer( 29195, "Lady Alistra", 2, 9, 83.8, 44.6, 23, nil, "Knights of the Ebon Blade", 3 ) -- zone: Eastern Plaguelands: Acherus: The Ebon Hold
--	AddTrainer( 26903, "Lanolis Dewdrop", 4, 6, 58.4, 62.3, 491, 0, nil, 1 ) -- zone: Howling Fjord: nil
	AddTrainer(  2485, "Larimaine Purdue", 2, 26, 50.2, 86.0, 301, nil, "Stormwind", 1 ) -- zone: Stormwind City: Wizard's Sanctum
	AddTrainer( 50732, "Larn Caverndeep", 2, 14, 49.9, 6.3, 341, 0, "Ironforge", 1 ) -- zone: Ironforge: The Forlorn Cavern
	AddTrainer(  5941, "Lau'Tiki", 1, 9, 57.3, 77.1, 4, 0, "Darkspear Trolls", 2 ) -- zone: Durotar: Darkspear Strand
	AddTrainer(  4616, "Lavinia Crowe", 2, 35, 61.9, 60.9, 382, 0, "Undercity", 2 ) -- zone: Undercity: The Apothecarium
	AddTrainer( 33612, "Leatherworking", 3, 6, 43.9, 91.0, 481, 0, "The Scryers", 3 ) -- zone: Shattrath City: The Seer's Library
	AddTrainer( 18775, "Lebowski", 3, 2, 55.7, 65.6, 465, 0, "Honor Hold", 1 ) -- zone: Hellfire Peninsula: Honor Hold
	AddTrainer(  2492, "Lexington Mortaim", 2, 35, 84.4, 15.9, 382, nil, "Undercity", 2 ) -- zone: Undercity: Magic Quarter
	AddTrainer(  5518, "Lilliam Sparkspindle", 2, 26, 62.8, 32.2, 301, nil, "Gnomeregan", 1 ) -- zone: Stormwind City: Dwarven District
	AddTrainer(  5499, "Lilyssia Nightbreeze", 2, 26, 55.6, 85.9, 301, nil, "Stormwind", 1 ) -- zone: Stormwind City: Mage Quarter
	AddTrainer( 28703, "Linzy Blackbolt", 4, 3, 42.8, 32.0, 504, 1, "Kirin Tor", 3 ) -- zone: Dalaran: The Agronomical Apothecary
	AddTrainer(   911, "Llane Beshere", 2, 10, 50.2, 42.2, 30, 0, "Stormwind", 1 ) -- zone: Elwynn Forest: Hall of Arms
	AddTrainer( 12042, "Loganaar", 1, 13, 52.4, 40.5, 241, 0, "Cenarion Circle", 3 ) -- zone: Moonglade: Nighthaven
	AddTrainer(   928, "Lord Grayson Shadowbreaker", 2, 26, 52.8, 45.2, 301, nil, "Stormwind", 1 ) -- zone: Stormwind City: Cathedral of Light
	AddTrainer( 29196, "Lord Thorval", 2, 9, 80.9, 43.8, 23, 0, "Knights of the Ebon Blade", 3 ) -- zone: Eastern Plaguelands: Acherus: The Ebon Hold
	AddTrainer( 13283, "Lord Tony Romano", 2, 26, 79.6, 61.4, 301, 0, "Stormwind", 1 ) -- zone: Stormwind City: SI:7
--	AddTrainer( 19052, "Lorokeem", 3, 6, 45.4, 19.5, 481, 0, nil, 3 ) -- zone: Shattrath City: nil
	AddTrainer(  1317, "Lucan Cordell", 2, 26, 53.0, 74.2, 301, nil, "Stormwind", 1 ) -- zone: Stormwind City: Cordell's Enchanting
--	AddTrainer( 16723, "Lucc", 1, 23, 27.5, 60.9, 471, 0, nil, 1 ) -- zone: The Exodar: nil
	AddTrainer( 46675, "Lugrah", 1, 17, 72.4, 34.5, 321, 2, "Orgrimmar", 2 ) -- zone: Orgrimmar: Valley of Honor
	AddTrainer(  3332, "Lumak", 1, 17, 66.6, 41.6, 321, 2, "Orgrimmar", 2 ) -- zone: Orgrimmar: Valley of Honor
	AddTrainer( 16755, "Lunaraa", 1, 23, 46.3, 63.0, 471, 0, "Exodar", 1 ) -- zone: The Exodar: The Vault of Lights
--	AddTrainer( 16688, "Lynalis", 2, 24, 84.0, 80.2, 480, 0, nil, 2 ) -- zone: Silvermoon City: nil
	AddTrainer(   913, "Lyria Du Lac", 2, 10, 41.1, 65.9, 30, 0, "Stormwind", 1 ) -- zone: Elwynn Forest: Goldshire
--	AddTrainer( 17637, "Mack Diver", 3, 8, 33.9, 51.0, 467, 0, nil, 2 ) -- zone: Zangarmarsh: nil
	AddTrainer( 50715, "Maelir", 1, 7, 37.7, 81.1, 381, 0, "Darnassus", 1 ) -- zone: Darnassus: nil
	AddTrainer(  3363, "Magar", 1, 17, 60.6, 59.1, 321, 2, "Orgrimmar", 2 ) -- zone: Orgrimmar: The Drag
	AddTrainer(   331, "Maginor Dumas", 2, 26, 49.1, 87.6, 301, 0, "Stormwind", 1 ) -- zone: Stormwind City: Wizard's Sanctum
	AddTrainer(  1228, "Magis Sparkmantle", 2, 7, 54.6, 50.4, 27, 0, "Gnomeregan", 1 ) -- zone: Dun Morogh: Thunderbrew Distillery
--	AddTrainer( 16160, "Magistrix Eredania", 2, 11, 38.2, 72.6, 462, 0, nil, 2 ) -- zone: Eversong Woods: nil
	AddTrainer( 35133, "Maigra Keenfeather", 4, 1, 58.9, 68.3, 486, 0, "Valiance Expedition", 1 ) -- zone: Borean Tundra: Valiance Keep
	AddTrainer(  3357, "Makaru", 1, 17, 72.3, 35.0, 321, 2, "Orgrimmar", 2 ) -- zone: Orgrimmar: Valley of Honor
	AddTrainer( 12025, "Malvor", 1, 13, 45.5, 47.0, 241, 0, "Cenarion Circle", 1 ) -- zone: Moonglade: Nighthaven
	AddTrainer( 29507, "Manfred Staller", 4, 3, 34.3, 29.4, 504, 1, "Kirin Tor", 3 ) -- zone: Dalaran: Legendary Leathers
	AddTrainer( 28742, "Marcia Chase", 4, 3, 52.7, 64.4, 504, 1, "Kirin Tor", 3 ) -- zone: Dalaran: The Eventide
	AddTrainer( 30711, "Margaux Parchley", 2, 35, 61.1, 58.6, 382, 0, "Undercity", 2 ) -- zone: Undercity: The Apothecarium
	AddTrainer(  1292, "Maris Granger", 2, 26, 72.1, 62.3, 301, nil, "Stormwind", 1 ) -- zone: Stormwind City: Old Town
	AddTrainer( 26958, "Marjory Kains", 4, 6, 78.5, 28.4, 491, 0, "The Hand of Vengeance", 2 ) -- zone: Howling Fjord: Vengeance Landing
	AddTrainer(  4614, "Martha Alliestar", 2, 35, 54.3, 49.7, 382, 0, "Undercity", 2 ) -- zone: Undercity: The Apothecarium
	AddTrainer( 47247, "Marud", 1, 17, 50.4, 69.7, 321, 2, "Orgrimmar", 2 ) -- zone: Orgrimmar:
	AddTrainer(  4591, "Mary Edras", 2, 35, 73.4, 55.8, 382, 0, "Undercity", 2 ) -- zone: Undercity: Rogues' Quarter
--	AddTrainer( 16253, "Master Chef Mouldier", 2, 12, 48.3, 30.9, 463, 0, nil, 2 ) -- zone: Ghostlands: nil
	AddTrainer( 23128, "Master Pyreanor", 1, 17, 49.2, 71.3, 321, 2, "Silvermoon City", 2 ) -- zone: Orgrimmar: Grommash Hold
	AddTrainer(  4217, "Mathrengyl Bearwalker", 1, 7, 40.4, 27.4, 381, 0, "Darnassus", 1 ) -- zone: Darnassus: Cenarion Enclave
--	AddTrainer(  3137, "Matt Johnson", 2, 8, 74.0, 49.7, 34, 0, nil, 1 ) -- zone: Duskwood: nil
	AddTrainer( 49900, "Maxx Avalanche", 1, 3, 56.7, 49.6, 181, 0, "Bilgewater Cartel", 2 ) -- zone: Azshara: Bilgewater Harbor
	AddTrainer( 44919, "Maztha", 1, 17, 49.1, 59.2, 321, 2, "Orgrimmar", 2 ) -- zone: Orgrimmar:
--	AddTrainer(  4159, "Me'lynn", 1, 7, 61.7, 23.0, 381, 0, nil, 1 ) -- zone: Darnassus: nil
--	AddTrainer( 11557, "Meilosh", 1, 11, 65.7, 2.9, 182, 0, nil, 2 ) -- zone: Felwood: nil
	AddTrainer( 16724, "Miall", 1, 23, 60.5, 90.0, 471, 0, "Exodar", 1 ) -- zone: The Exodar: Trader's Tier
	AddTrainer(  3184, "Miao'zan", 1, 9, 55.5, 74.0, 4, 0, "Darkspear Trolls", 2 ) -- zone: Durotar: Sen'jin Village
	AddTrainer( 30721, "Michael Schwan", 3, 2, 53.9, 65.4, 465, 0, "Honor Hold", 1 ) -- zone: Hellfire Peninsula: Honor Hold
	AddTrainer(  2329, "Michelle Belle", 2, 10, 43.4, 65.6, 30, 0, "Stormwind", 1 ) -- zone: Elwynn Forest: Lion's Pride Inn
	AddTrainer( 19184, "Mildred Fletcher", 3, 6, 66.6, 13.3, 481, 0, "Lower City", 3 ) -- zone: Shattrath City: Lower City
	AddTrainer(  2489, "Milstaff Stormeye", 2, 14, 25.4, 7.2, 341, 0, "Ironforge", 1 ) -- zone: Ironforge: Hall of Mysteries
	AddTrainer( 26916, "Mindri Dinkles", 4, 6, 58.3, 62.5, 491, 0, "Valiance Expedition", 1 ) -- zone: Howling Fjord: Valgarde
	AddTrainer( 33617, "Mining", 3, 6, 43.8, 91.0, 481, 0, "The Scryers", 3 ) -- zone: Shattrath City: The Seer's Library
	AddTrainer( 33636, "Miralisse", 3, 6, 41.4, 63.5, 481, 0, "The Scryers", 3 ) -- zone: Shattrath City:
	AddTrainer(  7089, "Mooranta", 1, 25, 44.5, 42.4, 362, nil, "Thunder Bluff", 2 ) -- zone: Thunder Bluff: Thunder Bluff
--	AddTrainer( 17442, "Moordo", 1, 4, 44.8, 23.8, 464, 0, nil, 1 ) -- zone: Azuremyst Isle: nil
	AddTrainer( 18755, "Moorutu", 3, 2, 56.3, 38.5, 465, 0, "Thrallmar", 2 ) -- zone: Hellfire Peninsula: Thrallmar
	AddTrainer( 16752, "Muaat", 1, 23, 59.9, 88.1, 471, 0, "Exodar", 1 ) -- zone: The Exodar: Trader's Tier
--	AddTrainer(  1382, "Mudduk", 2, 27, 31.4, 28.0, 689, 0, nil, 2 ) -- zone: Stranglethorn Vale: nil
--	AddTrainer( 11025, "Mukdrak", 1, 9, 52.2, 40.8, 4, 0, nil, 2 ) -- zone: Durotar: nil
	AddTrainer( 16719, "Mumman", 1, 23, 55.8, 27.0, 471, 0, "Exodar", 1 ) -- zone: The Exodar: Seat of the Naaru
	AddTrainer( 46741, "Muraga", 1, 17, 54.9, 50.5, 321, 2, "Orgrimmar", 2 ) -- zone: Orgrimmar: The Drag
	AddTrainer( 50034, "Musu Gentlemoon", 1, 16, 49.5, 61.3, 11, 0, "Thunder Bluff", 2 ) -- zone: Northern Barrens: The Crossroads
	AddTrainer(  2834, "Myizz Luckycatch", 2, 29, 41.5, 73.3, 673, 0, "Booty Bay", 3 ) -- zone: The Cape of Stranglethorn: Booty Bay
--	AddTrainer(  3605, "Nadyia Maneweaver", 1, 22, 41.8, 49.5, 41, 0, nil, 1 ) -- zone: Teldrassil: nil
	AddTrainer( 16725, "Nahogg", 1, 23, 40.8, 38.9, 471, 0, "Exodar", 1 ) -- zone: The Exodar: The Crystal Hall
--	AddTrainer( 18993, "Naka", 3, 8, 78.5, 63.0, 467, 0, nil, 3 ) -- zone: Zangarmarsh: nil
	AddTrainer( 29509, "Namha Moonwater", 4, 3, 36.4, 29.7, 504, 1, "Kirin Tor", 3 ) -- zone: Dalaran: Legendary Leathers
	AddTrainer( 16654, "Narinth", 2, 24, 58.1, 20.6, 480, nil, "Silvermoon City", 2 ) -- zone: Silvermoon City: Sunfury Spire
--	AddTrainer(  8153, "Narv Hidecrafter", 1, 8, 55.3, 56.3, 101, 0, nil, 2 ) -- zone: Desolace: nil
	AddTrainer( 50155, "Naseev", 4, 3, 38.7, 62.8, 504, 1, "The Silver Covenant", 1 ) -- zone: Dalaran: The Silver Enclave
--	AddTrainer( 30722, "Neferatti", 3, 2, 52.3, 36.1, 465, 0, nil, 2 ) -- zone: Hellfire Peninsula: nil
	AddTrainer( 38242, "Nekali", 1, 9, 65.0, 84.2, 4, 0, "Darkspear Trolls", 2 ) -- zone: Durotar: Darkspear Training Grounds
	AddTrainer( 33680, "Nemiha", 3, 6, 36.2, 47.7, 481, 0, "The Aldor", 3 ) -- zone: Shattrath City:
	AddTrainer( 46716, "Nerog", 1, 17, 55.3, 55.7, 321, 2, "Orgrimmar", 2 ) -- zone: Orgrimmar: The Drag
--	AddTrainer( 24868, "Niobe Whizzlespark", 3, 5, 36.7, 54.8, 473, 0, nil, 1 ) -- zone: Shadowmoon Valley: nil
	AddTrainer(  5150, "Nissa Firestone", 2, 14, 54.9, 58.5, 341, 0, "Ironforge", 1 ) -- zone: Ironforge: The Great Forge
--	AddTrainer( 45559, "Nivi Weavewell", 1, 17, 41.1, 79.7, 321, 2, nil, 2 ) -- zone: Orgrimmar: nil
--	AddTrainer(  8126, "Nixx Sprocketspring", 1, 21, 52.5, 27.3, 161, 0, nil, 3 ) -- zone: Tanaris: nil
--	AddTrainer( 29233, "Nurse Applewood", 4, 1, 41.7, 54.5, 486, 0, nil, 2 ) -- zone: Borean Tundra: nil
--	AddTrainer(  5759, "Nurse Neela", 2, 31, 61.8, 52.8, 20, 0, nil, 2 ) -- zone: Tirisfal Glades: nil
	AddTrainer( 16731, "Nus", 1, 23, 39.3, 22.3, 471, 0, "Exodar", 1 ) -- zone: The Exodar: The Crystal Hall
	AddTrainer( 16726, "Ockil", 1, 23, 53.9, 92.5, 471, 0, "Exodar", 1 ) -- zone: The Exodar: Trader's Tier
--	AddTrainer(  7406, "Oglethorpe Obnoticus", 2, 27, 28.3, 76.3, 689, 0, nil, 3 ) -- zone: Stranglethorn Vale: nil
	AddTrainer( 11177, "Okothos Ironrager", 1, 17, 75.4, 34.0, 321, 2, "Orgrimmar", 2 ) -- zone: Orgrimmar: Valley of Honor
--	AddTrainer( 25580, "Old Man Barlo", 3, 7, 38.8, 12.8, 478, 0, nil, 1 ) -- zone: Terokkar Forest: Silmyr Lake
	AddTrainer( 26993, "Old Man Robert", 4, 1, 57.9, 71.6, 486, 0, "Valiance Expedition", 1 ) -- zone: Borean Tundra: Valiance Keep
	AddTrainer( 44975, "Old Umbehto", 1, 17, 35.3, 67.5, 321, 2, "Orgrimmar", 2 ) -- zone: Orgrimmar: Valley of Spirits
	AddTrainer( 28706, "Olisarra the Kind", 4, 3, 36.7, 37.5, 504, 1, "Kirin Tor", 3 ) -- zone: Dalaran: First to Your Aid
	AddTrainer( 33590, "Oluros", 4, 8, 71.4, 20.8, 492, 0, "Argent Crusade", 3 ) -- zone: Icecrown: Argent Tournament Grounds
	AddTrainer( 33675, "Onodo", 3, 6, 37.7, 31.1, 481, 0, "The Aldor", 3 ) -- zone: Shattrath City:
	AddTrainer( 44781, "Opuno Ironhorn", 1, 17, 40.5, 49.9, 321, 2, "Thunder Bluff", 2 ) -- zone: Orgrimmar: Valley of Wisdom
	AddTrainer( 29506, "Orland Schaeffer", 4, 3, 44.7, 28.9, 504, 1, "Kirin Tor", 3 ) -- zone: Dalaran: Tanks for Everything
	AddTrainer(  5166, "Ormyr Flinteye", 2, 14, 52.4, 15.0, 341, 0, "Ironforge", 1 ) -- zone: Ironforge: The Forlorn Cavern
--	AddTrainer( 26972, "Orn Tenderhoof", 4, 1, 42.0, 54.2, 486, 0, nil, 2 ) -- zone: Borean Tundra: nil
	AddTrainer(   918, "Osborne the Night Man", 2, 26, 77.4, 65.3, 301, nil, "Stormwind", 1 ) -- zone: Stormwind City: Old Town
	AddTrainer( 26915, "Ounhulo", 4, 6, 59.9, 63.8, 491, 0, "Valiance Expedition", 1 ) -- zone: Howling Fjord: Valgarde
	AddTrainer(  2798, "Pand Stonebinder", 1, 25, 29.4, 21.2, 362, 0, "Thunder Bluff", 2 ) -- zone: Thunder Bluff: Spirit Rise
	AddTrainer( 50158, "Pathstalker Ralsir", 4, 3, 38.7, 64.9, 504, 1, "The Silver Covenant", 1 ) -- zone: Dalaran: The Silver Enclave
	AddTrainer(  1700, "Paxton Ganter", 2, 7, 42.5, 38.6, 27, 0, "Ironforge", 1 ) -- zone: Dun Morogh: Iceflow Lake
	AddTrainer(  5882, "Pephredo", 1, 17, 38.5, 85.7, 321, 2, "Orgrimmar", 2 ) -- zone: Orgrimmar: Valley of Spirits
	AddTrainer( 16280, "Perascamin", 2, 11, 61.2, 54.0, 462, 0, "Silvermoon City", 2 ) -- zone: Eversong Woods: Thuron's Livery
	AddTrainer( 43431, "Periale", 1, 6, 51.4, 19.1, 42, 0, "Darnassus", 1 ) -- zone: Darkshore: Lor'danel
--	AddTrainer(  7866, "Peter Galen", 1, 3, 37.5, 65.5, 181, 0, nil, 1 ) -- zone: Azshara: nil
	AddTrainer(  4567, "Pierce Shackleton", 2, 35, 85.2, 13.9, 382, nil, "Undercity", 2 ) -- zone: Undercity: Magic Quarter
--	AddTrainer(  8128, "Pikkle", 1, 21, 51.1, 28.1, 161, 0, nil, 3 ) -- zone: Tanaris: nil
	AddTrainer( 30709, "Poshken Hardbinder", 1, 25, 28.8, 20.6, 362, nil, "Undercity", 2 ) -- zone: Thunder Bluff: The Pools of Vision
	AddTrainer( 28702, "Professor Pallin", 4, 3, 41.7, 36.5, 504, 1, "Kirin Tor", 3 ) -- zone: Dalaran: The Scribes' Sacellum
--	AddTrainer( 18804, "Prospector Nachlan", 1, 5, 56.3, 54.3, 476, 0, nil, 1 ) -- zone: Bloodmyst Isle: nil
--	AddTrainer(  3067, "Pyall Silentstride", 1, 15, 45.5, 58.1, 9, 0, nil, 2 ) -- zone: Mulgore: nil
--	AddTrainer( 16277, "Quarelestra", 2, 11, 48.6, 47.1, 462, 0, nil, 2 ) -- zone: Eversong Woods: nil
	AddTrainer( 16652, "Quithas", 2, 24, 58.2, 18.0, 480, nil, "Silvermoon City", 2 ) -- zone: Silvermoon City: Sunfury Spire
--	AddTrainer( 26969, "Raenah", 4, 1, 41.6, 53.5, 486, 0, nil, 2 ) -- zone: Borean Tundra: nil
	AddTrainer( 50157, "Ranger Selone", 4, 3, 39.2, 63.4, 504, 1, "The Silver Covenant", 1 ) -- zone: Dalaran: The Silver Enclave
	AddTrainer(  5943, "Rawrk", 1, 9, 54.1, 42.0, 4, 0, "Orgrimmar", 2 ) -- zone: Durotar: Razor Hill Barracks
	AddTrainer( 33679, "Recorder Lidio", 3, 6, 36.3, 43.9, 481, 0, "The Aldor", 3 ) -- zone: Shattrath City:
	AddTrainer( 16729, "Refik", 1, 23, 63.9, 69.0, 471, 0, "Exodar", 1 ) -- zone: The Exodar: Trader's Tier
	AddTrainer( 33591, "Rekka the Hammer", 4, 8, 71.9, 20.9, 492, 0, "Argent Crusade", 3 ) -- zone: Icecrown: Argent Tournament Grounds
	AddTrainer( 44782, "Rento", 1, 17, 39.5, 49.9, 321, 2, "Thunder Bluff", 2 ) -- zone: Orgrimmar: Valley of Wisdom
	AddTrainer( 48513, "Revi Ramrod", 1, 17, 36.7, 87.2, 321, 2, "Bilgewater Cartel", 2 ) -- zone: Orgrimmar: Goblin Slums
	AddTrainer(  5137, "Reyna Stonebranch", 2, 14, 55.6, 58.8, 341, 0, "Ironforge", 1 ) -- zone: Ironforge: The Great Forge
--	AddTrainer( 34712, "Roberta Carter", 2, 35, 64.0, 9.6, 382, 0, nil, 2 ) -- zone: Undercity: Ruins of Lordaeron
	AddTrainer( 26963, "Roberta Jacks", 4, 6, 78.3, 28.2, 491, 0, "The Hand of Vengeance", 2 ) -- zone: Howling Fjord: Vengeance Landing
	AddTrainer( 37072, "Rogg", 1, 17, 44.3, 77.6, 321, 2, "Orgrimmar", 2 ) -- zone: Orgrimmar: Valley of Strength
	AddTrainer(  1386, "Rogvar", 2, 28, 50.1, 56.1, 38, nil, "Orgrimmar", 2 ) -- zone: Swamp of Sorrows: Stonard
--	AddTrainer( 16583, "Rohok", 3, 2, 53.2, 38.2, 465, 0, nil, 2 ) -- zone: Hellfire Peninsula: nil
	AddTrainer( 26989, "Rollick MacKreel", 4, 1, 57.9, 71.5, 486, 0, "Valiance Expedition", 1 ) -- zone: Borean Tundra: Valiance Keep
	AddTrainer( 18776, "Rorelien", 3, 2, 53.7, 65.8, 465, 0, "Honor Hold", 1 ) -- zone: Hellfire Peninsula: Honor Hold
	AddTrainer( 26998, "Rosemary Bovard", 4, 1, 57.6, 71.9, 486, 0, "Valiance Expedition", 1 ) -- zone: Borean Tundra: Valiance Keep
	AddTrainer( 26904, "Rosina Rivet", 4, 6, 59.6, 63.7, 491, 0, "Valiance Expedition", 1 ) -- zone: Howling Fjord: Valgarde
--	AddTrainer( 31247, "Roxi Ramrocket", 4, 10, 40.8, 84.8, 495, 0, nil, 1 ) -- zone: The Storm Peaks: K3
	AddTrainer( 11017, "Roxxik", 1, 17, 57.0, 56.4, 321, 2, "Orgrimmar", 2 ) -- zone: Orgrimmar: The Drag
	AddTrainer( 50160, "Rulen Lightsreap", 4, 3, 39.0, 62.9, 504, 1, "The Silver Covenant", 1 ) -- zone: Dalaran: The Silver Enclave
	AddTrainer( 47253, "Rundok", 1, 17, 46.3, 66.2, 321, 2, "Orgrimmar", 2 ) -- zone: Orgrimmar:
	AddTrainer( 13417, "Sagorne Creststrider", 1, 17, 39.7, 47.2, 321, 2, "Thunder Bluff", 2 ) -- zone: Orgrimmar: Valley of Wisdom
	AddTrainer( 44740, "Sahi Cloudsinger", 1, 17, 44.7, 52.3, 321, 2, "Thunder Bluff", 2 ) -- zone: Orgrimmar: Valley of Wisdom
	AddTrainer( 26956, "Sally Tompkins", 4, 6, 79.4, 29.4, 491, 0, "The Hand of Vengeance", 2 ) -- zone: Howling Fjord: Vengeance Landing
	AddTrainer(  5496, "Sandahl", 2, 26, 39.5, 85.5, 301, 0, "Stormwind", 1 ) -- zone: Stormwind City: The Slaughtered Lamb
--	AddTrainer(  7868, "Sarah Tanner", 2, 22, 63.7, 75.7, 28, 0, nil, 1 ) -- zone: Searing Gorge: nil
	AddTrainer( 44249, "Sarisse Jume", 2, 26, 79.0, 70.6, 301, 0, "Stormwind", 1 ) -- zone: Stormwind City: Command Center
	AddTrainer(  3355, "Saru Steelfury", 1, 17, 76.4, 34.6, 321, 2, "Orgrimmar", 2 ) -- zone: Orgrimmar: Valley of Honor
--	AddTrainer( 16278, "Sathein", 2, 11, 53.5, 51.0, 462, 0, nil, 2 ) -- zone: Eversong Woods: nil
	AddTrainer( 33638, "Scribe Lanloer", 3, 6, 56.2, 74.4, 481, 0, "The Scryers", 2 ) -- zone: Shattrath City:
--	AddTrainer(  7871, "Se'Jib", 2, 27, 36.6, 34.2, 689, 0, nil, 2 ) -- zone: Stranglethorn Vale: nil
	AddTrainer( 16633, "Sedana", 2, 24, 70.0, 24.0, 480, 0, "Silvermoon City", 2 ) -- zone: Silvermoon City: Court of the Sun
--	AddTrainer( 16366, "Sempstress Ambershine", 2, 11, 37.4, 71.9, 462, 0, nil, 2 ) -- zone: Eversong Woods: nil
--	AddTrainer(  2391, "Serge Hinott", 2, 13, 61.6, 19.2, 24, 0, nil, 2 ) -- zone: Hillsbrad Foothills: nil
	AddTrainer(  2327, "Shaina Fuller", 2, 26, 52.1, 45.6, 301, nil, "Stormwind", 1 ) -- zone: Stormwind City: Cathedral of Light
	AddTrainer( 44726, "Shalla Whiteleaf", 1, 17, 44.9, 51.6, 321, 2, "Thunder Bluff", 2 ) -- zone: Orgrimmar: Valley of Wisdom
--	AddTrainer(  7230, "Shayis Steelfury", 1, 17, 80.3, 23.2, 321, 2, nil, 2 ) -- zone: Orgrimmar: nil
	AddTrainer(  3034, "Sheal Runetotem", 1, 25, 76.6, 27.4, 362, 0, "Thunder Bluff", 2 ) -- zone: Thunder Bluff: Elder Rise
	AddTrainer(  5504, "Sheldras Moontree", 2, 26, 27.5, 50.2, 301, nil, "Stormwind", 1 ) -- zone: Stormwind City: Stormwind Harbor
--	AddTrainer(  3549, "Shelene Rhobart", 2, 31, 65.5, 61.0, 20, 0, nil, 2 ) -- zone: Tirisfal Glades: nil
	AddTrainer(  3403, "Sian'tsu", 1, 17, 39.2, 47.8, 321, 2, "Orgrimmar", 2 ) -- zone: Orgrimmar: Valley of Wisdom
	AddTrainer(  4089, "Sildanair", 1, 7, 58.8, 50.7, 381, 0, "Darnassus", 1 ) -- zone: Darnassus:
	AddTrainer(  3030, "Siln Skychaser", 1, 25, 23.1, 20.7, 362, 0, "Thunder Bluff", 2 ) -- zone: Thunder Bluff: Spirit Rise
	AddTrainer(  5564, "Simon Tanner", 2, 26, 71.8, 62.9, 301, nil, "Stormwind", 1 ) -- zone: Stormwind City: Old Town
	AddTrainer( 38516, "Sister Goldskimmer", 5, 3, 42.6, 16.5, 544, 0, "Bilgewater Cartel", 2 ) -- zone: The Lost Isles: Gallywix Docks
	AddTrainer( 33618, "Skinning", 3, 6, 43.5, 90.9, 481, 0, "The Scryers", 3 ) -- zone: Shattrath City: The Seer's Library
--	AddTrainer(  2818, "Slagg", 2, 2, 74.1, 33.8, 16, 0, nil, 2 ) -- zone: Arathi Highlands: nil
--	AddTrainer( 21494, "Smiles O'Byron", 3, 1, 60.3, 65.2, 475, 0, nil, 3 ) -- zone: Blade's Edge Mountains: nil
	AddTrainer(   514, "Smith Argus", 2, 10, 41.7, 65.6, 30, 0, "Stormwind", 1 ) -- zone: Elwynn Forest: Goldshire
	AddTrainer( 26991, "Sock Brightbolt", 4, 1, 57.7, 72.2, 486, 0, "Valiance Expedition", 1 ) -- zone: Borean Tundra: Valiance Keep
	AddTrainer(  3354, "Sorek", 1, 17, 80.1, 32.4, 321, 2, "Orgrimmar", 2 ) -- zone: Orgrimmar: Hall of the Brave
	AddTrainer(  5174, "Springspindle Fizzlegear", 2, 14, 68.7, 44.3, 341, 0, "Ironforge", 1 ) -- zone: Ironforge: Tinker Town
	AddTrainer(  5482, "Stephen Ryback", 2, 26, 77.2, 53.3, 301, nil, "Stormwind", 1 ) -- zone: Stormwind City: Old Town
	AddTrainer( 50156, "Summoner Nolric", 4, 3, 38.8, 63.9, 504, 1, "The Silver Covenant", 1 ) -- zone: Dalaran: The Silver Enclave
	AddTrainer( 44725, "Sunwalker Atohmo", 1, 17, 45.2, 53.6, 321, 2, "Thunder Bluff", 2 ) -- zone: Orgrimmar:
	AddTrainer(  3173, "Swart", 1, 9, 54.4, 42.5, 4, 0, "Orgrimmar", 2 ) -- zone: Durotar: Razor Hill Barracks
	AddTrainer( 16676, "Sylann", 2, 24, 69.5, 71.5, 480, 0, "Silvermoon City", 2 ) -- zone: Silvermoon City:
	AddTrainer(  4163, "Syurna", 1, 7, 41.4, 37.0, 381, 0, "Darnassus", 1 ) -- zone: Darnassus: Cenarion Enclave
	AddTrainer( 33613, "Tailoring", 3, 6, 44.1, 91.1, 481, 0, "The Scryers", 3 ) -- zone: Shattrath City: The Seer's Library
--	AddTrainer(  4213, "Taladan", 1, 7, 58.6, 13.2, 381, 0, nil, 1 ) -- zone: Darnassus: nil
	AddTrainer(  5177, "Tally Berryfizz", 2, 14, 66.8, 55.0, 341, 0, "Gnomeregan", 1 ) -- zone: Ironforge: Tinker Town
	AddTrainer(  5566, "Tannysa", 2, 26, 54.4, 84.2, 301, nil, "Stormwind", 1 ) -- zone: Stormwind City: Mage Quarter
	AddTrainer( 50690, "Tarelvir", 1, 7, 37.7, 80.0, 381, 0, "Darnassus", 1 ) -- zone: Darnassus: nil
	AddTrainer( 18774, "Tatiana", 3, 2, 54.7, 63.6, 465, 0, "Honor Hold", 1 ) -- zone: Hellfire Peninsula: Honor Hold
	AddTrainer( 33677, "Technician Mihila", 3, 6, 37.8, 31.8, 481, 0, "The Aldor", 3 ) -- zone: Shattrath City:
	AddTrainer(  3011, "Teg Dawnstrider", 1, 25, 45.4, 39.0, 362, nil, "Thunder Bluff", 2 ) -- zone: Thunder Bluff: Thunder Bluff
--	AddTrainer(  4212, "Telonis", 1, 7, 64.5, 21.3, 381, 0, nil, 1 ) -- zone: Darnassus: nil
	AddTrainer(  1458, "Telurinon Moonshadow", 2, 39, 11.3, 52.1, 40, 0, "Ironforge", 1 ) -- zone: Wetlands: Menethil Harbor
	AddTrainer(  3004, "Tepa", 1, 25, 44.3, 45.0, 362, 0, "Thunder Bluff", 2 ) -- zone: Thunder Bluff: Thunder Bluff
	AddTrainer(  2326, "Thamner Pol", 2, 7, 54.3, 50.9, 27, 0, "Ironforge", 1 ) -- zone: Dun Morogh: Thunderbrew Distillery
	AddTrainer( 32712, "The Amazing Zanzo", 4, 3, 47.2, 36.9, 504, 1, "Kirin Tor", 1 ) -- zone: Dalaran: Dalaran
	AddTrainer( 44582, "Theresa Denman", 2, 26, 63.4, 61.7, 301, nil, "Stormwind", 1 ) -- zone: Stormwind City: Trade District
	AddTrainer(  5511, "Therum Deepforge", 2, 26, 63.4, 37.1, 301, nil, "Stormwind", 1 ) -- zone: Stormwind City: Dwarven District
	AddTrainer(  5171, "Thistleheart", 2, 14, 50.9, 6.8, 341, 0, "Ironforge", 1 ) -- zone: Ironforge: The Forlorn Cavern
	AddTrainer( 26953, "Thomas Kolichio", 4, 6, 78.6, 29.5, 491, 0, "The Hand of Vengeance", 2 ) -- zone: Howling Fjord: Vengeance Landing
	AddTrainer(  5517, "Thorfin Stoneshield", 2, 26, 67.7, 36.5, 301, 0, "Stormwind", 1 ) -- zone: Stormwind City: Dwarven District
--	AddTrainer(  7867, "Thorkaf Dragoneye", 2, 3, 62.6, 57.6, 17, 0, nil, 2 ) -- zone: Badlands: nil
	AddTrainer( 30716, "Thoth", 1, 23, 39.7, 38.9, 471, 0, "Exodar", 1 ) -- zone: The Exodar: The Crystal Hall
	AddTrainer(   912, "Thran Khorman", 2, 7, 35.9, 65.7, 27, 0, "Ironforge", 1 ) -- zone: Dun Morogh:
	AddTrainer(  3049, "Thurston Xane", 1, 25, 25.2, 21.0, 362, nil, "Undercity", 2 ) -- zone: Thunder Bluff: The Pools of Vision
	AddTrainer(  5958, "Thuul", 1, 17, 38.6, 85.7, 321, 2, "Orgrimmar", 2 ) -- zone: Orgrimmar: Valley of Spirits
	AddTrainer(  7088, "Thuwd", 1, 17, 60.9, 54.6, 321, 2, "Orgrimmar", 2 ) -- zone: Orgrimmar: The Drag
	AddTrainer(  3031, "Tigor Skychaser", 1, 25, 23.0, 18.8, 362, 0, "Thunder Bluff", 2 ) -- zone: Thunder Bluff: Spirit Rise
	AddTrainer( 28697, "Timofey Oshenko", 4, 3, 38.9, 25.9, 504, 1, "Kirin Tor", 3 ) -- zone: Dalaran: Like Clockwork
	AddTrainer( 28701, "Timothy Jones", 4, 3, 40.6, 35.3, 504, 1, "Kirin Tor", 3 ) -- zone: Dalaran: Cartier & Co. Fine Jewelry
--	AddTrainer( 11052, "Timothy Worthington", 1, 10, 66.2, 51.7, 141, 0, nil, 1 ) -- zone: Dustwallow Marsh: nil
	AddTrainer( 26995, "Tink Brightbolt", 4, 1, 57.6, 71.7, 486, 0, "Valiance Expedition", 1 ) -- zone: Borean Tundra: Valiance Keep
--	AddTrainer(  7944, "Tinkmaster Overspark", 2, 14, 69.8, 50.0, 341, 0, nil, 1 ) -- zone: Ironforge: nil
	AddTrainer( 26907, "Tisha Longbridge", 4, 6, 59.7, 64.0, 491, 0, "Valiance Expedition", 1 ) -- zone: Howling Fjord: Valgarde
	AddTrainer(  1241, "Tognus Flintfire", 2, 7, 52.4, 50.3, 27, 0, "Ironforge", 1 ) -- zone: Dun Morogh: Kharanos
	AddTrainer(  5143, "Toldren Deepiron", 2, 14, 25.2, 10.2, 341, 0, "Ironforge", 1 ) -- zone: Ironforge: Hall of Mysteries
	AddTrainer(  1430, "Tomas", 2, 10, 44.3, 66.0, 30, 0, "Stormwind", 1 ) -- zone: Elwynn Forest: Lion's Pride Inn
	AddTrainer( 27000, "Trapper Jack", 4, 1, 57.6, 71.8, 486, 0, "Valiance Expedition", 1 ) -- zone: Borean Tundra: Valiance Keep
	AddTrainer(  3033, "Turak Runetotem", 1, 25, 76.2, 27.8, 362, 0, "Thunder Bluff", 2 ) -- zone: Thunder Bluff: Elder Rise
	AddTrainer( 45337, "Tyelis", 1, 17, 49.2, 71.0, 321, 2, "Silvermoon City", 2 ) -- zone: Orgrimmar: Grommash Hold
	AddTrainer(  5516, "Ulfir Ironbeard", 2, 26, 67.7, 36.3, 301, 0, "Stormwind", 1 ) -- zone: Stormwind City: Dwarven District
	AddTrainer(  4772, "Ultham Ironhorn", 2, 7, 71.1, 48.5, 27, 0, "Ironforge", 1 ) -- zone: Dun Morogh: Amberstill Ranch
	AddTrainer(  3007, "Una", 1, 25, 41.8, 42.7, 362, 0, "Thunder Bluff", 2 ) -- zone: Thunder Bluff: Thunder Bluff
	AddTrainer( 47246, "Ureda", 1, 17, 52.0, 72.4, 321, 2, "Orgrimmar", 2 ) -- zone: Orgrimmar:
	AddTrainer(  5495, "Ursula Deline", 2, 26, 40.0, 84.3, 301, 0, "Stormwind", 1 ) -- zone: Stormwind City: The Slaughtered Lamb
	AddTrainer(  3048, "Ursyn Ghull", 1, 25, 27.2, 16.5, 362, nil, "Undercity", 2 ) -- zone: Thunder Bluff: The Pools of Vision
	AddTrainer(  7311, "Uthel'nay", 1, 17, 35.7, 68.8, 321, 2, "Darkspear Trolls", 2 ) -- zone: Orgrimmar: Valley of Spirits
--	AddTrainer(  5695, "Vance Undergloom", 2, 31, 61.7, 51.6, 20, 0, nil, 2 ) -- zone: Tirisfal Glades: nil
--	AddTrainer(  5939, "Vira Younghoof", 1, 15, 46.8, 60.8, 9, 0, nil, 2 ) -- zone: Mulgore: nil
--	AddTrainer(  1246, "Vosur Brakthel", 2, 14, 66.5, 55.2, 341, 0, nil, 1 ) -- zone: Ironforge: nil
	AddTrainer( 28956, "Warcaster Fanoraithe", 4, 3, 55.2, 47.8, 504, 1, "Kirin Tor", 1 ) -- zone: Dalaran: nil
	AddTrainer(  1683, "Warg Deepwater", 2, 17, 40.6, 39.5, 35, 0, "Ironforge", 1 ) -- zone: Loch Modan: The Loch
	AddTrainer( 33684, "Weaver Aoa", 3, 6, 37.5, 27.1, 481, 0, "The Aldor", 3 ) -- zone: Shattrath City:
	AddTrainer( 26951, "Wilhelmina Renel", 4, 6, 78.7, 28.5, 491, 0, "The Hand of Vengeance", 2 ) -- zone: Howling Fjord: Vengeance Landing
	AddTrainer( 35093, "Wind Rider Jahubo", 3, 2, 54.2, 41.6, 465, 0, "Orgrimmar", 2 ) -- zone: Hellfire Peninsula: Thrallmar
	AddTrainer( 50127, "Windstalker Ifram", 3, 6, 59.3, 46.6, 481, 0, "The Consortium", 1 ) -- zone: Shattrath City: Terrace of Light
	AddTrainer( 45029, "Witch Doctor Umbu", 1, 17, 34.2, 64.5, 321, 2, "Darkspear Trolls", 2 ) -- zone: Orgrimmar: Valley of Spirits
	AddTrainer(  5479, "Wu Shen", 2, 26, 80.1, 69.9, 301, 0, "Stormwind", 1 ) -- zone: Stormwind City: Command Center
	AddTrainer( 44247, "Wulf Hansreim", 2, 26, 79.1, 71.1, 301, 0, "Stormwind", 1 ) -- zone: Stormwind City: Command Center
	AddTrainer(  7953, "Xar'Ti", 1, 9, 55.3, 75.5, 4, 0, "Darkspear Trolls", 2 ) -- zone: Durotar: Sen'jin Village
	AddTrainer(  7949, "Xylinnia Starshine", 1, 12, 46.7, 42.8, 121, 0, "Darnassus", 1 ) -- zone: Feralas: Feathermoon Stronghold
--	AddTrainer( 19576, "Xyrol", 3, 4, 32.5, 66.7, 479, 0, nil, 3 ) -- zone: Netherstorm: nil
--	AddTrainer(  5392, "Yarr Hammerstone", 2, 7, 50.0, 50.3, 27, 0, nil, 1 ) -- zone: Dun Morogh: nil
	AddTrainer(  3347, "Yelmak", 1, 17, 55.7, 46.0, 321, 2, "Orgrimmar", 2 ) -- zone: Orgrimmar: The Drag
--	AddTrainer( 27703, "Ysuria", 1, 10, 66.0, 49.0, 141, 0, nil, 1 ) -- zone: Dustwallow Marsh: Theramore Isle
	AddTrainer( 16651, "Zaedana", 2, 24, 57.4, 19.2, 480, nil, "Silvermoon City", 2 ) -- zone: Silvermoon City: Sunfury Spire
	AddTrainer(  3399, "Zamja", 1, 17, 32.3, 69.2, 321, 2, "Darkspear Trolls", 2 ) -- zone: Orgrimmar: Valley of Spirits
	AddTrainer( 30710, "Zantasia", 2, 24, 69.5, 24.0, 480, 0, "Silvermoon City", 2 ) -- zone: Silvermoon City: Court of the Sun
--	AddTrainer( 14742, "Zap Farflinger", 1, 28, 61.2, 37.6, 281, 0, nil, 3 ) -- zone: Winterspring: nil
	AddTrainer( 45550, "Zarbo Porkpatty", 1, 17, 39.1, 86.2, 321, 2, "Bilgewater Cartel", 2 ) -- zone: Orgrimmar: Goblin Slums
--	AddTrainer(  6286, "Zarrin", 1, 22, 57.1, 61.3, 41, 0, nil, 1 ) -- zone: Teldrassil: nil
--	AddTrainer( 18752, "Zebig", 3, 2, 54.8, 38.5, 465, 0, nil, 2 ) -- zone: Hellfire Peninsula: nil
	AddTrainer(  3408, "Zel'mak", 1, 17, 80.2, 29.4, 321, 2, "Orgrimmar", 2 ) -- zone: Orgrimmar: Hall of the Brave
	AddTrainer( 45139, "Zirazi the Star-Gazer", 1, 17, 35.7, 68.8, 321, 2, "Darkspear Trolls", 2 ) -- zone: Orgrimmar: Valley of Spirits
	AddTrainer( 20125, "Zula Slagfury", 3, 6, 69.8, 42.2, 481, 0, "Lower City", 3 ) -- zone: Shattrath City: Lower City
	AddTrainer( 33676, "Zurii", 3, 6, 36.5, 44.7, 481, 0, "The Aldor", 3 ) -- zone: Shattrath City:

	self:FixTrainerRef()

end

-------------------------------------------------------------------------------
-- Trainer reference (in learnable spells)
-------------------------------------------------------------------------------

local function AddTrainerRef(type_name, skill_name, spell_id, ...)
	local skills_db = Syllabus.db.global.skills
	local trainers_db = Syllabus.db.global.trainers

	local local_skill_name = type_name == "professions" and GetLocalProfName(skill_name) or skill_name
	local spell
	if type_name == "all_classes"then
		spell = skills_db[type_name][spell_id]
	else
		spell = skills_db[type_name][local_skill_name][spell_id]
	end

	if IsTableEmpty(spell) then
		err("Spell doesn't exists in the database: %s - %s - %s", type_name, skill_name, spell_id)
		return
	end

	for i=1,select('#',...) do
		local trainer_id = select(i,...)

		if type(trainer_id) ~= "number" then
			err("Invalid trainer_id %s for spell %s - %s - %s", trainer_id, type_name, skill_name, spell_id)
		elseif IsTableEmpty(trainers_db[trainer_id]) then
			--err("Trainer %s doesn't exists for spell %s - %s - %s", trainer_id, type_name, skill_name, spell_id)
		else
			spell.trainers[trainer_id] = true

			-- Get the reputation and the faction from the trainer
			if trainers_db[trainer_id].rep then
				spell.valid_rep[trainers_db[trainer_id].rep] = true
			end
			if trainers_db[trainer_id].is_alliance then
				spell.is_alliance = true
			end
			if trainers_db[trainer_id].is_horde then
				spell.is_horde = true
			end
		end
	end
end

function Syllabus:AddTrainerReferences()

	AddTrainerRef( "all_classes", nil, 33388, 4752, 4753, 4772, 7953, 7954, 16280, 20914, 31238, 35100, 35133, 43693, 43769, 44919, 48513 ) -- Apprentice Riding
	AddTrainerRef( "all_classes", nil, 33391, 4752, 4753, 4772, 7953, 7954, 16280, 20914, 31238, 35100, 35133, 43693, 43769, 44919, 48513 ) -- Journeyman Riding
	AddTrainerRef( "all_classes", nil, 34090, 31238, 35100, 35133, 43693, 43769, 44919 ) -- Expert Riding
	AddTrainerRef( "all_classes", nil, 34091, 31238, 35100, 35133, 43693, 43769, 44919 ) -- Artisan Riding
	AddTrainerRef( "all_classes", nil, 54197, 31238, 35100, 35133, 43693, 43769, 44919 ) -- Cold Weather Flying
	AddTrainerRef( "all_classes", nil, 90265, 31238, 35100, 35133, 43693, 43769, 44919 ) -- Master Riding
	AddTrainerRef( "all_classes", nil, 90267, 31238, 35100, 35133, 43693, 43769, 44919 ) -- Flight Master's License
	AddTrainerRef( "classes", "DEATHKNIGHT",  3714, 29194, 29195, 29196 ) -- Path of Frost
	AddTrainerRef( "classes", "DEATHKNIGHT", 42650, 29194, 29195, 29196 ) -- Army of the Dead
	AddTrainerRef( "classes", "DEATHKNIGHT", 43265, 29194, 29195, 29196 ) -- Death and Decay
	AddTrainerRef( "classes", "DEATHKNIGHT", 45524, 29194, 29195, 29196 ) -- Chains of Ice
	AddTrainerRef( "classes", "DEATHKNIGHT", 45529, 29194, 29195, 29196 ) -- Blood Tap
	AddTrainerRef( "classes", "DEATHKNIGHT", 46584, 29194, 29195, 29196 ) -- Raise Dead
	AddTrainerRef( "classes", "DEATHKNIGHT", 47476, 29194, 29195, 29196 ) -- Strangulate
	AddTrainerRef( "classes", "DEATHKNIGHT", 47528, 29194, 29195, 29196 ) -- Mind Freeze
	AddTrainerRef( "classes", "DEATHKNIGHT", 47568, 29194, 29195, 29196 ) -- Empower Rune Weapon
	AddTrainerRef( "classes", "DEATHKNIGHT", 48263, 29194, 29195, 29196 ) -- Blood Presence
	AddTrainerRef( "classes", "DEATHKNIGHT", 48265, 29194, 29195, 29196 ) -- Unholy Presence
	AddTrainerRef( "classes", "DEATHKNIGHT", 48707, 29194, 29195, 29196 ) -- Anti-Magic Shell
	AddTrainerRef( "classes", "DEATHKNIGHT", 48721, 29194, 29195, 29196 ) -- Blood Boil
	AddTrainerRef( "classes", "DEATHKNIGHT", 48743, 29194, 29195, 29196 ) -- Death Pact
	AddTrainerRef( "classes", "DEATHKNIGHT", 48792, 29194, 29195, 29196 ) -- Icebound Fortitude
	AddTrainerRef( "classes", "DEATHKNIGHT", 49020, 29194, 29195, 29196 ) -- Obliterate
	AddTrainerRef( "classes", "DEATHKNIGHT", 49998, 29194, 29195, 29196 ) -- Death Strike
	AddTrainerRef( "classes", "DEATHKNIGHT", 50842, 29194, 29195, 29196 ) -- Pestilence
	AddTrainerRef( "classes", "DEATHKNIGHT", 53323, 29194, 29195, 29196 ) -- Rune of Swordshattering
	AddTrainerRef( "classes", "DEATHKNIGHT", 53331, 29194, 29195, 29196 ) -- Rune of Lichbane
	AddTrainerRef( "classes", "DEATHKNIGHT", 53341, 29194, 29195, 29196 ) -- Rune of Cinderglacier
	AddTrainerRef( "classes", "DEATHKNIGHT", 53342, 29194, 29195, 29196 ) -- Rune of Spellshattering
	AddTrainerRef( "classes", "DEATHKNIGHT", 53343, 29194, 29195, 29196 ) -- Rune of Razorice
	AddTrainerRef( "classes", "DEATHKNIGHT", 53344, 29194, 29195, 29196 ) -- Rune of the Fallen Crusader
	AddTrainerRef( "classes", "DEATHKNIGHT", 54446, 29194, 29195, 29196 ) -- Rune of Swordbreaking
	AddTrainerRef( "classes", "DEATHKNIGHT", 54447, 29194, 29195, 29196 ) -- Rune of Spellbreaking
	AddTrainerRef( "classes", "DEATHKNIGHT", 56222, 29194, 29195, 29196 ) -- Dark Command
	AddTrainerRef( "classes", "DEATHKNIGHT", 56815, 29194, 29195, 29196 ) -- Rune Strike
	AddTrainerRef( "classes", "DEATHKNIGHT", 57330, 29194, 29195, 29196 ) -- Horn of Winter
	AddTrainerRef( "classes", "DEATHKNIGHT", 61999, 29194, 29195, 29196 ) -- Raise Ally
	AddTrainerRef( "classes", "DEATHKNIGHT", 62158, 29194, 29195, 29196 ) -- Rune of the Stoneskin Gargoyle
	AddTrainerRef( "classes", "DEATHKNIGHT", 70164, 29194, 29195, 29196 ) -- Rune of the Nerubian Carapace
	AddTrainerRef( "classes", "DEATHKNIGHT", 73975, 29194, 29195, 29196 ) -- Necrotic Strike
	AddTrainerRef( "classes", "DEATHKNIGHT", 77575, 29194, 29195, 29196 ) -- Outbreak
	AddTrainerRef( "classes", "DEATHKNIGHT", 77606, 29194, 29195, 29196 ) -- Dark Simulacrum
	AddTrainerRef( "classes", "DEATHKNIGHT", 81229, 29194, 29195, 29196 ) -- Runic Empowerment
	AddTrainerRef( "classes", "DEATHKNIGHT", 85948, 29194, 29195, 29196 ) -- Festering Strike
	AddTrainerRef( "classes", "DEATHKNIGHT", 87492, 29194, 29195, 29196 ) -- Mastery
	AddTrainerRef( "classes", "DEATHKNIGHT", 87510, 29194, 29195, 29196 ) -- Plate Specialization
	AddTrainerRef( "classes", "DRUID",    99, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Demoralizing Roar
	AddTrainerRef( "classes", "DRUID",   339, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Entangling Roots
	AddTrainerRef( "classes", "DRUID",   467, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Thorns
	AddTrainerRef( "classes", "DRUID",   740, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Tranquility
	AddTrainerRef( "classes", "DRUID",   768, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Cat Form
	AddTrainerRef( "classes", "DRUID",   770, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Faerie Fire
	AddTrainerRef( "classes", "DRUID",   774, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Rejuvenation
	AddTrainerRef( "classes", "DRUID",   779, 4217, 4218, 4219, 5504, 12042, 44395, 52335 ) -- Swipe
	AddTrainerRef( "classes", "DRUID",   783, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Travel Form
	AddTrainerRef( "classes", "DRUID",  1066, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Aquatic Form
	AddTrainerRef( "classes", "DRUID",  1079, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Rip
	AddTrainerRef( "classes", "DRUID",  1082, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Claw
	AddTrainerRef( "classes", "DRUID",  1126, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Mark of the Wild
	AddTrainerRef( "classes", "DRUID",  1822, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Rake
	AddTrainerRef( "classes", "DRUID",  1850, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Dash
	AddTrainerRef( "classes", "DRUID",  2637, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Hibernate
	AddTrainerRef( "classes", "DRUID",  2782, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Remove Corruption
	AddTrainerRef( "classes", "DRUID",  2908, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Soothe
	AddTrainerRef( "classes", "DRUID",  2912, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Starfire
	AddTrainerRef( "classes", "DRUID",  5185, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Healing Touch
	AddTrainerRef( "classes", "DRUID",  5209, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Challenging Roar
	AddTrainerRef( "classes", "DRUID",  5211, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Bash
	AddTrainerRef( "classes", "DRUID",  5215, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Prowl
	AddTrainerRef( "classes", "DRUID",  5217, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Tiger's Fury
	AddTrainerRef( "classes", "DRUID",  5221, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Shred
	AddTrainerRef( "classes", "DRUID",  5225, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Track Humanoids
	AddTrainerRef( "classes", "DRUID",  5229, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Enrage
	AddTrainerRef( "classes", "DRUID",  5487, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Bear Form
	AddTrainerRef( "classes", "DRUID",  5570, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Insect Swarm
	AddTrainerRef( "classes", "DRUID",  6785, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Ravage
	AddTrainerRef( "classes", "DRUID",  6795, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Growl
	AddTrainerRef( "classes", "DRUID",  6807, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Maul
	AddTrainerRef( "classes", "DRUID",  8921, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Moonfire
	AddTrainerRef( "classes", "DRUID",  8936, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Regrowth
	AddTrainerRef( "classes", "DRUID",  8998, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Cower
	AddTrainerRef( "classes", "DRUID",  9005, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Pounce
	AddTrainerRef( "classes", "DRUID", 16689, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Nature's Grasp
	AddTrainerRef( "classes", "DRUID", 16857, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Faerie Fire (Feral)
	AddTrainerRef( "classes", "DRUID", 16864, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Omen of Clarity
	AddTrainerRef( "classes", "DRUID", 16914, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Hurricane
	AddTrainerRef( "classes", "DRUID", 18960, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Teleport: Moonglade
	AddTrainerRef( "classes", "DRUID", 20484, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Rebirth
	AddTrainerRef( "classes", "DRUID", 20719, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Feline Grace
	AddTrainerRef( "classes", "DRUID", 22568, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Ferocious Bite
	AddTrainerRef( "classes", "DRUID", 22570, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Maim
	AddTrainerRef( "classes", "DRUID", 22812, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Barkskin
	AddTrainerRef( "classes", "DRUID", 22842, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Frenzied Regeneration
	AddTrainerRef( "classes", "DRUID", 29166, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Innervate
	AddTrainerRef( "classes", "DRUID", 33745, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Lacerate
	AddTrainerRef( "classes", "DRUID", 33763, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Lifebloom
	AddTrainerRef( "classes", "DRUID", 33786, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Cyclone
	AddTrainerRef( "classes", "DRUID", 33943, 4217, 4218, 4219, 5504, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Flight Form
	AddTrainerRef( "classes", "DRUID", 40120, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Swift Flight Form
	AddTrainerRef( "classes", "DRUID", 50464, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Nourish
	AddTrainerRef( "classes", "DRUID", 50769, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Revive
	AddTrainerRef( "classes", "DRUID", 52610, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Savage Roar
	AddTrainerRef( "classes", "DRUID", 62078, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Swipe
	AddTrainerRef( "classes", "DRUID", 62600, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Savage Defense
	AddTrainerRef( "classes", "DRUID", 77758, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Thrash
	AddTrainerRef( "classes", "DRUID", 77761, 4217, 4218, 4219, 5504, 12042, 44395, 52335 ) -- Stampeding Roar
	AddTrainerRef( "classes", "DRUID", 77764, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Stampeding Roar
	AddTrainerRef( "classes", "DRUID", 80964, 4217, 4218, 4219, 5504, 12042, 44395, 52335 ) -- Skull Bash
	AddTrainerRef( "classes", "DRUID", 80965, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Skull Bash
	AddTrainerRef( "classes", "DRUID", 87491, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Mastery
	AddTrainerRef( "classes", "DRUID", 87505, 3033, 3034, 3036, 4217, 4218, 4219, 5504, 8142, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Leather Specialization
	AddTrainerRef( "classes", "DRUID", 88747, 4217, 4218, 4219, 5504, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Wild Mushroom
	AddTrainerRef( "classes", "DRUID", 88751, 4217, 4218, 4219, 5504, 12042, 44395, 44726, 50034, 50152, 52335 ) -- Wild Mushroom: Detonate
	AddTrainerRef( "classes", "HUNTER",   136, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Mend Pet
	AddTrainerRef( "classes", "HUNTER",   674, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Dual Wield
	AddTrainerRef( "classes", "HUNTER",   781, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Disengage
	AddTrainerRef( "classes", "HUNTER",  1130, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Hunter's Mark
	AddTrainerRef( "classes", "HUNTER",  1462, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Beast Lore
	AddTrainerRef( "classes", "HUNTER",  1494, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Track Beasts
	AddTrainerRef( "classes", "HUNTER",  1499, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Freezing Trap
	AddTrainerRef( "classes", "HUNTER",  1513, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Scare Beast
	AddTrainerRef( "classes", "HUNTER",  1515, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Tame Beast
	AddTrainerRef( "classes", "HUNTER",  1543, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Flare
	AddTrainerRef( "classes", "HUNTER",  1978, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Serpent Sting
	AddTrainerRef( "classes", "HUNTER",  2641, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Dismiss Pet
	AddTrainerRef( "classes", "HUNTER",  2643, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Multi-Shot
	AddTrainerRef( "classes", "HUNTER",  2973, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Raptor Strike
	AddTrainerRef( "classes", "HUNTER",  2974, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Wing Clip
	AddTrainerRef( "classes", "HUNTER",  3045, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Rapid Fire
	AddTrainerRef( "classes", "HUNTER",  5116, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Concussive Shot
	AddTrainerRef( "classes", "HUNTER",  5118, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Aspect of the Cheetah
	AddTrainerRef( "classes", "HUNTER",  5384, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Feign Death
	AddTrainerRef( "classes", "HUNTER",  6197, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Eagle Eye
	AddTrainerRef( "classes", "HUNTER",  6991, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Feed Pet
	AddTrainerRef( "classes", "HUNTER",  8737, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Mail
	AddTrainerRef( "classes", "HUNTER", 13159, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Aspect of the Pack
	AddTrainerRef( "classes", "HUNTER", 13165, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Aspect of the Hawk
	AddTrainerRef( "classes", "HUNTER", 13795, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Immolation Trap
	AddTrainerRef( "classes", "HUNTER", 13809, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Ice Trap
	AddTrainerRef( "classes", "HUNTER", 13813, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Explosive Trap
	AddTrainerRef( "classes", "HUNTER", 19263, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Deterrence
	AddTrainerRef( "classes", "HUNTER", 19503, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Scatter Shot
	AddTrainerRef( "classes", "HUNTER", 19801, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Tranquilizing Shot
	AddTrainerRef( "classes", "HUNTER", 19878, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Track Demons
	AddTrainerRef( "classes", "HUNTER", 19879, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Track Dragonkin
	AddTrainerRef( "classes", "HUNTER", 19880, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Track Elementals
	AddTrainerRef( "classes", "HUNTER", 19882, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Track Giants
	AddTrainerRef( "classes", "HUNTER", 19883, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Track Humanoids
	AddTrainerRef( "classes", "HUNTER", 19884, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Track Undead
	AddTrainerRef( "classes", "HUNTER", 19885, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Track Hidden
	AddTrainerRef( "classes", "HUNTER", 20043, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Aspect of the Wild
	AddTrainerRef( "classes", "HUNTER", 20736, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Distracting Shot
	AddTrainerRef( "classes", "HUNTER", 34026, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Kill Command
	AddTrainerRef( "classes", "HUNTER", 34477, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Misdirection
	AddTrainerRef( "classes", "HUNTER", 34600, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Snake Trap
	AddTrainerRef( "classes", "HUNTER", 51753, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Camouflage
	AddTrainerRef( "classes", "HUNTER", 53271, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Master's Call
	AddTrainerRef( "classes", "HUNTER", 53351, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Kill Shot
	AddTrainerRef( "classes", "HUNTER", 56641, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Steady Shot
	AddTrainerRef( "classes", "HUNTER", 77767, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Cobra Shot
	AddTrainerRef( "classes", "HUNTER", 77769, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Trap Launcher
	AddTrainerRef( "classes", "HUNTER", 79682, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Control Pet
	AddTrainerRef( "classes", "HUNTER", 82243, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Parry
	AddTrainerRef( "classes", "HUNTER", 82654, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Widow Venom
	AddTrainerRef( "classes", "HUNTER", 82661, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Aspect of the Fox
	AddTrainerRef( "classes", "HUNTER", 83242, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Call Pet 2
	AddTrainerRef( "classes", "HUNTER", 83243, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Call Pet 3
	AddTrainerRef( "classes", "HUNTER", 83244, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Call Pet 4
	AddTrainerRef( "classes", "HUNTER", 83245, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Call Pet 5
	AddTrainerRef( "classes", "HUNTER", 87493, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Mastery
	AddTrainerRef( "classes", "HUNTER", 87506, 5515, 5516, 5517, 17505, 43277, 44247, 44249, 50157 ) -- Mail Specialization
	AddTrainerRef( "classes", "MAGE",    10, 331, 1228, 3047, 3048, 3049, 4566, 4567, 4568, 5144, 5145, 5497, 5498, 5882, 5885, 7311, 7312, 16651, 16652, 16653, 16749, 17513, 17514, 23103, 45714, 47246, 47247, 47248 ) -- Blizzard
	AddTrainerRef( "classes", "MAGE",    66, 331, 1228, 3047, 3048, 3049, 4566, 4567, 4568, 5144, 5145, 5497, 5498, 5882, 5885, 7311, 7312, 16651, 16652, 16653, 16749, 17513, 17514, 23103, 45714, 47246, 47247, 47248 ) -- Invisibility
	AddTrainerRef( "classes", "MAGE",   116, 331, 1228, 3047, 3048, 3049, 4566, 4567, 4568, 5144, 5145, 5497, 5498, 5882, 5885, 7311, 7312, 16651, 16652, 16653, 16749, 17513, 17514, 23103, 45714, 47246, 47247, 47248 ) -- Frostbolt
	AddTrainerRef( "classes", "MAGE",   118, 331, 1228, 3047, 3048, 3049, 4566, 4567, 4568, 5144, 5145, 5497, 5498, 5882, 5885, 7311, 7312, 16651, 16652, 16653, 16749, 17513, 17514, 23103, 45714, 47246, 47247, 47248 ) -- Polymorph
	AddTrainerRef( "classes", "MAGE",   120, 331, 1228, 3047, 3048, 3049, 4566, 4567, 4568, 5144, 5145, 5497, 5498, 5882, 5885, 7311, 7312, 16651, 16652, 16653, 16749, 17513, 17514, 23103, 45714, 47246, 47247, 47248 ) -- Cone of Cold
	AddTrainerRef( "classes", "MAGE",   122, 331, 1228, 3047, 3048, 3049, 4566, 4567, 4568, 5144, 5145, 5497, 5498, 5882, 5885, 7311, 7312, 16651, 16652, 16653, 16749, 17513, 17514, 23103, 45714, 47246, 47247, 47248 ) -- Frost Nova
	AddTrainerRef( "classes", "MAGE",   130, 331, 1228, 3047, 3048, 3049, 4566, 4567, 4568, 5144, 5145, 5497, 5498, 5882, 5885, 7311, 7312, 16651, 16652, 16653, 16749, 17513, 17514, 23103, 45714, 47246, 47247, 47248 ) -- Slow Fall
	AddTrainerRef( "classes", "MAGE",   475, 331, 1228, 3047, 3048, 3049, 4566, 4567, 4568, 5144, 5145, 5497, 5498, 5882, 5885, 7311, 7312, 16651, 16652, 16653, 16749, 17513, 17514, 23103, 45714, 47246, 47247, 47248 ) -- Remove Curse
	AddTrainerRef( "classes", "MAGE",   543, 331, 1228, 3047, 3048, 3049, 4566, 4567, 4568, 5144, 5145, 5497, 5498, 5882, 5885, 7311, 7312, 16651, 16652, 16653, 16749, 17513, 17514, 23103, 45714, 47246, 47247, 47248 ) -- Mage Ward
	AddTrainerRef( "classes", "MAGE",   759, 331, 1228, 3047, 3048, 3049, 4566, 4567, 4568, 5144, 5145, 5497, 5498, 5882, 5885, 7311, 7312, 16651, 16652, 16653, 16749, 17513, 17514, 23103, 45714, 47246, 47247, 47248 ) -- Conjure Mana Gem
	AddTrainerRef( "classes", "MAGE",  1449, 331, 1228, 3047, 3048, 3049, 4566, 4567, 4568, 5144, 5145, 5497, 5498, 5882, 5885, 7311, 7312, 16651, 16652, 16653, 16749, 17513, 17514, 23103, 45714, 47246, 47247, 47248 ) -- Arcane Explosion
	AddTrainerRef( "classes", "MAGE",  1459, 331, 1228, 3047, 3048, 3049, 4566, 4567, 4568, 5144, 5145, 5497, 5498, 5882, 5885, 7311, 7312, 16651, 16652, 16653, 16749, 17513, 17514, 23103, 45714, 47246, 47247, 47248 ) -- Arcane Brilliance
	AddTrainerRef( "classes", "MAGE",  1463, 331, 1228, 3047, 3048, 3049, 4566, 4567, 4568, 5144, 5145, 5497, 5498, 5882, 5885, 7311, 7312, 16651, 16652, 16653, 16749, 17513, 17514, 23103, 45714, 47246, 47247, 47248 ) -- Mana Shield
	AddTrainerRef( "classes", "MAGE",  1953, 331, 1228, 3047, 3048, 3049, 4566, 4567, 4568, 5144, 5145, 5497, 5498, 5882, 5885, 7311, 7312, 16651, 16652, 16653, 16749, 17513, 17514, 23103, 45714, 47246, 47247, 47248 ) -- Blink
	AddTrainerRef( "classes", "MAGE",  2120, 331, 1228, 3047, 3048, 3049, 4566, 4567, 4568, 5144, 5145, 5497, 5498, 5882, 5885, 7311, 7312, 16651, 16652, 16653, 16749, 17513, 17514, 23103, 45714, 47246, 47247, 47248 ) -- Flamestrike
	AddTrainerRef( "classes", "MAGE",  2136, 331, 1228, 3047, 3048, 3049, 4566, 4567, 4568, 5144, 5145, 5497, 5498, 5882, 5885, 7311, 7312, 16651, 16652, 16653, 16749, 17513, 17514, 23103, 42331, 45714, 47246, 47247, 47248 ) -- Fire Blast
	AddTrainerRef( "classes", "MAGE",  2139, 331, 1228, 3047, 3048, 3049, 4566, 4567, 4568, 5144, 5145, 5497, 5498, 5882, 5885, 7311, 7312, 16651, 16652, 16653, 16749, 17513, 17514, 23103, 45714, 47246, 47247, 47248 ) -- Counterspell
	AddTrainerRef( "classes", "MAGE",  2948, 331, 1228, 3047, 3048, 3049, 4566, 4567, 4568, 5144, 5145, 5497, 5498, 5882, 5885, 7311, 7312, 16651, 16652, 16653, 16749, 17513, 17514, 23103, 45714, 47246, 47247, 47248 ) -- Scorch
	AddTrainerRef( "classes", "MAGE",  3561, 2485, 2489, 4165, 16755, 29156 ) -- Teleport: Stormwind
	AddTrainerRef( "classes", "MAGE",  3562, 2485, 2489, 4165, 16755, 29156 ) -- Teleport: Ironforge
	AddTrainerRef( "classes", "MAGE",  3563, 2492, 5957, 5958, 16654, 45139, 47253 ) -- Teleport: Undercity
	AddTrainerRef( "classes", "MAGE",  3565, 2485, 2489, 4165, 16755, 29156 ) -- Teleport: Darnassus
	AddTrainerRef( "classes", "MAGE",  3566, 2492, 5957, 5958, 16654, 45139, 47253 ) -- Teleport: Thunder Bluff
	AddTrainerRef( "classes", "MAGE",  3567, 2492, 5957, 5958, 16654, 45139, 47253 ) -- Teleport: Orgrimmar
	AddTrainerRef( "classes", "MAGE",  5143, 331, 1228, 3047, 3048, 3049, 4566, 4567, 4568, 5144, 5145, 5497, 5498, 5882, 5885, 7311, 7312, 16651, 16652, 16653, 16749, 17513, 17514, 23103, 42331, 45714, 47246, 47247, 47248 ) -- Arcane Missiles
	AddTrainerRef( "classes", "MAGE",  6117, 331, 1228, 3047, 3048, 3049, 4566, 4567, 4568, 5144, 5145, 5497, 5498, 5882, 5885, 7311, 7312, 16651, 16652, 16653, 16749, 17513, 17514, 23103, 45714, 47246, 47247, 47248 ) -- Mage Armor
	AddTrainerRef( "classes", "MAGE",  7302, 331, 1228, 3047, 3048, 3049, 4566, 4567, 4568, 5144, 5145, 5497, 5498, 5882, 5885, 7311, 7312, 16651, 16652, 16653, 16749, 17513, 17514, 23103, 45714, 47246, 47247, 47248 ) -- Frost Armor
	AddTrainerRef( "classes", "MAGE", 10059, 2485, 2489, 4165, 16755, 29156 ) -- Portal: Stormwind
	AddTrainerRef( "classes", "MAGE", 11416, 2485, 2489, 4165, 16755, 29156 ) -- Portal: Ironforge
	AddTrainerRef( "classes", "MAGE", 11417, 2492, 5957, 5958, 16654, 45139, 47253 ) -- Portal: Orgrimmar
	AddTrainerRef( "classes", "MAGE", 11418, 2492, 5957, 5958, 16654, 45139, 47253 ) -- Portal: Undercity
	AddTrainerRef( "classes", "MAGE", 11419, 2485, 2489, 4165, 16755, 29156 ) -- Portal: Darnassus
	AddTrainerRef( "classes", "MAGE", 11420, 2492, 5957, 5958, 16654, 45139, 47253 ) -- Portal: Thunder Bluff
	AddTrainerRef( "classes", "MAGE", 12051, 331, 1228, 3047, 3048, 3049, 4566, 4567, 4568, 5144, 5145, 5497, 5498, 5882, 5885, 7311, 7312, 16651, 16652, 16653, 16749, 17513, 17514, 23103, 45714, 47246, 47247, 47248 ) -- Evocation
	AddTrainerRef( "classes", "MAGE", 30449, 331, 1228, 3047, 3048, 3049, 4566, 4567, 4568, 5144, 5145, 5497, 5498, 5882, 5885, 7311, 7312, 16651, 16652, 16653, 16749, 17513, 17514, 23103, 45714, 47246, 47247, 47248 ) -- Spellsteal
	AddTrainerRef( "classes", "MAGE", 30451, 331, 1228, 3047, 3048, 3049, 4566, 4567, 4568, 5144, 5145, 5497, 5498, 5882, 5885, 7311, 7312, 16651, 16652, 16653, 16749, 17513, 17514, 23103, 45714, 47246, 47247, 47248 ) -- Arcane Blast
	AddTrainerRef( "classes", "MAGE", 30455, 331, 1228, 3047, 3048, 3049, 4566, 4567, 4568, 5144, 5145, 5497, 5498, 5882, 5885, 7311, 7312, 16651, 16652, 16653, 16749, 17513, 17514, 23103, 45714, 47246, 47247, 47248 ) -- Ice Lance
	AddTrainerRef( "classes", "MAGE", 30482, 331, 1228, 3047, 3048, 3049, 4566, 4567, 4568, 5144, 5145, 5497, 5498, 5882, 5885, 7311, 7312, 16651, 16652, 16653, 16749, 17513, 17514, 23103, 45714, 47246, 47247, 47248 ) -- Molten Armor
	AddTrainerRef( "classes", "MAGE", 32266, 2485, 2489, 4165, 16755, 29156 ) -- Portal: Exodar
	AddTrainerRef( "classes", "MAGE", 32267, 2492, 5957, 5958, 16654, 45139, 47253 ) -- Portal: Silvermoon
	AddTrainerRef( "classes", "MAGE", 32271, 2485, 2489, 4165, 16755, 29156 ) -- Teleport: Exodar
	AddTrainerRef( "classes", "MAGE", 32272, 2492, 5957, 5958, 16654, 45139, 47253 ) -- Teleport: Silvermoon
	AddTrainerRef( "classes", "MAGE", 33690, 2485, 2489, 4165, 16755, 29156 ) -- Teleport: Shattrath
	AddTrainerRef( "classes", "MAGE", 33691, 2485, 2489, 4165, 16755, 29156 ) -- Portal: Shattrath
	AddTrainerRef( "classes", "MAGE", 35715, 2492, 5957, 5958, 16654, 45139, 47253 ) -- Teleport: Shattrath
	AddTrainerRef( "classes", "MAGE", 35717, 2492, 5957, 5958, 16654, 45139, 47253 ) -- Portal: Shattrath
	AddTrainerRef( "classes", "MAGE", 42955, 331, 1228, 3047, 3048, 3049, 4566, 4567, 4568, 5144, 5145, 5497, 5498, 5882, 5885, 7311, 7312, 16651, 16652, 16653, 16749, 17513, 17514, 23103, 45714, 47246, 47247, 47248 ) -- Conjure Refreshment
	AddTrainerRef( "classes", "MAGE", 43987, 331, 1228, 3047, 3048, 3049, 4566, 4567, 4568, 5144, 5145, 5497, 5498, 5882, 5885, 7311, 7312, 16651, 16652, 16653, 16749, 17513, 17514, 23103, 45714, 47246, 47247, 47248 ) -- Ritual of Refreshment
	AddTrainerRef( "classes", "MAGE", 44614, 331, 1228, 3047, 3048, 3049, 4566, 4567, 4568, 5144, 5145, 5497, 5498, 5882, 5885, 7311, 7312, 16651, 16652, 16653, 16749, 17513, 17514, 23103, 45714, 47246, 47247, 47248 ) -- Frostfire Bolt
	AddTrainerRef( "classes", "MAGE", 45438, 331, 1228, 3047, 3048, 3049, 4566, 4567, 4568, 5144, 5145, 5497, 5498, 5882, 5885, 7311, 7312, 16651, 16652, 16653, 16749, 17513, 17514, 23103, 45714, 47246, 47247, 47248 ) -- Ice Block
	AddTrainerRef( "classes", "MAGE", 49358, 2492, 5957, 5958, 16654, 45139, 47253 ) -- Teleport: Stonard
	AddTrainerRef( "classes", "MAGE", 49359, 2485, 2489, 4165, 16755, 29156 ) -- Teleport: Theramore
	AddTrainerRef( "classes", "MAGE", 49360, 2485, 2489, 4165, 16755, 29156 ) -- Portal: Theramore
	AddTrainerRef( "classes", "MAGE", 49361, 2492, 5957, 5958, 16654, 45139, 47253 ) -- Portal: Stonard
	AddTrainerRef( "classes", "MAGE", 53140, 2485, 2489, 2492, 4165, 5957, 5958, 16654, 16755, 29156, 45139, 47253 ) -- Teleport: Dalaran
	AddTrainerRef( "classes", "MAGE", 53142, 2485, 2489, 2492, 4165, 5957, 5958, 16654, 16755, 29156, 45139, 47253 ) -- Portal: Dalaran
	AddTrainerRef( "classes", "MAGE", 55342, 331, 1228, 3047, 3048, 3049, 4566, 4567, 4568, 5144, 5145, 5497, 5498, 5882, 5885, 7311, 7312, 16651, 16652, 16653, 16749, 17513, 17514, 23103, 45714, 47246, 47247, 47248 ) -- Mirror Image
	AddTrainerRef( "classes", "MAGE", 80353, 331, 1228, 3047, 3048, 3049, 4566, 4567, 4568, 5144, 5145, 5497, 5498, 5882, 5885, 7311, 7312, 16651, 16652, 16653, 16749, 17513, 17514, 23103, 45714, 47246, 47247, 47248 ) -- Time Warp
	AddTrainerRef( "classes", "MAGE", 82676, 331, 1228, 3047, 3048, 3049, 4566, 4567, 4568, 5144, 5145, 5497, 5498, 5882, 5885, 7311, 7312, 16651, 16652, 16653, 16749, 17513, 17514, 23103, 45714, 47246, 47247, 47248 ) -- Ring of Frost
	AddTrainerRef( "classes", "MAGE", 82731, 331, 1228, 3047, 3048, 3049, 4566, 4567, 4568, 5144, 5145, 5497, 5498, 5882, 5885, 7311, 7312, 16651, 16652, 16653, 16749, 17513, 17514, 23103, 45714, 47246, 47247, 47248 ) -- Flame Orb
	AddTrainerRef( "classes", "MAGE", 86467, 331, 1228, 3047, 3048, 3049, 4566, 4567, 4568, 5144, 5145, 5497, 5498, 5882, 5885, 7311, 7312, 16651, 16652, 16653, 16749, 17513, 17514, 23103, 45714, 47246, 47247, 47248 ) -- Mastery
	AddTrainerRef( "classes", "MAGE", 88342, 2485, 2489, 4165, 16755 ) -- Teleport: Tol Barad
	AddTrainerRef( "classes", "MAGE", 88344, 2492, 5957, 16654, 45139, 47253 ) -- Teleport: Tol Barad
	AddTrainerRef( "classes", "MAGE", 88345, 2485, 2489, 4165, 16755 ) -- Portal: Tol Barad
	AddTrainerRef( "classes", "MAGE", 88346, 2492, 5957, 16654, 45139, 47253 ) -- Portal: Tol Barad
	AddTrainerRef( "classes", "MAGE", 89744, 331, 1228, 3047, 3048, 3049, 4566, 4567, 4568, 5144, 5145, 5497, 5498, 5882, 5885, 7311, 7312, 16651, 16652, 16653, 16749, 17513, 17514, 23103, 45714, 47246, 47247, 47248 ) -- Wizardry
	AddTrainerRef( "classes", "PALADIN",   465, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Devotion Aura
	AddTrainerRef( "classes", "PALADIN",   498, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Divine Protection
	AddTrainerRef( "classes", "PALADIN",   633, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Lay on Hands
	AddTrainerRef( "classes", "PALADIN",   635, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Holy Light
	AddTrainerRef( "classes", "PALADIN",   642, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Divine Shield
	AddTrainerRef( "classes", "PALADIN",   750, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Plate Mail
	AddTrainerRef( "classes", "PALADIN",   853, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Hammer of Justice
	AddTrainerRef( "classes", "PALADIN",   879, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Exorcism
	AddTrainerRef( "classes", "PALADIN",  1022, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Hand of Protection
	AddTrainerRef( "classes", "PALADIN",  1038, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Hand of Salvation
	AddTrainerRef( "classes", "PALADIN",  1044, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Hand of Freedom
	AddTrainerRef( "classes", "PALADIN",  2812, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Holy Wrath
	AddTrainerRef( "classes", "PALADIN",  4987, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Cleanse
	AddTrainerRef( "classes", "PALADIN",  6940, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Hand of Sacrifice
	AddTrainerRef( "classes", "PALADIN",  7294, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Retribution Aura
	AddTrainerRef( "classes", "PALADIN",  7328, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Redemption
	AddTrainerRef( "classes", "PALADIN", 10326, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Turn Evil
	AddTrainerRef( "classes", "PALADIN", 13819, 928, 5149, 5491, 5492, 50160 ) -- Summon Warhorse
	AddTrainerRef( "classes", "PALADIN", 19740, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Blessing of Might
	AddTrainerRef( "classes", "PALADIN", 19746, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Concentration Aura
	AddTrainerRef( "classes", "PALADIN", 19750, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Flash of Light
	AddTrainerRef( "classes", "PALADIN", 19891, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Resistance Aura
	AddTrainerRef( "classes", "PALADIN", 20154, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Seal of Righteousness
	AddTrainerRef( "classes", "PALADIN", 20164, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Seal of Justice
	AddTrainerRef( "classes", "PALADIN", 20165, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Seal of Insight
	AddTrainerRef( "classes", "PALADIN", 20217, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Blessing of Kings
	AddTrainerRef( "classes", "PALADIN", 20271, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Judgement
	AddTrainerRef( "classes", "PALADIN", 23214, 928, 5149, 5491, 5492, 50160 ) -- Summon Charger
	AddTrainerRef( "classes", "PALADIN", 24275, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Hammer of Wrath
	AddTrainerRef( "classes", "PALADIN", 25780, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Righteous Fury
	AddTrainerRef( "classes", "PALADIN", 26573, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Consecration
	AddTrainerRef( "classes", "PALADIN", 31789, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Righteous Defense
	AddTrainerRef( "classes", "PALADIN", 31801, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Seal of Truth
	AddTrainerRef( "classes", "PALADIN", 31884, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Avenging Wrath
	AddTrainerRef( "classes", "PALADIN", 32223, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Crusader Aura
	AddTrainerRef( "classes", "PALADIN", 34767, 23128, 44725 ) -- Summon Charger
	AddTrainerRef( "classes", "PALADIN", 34769, 23128, 44725 ) -- Summon Warhorse
	AddTrainerRef( "classes", "PALADIN", 54428, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Divine Plea
	AddTrainerRef( "classes", "PALADIN", 62124, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Hand of Reckoning
	AddTrainerRef( "classes", "PALADIN", 82242, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Parry
	AddTrainerRef( "classes", "PALADIN", 82326, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Divine Light
	AddTrainerRef( "classes", "PALADIN", 82327, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Holy Radiance
	AddTrainerRef( "classes", "PALADIN", 84963, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Inquisition
	AddTrainerRef( "classes", "PALADIN", 85673, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Word of Glory
	AddTrainerRef( "classes", "PALADIN", 86150, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Guardian of Ancient Kings
	AddTrainerRef( "classes", "PALADIN", 87494, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Mastery
	AddTrainerRef( "classes", "PALADIN", 87511, 928, 5149, 5491, 5492, 23128, 44725, 50160 ) -- Plate Specialization
	AddTrainerRef( "classes", "PALADIN", 96231, 928, 5491, 5492 ) -- Rebuke
	AddTrainerRef( "classes", "PRIEST",    17, 376, 5142, 5143, 5484, 5489, 11406, 38516, 45306, 45337, 45339 ) -- Power Word: Shield
	AddTrainerRef( "classes", "PRIEST",   139, 376, 5142, 5143, 5484, 5489, 11406, 38516, 45306, 45337, 45339 ) -- Renew
	AddTrainerRef( "classes", "PRIEST",   453, 376, 5142, 5143, 5484, 5489, 11406, 38516, 45306, 45337, 45339 ) -- Mind Soothe
	AddTrainerRef( "classes", "PRIEST",   527, 376, 5142, 5143, 5484, 5489, 11406, 38516, 45306, 45337, 45339 ) -- Dispel Magic
	AddTrainerRef( "classes", "PRIEST",   528, 376, 5142, 5143, 5484, 5489, 11406, 38516, 45306, 45337, 45339 ) -- Cure Disease
	AddTrainerRef( "classes", "PRIEST",   586, 376, 5142, 5143, 5484, 5489, 11406, 38516, 45306, 45337, 45339 ) -- Fade
	AddTrainerRef( "classes", "PRIEST",   588, 376, 5142, 5143, 5484, 5489, 11406, 38516, 45306, 45337, 45339 ) -- Inner Fire
	AddTrainerRef( "classes", "PRIEST",   589, 376, 5142, 5143, 5484, 5489, 11406, 38516, 45306, 45337, 45339 ) -- Shadow Word: Pain
	AddTrainerRef( "classes", "PRIEST",   596, 376, 5142, 5143, 5484, 5489, 11406, 38516, 45306, 45337, 45339 ) -- Prayer of Healing
	AddTrainerRef( "classes", "PRIEST",   605, 376, 5142, 5143, 5484, 5489, 11406, 38516, 45306, 45337, 45339 ) -- Mind Control
	AddTrainerRef( "classes", "PRIEST",  1706, 376, 5142, 5143, 5484, 5489, 11406, 38516, 45306, 45337, 45339 ) -- Levitate
	AddTrainerRef( "classes", "PRIEST",  2006, 376, 5142, 5143, 5484, 5489, 11406, 38516, 45306, 45337, 45339 ) -- Resurrection
	AddTrainerRef( "classes", "PRIEST",  2050, 376, 5142, 5143, 5484, 5489, 11406, 38516, 45306, 45337, 45339 ) -- Heal
	AddTrainerRef( "classes", "PRIEST",  2060, 376, 5142, 5143, 5484, 5489, 11406, 38516, 45306, 45337, 45339 ) -- Greater Heal
	AddTrainerRef( "classes", "PRIEST",  2061, 376, 5142, 5143, 5484, 5489, 11406, 38516, 45306, 45337, 45339 ) -- Flash Heal
	AddTrainerRef( "classes", "PRIEST",  2096, 376, 5142, 5143, 5484, 5489, 11406, 38516, 45306, 45337, 45339 ) -- Mind Vision
	AddTrainerRef( "classes", "PRIEST",  2944, 376, 5142, 5143, 5484, 5489, 11406, 38516, 45306, 45337, 45339 ) -- Devouring Plague
	AddTrainerRef( "classes", "PRIEST",  6346, 376, 5142, 5143, 5484, 5489, 11406, 38516, 45306, 45337, 45339 ) -- Fear Ward
	AddTrainerRef( "classes", "PRIEST",  8092, 376, 5142, 5143, 5484, 5489, 11406, 38516, 45306, 45337, 45339 ) -- Mind Blast
	AddTrainerRef( "classes", "PRIEST",  8122, 376, 5142, 5143, 5484, 5489, 11406, 38516, 45306, 45337, 45339 ) -- Psychic Scream
	AddTrainerRef( "classes", "PRIEST",  8129, 376, 5142, 5143, 5484, 5489, 11406, 38516, 45306, 45337, 45339 ) -- Mana Burn
	AddTrainerRef( "classes", "PRIEST",  9484, 376, 5142, 5143, 5484, 5489, 11406, 38516, 45306, 45337, 45339 ) -- Shackle Undead
	AddTrainerRef( "classes", "PRIEST", 14914, 376, 5142, 5143, 5484, 5489, 11406, 38516, 45306, 45337, 45339 ) -- Holy Fire
	AddTrainerRef( "classes", "PRIEST", 15237, 376, 5142, 5143, 5484, 5489, 11406, 38516, 45306, 45337, 45339 ) -- Holy Nova
	AddTrainerRef( "classes", "PRIEST", 21562, 376, 5142, 5143, 5484, 5489, 11406, 38516, 45306, 45337, 45339 ) -- Power Word: Fortitude
	AddTrainerRef( "classes", "PRIEST", 27683, 376, 5142, 5143, 5484, 5489, 11406, 38516, 45306, 45337, 45339 ) -- Shadow Protection
	AddTrainerRef( "classes", "PRIEST", 32375, 376, 5142, 5143, 5484, 5489, 11406, 38516, 45306, 45337, 45339 ) -- Mass Dispel
	AddTrainerRef( "classes", "PRIEST", 32379, 376, 5142, 5143, 5484, 5489, 11406, 38516, 45306, 45337, 45339 ) -- Shadow Word: Death
	AddTrainerRef( "classes", "PRIEST", 32546, 376, 5142, 5143, 5484, 5489, 11406, 38516, 45306, 45337, 45339 ) -- Binding Heal
	AddTrainerRef( "classes", "PRIEST", 33076, 376, 5142, 5143, 5484, 5489, 11406, 38516, 45306, 45337, 45339 ) -- Prayer of Mending
	AddTrainerRef( "classes", "PRIEST", 34433, 376, 5142, 5143, 5484, 5489, 11406, 38516, 45306, 45337, 45339 ) -- Shadowfiend
	AddTrainerRef( "classes", "PRIEST", 48045, 376, 5142, 5143, 5484, 5489, 11406, 38516, 45306, 45337, 45339 ) -- Mind Sear
	AddTrainerRef( "classes", "PRIEST", 64843, 376, 5142, 5143, 5484, 5489, 11406, 38516, 45306, 45337, 45339 ) -- Divine Hymn
	AddTrainerRef( "classes", "PRIEST", 64901, 376, 5142, 5143, 5484, 5489, 11406, 38516, 45306, 45337, 45339 ) -- Hymn of Hope
	AddTrainerRef( "classes", "PRIEST", 73325, 376, 5142, 5143, 5484, 5489, 11406, 38516, 45306, 45337, 45339 ) -- Leap of Faith
	AddTrainerRef( "classes", "PRIEST", 73413, 376, 5142, 5143, 5484, 5489, 11406, 38516, 45306, 45337, 45339 ) -- Inner Will
	AddTrainerRef( "classes", "PRIEST", 73510, 376, 5142, 5143, 5484, 5489, 11406, 38516, 45306, 45337, 45339 ) -- Mind Spike
	AddTrainerRef( "classes", "PRIEST", 87495, 376, 5142, 5143, 5484, 5489, 11406, 38516, 45306, 45337, 45339 ) -- Mastery
	AddTrainerRef( "classes", "PRIEST", 89745, 376, 5142, 5143, 5484, 5489, 11406, 38516, 45306, 45337, 45339 ) -- Mysticism
	AddTrainerRef( "classes", "ROGUE",    53, 918, 4163, 4214, 4215, 5165, 5166, 5167, 13283, 49939, 50127, 50158 ) -- Backstab
	AddTrainerRef( "classes", "ROGUE",   408, 918, 4163, 4214, 4215, 5165, 5166, 5167, 13283, 49939, 50127, 50158 ) -- Kidney Shot
	AddTrainerRef( "classes", "ROGUE",   703, 918, 4163, 4214, 4215, 5165, 5166, 5167, 13283, 49939, 50127, 50158 ) -- Garrote
	AddTrainerRef( "classes", "ROGUE",   921, 918, 4163, 4214, 4215, 5165, 5166, 5167, 13283, 49939, 50127, 50158 ) -- Pick Pocket
	AddTrainerRef( "classes", "ROGUE",  1725, 918, 4163, 4214, 4215, 5165, 5166, 5167, 13283, 49939, 50127, 50158 ) -- Distract
	AddTrainerRef( "classes", "ROGUE",  1766, 918, 4163, 4214, 4215, 5165, 5166, 5167, 13283, 49939, 50127, 50158 ) -- Kick
	AddTrainerRef( "classes", "ROGUE",  1776, 918, 4163, 4214, 4215, 5165, 5166, 5167, 13283, 49939, 50127, 50158 ) -- Gouge
	AddTrainerRef( "classes", "ROGUE",  1784, 918, 4163, 4214, 4215, 5165, 5166, 5167, 13283, 49939, 50127, 50158 ) -- Stealth
	AddTrainerRef( "classes", "ROGUE",  1804, 918, 4163, 4214, 4215, 5165, 5166, 5167, 13283, 49939, 50127, 50158 ) -- Pick Lock
	AddTrainerRef( "classes", "ROGUE",  1833, 918, 4163, 4214, 4215, 5165, 5166, 5167, 13283, 49939, 50127, 50158 ) -- Cheap Shot
	AddTrainerRef( "classes", "ROGUE",  1842, 918, 4163, 4214, 4215, 5165, 5166, 5167, 13283, 49939, 50127, 50158 ) -- Disarm Trap
	AddTrainerRef( "classes", "ROGUE",  1856, 918, 4163, 4214, 4215, 5165, 5166, 5167, 13283, 49939, 50127, 50158 ) -- Vanish
	AddTrainerRef( "classes", "ROGUE",  1860, 918, 4163, 4214, 4215, 5165, 5166, 5167, 13283, 49939, 50127, 50158 ) -- Safe Fall
	AddTrainerRef( "classes", "ROGUE",  1943, 918, 4163, 4214, 4215, 5165, 5166, 5167, 13283, 49939, 50127, 50158 ) -- Rupture
	AddTrainerRef( "classes", "ROGUE",  1966, 918, 4163, 4214, 4215, 5165, 5166, 5167, 13283, 49939, 50127, 50158 ) -- Feint
	AddTrainerRef( "classes", "ROGUE",  2094, 918, 4163, 4214, 4215, 5165, 5166, 5167, 13283, 49939, 50127, 50158 ) -- Blind
	AddTrainerRef( "classes", "ROGUE",  2098, 918, 4163, 4214, 4215, 5165, 5166, 5167, 13283, 49939, 50127, 50158 ) -- Eviscerate
	AddTrainerRef( "classes", "ROGUE",  2836, 918, 4163, 4214, 4215, 5165, 5166, 5167, 13283, 49939, 50127, 50158 ) -- Detect Traps
	AddTrainerRef( "classes", "ROGUE",  2983, 918, 4163, 4214, 4215, 5165, 5166, 5167, 13283, 49939, 50127, 50158 ) -- Sprint
	AddTrainerRef( "classes", "ROGUE",  5171, 918, 4163, 4214, 4215, 5165, 5166, 5167, 13283, 49939, 50127, 50158 ) -- Slice and Dice
	AddTrainerRef( "classes", "ROGUE",  5277, 918, 4163, 4214, 4215, 5165, 5166, 5167, 13283, 49939, 50127, 50158 ) -- Evasion
	AddTrainerRef( "classes", "ROGUE",  5938, 918, 4163, 4214, 4215, 5165, 5166, 5167, 13283, 49939, 50127, 50158 ) -- Shiv
	AddTrainerRef( "classes", "ROGUE",  6770, 918, 4163, 4214, 4215, 5165, 5166, 5167, 13283, 49939, 50127, 50158 ) -- Sap
	AddTrainerRef( "classes", "ROGUE",  8647, 918, 4163, 4214, 4215, 5165, 5166, 5167, 13283, 49939, 50127, 50158 ) -- Expose Armor
	AddTrainerRef( "classes", "ROGUE",  8676, 918, 4163, 4214, 4215, 5165, 5166, 5167, 13283, 49939, 50127, 50158 ) -- Ambush
	AddTrainerRef( "classes", "ROGUE", 26679, 918, 4163, 4214, 4215, 5165, 5166, 5167, 13283, 49939, 50127, 50158 ) -- Deadly Throw
	AddTrainerRef( "classes", "ROGUE", 31224, 918, 4163, 4214, 4215, 5165, 5166, 5167, 13283, 49939, 50127, 50158 ) -- Cloak of Shadows
	AddTrainerRef( "classes", "ROGUE", 32645, 918, 4163, 4214, 4215, 5165, 5166, 5167, 13283, 49939, 50127, 50158 ) -- Envenom
	AddTrainerRef( "classes", "ROGUE", 51722, 918, 4163, 4214, 4215, 5165, 5166, 5167, 13283, 49939, 50127, 50158 ) -- Dismantle
	AddTrainerRef( "classes", "ROGUE", 51723, 918, 4163, 4214, 4215, 5165, 5166, 5167, 13283, 49939, 50127, 50158 ) -- Fan of Knives
	AddTrainerRef( "classes", "ROGUE", 57934, 918, 4163, 4214, 4215, 5165, 5166, 5167, 13283, 49939, 50127, 50158 ) -- Tricks of the Trade
	AddTrainerRef( "classes", "ROGUE", 73651, 918, 4163, 4214, 4215, 5165, 5166, 5167, 13283, 49939, 50127, 50158 ) -- Recuperate
	AddTrainerRef( "classes", "ROGUE", 73981, 918, 4163, 4214, 4215, 5165, 5166, 5167, 13283, 49939, 50127, 50158 ) -- Redirect
	AddTrainerRef( "classes", "ROGUE", 74001, 918, 4163, 4214, 4215, 5165, 5166, 5167, 13283, 49939, 50127, 50158 ) -- Combat Readiness
	AddTrainerRef( "classes", "ROGUE", 76577, 918, 4163, 4214, 4215, 5165, 5166, 5167, 13283, 49939, 50127, 50158 ) -- Smoke Bomb
	AddTrainerRef( "classes", "ROGUE", 82245, 918, 4163, 4214, 4215, 5165, 5166, 5167, 13283, 49939, 50127, 50158 ) -- Parry
	AddTrainerRef( "classes", "ROGUE", 87496, 918, 4163, 4214, 4215, 5165, 5166, 5167, 13283, 49939, 50127, 50158 ) -- Mastery
	AddTrainerRef( "classes", "ROGUE", 87504, 918, 4163, 4214, 4215, 5165, 5166, 5167, 13283, 49939, 50127, 50158 ) -- Leather Specialization
	AddTrainerRef( "classes", "SHAMAN",   131, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Water Breathing
	AddTrainerRef( "classes", "SHAMAN",   324, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Lightning Shield
	AddTrainerRef( "classes", "SHAMAN",   331, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Healing Wave
	AddTrainerRef( "classes", "SHAMAN",   370, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Purge
	AddTrainerRef( "classes", "SHAMAN",   421, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Chain Lightning
	AddTrainerRef( "classes", "SHAMAN",   546, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Water Walking
	AddTrainerRef( "classes", "SHAMAN",   556, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Astral Recall
	AddTrainerRef( "classes", "SHAMAN",  1064, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Chain Heal
	AddTrainerRef( "classes", "SHAMAN",  1535, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Fire Nova
	AddTrainerRef( "classes", "SHAMAN",  2008, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Ancestral Spirit
	AddTrainerRef( "classes", "SHAMAN",  2062, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Earth Elemental Totem
	AddTrainerRef( "classes", "SHAMAN",  2484, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Earthbind Totem
	AddTrainerRef( "classes", "SHAMAN",  2645, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Ghost Wolf
	AddTrainerRef( "classes", "SHAMAN",  2825, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 44740, 45029, 45718, 49900, 50011, 50022 ) -- Bloodlust
	AddTrainerRef( "classes", "SHAMAN",  2894, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Fire Elemental Totem
	AddTrainerRef( "classes", "SHAMAN",  3599, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Searing Totem
	AddTrainerRef( "classes", "SHAMAN",  3738, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Wrath of Air Totem
	AddTrainerRef( "classes", "SHAMAN",  5394, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Healing Stream Totem
	AddTrainerRef( "classes", "SHAMAN",  5675, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Mana Spring Totem
	AddTrainerRef( "classes", "SHAMAN",  5730, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Stoneclaw Totem
	AddTrainerRef( "classes", "SHAMAN",  6196, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Far Sight
	AddTrainerRef( "classes", "SHAMAN",  8004, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Healing Surge
	AddTrainerRef( "classes", "SHAMAN",  8017, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Rockbiter Weapon
	AddTrainerRef( "classes", "SHAMAN",  8024, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Flametongue Weapon
	AddTrainerRef( "classes", "SHAMAN",  8033, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Frostbrand Weapon
	AddTrainerRef( "classes", "SHAMAN",  8042, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 38242, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Earth Shock
	AddTrainerRef( "classes", "SHAMAN",  8050, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Flame Shock
	AddTrainerRef( "classes", "SHAMAN",  8056, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Frost Shock
	AddTrainerRef( "classes", "SHAMAN",  8071, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Stoneskin Totem
	AddTrainerRef( "classes", "SHAMAN",  8075, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 38242, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Strength of Earth Totem
	AddTrainerRef( "classes", "SHAMAN",  8143, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Tremor Totem
	AddTrainerRef( "classes", "SHAMAN",  8177, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Grounding Totem
	AddTrainerRef( "classes", "SHAMAN",  8184, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Elemental Resistance Totem
	AddTrainerRef( "classes", "SHAMAN",  8190, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Magma Totem
	AddTrainerRef( "classes", "SHAMAN",  8227, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Flametongue Totem
	AddTrainerRef( "classes", "SHAMAN",  8232, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Windfury Weapon
	AddTrainerRef( "classes", "SHAMAN",  8512, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Windfury Totem
	AddTrainerRef( "classes", "SHAMAN",  8737, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Mail
	AddTrainerRef( "classes", "SHAMAN", 20608, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Reincarnation
	AddTrainerRef( "classes", "SHAMAN", 32182, 20407, 23127, 44393, 44394, 50174 ) -- Heroism
	AddTrainerRef( "classes", "SHAMAN", 36936, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Totemic Recall
	AddTrainerRef( "classes", "SHAMAN", 51505, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Lava Burst
	AddTrainerRef( "classes", "SHAMAN", 51514, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Hex
	AddTrainerRef( "classes", "SHAMAN", 51730, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Earthliving Weapon
	AddTrainerRef( "classes", "SHAMAN", 51886, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Cleanse Spirit
	AddTrainerRef( "classes", "SHAMAN", 52127, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Water Shield
	AddTrainerRef( "classes", "SHAMAN", 57994, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Wind Shear
	AddTrainerRef( "classes", "SHAMAN", 66842, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Call of the Elements
	AddTrainerRef( "classes", "SHAMAN", 66843, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Call of the Ancestors
	AddTrainerRef( "classes", "SHAMAN", 66844, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Call of the Spirits
	AddTrainerRef( "classes", "SHAMAN", 73680, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Unleash Elements
	AddTrainerRef( "classes", "SHAMAN", 73899, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 38242, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Primal Strike
	AddTrainerRef( "classes", "SHAMAN", 73920, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Healing Rain
	AddTrainerRef( "classes", "SHAMAN", 76780, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Bind Elemental
	AddTrainerRef( "classes", "SHAMAN", 77472, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Greater Healing Wave
	AddTrainerRef( "classes", "SHAMAN", 79206, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Spiritwalker's Grace
	AddTrainerRef( "classes", "SHAMAN", 87497, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Mastery
	AddTrainerRef( "classes", "SHAMAN", 87507, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Mail Specialization
	AddTrainerRef( "classes", "SHAMAN", 87718, 3030, 3031, 3032, 3173, 3344, 3403, 13417, 20407, 23127, 44393, 44394, 44740, 45029, 45718, 49900, 50011, 50022, 50174 ) -- Totem of Tranquil Mind
	AddTrainerRef( "classes", "WARLOCK",   126, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Eye of Kilrogg
	AddTrainerRef( "classes", "WARLOCK",   172, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Corruption
	AddTrainerRef( "classes", "WARLOCK",   348, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Immolate
	AddTrainerRef( "classes", "WARLOCK",   603, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Bane of Doom
	AddTrainerRef( "classes", "WARLOCK",   687, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Demon Armor
	AddTrainerRef( "classes", "WARLOCK",   689, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Drain Life
	AddTrainerRef( "classes", "WARLOCK",   691, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Summon Felhunter
	AddTrainerRef( "classes", "WARLOCK",   693, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Create Soulstone
	AddTrainerRef( "classes", "WARLOCK",   697, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Summon Voidwalker
	AddTrainerRef( "classes", "WARLOCK",   698, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Ritual of Summoning
	AddTrainerRef( "classes", "WARLOCK",   702, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Curse of Weakness
	AddTrainerRef( "classes", "WARLOCK",   710, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Banish
	AddTrainerRef( "classes", "WARLOCK",   712, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Summon Succubus
	AddTrainerRef( "classes", "WARLOCK",   755, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Health Funnel
	AddTrainerRef( "classes", "WARLOCK",   980, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Bane of Agony
	AddTrainerRef( "classes", "WARLOCK",  1098, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Enslave Demon
	AddTrainerRef( "classes", "WARLOCK",  1120, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Drain Soul
	AddTrainerRef( "classes", "WARLOCK",  1122, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Summon Infernal
	AddTrainerRef( "classes", "WARLOCK",  1454, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Life Tap
	AddTrainerRef( "classes", "WARLOCK",  1490, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Curse of the Elements
	AddTrainerRef( "classes", "WARLOCK",  1714, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Curse of Tongues
	AddTrainerRef( "classes", "WARLOCK",  1949, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Hellfire
	AddTrainerRef( "classes", "WARLOCK",  5138, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Drain Mana
	AddTrainerRef( "classes", "WARLOCK",  5484, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Howl of Terror
	AddTrainerRef( "classes", "WARLOCK",  5676, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Searing Pain
	AddTrainerRef( "classes", "WARLOCK",  5697, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Unending Breath
	AddTrainerRef( "classes", "WARLOCK",  5740, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Rain of Fire
	AddTrainerRef( "classes", "WARLOCK",  5782, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Fear
	AddTrainerRef( "classes", "WARLOCK",  5784, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Felsteed
	AddTrainerRef( "classes", "WARLOCK",  6201, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Create Healthstone
	AddTrainerRef( "classes", "WARLOCK",  6229, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Shadow Ward
	AddTrainerRef( "classes", "WARLOCK",  6353, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Soul Fire
	AddTrainerRef( "classes", "WARLOCK",  6789, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Death Coil
	AddTrainerRef( "classes", "WARLOCK", 18540, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Summon Doomguard
	AddTrainerRef( "classes", "WARLOCK", 19028, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Soul Link
	AddTrainerRef( "classes", "WARLOCK", 23161, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Dreadsteed
	AddTrainerRef( "classes", "WARLOCK", 27243, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Seed of Corruption
	AddTrainerRef( "classes", "WARLOCK", 28176, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Fel Armor
	AddTrainerRef( "classes", "WARLOCK", 29722, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Incinerate
	AddTrainerRef( "classes", "WARLOCK", 29858, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Soulshatter
	AddTrainerRef( "classes", "WARLOCK", 29893, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Ritual of Souls
	AddTrainerRef( "classes", "WARLOCK", 47897, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Shadowflame
	AddTrainerRef( "classes", "WARLOCK", 48018, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Demonic Circle: Summon
	AddTrainerRef( "classes", "WARLOCK", 48020, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Demonic Circle: Teleport
	AddTrainerRef( "classes", "WARLOCK", 74434, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Soulburn
	AddTrainerRef( "classes", "WARLOCK", 77799, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Fel Flame
	AddTrainerRef( "classes", "WARLOCK", 77801, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Demon Soul
	AddTrainerRef( "classes", "WARLOCK", 79268, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Soul Harvest
	AddTrainerRef( "classes", "WARLOCK", 80388, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Control Demon
	AddTrainerRef( "classes", "WARLOCK", 80398, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Dark Intent
	AddTrainerRef( "classes", "WARLOCK", 86091, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Nethermancy
	AddTrainerRef( "classes", "WARLOCK", 87498, 461, 5171, 5172, 5173, 5495, 5496, 50156, 50729, 50732 ) -- Mastery
	AddTrainerRef( "classes", "WARRIOR",    71, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781, 50025, 50155 ) -- Defensive Stance
	AddTrainerRef( "classes", "WARRIOR",    72, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781 ) -- Shield Bash
	AddTrainerRef( "classes", "WARRIOR",    78, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781, 50025, 50155 ) -- Heroic Strike
	AddTrainerRef( "classes", "WARRIOR",   100, 911, 912, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 42324, 49781, 50025, 50155 ) -- Charge
	AddTrainerRef( "classes", "WARRIOR",   355, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781, 50025, 50155 ) -- Taunt
	AddTrainerRef( "classes", "WARRIOR",   469, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781, 50025, 50155 ) -- Commanding Shout
	AddTrainerRef( "classes", "WARRIOR",   676, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781, 50025, 50155 ) -- Disarm
	AddTrainerRef( "classes", "WARRIOR",   750, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781, 50025, 50155 ) -- Plate Mail
	AddTrainerRef( "classes", "WARRIOR",   772, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781, 50025, 50155 ) -- Rend
	AddTrainerRef( "classes", "WARRIOR",   845, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781, 50025, 50155 ) -- Cleave
	AddTrainerRef( "classes", "WARRIOR",   871, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781, 50025, 50155 ) -- Shield Wall
	AddTrainerRef( "classes", "WARRIOR",  1134, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781, 50025, 50155 ) -- Inner Rage
	AddTrainerRef( "classes", "WARRIOR",  1160, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781, 50025, 50155 ) -- Demoralizing Shout
	AddTrainerRef( "classes", "WARRIOR",  1161, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781, 50025, 50155 ) -- Challenging Shout
	AddTrainerRef( "classes", "WARRIOR",  1464, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781, 50025, 50155 ) -- Slam
	AddTrainerRef( "classes", "WARRIOR",  1680, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781, 50025, 50155 ) -- Whirlwind
	AddTrainerRef( "classes", "WARRIOR",  1715, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781, 50025, 50155 ) -- Hamstring
	AddTrainerRef( "classes", "WARRIOR",  1719, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781, 50025, 50155 ) -- Recklessness
	AddTrainerRef( "classes", "WARRIOR",  2458, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781, 50025, 50155 ) -- Berserker Stance
	AddTrainerRef( "classes", "WARRIOR",  2565, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781, 50025, 50155 ) -- Shield Block
	AddTrainerRef( "classes", "WARRIOR",  3127, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781, 50025, 50155 ) -- Parry
	AddTrainerRef( "classes", "WARRIOR",  3411, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781, 50025, 50155 ) -- Intervene
	AddTrainerRef( "classes", "WARRIOR",  5246, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781, 50025, 50155 ) -- Intimidating Shout
	AddTrainerRef( "classes", "WARRIOR",  5308, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781, 50025, 50155 ) -- Execute
	AddTrainerRef( "classes", "WARRIOR",  6343, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781, 50025, 50155 ) -- Thunder Clap
	AddTrainerRef( "classes", "WARRIOR",  6544, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781, 50025, 50155 ) -- Heroic Leap
	AddTrainerRef( "classes", "WARRIOR",  6552, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781, 50025, 50155 ) -- Pummel
	AddTrainerRef( "classes", "WARRIOR",  6572, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781, 50025, 50155 ) -- Revenge
	AddTrainerRef( "classes", "WARRIOR",  6673, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781, 50025, 50155 ) -- Battle Shout
	AddTrainerRef( "classes", "WARRIOR",  7384, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781, 50025, 50155 ) -- Overpower
	AddTrainerRef( "classes", "WARRIOR",  7386, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781, 50025, 50155 ) -- Sunder Armor
	AddTrainerRef( "classes", "WARRIOR", 12678, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781, 50025, 50155 ) -- Stance Mastery
	AddTrainerRef( "classes", "WARRIOR", 18499, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781, 50025, 50155 ) -- Berserker Rage
	AddTrainerRef( "classes", "WARRIOR", 20230, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781, 50025, 50155 ) -- Retaliation
	AddTrainerRef( "classes", "WARRIOR", 20252, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781, 50025, 50155 ) -- Intercept
	AddTrainerRef( "classes", "WARRIOR", 23920, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781, 50025, 50155 ) -- Spell Reflection
	AddTrainerRef( "classes", "WARRIOR", 34428, 911, 912, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 42324, 49781, 50025, 50155 ) -- Victory Rush
	AddTrainerRef( "classes", "WARRIOR", 55694, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781, 50025, 50155 ) -- Enraged Regeneration
	AddTrainerRef( "classes", "WARRIOR", 57755, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781, 50025, 50155 ) -- Heroic Throw
	AddTrainerRef( "classes", "WARRIOR", 64382, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781, 50025, 50155 ) -- Shattering Throw
	AddTrainerRef( "classes", "WARRIOR", 86346, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781, 50025, 50155 ) -- Colossus Smash
	AddTrainerRef( "classes", "WARRIOR", 87500, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781, 50025, 50155 ) -- Mastery
	AddTrainerRef( "classes", "WARRIOR", 87509, 913, 914, 1229, 1901, 3353, 3354, 3408, 4087, 4089, 5113, 5114, 5479, 5480, 7315, 16771, 17120, 17504, 49781, 50025, 50155 ) -- Plate Specialization
	AddTrainerRef( "classes", "WARRIOR", 97462, 1901, 5113, 5114, 5479, 5480, 50025, 50155 ) -- Rallying Cry
	AddTrainerRef( "professions", "ALCHEMY",  2259, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Apprentice Alchemist
	AddTrainerRef( "professions", "ALCHEMY",  2331, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Minor Mana Potion
	AddTrainerRef( "professions", "ALCHEMY",  2332, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Minor Rejuvenation Potion
	AddTrainerRef( "professions", "ALCHEMY",  2334, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Elixir of Minor Fortitude
	AddTrainerRef( "professions", "ALCHEMY",  2337, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Lesser Healing Potion
	AddTrainerRef( "professions", "ALCHEMY",  3101, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Journeyman Alchemist
	AddTrainerRef( "professions", "ALCHEMY",  3170, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Weak Troll's Blood Elixir
	AddTrainerRef( "professions", "ALCHEMY",  3171, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Elixir of Wisdom
	AddTrainerRef( "professions", "ALCHEMY",  3173, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Lesser Mana Potion
	AddTrainerRef( "professions", "ALCHEMY",  3176, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Strong Troll's Blood Elixir
	AddTrainerRef( "professions", "ALCHEMY",  3177, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Elixir of Defense
	AddTrainerRef( "professions", "ALCHEMY",  3447, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Healing Potion
	AddTrainerRef( "professions", "ALCHEMY",  3448, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Lesser Invisibility Potion
	AddTrainerRef( "professions", "ALCHEMY",  3449, 1386, 5499, 18802, 26987, 28703, 33588, 33608, 33674 ) -- Shadow Oil
	AddTrainerRef( "professions", "ALCHEMY",  3450, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Elixir of Fortitude
	AddTrainerRef( "professions", "ALCHEMY",  3452, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Mana Potion
	AddTrainerRef( "professions", "ALCHEMY",  3464, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Expert Alchemist
	AddTrainerRef( "professions", "ALCHEMY",  7179, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Elixir of Water Breathing
	AddTrainerRef( "professions", "ALCHEMY",  7181, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Greater Healing Potion
	AddTrainerRef( "professions", "ALCHEMY",  7836, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Blackmouth Oil
	AddTrainerRef( "professions", "ALCHEMY",  7837, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Fire Oil
	AddTrainerRef( "professions", "ALCHEMY",  7841, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Swim Speed Potion
	AddTrainerRef( "professions", "ALCHEMY",  7845, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Elixir of Firepower
	AddTrainerRef( "professions", "ALCHEMY", 11448, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Greater Mana Potion
	AddTrainerRef( "professions", "ALCHEMY", 11449, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Elixir of Agility
	AddTrainerRef( "professions", "ALCHEMY", 11450, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Elixir of Greater Defense
	AddTrainerRef( "professions", "ALCHEMY", 11451, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Oil of Immolation
	AddTrainerRef( "professions", "ALCHEMY", 11457, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Superior Healing Potion
	AddTrainerRef( "professions", "ALCHEMY", 11460, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Elixir of Detect Undead
	AddTrainerRef( "professions", "ALCHEMY", 11461, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Arcane Elixir
	AddTrainerRef( "professions", "ALCHEMY", 11465, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Elixir of Greater Intellect
	AddTrainerRef( "professions", "ALCHEMY", 11467, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Elixir of Greater Agility
	AddTrainerRef( "professions", "ALCHEMY", 11478, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Elixir of Detect Demon
	AddTrainerRef( "professions", "ALCHEMY", 11611, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Artisan Alchemist
	AddTrainerRef( "professions", "ALCHEMY", 12609, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Catseye Elixir
	AddTrainerRef( "professions", "ALCHEMY", 15833, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Dreamless Sleep Potion
	AddTrainerRef( "professions", "ALCHEMY", 17551, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Stonescale Oil
	AddTrainerRef( "professions", "ALCHEMY", 17552, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Mighty Rage Potion
	AddTrainerRef( "professions", "ALCHEMY", 17553, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Superior Mana Potion
	AddTrainerRef( "professions", "ALCHEMY", 17555, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Elixir of the Sages
	AddTrainerRef( "professions", "ALCHEMY", 17556, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Major Healing Potion
	AddTrainerRef( "professions", "ALCHEMY", 17557, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Elixir of Brute Force
	AddTrainerRef( "professions", "ALCHEMY", 17572, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Purification Potion
	AddTrainerRef( "professions", "ALCHEMY", 17573, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Greater Arcane Elixir
	AddTrainerRef( "professions", "ALCHEMY", 22808, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Elixir of Greater Water Breathing
	AddTrainerRef( "professions", "ALCHEMY", 28544, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Elixir of Major Strength
	AddTrainerRef( "professions", "ALCHEMY", 28545, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Elixir of Healing Power
	AddTrainerRef( "professions", "ALCHEMY", 28551, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Super Healing Potion
	AddTrainerRef( "professions", "ALCHEMY", 28596, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Master Alchemist
	AddTrainerRef( "professions", "ALCHEMY", 33732, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Volatile Healing Potion
	AddTrainerRef( "professions", "ALCHEMY", 33733, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Unstable Mana Potion
	AddTrainerRef( "professions", "ALCHEMY", 33738, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Onslaught Elixir
	AddTrainerRef( "professions", "ALCHEMY", 33740, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Adept's Elixir
	AddTrainerRef( "professions", "ALCHEMY", 33741, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Elixir of Mastery
	AddTrainerRef( "professions", "ALCHEMY", 38070, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Mercurial Stone
	AddTrainerRef( "professions", "ALCHEMY", 39636, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Elixir of Major Fortitude
	AddTrainerRef( "professions", "ALCHEMY", 39638, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Elixir of Draenic Wisdom
	AddTrainerRef( "professions", "ALCHEMY", 45061, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Mad Alchemist's Potion
	AddTrainerRef( "professions", "ALCHEMY", 51304, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Grand Master Alchemist
	AddTrainerRef( "professions", "ALCHEMY", 53812, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Pygmy Oil
	AddTrainerRef( "professions", "ALCHEMY", 53836, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Runic Healing Potion
	AddTrainerRef( "professions", "ALCHEMY", 53837, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Runic Mana Potion
	AddTrainerRef( "professions", "ALCHEMY", 53838, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Resurgent Healing Potion
	AddTrainerRef( "professions", "ALCHEMY", 53839, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Icy Mana Potion
	AddTrainerRef( "professions", "ALCHEMY", 53840, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Elixir of Mighty Agility
	AddTrainerRef( "professions", "ALCHEMY", 53841, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Wrath Elixir
	AddTrainerRef( "professions", "ALCHEMY", 53842, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Spellpower Elixir
	AddTrainerRef( "professions", "ALCHEMY", 53847, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Elixir of Spirit
	AddTrainerRef( "professions", "ALCHEMY", 53848, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Guru's Elixir
	AddTrainerRef( "professions", "ALCHEMY", 53898, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Elixir of Mighty Fortitude
	AddTrainerRef( "professions", "ALCHEMY", 53899, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Lesser Flask of Toughness
	AddTrainerRef( "professions", "ALCHEMY", 53900, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Potion of Nightmares
	AddTrainerRef( "professions", "ALCHEMY", 53901, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Flask of the Frost Wyrm
	AddTrainerRef( "professions", "ALCHEMY", 53902, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Flask of Stoneblood
	AddTrainerRef( "professions", "ALCHEMY", 53903, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Flask of Endless Rage
	AddTrainerRef( "professions", "ALCHEMY", 53905, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Indestructible Potion
	AddTrainerRef( "professions", "ALCHEMY", 54213, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Flask of Pure Mojo
	AddTrainerRef( "professions", "ALCHEMY", 54218, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Elixir of Mighty Strength
	AddTrainerRef( "professions", "ALCHEMY", 57425, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Transmute: Skyflare Diamond
	AddTrainerRef( "professions", "ALCHEMY", 57427, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Transmute: Earthsiege Diamond
	AddTrainerRef( "professions", "ALCHEMY", 58868, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Endless Mana Potion
	AddTrainerRef( "professions", "ALCHEMY", 58871, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Endless Healing Potion
	AddTrainerRef( "professions", "ALCHEMY", 60350, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Transmute: Titanium
	AddTrainerRef( "professions", "ALCHEMY", 60367, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Elixir of Mighty Thoughts
	AddTrainerRef( "professions", "ALCHEMY", 60396, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Mercurial Alchemist Stone
	AddTrainerRef( "professions", "ALCHEMY", 60403, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Indestructible Alchemist Stone
	AddTrainerRef( "professions", "ALCHEMY", 60405, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Mighty Alchemist Stone
	AddTrainerRef( "professions", "ALCHEMY", 60893, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Northrend Alchemy Research
	AddTrainerRef( "professions", "ALCHEMY", 62213, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Lesser Flask of Resistance
	AddTrainerRef( "professions", "ALCHEMY", 62409, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Ethereal Oil
	AddTrainerRef( "professions", "ALCHEMY", 63732, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Elixir of Minor Accuracy
	AddTrainerRef( "professions", "ALCHEMY", 66658, 1386, 2837, 3184, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Transmute: Ametrine
	AddTrainerRef( "professions", "ALCHEMY", 66660, 1386, 2837, 3184, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Transmute: King's Amber
	AddTrainerRef( "professions", "ALCHEMY", 66662, 1386, 2837, 3184, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Transmute: Dreadstone
	AddTrainerRef( "professions", "ALCHEMY", 66663, 1386, 2837, 3184, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Transmute: Majestic Zircon
	AddTrainerRef( "professions", "ALCHEMY", 66664, 1386, 2837, 3184, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Transmute: Eye of Zul
	AddTrainerRef( "professions", "ALCHEMY", 67025, 1386, 2837, 3009, 3184, 3347, 4611, 5177, 5499, 16642, 18802, 26951, 26987, 28703, 33588, 33608, 33630, 33674 ) -- Flask of the North
	AddTrainerRef( "professions", "ALCHEMY", 78866, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Transmute: Living Elements
	AddTrainerRef( "professions", "ALCHEMY", 80237, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Transmute: Shadowspirit Diamond
	AddTrainerRef( "professions", "ALCHEMY", 80243, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Transmute: Truegold
	AddTrainerRef( "professions", "ALCHEMY", 80244, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Transmute: Pyrium Bar
	AddTrainerRef( "professions", "ALCHEMY", 80245, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Transmute: Inferno Ruby
	AddTrainerRef( "professions", "ALCHEMY", 80246, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Transmute: Ocean Sapphire
	AddTrainerRef( "professions", "ALCHEMY", 80247, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Transmute: Amberjewel
	AddTrainerRef( "professions", "ALCHEMY", 80248, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Transmute: Demonseye
	AddTrainerRef( "professions", "ALCHEMY", 80250, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Transmute: Ember Topaz
	AddTrainerRef( "professions", "ALCHEMY", 80251, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Transmute: Dream Emerald
	AddTrainerRef( "professions", "ALCHEMY", 80269, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Potion of Illusion
	AddTrainerRef( "professions", "ALCHEMY", 80477, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Ghost Elixir
	AddTrainerRef( "professions", "ALCHEMY", 80478, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Earthen Potion
	AddTrainerRef( "professions", "ALCHEMY", 80479, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Deathblood Venom
	AddTrainerRef( "professions", "ALCHEMY", 80480, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Elixir of the Naga
	AddTrainerRef( "professions", "ALCHEMY", 80481, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Volcanic Potion
	AddTrainerRef( "professions", "ALCHEMY", 80482, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Potion of Concentration
	AddTrainerRef( "professions", "ALCHEMY", 80484, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Elixir of the Cobra
	AddTrainerRef( "professions", "ALCHEMY", 80486, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Deepstone Oil
	AddTrainerRef( "professions", "ALCHEMY", 80487, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Mysterious Potion
	AddTrainerRef( "professions", "ALCHEMY", 80488, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Elixir of Deep Earth
	AddTrainerRef( "professions", "ALCHEMY", 80490, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Mighty Rejuvenation Potion
	AddTrainerRef( "professions", "ALCHEMY", 80491, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Elixir of Impossible Accuracy
	AddTrainerRef( "professions", "ALCHEMY", 80492, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Prismatic Elixir
	AddTrainerRef( "professions", "ALCHEMY", 80493, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Elixir of Mighty Speed
	AddTrainerRef( "professions", "ALCHEMY", 80494, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Mythical Mana Potion
	AddTrainerRef( "professions", "ALCHEMY", 80495, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Potion of the Tol'vir
	AddTrainerRef( "professions", "ALCHEMY", 80496, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Golemblood Potion
	AddTrainerRef( "professions", "ALCHEMY", 80497, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Elixir of the Master
	AddTrainerRef( "professions", "ALCHEMY", 80498, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Mythical Healing Potion
	AddTrainerRef( "professions", "ALCHEMY", 80508, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Lifebound Alchemist Stone
	AddTrainerRef( "professions", "ALCHEMY", 80719, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Flask of Steelskin
	AddTrainerRef( "professions", "ALCHEMY", 80720, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Flask of the Draconic Mind
	AddTrainerRef( "professions", "ALCHEMY", 80721, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Flask of the Winds
	AddTrainerRef( "professions", "ALCHEMY", 80723, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Flask of Titanic Strength
	AddTrainerRef( "professions", "ALCHEMY", 80724, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Flask of Enhancement
	AddTrainerRef( "professions", "ALCHEMY", 80725, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Potion of Deepholm
	AddTrainerRef( "professions", "ALCHEMY", 80726, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Potion of Treasure Finding
	AddTrainerRef( "professions", "ALCHEMY", 80731, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Illustrious Grand Master Alchemist
	AddTrainerRef( "professions", "ALCHEMY", 93935, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Draught of War
	AddTrainerRef( "professions", "ALCHEMY", 94162, 1386, 2837, 3347, 5177, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Flask of Flowing Water
	AddTrainerRef( "professions", "ALCHEMY", 96252, 1386, 2837, 3347, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Volatile Alchemist Stone
	AddTrainerRef( "professions", "ALCHEMY", 96253, 1386, 2837, 3347, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Quicksilver Alchemist Stone
	AddTrainerRef( "professions", "ALCHEMY", 96254, 1386, 2837, 3347, 5499, 18802, 26951, 26987, 28703, 33588, 33608, 33674 ) -- Vibrant Alchemist Stone
	AddTrainerRef( "professions", "ARCHAEOLOGY", 78670, 39718, 44238, 47568, 47569, 47571, 47574, 47575, 47576, 47578, 47579 ) -- Apprentice Archaeology
	AddTrainerRef( "professions", "ARCHAEOLOGY", 88961, 39718, 44238, 47568, 47569, 47571, 47574, 47575, 47576, 47578, 47579 ) -- Journeyman Archaeology
	AddTrainerRef( "professions", "ARCHAEOLOGY", 89718, 39718, 44238, 47568, 47569, 47571, 47574, 47575, 47576, 47578, 47579 ) -- Expert Archaeology
	AddTrainerRef( "professions", "ARCHAEOLOGY", 89719, 39718, 44238, 47568, 47569, 47571, 47574, 47575, 47576, 47578, 47579 ) -- Artisan Archaeology
	AddTrainerRef( "professions", "ARCHAEOLOGY", 89720, 39718, 44238, 47568, 47569, 47571, 47574, 47575, 47576, 47578, 47579 ) -- Master Archaeology
	AddTrainerRef( "professions", "ARCHAEOLOGY", 89721, 39718, 44238, 47568, 47569, 47571, 47574, 47575, 47576, 47578, 47579 ) -- Grand Master Archaeology
	AddTrainerRef( "professions", "ARCHAEOLOGY", 89722, 39718, 44238, 47568, 47569, 47571, 47574, 47575, 47576, 47578, 47579 ) -- Illustrious Grand Master Archaeology
	AddTrainerRef( "professions", "BLACKSMITHING",  2018, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Apprentice Blacksmith
	AddTrainerRef( "professions", "BLACKSMITHING",  2661, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Copper Chain Belt
	AddTrainerRef( "professions", "BLACKSMITHING",  2662, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Copper Chain Pants
	AddTrainerRef( "professions", "BLACKSMITHING",  2664, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Runed Copper Bracers
	AddTrainerRef( "professions", "BLACKSMITHING",  2665, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Coarse Sharpening Stone
	AddTrainerRef( "professions", "BLACKSMITHING",  2666, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Runed Copper Belt
	AddTrainerRef( "professions", "BLACKSMITHING",  2668, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Rough Bronze Leggings
	AddTrainerRef( "professions", "BLACKSMITHING",  2670, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Rough Bronze Cuirass
	AddTrainerRef( "professions", "BLACKSMITHING",  2672, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Patterned Bronze Bracers
	AddTrainerRef( "professions", "BLACKSMITHING",  2674, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Heavy Sharpening Stone
	AddTrainerRef( "professions", "BLACKSMITHING",  2675, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Shining Silver Breastplate
	AddTrainerRef( "professions", "BLACKSMITHING",  2737, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Copper Mace
	AddTrainerRef( "professions", "BLACKSMITHING",  2738, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Copper Axe
	AddTrainerRef( "professions", "BLACKSMITHING",  2739, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Copper Shortsword
	AddTrainerRef( "professions", "BLACKSMITHING",  2740, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Bronze Mace
	AddTrainerRef( "professions", "BLACKSMITHING",  2741, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Bronze Axe
	AddTrainerRef( "professions", "BLACKSMITHING",  2742, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Bronze Shortsword
	AddTrainerRef( "professions", "BLACKSMITHING",  3100, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Journeyman Blacksmith
	AddTrainerRef( "professions", "BLACKSMITHING",  3116, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Coarse Weightstone
	AddTrainerRef( "professions", "BLACKSMITHING",  3117, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Heavy Weightstone
	AddTrainerRef( "professions", "BLACKSMITHING",  3292, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Heavy Copper Broadsword
	AddTrainerRef( "professions", "BLACKSMITHING",  3293, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Copper Battle Axe
	AddTrainerRef( "professions", "BLACKSMITHING",  3294, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Thick War Axe
	AddTrainerRef( "professions", "BLACKSMITHING",  3296, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Heavy Bronze Mace
	AddTrainerRef( "professions", "BLACKSMITHING",  3319, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Copper Chain Boots
	AddTrainerRef( "professions", "BLACKSMITHING",  3320, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Rough Grinding Stone
	AddTrainerRef( "professions", "BLACKSMITHING",  3323, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Runed Copper Gauntlets
	AddTrainerRef( "professions", "BLACKSMITHING",  3324, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Runed Copper Pants
	AddTrainerRef( "professions", "BLACKSMITHING",  3326, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Coarse Grinding Stone
	AddTrainerRef( "professions", "BLACKSMITHING",  3328, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Rough Bronze Shoulders
	AddTrainerRef( "professions", "BLACKSMITHING",  3331, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Silvered Bronze Boots
	AddTrainerRef( "professions", "BLACKSMITHING",  3333, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Silvered Bronze Gauntlets
	AddTrainerRef( "professions", "BLACKSMITHING",  3337, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Heavy Grinding Stone
	AddTrainerRef( "professions", "BLACKSMITHING",  3491, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Big Bronze Knife
	AddTrainerRef( "professions", "BLACKSMITHING",  3501, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Green Iron Bracers
	AddTrainerRef( "professions", "BLACKSMITHING",  3502, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Green Iron Helm
	AddTrainerRef( "professions", "BLACKSMITHING",  3506, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Green Iron Leggings
	AddTrainerRef( "professions", "BLACKSMITHING",  3508, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Green Iron Hauberk
	AddTrainerRef( "professions", "BLACKSMITHING",  3538, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Expert Blacksmith
	AddTrainerRef( "professions", "BLACKSMITHING",  6517, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Pearl-handled Dagger
	AddTrainerRef( "professions", "BLACKSMITHING",  7223, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Golden Scale Bracers
	AddTrainerRef( "professions", "BLACKSMITHING",  7408, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Heavy Copper Maul
	AddTrainerRef( "professions", "BLACKSMITHING",  7817, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Rough Bronze Boots
	AddTrainerRef( "professions", "BLACKSMITHING",  7818, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Silver Rod
	AddTrainerRef( "professions", "BLACKSMITHING",  8768, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Iron Buckle
	AddTrainerRef( "professions", "BLACKSMITHING",  8880, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Copper Dagger
	AddTrainerRef( "professions", "BLACKSMITHING",  9785, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Artisan Blacksmith
	AddTrainerRef( "professions", "BLACKSMITHING",  9916, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Steel Breastplate
	AddTrainerRef( "professions", "BLACKSMITHING",  9918, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Solid Sharpening Stone
	AddTrainerRef( "professions", "BLACKSMITHING",  9920, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Solid Grinding Stone
	AddTrainerRef( "professions", "BLACKSMITHING",  9921, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Solid Weightstone
	AddTrainerRef( "professions", "BLACKSMITHING",  9926, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Heavy Mithril Shoulder
	AddTrainerRef( "professions", "BLACKSMITHING",  9928, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Heavy Mithril Gauntlet
	AddTrainerRef( "professions", "BLACKSMITHING",  9931, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Mithril Scale Pants
	AddTrainerRef( "professions", "BLACKSMITHING",  9935, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Steel Plate Helm
	AddTrainerRef( "professions", "BLACKSMITHING",  9959, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Heavy Mithril Breastplate
	AddTrainerRef( "professions", "BLACKSMITHING",  9961, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Mithril Coif
	AddTrainerRef( "professions", "BLACKSMITHING",  9968, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Heavy Mithril Boots
	AddTrainerRef( "professions", "BLACKSMITHING",  9983, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Copper Claymore
	AddTrainerRef( "professions", "BLACKSMITHING",  9985, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Bronze Warhammer
	AddTrainerRef( "professions", "BLACKSMITHING",  9986, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Bronze Greatsword
	AddTrainerRef( "professions", "BLACKSMITHING",  9987, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Bronze Battle Axe
	AddTrainerRef( "professions", "BLACKSMITHING",  9993, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Heavy Mithril Axe
	AddTrainerRef( "professions", "BLACKSMITHING", 10001, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Big Black Mace
	AddTrainerRef( "professions", "BLACKSMITHING", 14379, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Golden Rod
	AddTrainerRef( "professions", "BLACKSMITHING", 14380, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Truesilver Rod
	AddTrainerRef( "professions", "BLACKSMITHING", 15972, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Glinting Steel Dagger
	AddTrainerRef( "professions", "BLACKSMITHING", 16639, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Dense Grinding Stone
	AddTrainerRef( "professions", "BLACKSMITHING", 16640, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Dense Weightstone
	AddTrainerRef( "professions", "BLACKSMITHING", 16641, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Dense Sharpening Stone
	AddTrainerRef( "professions", "BLACKSMITHING", 16642, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Thorium Armor
	AddTrainerRef( "professions", "BLACKSMITHING", 16643, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Thorium Belt
	AddTrainerRef( "professions", "BLACKSMITHING", 16644, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Thorium Bracers
	AddTrainerRef( "professions", "BLACKSMITHING", 16646, 514, 1241, 2836, 3136, 3355, 4258, 5164, 5511, 11146, 11177, 11178, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 37072, 44781, 45548 ) -- Imperial Plate Shoulders
	AddTrainerRef( "professions", "BLACKSMITHING", 16647, 514, 1241, 2836, 3136, 3355, 4258, 5164, 5511, 11146, 11177, 11178, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 37072, 44781, 45548 ) -- Imperial Plate Belt
	AddTrainerRef( "professions", "BLACKSMITHING", 16649, 514, 1241, 2836, 3136, 3355, 4258, 5164, 5511, 11146, 11177, 11178, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 37072, 44781, 45548 ) -- Imperial Plate Bracers
	AddTrainerRef( "professions", "BLACKSMITHING", 16652, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Thorium Boots
	AddTrainerRef( "professions", "BLACKSMITHING", 16653, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Thorium Helm
	AddTrainerRef( "professions", "BLACKSMITHING", 16657, 514, 1241, 2836, 3136, 3355, 4258, 5164, 5511, 11146, 11177, 11178, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 37072, 44781, 45548 ) -- Imperial Plate Boots
	AddTrainerRef( "professions", "BLACKSMITHING", 16658, 514, 1241, 2836, 3136, 3355, 4258, 5164, 5511, 11146, 11177, 11178, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 37072, 44781, 45548 ) -- Imperial Plate Helm
	AddTrainerRef( "professions", "BLACKSMITHING", 16662, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Thorium Leggings
	AddTrainerRef( "professions", "BLACKSMITHING", 16663, 514, 1241, 2836, 3136, 3355, 4258, 5164, 5511, 11146, 11177, 11178, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 37072, 44781, 45548 ) -- Imperial Plate Chest
	AddTrainerRef( "professions", "BLACKSMITHING", 16730, 514, 1241, 2836, 3136, 3355, 4258, 5164, 5511, 11146, 11177, 11178, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 37072, 44781, 45548 ) -- Imperial Plate Leggings
	AddTrainerRef( "professions", "BLACKSMITHING", 16969, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Ornate Thorium Handaxe
	AddTrainerRef( "professions", "BLACKSMITHING", 16971, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Huge Thorium Battleaxe
	AddTrainerRef( "professions", "BLACKSMITHING", 19666, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Silver Skeleton Key
	AddTrainerRef( "professions", "BLACKSMITHING", 19667, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Golden Skeleton Key
	AddTrainerRef( "professions", "BLACKSMITHING", 19668, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Truesilver Skeleton Key
	AddTrainerRef( "professions", "BLACKSMITHING", 19669, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Arcanite Skeleton Key
	AddTrainerRef( "professions", "BLACKSMITHING", 20201, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Arcanite Rod
	AddTrainerRef( "professions", "BLACKSMITHING", 29545, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Fel Iron Plate Gloves
	AddTrainerRef( "professions", "BLACKSMITHING", 29547, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Fel Iron Plate Belt
	AddTrainerRef( "professions", "BLACKSMITHING", 29548, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Fel Iron Plate Boots
	AddTrainerRef( "professions", "BLACKSMITHING", 29549, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Fel Iron Plate Pants
	AddTrainerRef( "professions", "BLACKSMITHING", 29550, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Fel Iron Breastplate
	AddTrainerRef( "professions", "BLACKSMITHING", 29551, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Fel Iron Chain Coif
	AddTrainerRef( "professions", "BLACKSMITHING", 29552, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Fel Iron Chain Gloves
	AddTrainerRef( "professions", "BLACKSMITHING", 29553, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Fel Iron Chain Bracers
	AddTrainerRef( "professions", "BLACKSMITHING", 29556, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Fel Iron Chain Tunic
	AddTrainerRef( "professions", "BLACKSMITHING", 29557, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Fel Iron Hatchet
	AddTrainerRef( "professions", "BLACKSMITHING", 29558, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Fel Iron Hammer
	AddTrainerRef( "professions", "BLACKSMITHING", 29565, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Fel Iron Greatsword
	AddTrainerRef( "professions", "BLACKSMITHING", 29654, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Fel Sharpening Stone
	AddTrainerRef( "professions", "BLACKSMITHING", 29844, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Master Blacksmith
	AddTrainerRef( "professions", "BLACKSMITHING", 32284, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Lesser Rune of Warding
	AddTrainerRef( "professions", "BLACKSMITHING", 32655, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Fel Iron Rod
	AddTrainerRef( "professions", "BLACKSMITHING", 34607, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Fel Weightstone
	AddTrainerRef( "professions", "BLACKSMITHING", 34979, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Thick Bronze Darts
	AddTrainerRef( "professions", "BLACKSMITHING", 34981, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Whirling Steel Axes
	AddTrainerRef( "professions", "BLACKSMITHING", 34982, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Enchanted Thorium Blades
	AddTrainerRef( "professions", "BLACKSMITHING", 34983, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Felsteel Whisper Knives
	AddTrainerRef( "professions", "BLACKSMITHING", 51300, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Grand Master Blacksmith
	AddTrainerRef( "professions", "BLACKSMITHING", 52567, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Cobalt Legplates
	AddTrainerRef( "professions", "BLACKSMITHING", 52568, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Cobalt Belt
	AddTrainerRef( "professions", "BLACKSMITHING", 52569, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Cobalt Boots
	AddTrainerRef( "professions", "BLACKSMITHING", 52570, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Cobalt Chestpiece
	AddTrainerRef( "professions", "BLACKSMITHING", 52571, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Cobalt Helm
	AddTrainerRef( "professions", "BLACKSMITHING", 52572, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Cobalt Shoulders
	AddTrainerRef( "professions", "BLACKSMITHING", 54550, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Cobalt Triangle Shield
	AddTrainerRef( "professions", "BLACKSMITHING", 54551, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Tempered Saronite Belt
	AddTrainerRef( "professions", "BLACKSMITHING", 54552, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Tempered Saronite Boots
	AddTrainerRef( "professions", "BLACKSMITHING", 54553, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Tempered Saronite Breastplate
	AddTrainerRef( "professions", "BLACKSMITHING", 54554, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Tempered Saronite Legplates
	AddTrainerRef( "professions", "BLACKSMITHING", 54555, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Tempered Saronite Helm
	AddTrainerRef( "professions", "BLACKSMITHING", 54556, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Tempered Saronite Shoulders
	AddTrainerRef( "professions", "BLACKSMITHING", 54557, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Saronite Defender
	AddTrainerRef( "professions", "BLACKSMITHING", 54917, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Spiked Cobalt Helm
	AddTrainerRef( "professions", "BLACKSMITHING", 54918, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Spiked Cobalt Boots
	AddTrainerRef( "professions", "BLACKSMITHING", 54941, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Spiked Cobalt Shoulders
	AddTrainerRef( "professions", "BLACKSMITHING", 54944, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Spiked Cobalt Chestpiece
	AddTrainerRef( "professions", "BLACKSMITHING", 54945, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Spiked Cobalt Gauntlets
	AddTrainerRef( "professions", "BLACKSMITHING", 54946, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Spiked Cobalt Belt
	AddTrainerRef( "professions", "BLACKSMITHING", 54947, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Spiked Cobalt Legplates
	AddTrainerRef( "professions", "BLACKSMITHING", 54948, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Spiked Cobalt Bracers
	AddTrainerRef( "professions", "BLACKSMITHING", 54949, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Horned Cobalt Helm
	AddTrainerRef( "professions", "BLACKSMITHING", 55013, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Saronite Protector
	AddTrainerRef( "professions", "BLACKSMITHING", 55014, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Saronite Bulwark
	AddTrainerRef( "professions", "BLACKSMITHING", 55015, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Tempered Saronite Gauntlets
	AddTrainerRef( "professions", "BLACKSMITHING", 55017, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Tempered Saronite Bracers
	AddTrainerRef( "professions", "BLACKSMITHING", 55055, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Brilliant Saronite Legplates
	AddTrainerRef( "professions", "BLACKSMITHING", 55056, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Brilliant Saronite Gauntlets
	AddTrainerRef( "professions", "BLACKSMITHING", 55057, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Brilliant Saronite Boots
	AddTrainerRef( "professions", "BLACKSMITHING", 55058, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Brilliant Saronite Breastplate
	AddTrainerRef( "professions", "BLACKSMITHING", 55174, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Honed Cobalt Cleaver
	AddTrainerRef( "professions", "BLACKSMITHING", 55177, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Savage Cobalt Slicer
	AddTrainerRef( "professions", "BLACKSMITHING", 55179, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Saronite Ambusher
	AddTrainerRef( "professions", "BLACKSMITHING", 55181, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Saronite Shiv
	AddTrainerRef( "professions", "BLACKSMITHING", 55182, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Furious Saronite Beatstick
	AddTrainerRef( "professions", "BLACKSMITHING", 55185, 514, 1241, 2836, 3136, 3355, 4258, 5164, 5511, 11146, 11177, 11178, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 37072, 44781, 45548 ) -- Saronite Mindcrusher
	AddTrainerRef( "professions", "BLACKSMITHING", 55200, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Sturdy Cobalt Quickblade
	AddTrainerRef( "professions", "BLACKSMITHING", 55201, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Cobalt Tenderizer
	AddTrainerRef( "professions", "BLACKSMITHING", 55202, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Sure-fire Shuriken
	AddTrainerRef( "professions", "BLACKSMITHING", 55203, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Forged Cobalt Claymore
	AddTrainerRef( "professions", "BLACKSMITHING", 55204, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Notched Cobalt War Axe
	AddTrainerRef( "professions", "BLACKSMITHING", 55206, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Deadly Saronite Dirk
	AddTrainerRef( "professions", "BLACKSMITHING", 55298, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Vengeance Bindings
	AddTrainerRef( "professions", "BLACKSMITHING", 55300, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Righteous Gauntlets
	AddTrainerRef( "professions", "BLACKSMITHING", 55301, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Daunting Handguards
	AddTrainerRef( "professions", "BLACKSMITHING", 55302, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Helm of Command
	AddTrainerRef( "professions", "BLACKSMITHING", 55303, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Daunting Legplates
	AddTrainerRef( "professions", "BLACKSMITHING", 55304, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Righteous Greaves
	AddTrainerRef( "professions", "BLACKSMITHING", 55305, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Savage Saronite Bracers
	AddTrainerRef( "professions", "BLACKSMITHING", 55306, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Savage Saronite Pauldrons
	AddTrainerRef( "professions", "BLACKSMITHING", 55307, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Savage Saronite Waistguard
	AddTrainerRef( "professions", "BLACKSMITHING", 55308, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Savage Saronite Walkers
	AddTrainerRef( "professions", "BLACKSMITHING", 55309, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Savage Saronite Gauntlets
	AddTrainerRef( "professions", "BLACKSMITHING", 55310, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Savage Saronite Legplates
	AddTrainerRef( "professions", "BLACKSMITHING", 55311, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Savage Saronite Hauberk
	AddTrainerRef( "professions", "BLACKSMITHING", 55312, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Savage Saronite Skullshield
	AddTrainerRef( "professions", "BLACKSMITHING", 55369, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Titansteel Destroyer
	AddTrainerRef( "professions", "BLACKSMITHING", 55370, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Titansteel Bonecrusher
	AddTrainerRef( "professions", "BLACKSMITHING", 55371, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Titansteel Guardian
	AddTrainerRef( "professions", "BLACKSMITHING", 55372, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Spiked Titansteel Helm
	AddTrainerRef( "professions", "BLACKSMITHING", 55373, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Tempered Titansteel Helm
	AddTrainerRef( "professions", "BLACKSMITHING", 55374, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Brilliant Titansteel Helm
	AddTrainerRef( "professions", "BLACKSMITHING", 55375, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Spiked Titansteel Treads
	AddTrainerRef( "professions", "BLACKSMITHING", 55376, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Tempered Titansteel Treads
	AddTrainerRef( "professions", "BLACKSMITHING", 55377, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Brilliant Titansteel Treads
	AddTrainerRef( "professions", "BLACKSMITHING", 55628, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Socket Bracer
	AddTrainerRef( "professions", "BLACKSMITHING", 55641, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Socket Gloves
	AddTrainerRef( "professions", "BLACKSMITHING", 55656, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Eternal Belt Buckle
	AddTrainerRef( "professions", "BLACKSMITHING", 55732, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Titanium Rod
	AddTrainerRef( "professions", "BLACKSMITHING", 55834, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Cobalt Bracers
	AddTrainerRef( "professions", "BLACKSMITHING", 55835, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Cobalt Gauntlets
	AddTrainerRef( "professions", "BLACKSMITHING", 55839, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Titanium Weapon Chain
	AddTrainerRef( "professions", "BLACKSMITHING", 56234, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Titansteel Shanker
	AddTrainerRef( "professions", "BLACKSMITHING", 56280, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Cudgel of Saronite Justice
	AddTrainerRef( "professions", "BLACKSMITHING", 56357, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Titanium Shield Spike
	AddTrainerRef( "professions", "BLACKSMITHING", 56400, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Titansteel Shield Wall
	AddTrainerRef( "professions", "BLACKSMITHING", 56549, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Ornate Saronite Bracers
	AddTrainerRef( "professions", "BLACKSMITHING", 56550, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Ornate Saronite Pauldrons
	AddTrainerRef( "professions", "BLACKSMITHING", 56551, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Ornate Saronite Waistguard
	AddTrainerRef( "professions", "BLACKSMITHING", 56552, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Ornate Saronite Walkers
	AddTrainerRef( "professions", "BLACKSMITHING", 56553, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Ornate Saronite Gauntlets
	AddTrainerRef( "professions", "BLACKSMITHING", 56554, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Ornate Saronite Legplates
	AddTrainerRef( "professions", "BLACKSMITHING", 56555, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Ornate Saronite Hauberk
	AddTrainerRef( "professions", "BLACKSMITHING", 56556, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Ornate Saronite Skullshield
	AddTrainerRef( "professions", "BLACKSMITHING", 59405, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Cobalt Skeleton Key
	AddTrainerRef( "professions", "BLACKSMITHING", 59406, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Titanium Skeleton Key
	AddTrainerRef( "professions", "BLACKSMITHING", 59436, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Brilliant Saronite Belt
	AddTrainerRef( "professions", "BLACKSMITHING", 59438, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Brilliant Saronite Bracers
	AddTrainerRef( "professions", "BLACKSMITHING", 59440, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Brilliant Saronite Pauldrons
	AddTrainerRef( "professions", "BLACKSMITHING", 59441, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Brilliant Saronite Helm
	AddTrainerRef( "professions", "BLACKSMITHING", 59442, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Saronite Spellblade
	AddTrainerRef( "professions", "BLACKSMITHING", 61008, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Icebane Chestguard
	AddTrainerRef( "professions", "BLACKSMITHING", 61009, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Icebane Girdle
	AddTrainerRef( "professions", "BLACKSMITHING", 61010, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Icebane Treads
	AddTrainerRef( "professions", "BLACKSMITHING", 63182, 514, 1241, 2836, 3136, 3174, 3355, 4258, 4596, 5164, 5511, 11146, 11177, 11178, 16669, 16724, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 29506, 33591, 33609, 33631, 33675, 37072, 44781, 45548 ) -- Titansteel Spellblade
	AddTrainerRef( "professions", "BLACKSMITHING", 76178, 2836, 3136, 4258, 5164, 5511, 11146, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 45548 ) -- Folded Obsidium
	AddTrainerRef( "professions", "BLACKSMITHING", 76179, 2836, 3136, 4258, 5164, 5511, 11146, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 45548 ) -- Hardened Obsidium Bracers
	AddTrainerRef( "professions", "BLACKSMITHING", 76180, 2836, 3136, 4258, 5164, 5511, 11146, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 45548 ) -- Hardened Obsidium Gauntlets
	AddTrainerRef( "professions", "BLACKSMITHING", 76181, 2836, 3136, 4258, 5164, 5511, 11146, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 45548 ) -- Hardened Obsidium Belt
	AddTrainerRef( "professions", "BLACKSMITHING", 76182, 2836, 3136, 4258, 5164, 5511, 11146, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 45548 ) -- Hardened Obsidium Boots
	AddTrainerRef( "professions", "BLACKSMITHING", 76258, 2836, 3136, 4258, 5164, 5511, 11146, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 45548 ) -- Hardened Obsidium Shoulders
	AddTrainerRef( "professions", "BLACKSMITHING", 76259, 2836, 3136, 4258, 5164, 5511, 11146, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 45548 ) -- Hardened Obsidium Legguards
	AddTrainerRef( "professions", "BLACKSMITHING", 76260, 2836, 3136, 4258, 5164, 5511, 11146, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 45548 ) -- Hardened Obsidium Helm
	AddTrainerRef( "professions", "BLACKSMITHING", 76261, 2836, 3136, 4258, 5164, 5511, 11146, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 45548 ) -- Hardened Obsidium Breastplate
	AddTrainerRef( "professions", "BLACKSMITHING", 76262, 2836, 3136, 4258, 5164, 5511, 11146, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 45548 ) -- Redsteel Bracers
	AddTrainerRef( "professions", "BLACKSMITHING", 76263, 2836, 3136, 4258, 5164, 5511, 11146, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 45548 ) -- Redsteel Gauntlets
	AddTrainerRef( "professions", "BLACKSMITHING", 76264, 2836, 3136, 4258, 5164, 5511, 11146, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 45548 ) -- Redsteel Belt
	AddTrainerRef( "professions", "BLACKSMITHING", 76265, 2836, 3136, 4258, 5164, 5511, 11146, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 45548 ) -- Redsteel Boots
	AddTrainerRef( "professions", "BLACKSMITHING", 76266, 2836, 3136, 4258, 5164, 5511, 11146, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 45548 ) -- Redsteel Shoulders
	AddTrainerRef( "professions", "BLACKSMITHING", 76267, 2836, 3136, 4258, 5164, 5511, 11146, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 45548 ) -- Redsteel Legguards
	AddTrainerRef( "professions", "BLACKSMITHING", 76269, 2836, 3136, 4258, 5164, 5511, 11146, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 45548 ) -- Redsteel Helm
	AddTrainerRef( "professions", "BLACKSMITHING", 76270, 2836, 3136, 4258, 5164, 5511, 11146, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 45548 ) -- Redsteel Breastplate
	AddTrainerRef( "professions", "BLACKSMITHING", 76280, 2836, 3136, 4258, 5164, 5511, 11146, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 45548 ) -- Stormforged Bracers
	AddTrainerRef( "professions", "BLACKSMITHING", 76281, 2836, 3136, 4258, 5164, 5511, 11146, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 45548 ) -- Stormforged Gauntlets
	AddTrainerRef( "professions", "BLACKSMITHING", 76283, 2836, 3136, 4258, 5164, 5511, 11146, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 45548 ) -- Stormforged Belt
	AddTrainerRef( "professions", "BLACKSMITHING", 76285, 2836, 3136, 4258, 5164, 5511, 11146, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 45548 ) -- Stormforged Boots
	AddTrainerRef( "professions", "BLACKSMITHING", 76286, 2836, 3136, 4258, 5164, 5511, 11146, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 45548 ) -- Stormforged Shoulders
	AddTrainerRef( "professions", "BLACKSMITHING", 76287, 2836, 3136, 4258, 5164, 5511, 11146, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 45548 ) -- Stormforged Legguards
	AddTrainerRef( "professions", "BLACKSMITHING", 76288, 2836, 3136, 4258, 5164, 5511, 11146, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 45548 ) -- Stormforged Helm
	AddTrainerRef( "professions", "BLACKSMITHING", 76289, 2836, 3136, 4258, 5164, 5511, 11146, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 45548 ) -- Stormforged Breastplate
	AddTrainerRef( "professions", "BLACKSMITHING", 76291, 2836, 3136, 4258, 5164, 5511, 11146, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 45548 ) -- Hardened Obsidium Shield
	AddTrainerRef( "professions", "BLACKSMITHING", 76293, 2836, 3136, 4258, 5164, 5511, 11146, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 45548 ) -- Stormforged Shield
	AddTrainerRef( "professions", "BLACKSMITHING", 76433, 2836, 3136, 4258, 5164, 5511, 11146, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 45548 ) -- Decapitator's Razor
	AddTrainerRef( "professions", "BLACKSMITHING", 76434, 2836, 3136, 4258, 5164, 5511, 11146, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 45548 ) -- Cold-Forged Shank
	AddTrainerRef( "professions", "BLACKSMITHING", 76435, 2836, 3136, 4258, 5164, 5511, 11146, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 45548 ) -- Fire-Etched Dagger
	AddTrainerRef( "professions", "BLACKSMITHING", 76436, 2836, 3136, 4258, 5164, 5511, 11146, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 45548 ) -- Lifeforce Hammer
	AddTrainerRef( "professions", "BLACKSMITHING", 76437, 2836, 3136, 4258, 5164, 5511, 11146, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 45548 ) -- Obsidium Executioner
	AddTrainerRef( "professions", "BLACKSMITHING", 76438, 2836, 3136, 4258, 5164, 5511, 11146, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 45548 ) -- Obsidium Skeleton Key
	AddTrainerRef( "professions", "BLACKSMITHING", 76441, 2836, 3136, 4258, 5164, 5511, 11146, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 45548 ) -- Elementium Shield Spike
	AddTrainerRef( "professions", "BLACKSMITHING", 76474, 2836, 3136, 4258, 5164, 5511, 11146, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 45548 ) -- Obsidium Bladespear
	AddTrainerRef( "professions", "BLACKSMITHING", 76666, 2836, 3136, 4258, 5164, 5511, 11146, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 45548 ) -- Illustrious Grand Master Blacksmith
	AddTrainerRef( "professions", "BLACKSMITHING", 92375, 2836, 3136, 4258, 5164, 5511, 11146, 16823, 20124, 20125, 26904, 26952, 26988, 28694, 29505, 33609, 33675, 45548 ) -- Elementium Rod
	AddTrainerRef( "professions", "COOKING",  2539, 1355, 1430, 3026, 3399, 4210, 4552, 5159, 5482, 16676, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 45550, 46709 ) -- Spiced Wolf Meat
	AddTrainerRef( "professions", "COOKING",  2541, 1355, 1430, 3026, 3399, 4210, 4552, 5159, 5482, 16676, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 45550, 46709 ) -- Coyote Steak
	AddTrainerRef( "professions", "COOKING",  2544, 1355, 1430, 3026, 3399, 4210, 4552, 5159, 5482, 16676, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 45550, 46709 ) -- Crab Cake
	AddTrainerRef( "professions", "COOKING",  2546, 1355, 1430, 3026, 3399, 4210, 4552, 5159, 5482, 16676, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 45550, 46709 ) -- Dry Pork Ribs
	AddTrainerRef( "professions", "COOKING",  2550, 1355, 1430, 3026, 3399, 4210, 4552, 5159, 5482, 16676, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 45550, 46709 ) -- Apprentice Cook
	AddTrainerRef( "professions", "COOKING",  3102, 1355, 1430, 3026, 3399, 4210, 4552, 5159, 5482, 16676, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 45550, 46709 ) -- Journeyman Cook
	AddTrainerRef( "professions", "COOKING",  3399, 1355, 3399, 4210, 5159, 5482, 16719, 18987, 19186, 26905, 26989, 28705, 29631, 33587, 33619, 46709 ) -- Tasty Lion Steak
	AddTrainerRef( "professions", "COOKING",  3400, 1355, 3399, 4210, 5159, 5482, 16719, 18987, 19186, 26905, 26989, 28705, 29631, 33587, 33619, 46709 ) -- Soothing Turtle Bisque
	AddTrainerRef( "professions", "COOKING",  3413, 1355, 1430, 3026, 3399, 4210, 4552, 5159, 5482, 16676, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 45550, 46709 ) -- Expert Cook
	AddTrainerRef( "professions", "COOKING",  4094, 1355, 1430, 3026, 3399, 4210, 4552, 5159, 5482, 16676, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 45550, 46709 ) -- Barbecued Buzzard Wing
	AddTrainerRef( "professions", "COOKING",  6412, 1355, 3399, 4210, 5159, 5482, 16719, 18987, 19186, 26905, 26989, 28705, 29631, 33587, 33619, 46709 ) -- Kaldorei Spider Kabob
	AddTrainerRef( "professions", "COOKING",  6415, 1355, 3399, 4210, 5159, 5482, 16719, 18987, 19186, 26905, 26989, 28705, 29631, 33587, 33619, 46709 ) -- Fillet of Frenzy
	AddTrainerRef( "professions", "COOKING",  6499, 1355, 1430, 3026, 3399, 4210, 4552, 5159, 5482, 16676, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 45550, 46709 ) -- Boiled Clams
	AddTrainerRef( "professions", "COOKING",  6500, 1355, 1430, 3026, 3399, 4210, 4552, 5159, 5482, 16676, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 45550, 46709 ) -- Goblin Deviled Clams
	AddTrainerRef( "professions", "COOKING", 18238, 1355, 3399, 4210, 5159, 5482, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 46709 ) -- Spotted Yellowtail
	AddTrainerRef( "professions", "COOKING", 18240, 1355, 3399, 4210, 5159, 5482, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 46709 ) -- Grilled Squid
	AddTrainerRef( "professions", "COOKING", 18243, 1355, 3399, 4210, 5159, 5482, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 46709 ) -- Nightfin Soup
	AddTrainerRef( "professions", "COOKING", 18244, 1355, 3399, 4210, 5159, 5482, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 46709 ) -- Poached Sunscale Salmon
	AddTrainerRef( "professions", "COOKING", 18260, 1355, 1430, 3026, 3399, 4210, 4552, 5159, 5482, 16676, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 45550, 46709 ) -- Artisan Cook
	AddTrainerRef( "professions", "COOKING", 21175, 1355, 1430, 3026, 3399, 4210, 4552, 5159, 5482, 16676, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 45550, 46709 ) -- Spider Sausage
	AddTrainerRef( "professions", "COOKING", 33359, 1355, 1430, 3026, 3399, 4210, 4552, 5159, 5482, 16676, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 45550, 46709 ) -- Master Cook
	AddTrainerRef( "professions", "COOKING", 37836, 1355, 1430, 3026, 3399, 4210, 4552, 5159, 5482, 16676, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 45550, 46709 ) -- Spice Bread
	AddTrainerRef( "professions", "COOKING", 42296, 1355, 1430, 3026, 3399, 4210, 4552, 5159, 5482, 16676, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 45550, 46709 ) -- Stewed Trout
	AddTrainerRef( "professions", "COOKING", 42302, 1355, 1430, 3026, 3399, 4210, 4552, 5159, 5482, 16676, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 45550, 46709 ) -- Fisherman's Feast
	AddTrainerRef( "professions", "COOKING", 42305, 1355, 1430, 3026, 3399, 4210, 4552, 5159, 5482, 16676, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 45550, 46709 ) -- Hot Buttered Trout
	AddTrainerRef( "professions", "COOKING", 45549, 1355, 1430, 3026, 3399, 4210, 4552, 5159, 5482, 16676, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 45550, 46709 ) -- Mammoth Meal
	AddTrainerRef( "professions", "COOKING", 45550, 1355, 1430, 3026, 3399, 4210, 4552, 5159, 5482, 16676, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 45550, 46709 ) -- Shoveltusk Steak
	AddTrainerRef( "professions", "COOKING", 45551, 1355, 1430, 3026, 3399, 4210, 4552, 5159, 5482, 16676, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 45550, 46709 ) -- Worm Delight
	AddTrainerRef( "professions", "COOKING", 45552, 1355, 1430, 3026, 3399, 4210, 4552, 5159, 5482, 16676, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 45550, 46709 ) -- Roasted Worg
	AddTrainerRef( "professions", "COOKING", 45553, 1355, 1430, 3026, 3399, 4210, 4552, 5159, 5482, 16676, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 45550, 46709 ) -- Rhino Dogs
	AddTrainerRef( "professions", "COOKING", 45554, 1355, 1430, 3026, 3399, 4210, 4552, 5159, 5482, 16676, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 45550, 46709 ) -- Great Feast
	AddTrainerRef( "professions", "COOKING", 45560, 1355, 1430, 3026, 3399, 4210, 4552, 5159, 5482, 16676, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 45550, 46709 ) -- Smoked Rockfin
	AddTrainerRef( "professions", "COOKING", 45561, 1355, 1430, 3026, 3399, 4210, 4552, 5159, 5482, 16676, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 45550, 46709 ) -- Grilled Bonescale
	AddTrainerRef( "professions", "COOKING", 45562, 1355, 1430, 3026, 3399, 4210, 4552, 5159, 5482, 16676, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 45550, 46709 ) -- Sauteed Goby
	AddTrainerRef( "professions", "COOKING", 45563, 1355, 1430, 3026, 3399, 4210, 4552, 5159, 5482, 16676, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 45550, 46709 ) -- Grilled Sculpin
	AddTrainerRef( "professions", "COOKING", 45564, 1355, 1430, 3026, 3399, 4210, 4552, 5159, 5482, 16676, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 45550, 46709 ) -- Smoked Salmon
	AddTrainerRef( "professions", "COOKING", 45565, 1355, 1430, 3026, 3399, 4210, 4552, 5159, 5482, 16676, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 45550, 46709 ) -- Poached Nettlefish
	AddTrainerRef( "professions", "COOKING", 45566, 1355, 1430, 3026, 3399, 4210, 4552, 5159, 5482, 16676, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 45550, 46709 ) -- Pickled Fangtooth
	AddTrainerRef( "professions", "COOKING", 45569, 1355, 1430, 3026, 3399, 4210, 4552, 5159, 5482, 16676, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 45550, 46709 ) -- Baked Manta Ray
	AddTrainerRef( "professions", "COOKING", 46684, 1355, 3399, 4210, 5159, 5482, 16719, 18987, 19186, 26905, 26989, 28705, 29631, 33587, 33619, 46709 ) -- Charred Bear Kabobs
	AddTrainerRef( "professions", "COOKING", 46688, 1355, 3399, 4210, 5159, 5482, 16719, 18987, 19186, 26905, 26989, 28705, 29631, 33587, 33619, 46709 ) -- Juicy Bear Burger
	AddTrainerRef( "professions", "COOKING", 51296, 1355, 1430, 3026, 3399, 4210, 4552, 5159, 5482, 16676, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 45550, 46709 ) -- Grand Master Cook
	AddTrainerRef( "professions", "COOKING", 58065, 1355, 1430, 3026, 3399, 4210, 4552, 5159, 5482, 16676, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 45550, 46709 ) -- Dalaran Clam Chowder
	AddTrainerRef( "professions", "COOKING", 64358, 1355, 1430, 3026, 3399, 4210, 4552, 5159, 5482, 16676, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 45550, 46709 ) -- Black Jelly
	AddTrainerRef( "professions", "COOKING", 88006, 1355, 3399, 4210, 5159, 5482, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 46709 ) -- Blackened Surprise
	AddTrainerRef( "professions", "COOKING", 88015, 1355, 3399, 4210, 5159, 5482, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 46709 ) -- Darkbrew Lager
	AddTrainerRef( "professions", "COOKING", 88053, 1355, 3399, 4210, 5159, 5482, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 46709 ) -- Illustrious Grand Master Cook
	AddTrainerRef( "professions", "COOKING", 93741, 1355, 1430, 3399, 4210, 4552, 5159, 5482, 16719, 18987, 19186, 26905, 26953, 26989, 28705, 29631, 33587, 33619, 45550, 46709 ) -- Venison Jerky
	AddTrainerRef( "professions", "ENCHANTING",  7411, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Apprentice Enchanter
	AddTrainerRef( "professions", "ENCHANTING",  7412, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Journeyman Enchanter
	AddTrainerRef( "professions", "ENCHANTING",  7413, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Expert Enchanter
	AddTrainerRef( "professions", "ENCHANTING",  7420, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Chest - Minor Health
	AddTrainerRef( "professions", "ENCHANTING",  7426, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Chest - Minor Absorption
	AddTrainerRef( "professions", "ENCHANTING",  7454, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Cloak - Minor Resistance
	AddTrainerRef( "professions", "ENCHANTING",  7457, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Bracer - Minor Stamina
	AddTrainerRef( "professions", "ENCHANTING",  7745, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant 2H Weapon - Minor Impact
	AddTrainerRef( "professions", "ENCHANTING",  7748, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Chest - Lesser Health
	AddTrainerRef( "professions", "ENCHANTING",  7771, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Cloak - Minor Protection
	AddTrainerRef( "professions", "ENCHANTING",  7779, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Bracer - Minor Agility
	AddTrainerRef( "professions", "ENCHANTING",  7788, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Weapon - Minor Striking
	AddTrainerRef( "professions", "ENCHANTING",  7795, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Runed Silver Rod
	AddTrainerRef( "professions", "ENCHANTING",  7857, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Chest - Health
	AddTrainerRef( "professions", "ENCHANTING",  7861, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Cloak - Lesser Fire Resistance
	AddTrainerRef( "professions", "ENCHANTING",  7863, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Boots - Minor Stamina
	AddTrainerRef( "professions", "ENCHANTING", 13378, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Shield - Minor Stamina
	AddTrainerRef( "professions", "ENCHANTING", 13421, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Cloak - Lesser Protection
	AddTrainerRef( "professions", "ENCHANTING", 13485, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Shield - Lesser Spirit
	AddTrainerRef( "professions", "ENCHANTING", 13501, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Bracer - Lesser Stamina
	AddTrainerRef( "professions", "ENCHANTING", 13503, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Weapon - Lesser Striking
	AddTrainerRef( "professions", "ENCHANTING", 13529, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant 2H Weapon - Lesser Impact
	AddTrainerRef( "professions", "ENCHANTING", 13538, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Chest - Lesser Absorption
	AddTrainerRef( "professions", "ENCHANTING", 13607, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Chest - Mana
	AddTrainerRef( "professions", "ENCHANTING", 13622, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Bracer - Lesser Intellect
	AddTrainerRef( "professions", "ENCHANTING", 13626, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Chest - Minor Stats
	AddTrainerRef( "professions", "ENCHANTING", 13628, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Runed Golden Rod
	AddTrainerRef( "professions", "ENCHANTING", 13631, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Shield - Lesser Stamina
	AddTrainerRef( "professions", "ENCHANTING", 13635, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Cloak - Defense
	AddTrainerRef( "professions", "ENCHANTING", 13637, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Boots - Lesser Agility
	AddTrainerRef( "professions", "ENCHANTING", 13640, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Chest - Greater Health
	AddTrainerRef( "professions", "ENCHANTING", 13642, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Bracer - Spirit
	AddTrainerRef( "professions", "ENCHANTING", 13644, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Boots - Lesser Stamina
	AddTrainerRef( "professions", "ENCHANTING", 13646, 1317, 3011, 3345, 7949, 16725, 18773, 26990, 28693, 33610 ) -- Enchant Bracer - Lesser Deflection
	AddTrainerRef( "professions", "ENCHANTING", 13648, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Bracer - Stamina
	AddTrainerRef( "professions", "ENCHANTING", 13657, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Cloak - Fire Resistance
	AddTrainerRef( "professions", "ENCHANTING", 13659, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Shield - Spirit
	AddTrainerRef( "professions", "ENCHANTING", 13661, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Bracer - Strength
	AddTrainerRef( "professions", "ENCHANTING", 13663, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Chest - Greater Mana
	AddTrainerRef( "professions", "ENCHANTING", 13693, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Weapon - Striking
	AddTrainerRef( "professions", "ENCHANTING", 13695, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant 2H Weapon - Impact
	AddTrainerRef( "professions", "ENCHANTING", 13700, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Chest - Lesser Stats
	AddTrainerRef( "professions", "ENCHANTING", 13702, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Runed Truesilver Rod
	AddTrainerRef( "professions", "ENCHANTING", 13746, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Cloak - Greater Defense
	AddTrainerRef( "professions", "ENCHANTING", 13794, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Cloak - Resistance
	AddTrainerRef( "professions", "ENCHANTING", 13815, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Gloves - Agility
	AddTrainerRef( "professions", "ENCHANTING", 13822, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Bracer - Intellect
	AddTrainerRef( "professions", "ENCHANTING", 13836, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Boots - Stamina
	AddTrainerRef( "professions", "ENCHANTING", 13858, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Chest - Superior Health
	AddTrainerRef( "professions", "ENCHANTING", 13887, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Gloves - Strength
	AddTrainerRef( "professions", "ENCHANTING", 13890, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Boots - Minor Speed
	AddTrainerRef( "professions", "ENCHANTING", 13905, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Shield - Greater Spirit
	AddTrainerRef( "professions", "ENCHANTING", 13917, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Chest - Superior Mana
	AddTrainerRef( "professions", "ENCHANTING", 13920, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Artisan Enchanter
	AddTrainerRef( "professions", "ENCHANTING", 13935, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Boots - Agility
	AddTrainerRef( "professions", "ENCHANTING", 13937, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant 2H Weapon - Greater Impact
	AddTrainerRef( "professions", "ENCHANTING", 13939, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Bracer - Greater Strength
	AddTrainerRef( "professions", "ENCHANTING", 13941, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Chest - Stats
	AddTrainerRef( "professions", "ENCHANTING", 13943, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Weapon - Greater Striking
	AddTrainerRef( "professions", "ENCHANTING", 13948, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Gloves - Minor Haste
	AddTrainerRef( "professions", "ENCHANTING", 14293, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Lesser Magic Wand
	AddTrainerRef( "professions", "ENCHANTING", 14807, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Greater Magic Wand
	AddTrainerRef( "professions", "ENCHANTING", 14809, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Lesser Mystic Wand
	AddTrainerRef( "professions", "ENCHANTING", 14810, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Greater Mystic Wand
	AddTrainerRef( "professions", "ENCHANTING", 17180, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchanted Thorium Bar
	AddTrainerRef( "professions", "ENCHANTING", 17181, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchanted Leather
	AddTrainerRef( "professions", "ENCHANTING", 20008, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Bracer - Greater Intellect
	AddTrainerRef( "professions", "ENCHANTING", 20012, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Gloves - Greater Agility
	AddTrainerRef( "professions", "ENCHANTING", 20013, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Gloves - Greater Strength
	AddTrainerRef( "professions", "ENCHANTING", 20014, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Cloak - Greater Resistance
	AddTrainerRef( "professions", "ENCHANTING", 20016, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Shield - Vitality
	AddTrainerRef( "professions", "ENCHANTING", 20023, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Boots - Greater Agility
	AddTrainerRef( "professions", "ENCHANTING", 20028, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Chest - Major Mana
	AddTrainerRef( "professions", "ENCHANTING", 20051, 1317, 3011, 3345, 7949, 16725, 18773, 26990, 28693, 33610 ) -- Runed Arcanite Rod
	AddTrainerRef( "professions", "ENCHANTING", 27899, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Bracer - Brawn
	AddTrainerRef( "professions", "ENCHANTING", 27905, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Bracer - Stats
	AddTrainerRef( "professions", "ENCHANTING", 27944, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Shield - Tough Shield
	AddTrainerRef( "professions", "ENCHANTING", 27957, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Chest - Exceptional Health
	AddTrainerRef( "professions", "ENCHANTING", 27958, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Chest - Exceptional Mana
	AddTrainerRef( "professions", "ENCHANTING", 27961, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Cloak - Major Armor
	AddTrainerRef( "professions", "ENCHANTING", 28027, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Prismatic Sphere
	AddTrainerRef( "professions", "ENCHANTING", 28028, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Void Sphere
	AddTrainerRef( "professions", "ENCHANTING", 28029, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Master Enchanter
	AddTrainerRef( "professions", "ENCHANTING", 32664, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Runed Fel Iron Rod
	AddTrainerRef( "professions", "ENCHANTING", 32665, 1317, 3011, 3345, 7949, 16725, 18773, 26990, 28693, 33610 ) -- Runed Adamantite Rod
	AddTrainerRef( "professions", "ENCHANTING", 32667, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Runed Eternium Rod
	AddTrainerRef( "professions", "ENCHANTING", 33990, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Chest - Major Spirit
	AddTrainerRef( "professions", "ENCHANTING", 33991, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Chest - Restore Mana Prime
	AddTrainerRef( "professions", "ENCHANTING", 33993, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Gloves - Blasting
	AddTrainerRef( "professions", "ENCHANTING", 33995, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Gloves - Major Strength
	AddTrainerRef( "professions", "ENCHANTING", 33996, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Gloves - Assault
	AddTrainerRef( "professions", "ENCHANTING", 34001, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Bracer - Major Intellect
	AddTrainerRef( "professions", "ENCHANTING", 34002, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Bracer - Assault
	AddTrainerRef( "professions", "ENCHANTING", 34004, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Cloak - Greater Agility
	AddTrainerRef( "professions", "ENCHANTING", 42613, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Nexus Transformation
	AddTrainerRef( "professions", "ENCHANTING", 42615, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Small Prismatic Shard
	AddTrainerRef( "professions", "ENCHANTING", 44383, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Shield - Resilience
	AddTrainerRef( "professions", "ENCHANTING", 44484, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Gloves - Expertise
	AddTrainerRef( "professions", "ENCHANTING", 44488, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Gloves - Precision
	AddTrainerRef( "professions", "ENCHANTING", 44489, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Shield - Dodge
	AddTrainerRef( "professions", "ENCHANTING", 44492, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Chest - Mighty Health
	AddTrainerRef( "professions", "ENCHANTING", 44500, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Cloak - Superior Agility
	AddTrainerRef( "professions", "ENCHANTING", 44506, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Gloves - Gatherer
	AddTrainerRef( "professions", "ENCHANTING", 44508, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Boots - Greater Spirit
	AddTrainerRef( "professions", "ENCHANTING", 44509, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Chest - Greater Mana Restoration
	AddTrainerRef( "professions", "ENCHANTING", 44510, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Weapon - Exceptional Spirit
	AddTrainerRef( "professions", "ENCHANTING", 44513, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Gloves - Greater Assault
	AddTrainerRef( "professions", "ENCHANTING", 44528, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Boots - Greater Fortitude
	AddTrainerRef( "professions", "ENCHANTING", 44529, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Gloves - Major Agility
	AddTrainerRef( "professions", "ENCHANTING", 44555, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Bracers - Exceptional Intellect
	AddTrainerRef( "professions", "ENCHANTING", 44582, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Cloak - Spell Piercing
	AddTrainerRef( "professions", "ENCHANTING", 44584, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Boots - Greater Vitality
	AddTrainerRef( "professions", "ENCHANTING", 44589, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Boots - Superior Agility
	AddTrainerRef( "professions", "ENCHANTING", 44592, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Gloves - Exceptional Spellpower
	AddTrainerRef( "professions", "ENCHANTING", 44593, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Bracers - Major Spirit
	AddTrainerRef( "professions", "ENCHANTING", 44598, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Bracers - Expertise
	AddTrainerRef( "professions", "ENCHANTING", 44616, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Bracers - Greater Stats
	AddTrainerRef( "professions", "ENCHANTING", 44623, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Chest - Super Stats
	AddTrainerRef( "professions", "ENCHANTING", 44629, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Weapon - Exceptional Spellpower
	AddTrainerRef( "professions", "ENCHANTING", 44630, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant 2H Weapon - Greater Savagery
	AddTrainerRef( "professions", "ENCHANTING", 44633, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Weapon - Exceptional Agility
	AddTrainerRef( "professions", "ENCHANTING", 44635, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Bracers - Greater Spellpower
	AddTrainerRef( "professions", "ENCHANTING", 44636, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Ring - Greater Spellpower
	AddTrainerRef( "professions", "ENCHANTING", 44645, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Ring - Assault
	AddTrainerRef( "professions", "ENCHANTING", 47766, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Chest - Greater Dodge
	AddTrainerRef( "professions", "ENCHANTING", 47900, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Chest - Super Health
	AddTrainerRef( "professions", "ENCHANTING", 51313, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Grand Master Enchanter
	AddTrainerRef( "professions", "ENCHANTING", 59636, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Ring - Stamina
	AddTrainerRef( "professions", "ENCHANTING", 60606, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Boots - Assault
	AddTrainerRef( "professions", "ENCHANTING", 60609, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Cloak - Speed
	AddTrainerRef( "professions", "ENCHANTING", 60616, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Bracers - Striking
	AddTrainerRef( "professions", "ENCHANTING", 60619, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Runed Titanium Rod
	AddTrainerRef( "professions", "ENCHANTING", 60621, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Weapon - Greater Potency
	AddTrainerRef( "professions", "ENCHANTING", 60623, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Boots - Icewalker
	AddTrainerRef( "professions", "ENCHANTING", 60653, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Shield - Greater Intellect
	AddTrainerRef( "professions", "ENCHANTING", 60663, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Cloak - Major Agility
	AddTrainerRef( "professions", "ENCHANTING", 60668, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Gloves - Crusher
	AddTrainerRef( "professions", "ENCHANTING", 62959, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Staff - Spellpower
	AddTrainerRef( "professions", "ENCHANTING", 63746, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Enchant Boots - Lesser Accuracy
	AddTrainerRef( "professions", "ENCHANTING", 69412, 1317, 3011, 3345, 4616, 5157, 7949, 16633, 16725, 18773, 26954, 26990, 28693, 33583, 33610, 33633, 33676 ) -- Abyssal Shatter
	AddTrainerRef( "professions", "ENCHANTING", 74132, 1317, 3011, 3345, 5157, 7949, 16725, 18773, 26954, 26990, 28693, 33610, 33676 ) -- Enchant Gloves - Mastery
	AddTrainerRef( "professions", "ENCHANTING", 74189, 1317, 3011, 3345, 5157, 7949, 16725, 18773, 26954, 26990, 28693, 33610, 33676 ) -- Enchant Boots - Earthen Vitality
	AddTrainerRef( "professions", "ENCHANTING", 74191, 1317, 3011, 3345, 5157, 7949, 16725, 18773, 26954, 26990, 28693, 33610, 33676 ) -- Enchant Chest - Mighty Stats
	AddTrainerRef( "professions", "ENCHANTING", 74192, 1317, 3011, 3345, 5157, 7949, 16725, 18773, 26954, 26990, 28693, 33610, 33676 ) -- Enchant Cloak - Greater Spell Piercing
	AddTrainerRef( "professions", "ENCHANTING", 74193, 1317, 3011, 3345, 5157, 7949, 16725, 18773, 26954, 26990, 28693, 33610, 33676 ) -- Enchant Bracer - Speed
	AddTrainerRef( "professions", "ENCHANTING", 74195, 1317, 3011, 3345, 5157, 7949, 16725, 18773, 26954, 26990, 28693, 33610, 33676 ) -- Enchant Weapon - Mending
	AddTrainerRef( "professions", "ENCHANTING", 74197, 1317, 3011, 3345, 5157, 7949, 16725, 18773, 26954, 26990, 28693, 33610, 33676 ) -- Enchant Weapon - Avalanche
	AddTrainerRef( "professions", "ENCHANTING", 74198, 1317, 3011, 3345, 5157, 7949, 16725, 18773, 26954, 26990, 28693, 33610, 33676 ) -- Enchant Gloves - Haste
	AddTrainerRef( "professions", "ENCHANTING", 74199, 1317, 3011, 3345, 5157, 7949, 16725, 18773, 26954, 26990, 28693, 33610, 33676 ) -- Enchant Boots - Haste
	AddTrainerRef( "professions", "ENCHANTING", 74200, 1317, 3011, 3345, 5157, 7949, 16725, 18773, 26954, 26990, 28693, 33610, 33676 ) -- Enchant Chest - Stamina
	AddTrainerRef( "professions", "ENCHANTING", 74201, 1317, 3011, 3345, 5157, 7949, 16725, 18773, 26954, 26990, 28693, 33610, 33676 ) -- Enchant Bracer - Critical Strike
	AddTrainerRef( "professions", "ENCHANTING", 74202, 1317, 3011, 3345, 5157, 7949, 16725, 18773, 26954, 26990, 28693, 33610, 33676 ) -- Enchant Cloak - Intellect
	AddTrainerRef( "professions", "ENCHANTING", 74207, 1317, 3011, 3345, 5157, 7949, 16725, 18773, 26954, 26990, 28693, 33610, 33676 ) -- Enchant Shield - Protection
	AddTrainerRef( "professions", "ENCHANTING", 74211, 1317, 3011, 3345, 5157, 7949, 16725, 18773, 26954, 26990, 28693, 33610, 33676 ) -- Enchant Weapon - Elemental Slayer
	AddTrainerRef( "professions", "ENCHANTING", 74212, 1317, 3011, 3345, 5157, 7949, 16725, 18773, 26954, 26990, 28693, 33610, 33676 ) -- Enchant Gloves - Exceptional Strength
	AddTrainerRef( "professions", "ENCHANTING", 74213, 1317, 3011, 3345, 5157, 7949, 16725, 18773, 26954, 26990, 28693, 33610, 33676 ) -- Enchant Boots - Major Agility
	AddTrainerRef( "professions", "ENCHANTING", 74214, 1317, 3011, 3345, 5157, 7949, 16725, 18773, 26954, 26990, 28693, 33610, 33676 ) -- Enchant Chest - Mighty Resilience
	AddTrainerRef( "professions", "ENCHANTING", 74215, 1317, 3011, 3345, 5157, 7949, 16725, 18773, 26954, 26990, 28693, 33610, 33676 ) -- Enchant Ring - Strength
	AddTrainerRef( "professions", "ENCHANTING", 74216, 1317, 3011, 3345, 5157, 7949, 16725, 18773, 26954, 26990, 28693, 33610, 33676 ) -- Enchant Ring - Agility
	AddTrainerRef( "professions", "ENCHANTING", 74217, 1317, 3011, 3345, 5157, 7949, 16725, 18773, 26954, 26990, 28693, 33610, 33676 ) -- Enchant Ring - Intellect
	AddTrainerRef( "professions", "ENCHANTING", 74218, 1317, 3011, 3345, 5157, 7949, 16725, 18773, 26954, 26990, 28693, 33610, 33676 ) -- Enchant Ring - Greater Stamina
	AddTrainerRef( "professions", "ENCHANTING", 74220, 1317, 3011, 3345, 5157, 7949, 16725, 18773, 26954, 26990, 28693, 33610, 33676 ) -- Enchant Gloves - Greater Expertise
	AddTrainerRef( "professions", "ENCHANTING", 74223, 1317, 3011, 3345, 5157, 7949, 16725, 18773, 26954, 26990, 28693, 33610, 33676 ) -- Enchant Weapon - Hurricane
	AddTrainerRef( "professions", "ENCHANTING", 74225, 1317, 3011, 3345, 5157, 7949, 16725, 18773, 26954, 26990, 28693, 33610, 33676 ) -- Enchant Weapon - Heartsong
	AddTrainerRef( "professions", "ENCHANTING", 74226, 1317, 3011, 3345, 5157, 7949, 16725, 18773, 26954, 26990, 28693, 33610, 33676 ) -- Enchant Shield - Mastery
	AddTrainerRef( "professions", "ENCHANTING", 74229, 1317, 3011, 3345, 5157, 7949, 16725, 18773, 26954, 26990, 28693, 33610, 33676 ) -- Enchant Bracer - Dodge
	AddTrainerRef( "professions", "ENCHANTING", 74230, 1317, 3011, 3345, 5157, 7949, 16725, 18773, 26954, 26990, 28693, 33610, 33676 ) -- Enchant Cloak - Critical Strike
	AddTrainerRef( "professions", "ENCHANTING", 74231, 1317, 3011, 3345, 5157, 7949, 16725, 18773, 26954, 26990, 28693, 33610, 33676 ) -- Enchant Chest - Exceptional Spirit
	AddTrainerRef( "professions", "ENCHANTING", 74232, 1317, 3011, 3345, 5157, 7949, 16725, 18773, 26954, 26990, 28693, 33610, 33676 ) -- Enchant Bracer - Precision
	AddTrainerRef( "professions", "ENCHANTING", 74234, 1317, 3011, 3345, 5157, 7949, 16725, 18773, 26954, 26990, 28693, 33610, 33676 ) -- Enchant Cloak - Protection
	AddTrainerRef( "professions", "ENCHANTING", 74235, 1317, 3011, 3345, 5157, 7949, 16725, 18773, 26954, 26990, 28693, 33610, 33676 ) -- Enchant Off-Hand - Superior Intellect
	AddTrainerRef( "professions", "ENCHANTING", 74236, 1317, 3011, 3345, 5157, 7949, 16725, 18773, 26954, 26990, 28693, 33610, 33676 ) -- Enchant Boots - Precision
	AddTrainerRef( "professions", "ENCHANTING", 74237, 1317, 3011, 3345, 5157, 7949, 16725, 18773, 26954, 26990, 28693, 33610, 33676 ) -- Enchant Bracer - Exceptional Spirit
	AddTrainerRef( "professions", "ENCHANTING", 74238, 1317, 3011, 3345, 5157, 7949, 16725, 18773, 26954, 26990, 28693, 33610, 33676 ) -- Enchant Boots - Mastery
	AddTrainerRef( "professions", "ENCHANTING", 74239, 1317, 3011, 3345, 5157, 7949, 16725, 18773, 26954, 26990, 28693, 33610, 33676 ) -- Enchant Bracer - Greater Expertise
	AddTrainerRef( "professions", "ENCHANTING", 74240, 1317, 3011, 3345, 5157, 7949, 16725, 18773, 26954, 26990, 28693, 33610, 33676 ) -- Enchant Cloak - Greater Intellect
	AddTrainerRef( "professions", "ENCHANTING", 74258, 1317, 3011, 3345, 5157, 7949, 16725, 18773, 26954, 26990, 28693, 33610, 33676 ) -- Illustrious Grand Master Enchanter
	AddTrainerRef( "professions", "ENCHANTING", 95471, 1317, 3011, 3345, 5157, 7949, 16725, 18773, 26954, 26990, 28693, 33610, 33676 ) -- Enchant 2H Weapon - Mighty Agility
	AddTrainerRef( "professions", "ENGINEERING",  3922, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Handful of Copper Bolts
	AddTrainerRef( "professions", "ENGINEERING",  3923, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Rough Copper Bomb
	AddTrainerRef( "professions", "ENGINEERING",  3924, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Copper Tube
	AddTrainerRef( "professions", "ENGINEERING",  3925, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Rough Boomstick
	AddTrainerRef( "professions", "ENGINEERING",  3926, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Copper Modulator
	AddTrainerRef( "professions", "ENGINEERING",  3929, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Coarse Blasting Powder
	AddTrainerRef( "professions", "ENGINEERING",  3931, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Coarse Dynamite
	AddTrainerRef( "professions", "ENGINEERING",  3932, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Target Dummy
	AddTrainerRef( "professions", "ENGINEERING",  3934, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Flying Tiger Goggles
	AddTrainerRef( "professions", "ENGINEERING",  3936, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Deadly Blunderbuss
	AddTrainerRef( "professions", "ENGINEERING",  3937, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Large Copper Bomb
	AddTrainerRef( "professions", "ENGINEERING",  3938, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Bronze Tube
	AddTrainerRef( "professions", "ENGINEERING",  3939, 5518, 18775, 26907, 26991, 28697, 33611, 33677 ) -- Lovingly Crafted Boomstick
	AddTrainerRef( "professions", "ENGINEERING",  3941, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Small Bronze Bomb
	AddTrainerRef( "professions", "ENGINEERING",  3942, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Whirring Bronze Gizmo
	AddTrainerRef( "professions", "ENGINEERING",  3945, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Heavy Blasting Powder
	AddTrainerRef( "professions", "ENGINEERING",  3946, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Heavy Dynamite
	AddTrainerRef( "professions", "ENGINEERING",  3949, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Silver-plated Shotgun
	AddTrainerRef( "professions", "ENGINEERING",  3950, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Big Bronze Bomb
	AddTrainerRef( "professions", "ENGINEERING",  3953, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Bronze Framework
	AddTrainerRef( "professions", "ENGINEERING",  3955, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Explosive Sheep
	AddTrainerRef( "professions", "ENGINEERING",  3956, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Green Tinted Goggles
	AddTrainerRef( "professions", "ENGINEERING",  3958, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Iron Strut
	AddTrainerRef( "professions", "ENGINEERING",  3961, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Gyrochronatom
	AddTrainerRef( "professions", "ENGINEERING",  3962, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Iron Grenade
	AddTrainerRef( "professions", "ENGINEERING",  3963, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Compact Harvest Reaper Kit
	AddTrainerRef( "professions", "ENGINEERING",  3965, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Advanced Target Dummy
	AddTrainerRef( "professions", "ENGINEERING",  3967, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Big Iron Bomb
	AddTrainerRef( "professions", "ENGINEERING",  3973, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Silver Contact
	AddTrainerRef( "professions", "ENGINEERING",  3977, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Crude Scope
	AddTrainerRef( "professions", "ENGINEERING",  3978, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Standard Scope
	AddTrainerRef( "professions", "ENGINEERING",  4036, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Apprentice Engineer
	AddTrainerRef( "professions", "ENGINEERING",  4037, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Journeyman Engineer
	AddTrainerRef( "professions", "ENGINEERING",  4038, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Expert Engineer
	AddTrainerRef( "professions", "ENGINEERING",  6458, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Ornate Spyglass
	AddTrainerRef( "professions", "ENGINEERING",  7430, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Arclight Spanner
	AddTrainerRef( "professions", "ENGINEERING",  8334, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Practice Lock
	AddTrainerRef( "professions", "ENGINEERING",  8895, 29513 ) -- Goblin Rocket Boots
	AddTrainerRef( "professions", "ENGINEERING",  9271, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Aquadynamic Fish Attractor
	AddTrainerRef( "professions", "ENGINEERING", 12584, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Gold Power Core
	AddTrainerRef( "professions", "ENGINEERING", 12585, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Solid Blasting Powder
	AddTrainerRef( "professions", "ENGINEERING", 12586, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Solid Dynamite
	AddTrainerRef( "professions", "ENGINEERING", 12589, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Mithril Tube
	AddTrainerRef( "professions", "ENGINEERING", 12590, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Gyromatic Micro-Adjustor
	AddTrainerRef( "professions", "ENGINEERING", 12591, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Unstable Trigger
	AddTrainerRef( "professions", "ENGINEERING", 12594, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Fire Goggles
	AddTrainerRef( "professions", "ENGINEERING", 12595, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Mithril Blunderbuss
	AddTrainerRef( "professions", "ENGINEERING", 12599, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Mithril Casing
	AddTrainerRef( "professions", "ENGINEERING", 12603, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Mithril Frag Bomb
	AddTrainerRef( "professions", "ENGINEERING", 12615, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Spellpower Goggles Xtreme
	AddTrainerRef( "professions", "ENGINEERING", 12617, 5518, 18775, 26907, 26991, 28697, 33611, 33677 ) -- Deepdive Helmet
	AddTrainerRef( "professions", "ENGINEERING", 12618, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Rose Colored Goggles
	AddTrainerRef( "professions", "ENGINEERING", 12619, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Hi-Explosive Bomb
	AddTrainerRef( "professions", "ENGINEERING", 12622, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Green Lens
	AddTrainerRef( "professions", "ENGINEERING", 12656, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Artisan Engineer
	AddTrainerRef( "professions", "ENGINEERING", 12715, 29513 ) -- Goblin Rocket Fuel Recipe
	AddTrainerRef( "professions", "ENGINEERING", 12716, 29513 ) -- Goblin Mortar
	AddTrainerRef( "professions", "ENGINEERING", 12717, 29513 ) -- Goblin Mining Helmet
	AddTrainerRef( "professions", "ENGINEERING", 12718, 29513 ) -- Goblin Construction Helmet
	AddTrainerRef( "professions", "ENGINEERING", 12754, 29513 ) -- The Big One
	AddTrainerRef( "professions", "ENGINEERING", 12755, 29513 ) -- Goblin Bomb Dispenser
	AddTrainerRef( "professions", "ENGINEERING", 12758, 29513 ) -- Goblin Rocket Helmet
	AddTrainerRef( "professions", "ENGINEERING", 12759, 29514 ) -- Gnomish Death Ray
	AddTrainerRef( "professions", "ENGINEERING", 12760, 29513 ) -- Goblin Sapper Charge
	AddTrainerRef( "professions", "ENGINEERING", 12895, 29514 ) -- Inlaid Mithril Cylinder Plans
	AddTrainerRef( "professions", "ENGINEERING", 12897, 29514 ) -- Gnomish Goggles
	AddTrainerRef( "professions", "ENGINEERING", 12899, 29514 ) -- Gnomish Shrink Ray
	AddTrainerRef( "professions", "ENGINEERING", 12902, 29514 ) -- Gnomish Net-o-Matic Projector
	AddTrainerRef( "professions", "ENGINEERING", 12903, 29514 ) -- Gnomish Harm Prevention Belt
	AddTrainerRef( "professions", "ENGINEERING", 12905, 29514 ) -- Gnomish Rocket Boots
	AddTrainerRef( "professions", "ENGINEERING", 12906, 29514 ) -- Gnomish Battle Chicken
	AddTrainerRef( "professions", "ENGINEERING", 12907, 29514 ) -- Gnomish Mind Control Cap
	AddTrainerRef( "professions", "ENGINEERING", 12908, 29513 ) -- Goblin Dragon Gun
	AddTrainerRef( "professions", "ENGINEERING", 15255, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Mechanical Repair Kit
	AddTrainerRef( "professions", "ENGINEERING", 19567, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Salt Shaker
	AddTrainerRef( "professions", "ENGINEERING", 19788, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Dense Blasting Powder
	AddTrainerRef( "professions", "ENGINEERING", 19790, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Thorium Grenade
	AddTrainerRef( "professions", "ENGINEERING", 19791, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Thorium Widget
	AddTrainerRef( "professions", "ENGINEERING", 19792, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Thorium Rifle
	AddTrainerRef( "professions", "ENGINEERING", 19794, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Spellpower Goggles Xtreme Plus
	AddTrainerRef( "professions", "ENGINEERING", 19795, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Thorium Tube
	AddTrainerRef( "professions", "ENGINEERING", 19825, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Master Engineer's Goggles
	AddTrainerRef( "professions", "ENGINEERING", 23070, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Dense Dynamite
	AddTrainerRef( "professions", "ENGINEERING", 23071, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Truesilver Transformer
	AddTrainerRef( "professions", "ENGINEERING", 30303, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Elemental Blasting Powder
	AddTrainerRef( "professions", "ENGINEERING", 30304, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Fel Iron Casing
	AddTrainerRef( "professions", "ENGINEERING", 30305, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Handful of Fel Iron Bolts
	AddTrainerRef( "professions", "ENGINEERING", 30306, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Adamantite Frame
	AddTrainerRef( "professions", "ENGINEERING", 30307, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Hardened Adamantite Tube
	AddTrainerRef( "professions", "ENGINEERING", 30308, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Khorium Power Core
	AddTrainerRef( "professions", "ENGINEERING", 30309, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Felsteel Stabilizer
	AddTrainerRef( "professions", "ENGINEERING", 30310, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Fel Iron Bomb
	AddTrainerRef( "professions", "ENGINEERING", 30311, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Adamantite Grenade
	AddTrainerRef( "professions", "ENGINEERING", 30312, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Fel Iron Musket
	AddTrainerRef( "professions", "ENGINEERING", 30350, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Master Engineer
	AddTrainerRef( "professions", "ENGINEERING", 30558, 29513 ) -- The Bigger One
	AddTrainerRef( "professions", "ENGINEERING", 30560, 29513 ) -- Super Sapper Charge
	AddTrainerRef( "professions", "ENGINEERING", 30563, 29513 ) -- Goblin Rocket Launcher
	AddTrainerRef( "professions", "ENGINEERING", 30565, 29513 ) -- Foreman's Enchanted Helmet
	AddTrainerRef( "professions", "ENGINEERING", 30566, 29513 ) -- Foreman's Reinforced Helmet
	AddTrainerRef( "professions", "ENGINEERING", 30568, 29514 ) -- Gnomish Flame Turret
	AddTrainerRef( "professions", "ENGINEERING", 30569, 29514 ) -- Gnomish Poultryizer
	AddTrainerRef( "professions", "ENGINEERING", 30570, 29514 ) -- Nigh-Invulnerability Belt
	AddTrainerRef( "professions", "ENGINEERING", 30574, 29514 ) -- Gnomish Power Goggles
	AddTrainerRef( "professions", "ENGINEERING", 30575, 29514 ) -- Gnomish Battle Goggles
	AddTrainerRef( "professions", "ENGINEERING", 39971, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Icy Blasting Primers
	AddTrainerRef( "professions", "ENGINEERING", 39973, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Frost Grenade
	AddTrainerRef( "professions", "ENGINEERING", 40274, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33611, 33634, 33677 ) -- Furious Gizmatic Goggles
	AddTrainerRef( "professions", "ENGINEERING", 41307, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Gyro-balanced Khorium Destroyer
	AddTrainerRef( "professions", "ENGINEERING", 41311, 5518, 28697 ) -- Justicebringer 2000 Specs
	AddTrainerRef( "professions", "ENGINEERING", 41312, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33611, 33634, 33677 ) -- Tankatronic Goggles
	AddTrainerRef( "professions", "ENGINEERING", 41314, 5174, 5518, 28697, 33586 ) -- Surestrike Goggles v2.0
	AddTrainerRef( "professions", "ENGINEERING", 41315, 5174, 5518, 28697, 33586 ) -- Gadgetstorm Goggles
	AddTrainerRef( "professions", "ENGINEERING", 41316, 5174, 5518, 28697, 33586 ) -- Living Replicator Specs
	AddTrainerRef( "professions", "ENGINEERING", 41317, 5174, 5518, 26991, 33586, 33677 ) -- Deathblow X11 Goggles
	AddTrainerRef( "professions", "ENGINEERING", 41318, 26991 ) -- Wonderheal XT40 Shades
	AddTrainerRef( "professions", "ENGINEERING", 41319, 26991 ) -- Magnified Moon Specs
	AddTrainerRef( "professions", "ENGINEERING", 41320, 5174, 5518, 28697, 33586, 33611 ) -- Destruction Holo-gogs
	AddTrainerRef( "professions", "ENGINEERING", 41321, 5174, 5518, 28697, 33586 ) -- Powerheal 4000 Lens
	AddTrainerRef( "professions", "ENGINEERING", 44155, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Flying Machine
	AddTrainerRef( "professions", "ENGINEERING", 44157, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Turbo-Charged Flying Machine
	AddTrainerRef( "professions", "ENGINEERING", 51306, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Grand Master Engineer
	AddTrainerRef( "professions", "ENGINEERING", 53281, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Volatile Blasting Trigger
	AddTrainerRef( "professions", "ENGINEERING", 54353, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Mark \"S\" Boomstick
	AddTrainerRef( "professions", "ENGINEERING", 54736, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Personal Electromagnetic Pulse Generator
	AddTrainerRef( "professions", "ENGINEERING", 54793, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Frag Belt
	AddTrainerRef( "professions", "ENGINEERING", 54998, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Hand-Mounted Pyro Rocket
	AddTrainerRef( "professions", "ENGINEERING", 54999, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Hyperspeed Accelerators
	AddTrainerRef( "professions", "ENGINEERING", 55002, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Flexweave Underlay
	AddTrainerRef( "professions", "ENGINEERING", 55016, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Nitro Boosts
	AddTrainerRef( "professions", "ENGINEERING", 56349, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Handful of Cobalt Bolts
	AddTrainerRef( "professions", "ENGINEERING", 56459, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Hammer Pick
	AddTrainerRef( "professions", "ENGINEERING", 56460, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Cobalt Frag Bomb
	AddTrainerRef( "professions", "ENGINEERING", 56461, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Bladed Pickaxe
	AddTrainerRef( "professions", "ENGINEERING", 56462, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Gnomish Army Knife
	AddTrainerRef( "professions", "ENGINEERING", 56463, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Explosive Decoy
	AddTrainerRef( "professions", "ENGINEERING", 56464, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Overcharged Capacitor
	AddTrainerRef( "professions", "ENGINEERING", 56465, 5518, 28697 ) -- Mechanized Snow Goggles
	AddTrainerRef( "professions", "ENGINEERING", 56466, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Sonic Booster
	AddTrainerRef( "professions", "ENGINEERING", 56467, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Noise Machine
	AddTrainerRef( "professions", "ENGINEERING", 56468, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Box of Bombs
	AddTrainerRef( "professions", "ENGINEERING", 56469, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Gnomish Lightning Generator
	AddTrainerRef( "professions", "ENGINEERING", 56470, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Sun Scope
	AddTrainerRef( "professions", "ENGINEERING", 56471, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Froststeel Tube
	AddTrainerRef( "professions", "ENGINEERING", 56472, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- MOLL-E
	AddTrainerRef( "professions", "ENGINEERING", 56473, 29514 ) -- Gnomish X-Ray Specs
	AddTrainerRef( "professions", "ENGINEERING", 56476, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Healing Injector Kit
	AddTrainerRef( "professions", "ENGINEERING", 56477, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Mana Injector Kit
	AddTrainerRef( "professions", "ENGINEERING", 56478, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Heartseeker Scope
	AddTrainerRef( "professions", "ENGINEERING", 56479, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Armor Plated Combat Shotgun
	AddTrainerRef( "professions", "ENGINEERING", 56480, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33611, 33634, 33677 ) -- Armored Titanium Goggles
	AddTrainerRef( "professions", "ENGINEERING", 56481, 5174, 5518, 26991, 33586, 33677 ) -- Weakness Spectralizers
	AddTrainerRef( "professions", "ENGINEERING", 56483, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33611, 33634, 33677 ) -- Charged Titanium Specs
	AddTrainerRef( "professions", "ENGINEERING", 56484, 5174, 5518, 28697, 33586, 33611 ) -- Visage Liquification Goggles
	AddTrainerRef( "professions", "ENGINEERING", 56486, 26991 ) -- Greensight Gogs
	AddTrainerRef( "professions", "ENGINEERING", 56487, 5174, 5518, 28697, 33586 ) -- Electroflux Sight Enhancers
	AddTrainerRef( "professions", "ENGINEERING", 56514, 29513 ) -- Global Thermal Sapper Charge
	AddTrainerRef( "professions", "ENGINEERING", 56574, 5174, 5518, 28697, 33586 ) -- Truesight Ice Blinders
	AddTrainerRef( "professions", "ENGINEERING", 60874, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Nesingwary 4000
	AddTrainerRef( "professions", "ENGINEERING", 61471, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Diamond-cut Refractor Scope
	AddTrainerRef( "professions", "ENGINEERING", 61481, 5518, 33677 ) -- Mechanized Snow Goggles
	AddTrainerRef( "professions", "ENGINEERING", 61482, 1676, 1702, 5174, 5518, 16726, 26991, 28697, 33586 ) -- Mechanized Snow Goggles
	AddTrainerRef( "professions", "ENGINEERING", 61483, 1676, 5174, 5518, 11017, 18775, 26907, 26955, 26991, 28697, 33611, 33634, 33677 ) -- Mechanized Snow Goggles
	AddTrainerRef( "professions", "ENGINEERING", 62271, 5518, 28697 ) -- Unbreakable Healing Amplifiers
	AddTrainerRef( "professions", "ENGINEERING", 63750, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- High-powered Flashlight
	AddTrainerRef( "professions", "ENGINEERING", 63765, 5174, 5518, 11017, 28697, 33586, 33611, 33634, 33677 ) -- Springy Arachnoweave
	AddTrainerRef( "professions", "ENGINEERING", 63770, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Reticulated Armor Webbing
	AddTrainerRef( "professions", "ENGINEERING", 67326, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Goblin Beam Welder
	AddTrainerRef( "professions", "ENGINEERING", 67839, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Mind Amplification Dish
	AddTrainerRef( "professions", "ENGINEERING", 67920, 1676, 1702, 5174, 5518, 11017, 16726, 18775, 26907, 26955, 26991, 28697, 33586, 33611, 33634, 33677 ) -- Wormhole Generator: Northrend
	AddTrainerRef( "professions", "ENGINEERING", 81714, 1676, 5174, 5518, 18775, 26907, 26955, 26991, 33611, 33677 ) -- Reinforced Bio-Optic Killshades
	AddTrainerRef( "professions", "ENGINEERING", 81715, 5518 ) -- Specialized Bio-Optic Killshades
	AddTrainerRef( "professions", "ENGINEERING", 81716, 5518, 28697 ) -- Deadly Bio-Optic Killshades
	AddTrainerRef( "professions", "ENGINEERING", 81720, 5518, 28697 ) -- Energized Bio-Optic Killshades
	AddTrainerRef( "professions", "ENGINEERING", 81722, 5518, 33677 ) -- Agile Bio-Optic Killshades
	AddTrainerRef( "professions", "ENGINEERING", 81725, 5518, 28697 ) -- Lightweight Bio-Optic Killshades
	AddTrainerRef( "professions", "ENGINEERING", 82774, 1676, 5174, 5518, 18775, 26907, 26955, 26991, 28697, 33611, 33677 ) -- Illustrious Grand Master Engineer
	AddTrainerRef( "professions", "ENGINEERING", 84403, 1676, 5174, 5518, 18775, 26907, 26955, 26991, 28697, 33611, 33677 ) -- Handful of Obsidium Bolts
	AddTrainerRef( "professions", "ENGINEERING", 84406, 1676, 5174, 5518, 18775, 26907, 26955, 26991, 28697, 33611, 33677 ) -- Authentic Jr. Engineer Goggles
	AddTrainerRef( "professions", "ENGINEERING", 84408, 1676, 5174, 5518, 18775, 26907, 26955, 26991, 28697, 33611, 33677 ) -- R19 Threatfinder
	AddTrainerRef( "professions", "ENGINEERING", 84409, 1676, 5174, 5518, 18775, 26907, 26955, 26991, 28697, 33611, 33677 ) -- Volatile Seaforium Blastpack
	AddTrainerRef( "professions", "ENGINEERING", 84410, 1676, 5174, 5518, 18775, 26907, 26955, 26991, 28697, 33611, 33677 ) -- Safety Catch Removal Kit
	AddTrainerRef( "professions", "ENGINEERING", 84411, 1676, 5174, 5518, 18775, 26907, 26955, 26991, 28697, 33611, 33677 ) -- High-Powered Bolt Gun
	AddTrainerRef( "professions", "ENGINEERING", 84412, 29513 ) -- Personal World Destroyer
	AddTrainerRef( "professions", "ENGINEERING", 84413, 29514 ) -- De-Weaponized Mechanical Companion
	AddTrainerRef( "professions", "ENGINEERING", 84415, 1676, 5174, 5518, 18775, 26907, 26955, 26991, 28697, 33611, 33677 ) -- Lure Master Tackle Box
	AddTrainerRef( "professions", "ENGINEERING", 84416, 1676, 5174, 5518, 18775, 26907, 26955, 26991, 28697, 33611, 33677 ) -- Elementium Toolbox
	AddTrainerRef( "professions", "ENGINEERING", 84417, 1676, 5174, 5518, 18775, 26907, 26955, 26991, 28697, 33611, 33677 ) -- Volatile Thunderstick
	AddTrainerRef( "professions", "ENGINEERING", 84418, 1676, 5174, 5518, 18775, 26907, 26955, 26991, 28697, 33611, 33677 ) -- Elementium Dragonling
	AddTrainerRef( "professions", "ENGINEERING", 84420, 1676, 5174, 5518, 18775, 26907, 26955, 26991, 28697, 33611, 33677 ) -- Finely-Tuned Throat Needler
	AddTrainerRef( "professions", "ENGINEERING", 84421, 1676, 5174, 5518, 18775, 26907, 26955, 26991, 28697, 33611, 33677 ) -- Loot-a-Rang
	AddTrainerRef( "professions", "ENGINEERING", 84428, 1676, 5174, 5518, 18775, 26907, 26955, 26991, 28697, 33611, 33677 ) -- Gnomish X-Ray Scope
	AddTrainerRef( "professions", "ENGINEERING", 84429, 1676, 5174, 5518, 18775, 26907, 26955, 26991, 28697, 33611, 33677 ) -- Goblin Barbecue
	AddTrainerRef( "professions", "ENGINEERING", 84430, 1676, 5174, 5518, 18775, 26907, 26955, 26991, 28697, 33611, 33677 ) -- Heat-Treated Spinning Lure
	AddTrainerRef( "professions", "ENGINEERING", 84431, 1676, 5174, 5518, 18775, 26907, 26955, 26991, 28697, 33611, 33677 ) -- Overpowered Chicken Splitter
	AddTrainerRef( "professions", "ENGINEERING", 84432, 1676, 5174, 5518, 18775, 26907, 26955, 26991, 28697, 33611, 33677 ) -- Kickback 5000
	AddTrainerRef( "professions", "ENGINEERING", 94748, 1676, 5174, 5518, 18775, 26907, 26955, 26991, 28697, 33611, 33677 ) -- Electrified Ether
	AddTrainerRef( "professions", "ENGINEERING", 95703, 1676, 5174, 5518, 18775, 26907, 26955, 26991, 28697, 33611, 33677 ) -- Electrostatic Condenser
	AddTrainerRef( "professions", "ENGINEERING", 95705, 29514 ) -- Gnomish Gravity Well
	AddTrainerRef( "professions", "ENGINEERING", 95707, 29513 ) -- Big Daddy
	AddTrainerRef( "professions", "FIRSTAID",  3273, 2326, 2327, 2329, 2798, 3181, 4211, 4591, 5150, 5943, 16662, 16731, 18990, 19184, 22477, 23734, 26956, 26992, 28706, 33589, 33621, 36615, 45540 ) -- Apprentice First Aid
	AddTrainerRef( "professions", "FIRSTAID",  3274, 2326, 2327, 2329, 2798, 3181, 4211, 4591, 5150, 5943, 16662, 16731, 18990, 19184, 22477, 23734, 26956, 26992, 28706, 33589, 33621, 36615, 45540 ) -- Journeyman First Aid
	AddTrainerRef( "professions", "FIRSTAID",  3276, 2326, 2327, 2329, 2798, 3181, 4211, 4591, 5150, 5943, 16662, 16731, 18990, 19184, 22477, 23734, 26956, 26992, 28706, 33589, 33621, 36615, 45540 ) -- Heavy Linen Bandage
	AddTrainerRef( "professions", "FIRSTAID",  3277, 2326, 2327, 2329, 2798, 3181, 4211, 4591, 5150, 5943, 16662, 16731, 18990, 19184, 22477, 23734, 26956, 26992, 28706, 33589, 33621, 36615, 45540 ) -- Wool Bandage
	AddTrainerRef( "professions", "FIRSTAID",  3278, 2326, 2327, 2329, 2798, 3181, 4211, 4591, 5150, 5943, 16662, 16731, 18990, 19184, 22477, 23734, 26956, 26992, 28706, 33589, 33621, 36615, 45540 ) -- Heavy Wool Bandage
	AddTrainerRef( "professions", "FIRSTAID",  7924, 2326, 2327, 2329, 2798, 3181, 4211, 4591, 5150, 5943, 16662, 16731, 18990, 19184, 22477, 23734, 26956, 26992, 28706, 33589, 33621, 36615, 45540 ) -- Expert First Aid
	AddTrainerRef( "professions", "FIRSTAID",  7928, 2326, 2327, 2329, 2798, 3181, 4211, 4591, 5150, 5943, 16662, 16731, 18990, 19184, 22477, 23734, 26956, 26992, 28706, 33589, 33621, 36615, 45540 ) -- Silk Bandage
	AddTrainerRef( "professions", "FIRSTAID",  7929, 2326, 2327, 2329, 2798, 3181, 4211, 4591, 5150, 5943, 16662, 16731, 18990, 19184, 22477, 23734, 26956, 26992, 28706, 33589, 33621, 36615, 45540 ) -- Heavy Silk Bandage
	AddTrainerRef( "professions", "FIRSTAID",  7934, 2326, 2327, 2329, 2798, 3181, 4211, 4591, 5150, 5943, 16662, 16731, 18990, 19184, 22477, 23734, 26956, 26992, 28706, 33589, 33621, 36615, 45540 ) -- Anti-Venom
	AddTrainerRef( "professions", "FIRSTAID", 10840, 2326, 2327, 2329, 2798, 3181, 4211, 4591, 5150, 5943, 16662, 16731, 18990, 19184, 22477, 23734, 26956, 26992, 28706, 33589, 33621, 36615, 45540 ) -- Mageweave Bandage
	AddTrainerRef( "professions", "FIRSTAID", 10841, 2326, 2327, 2329, 2798, 3181, 4211, 4591, 5150, 5943, 16662, 16731, 18990, 19184, 22477, 23734, 26956, 26992, 28706, 33589, 33621, 36615, 45540 ) -- Heavy Mageweave Bandage
	AddTrainerRef( "professions", "FIRSTAID", 10846, 2326, 2327, 2329, 2798, 3181, 4211, 4591, 5150, 5943, 16662, 16731, 18990, 19184, 22477, 23734, 26956, 26992, 28706, 33589, 33621, 36615, 45540 ) -- Artisan First Aid
	AddTrainerRef( "professions", "FIRSTAID", 18629, 2326, 2327, 2329, 2798, 3181, 4211, 4591, 5150, 5943, 16662, 16731, 18990, 19184, 22477, 23734, 26956, 26992, 28706, 33589, 33621, 36615, 45540 ) -- Runecloth Bandage
	AddTrainerRef( "professions", "FIRSTAID", 18630, 2326, 2327, 2329, 2798, 3181, 4211, 4591, 5150, 5943, 16662, 16731, 18990, 19184, 22477, 23734, 26956, 26992, 28706, 33589, 33621, 36615, 45540 ) -- Heavy Runecloth Bandage
	AddTrainerRef( "professions", "FIRSTAID", 27028, 2326, 2327, 2329, 2798, 3181, 4211, 4591, 5150, 5943, 16662, 16731, 18990, 19184, 22477, 23734, 26956, 26992, 28706, 33589, 33621, 36615, 45540 ) -- Master First Aid
	AddTrainerRef( "professions", "FIRSTAID", 27032, 2326, 2327, 2329, 2798, 3181, 4211, 4591, 5150, 5943, 16662, 16731, 18990, 19184, 22477, 23734, 26956, 26992, 28706, 33589, 33621, 36615, 45540 ) -- Netherweave Bandage
	AddTrainerRef( "professions", "FIRSTAID", 27033, 2326, 2327, 2329, 2798, 3181, 4211, 4591, 5150, 5943, 16662, 16731, 18990, 19184, 22477, 23734, 26956, 26992, 28706, 33589, 33621, 36615, 45540 ) -- Heavy Netherweave Bandage
	AddTrainerRef( "professions", "FIRSTAID", 45542, 2326, 2327, 2329, 2798, 3181, 4211, 4591, 5150, 5943, 16662, 16731, 18990, 19184, 22477, 23734, 26956, 26992, 28706, 33589, 33621, 36615, 45540 ) -- Grand Master First Aid
	AddTrainerRef( "professions", "FIRSTAID", 45545, 2326, 2327, 2329, 2798, 3181, 4211, 4591, 5150, 5943, 16662, 16731, 18990, 19184, 22477, 23734, 26956, 26992, 28706, 33589, 33621, 36615, 45540 ) -- Frostweave Bandage
	AddTrainerRef( "professions", "FIRSTAID", 45546, 2326, 2327, 2329, 2798, 3181, 4211, 4591, 5150, 5943, 16662, 16731, 18990, 19184, 22477, 23734, 26956, 26992, 28706, 33589, 33621, 36615, 45540 ) -- Heavy Frostweave Bandage
	AddTrainerRef( "professions", "FIRSTAID", 74556, 2327, 4211, 5150, 16731, 18990, 19184, 22477, 23734, 26956, 26992, 28706, 33589, 33621, 36615, 45540 ) -- Embersilk Bandage
	AddTrainerRef( "professions", "FIRSTAID", 74557, 2327, 4211, 5150, 16731, 18990, 19184, 22477, 23734, 26956, 26992, 28706, 33589, 33621, 36615, 45540 ) -- Heavy Embersilk Bandage
	AddTrainerRef( "professions", "FIRSTAID", 74558, 2327, 4211, 5150, 16731, 18990, 19184, 22477, 23734, 26956, 26992, 28706, 33589, 33621, 36615, 45540 ) -- Field Bandage: Dense Embersilk
	AddTrainerRef( "professions", "FIRSTAID", 74559, 2327, 4211, 5150, 16731, 18990, 19184, 22477, 23734, 26956, 26992, 28706, 33589, 33621, 36615, 45540 ) -- Illustrious Grand Master First Aid
	AddTrainerRef( "professions", "FIRSTAID", 88893, 2327, 4211, 5150, 16731, 18990, 19184, 22477, 23734, 26956, 26992, 28706, 33589, 33621, 36615, 45540 ) -- Dense Embersilk Bandage
	AddTrainerRef( "professions", "FISHING",  7620, 1683, 1700, 2834, 3028, 3179, 3332, 3607, 4156, 4573, 5161, 5493, 5690, 5941, 7946, 16774, 16780, 26909, 26993, 28742, 33623, 44975 ) -- Apprentice Fishing
	AddTrainerRef( "professions", "FISHING",  7731, 1683, 1700, 2834, 3028, 3179, 3332, 3607, 4156, 4573, 5161, 5493, 5690, 5941, 7946, 16774, 16780, 26909, 26993, 28742, 33623, 44975 ) -- Journeyman Fishing
	AddTrainerRef( "professions", "FISHING",  7732, 1683, 1700, 2834, 3028, 3179, 3332, 3607, 4156, 4573, 5161, 5493, 5690, 5941, 7946, 16774, 16780, 26909, 26993, 28742, 33623, 44975 ) -- Expert Fishing
	AddTrainerRef( "professions", "FISHING", 18248, 1683, 1700, 2834, 3028, 3179, 3332, 3607, 4156, 4573, 5161, 5493, 5690, 5941, 7946, 16774, 16780, 26909, 26993, 28742, 33623, 44975 ) -- Artisan Fishing
	AddTrainerRef( "professions", "FISHING", 33095, 1683, 1700, 2834, 3028, 3179, 3332, 3607, 4156, 4573, 5161, 5493, 5690, 5941, 7946, 16774, 16780, 26909, 26993, 28742, 33623, 44975 ) -- Master Fishing
	AddTrainerRef( "professions", "FISHING", 51294, 1683, 1700, 2834, 3028, 3179, 3332, 3607, 4156, 4573, 5161, 5493, 5690, 5941, 7946, 16774, 16780, 26909, 26993, 28742, 33623, 44975 ) -- Grand Master Fishing
	AddTrainerRef( "professions", "FISHING", 88868, 2834, 3332, 3607, 4156, 5161, 5493, 7946, 16774, 26909, 26993, 28742, 33623, 44975 ) -- Illustrious Grand Master Fishing
	AddTrainerRef( "professions", "HERBALISM",  2366, 908, 1458, 3013, 3404, 4614, 5137, 5566, 12025, 16644, 18776, 26958, 26994, 28704, 33616, 33639, 33678, 46741 ) -- Apprentice Herbalist
	AddTrainerRef( "professions", "HERBALISM",  2368, 908, 1458, 3013, 3404, 4614, 5137, 5566, 12025, 16644, 18776, 26958, 26994, 28704, 33616, 33639, 33678, 46741 ) -- Journeyman Herbalist
	AddTrainerRef( "professions", "HERBALISM",  3570, 908, 1458, 3013, 3404, 4614, 5137, 5566, 12025, 16644, 18776, 26958, 26994, 28704, 33616, 33639, 33678, 46741 ) -- Expert Herbalist
	AddTrainerRef( "professions", "HERBALISM", 11993, 908, 1458, 3013, 3404, 4614, 5137, 5566, 12025, 16644, 18776, 26958, 26994, 28704, 33616, 33639, 33678, 46741 ) -- Artisan Herbalist
	AddTrainerRef( "professions", "HERBALISM", 28695, 908, 1458, 3013, 3404, 4614, 5137, 5566, 12025, 16644, 18776, 26958, 26994, 28704, 33616, 33639, 33678, 46741 ) -- Master Herbalist
	AddTrainerRef( "professions", "HERBALISM", 50300, 908, 1458, 3013, 3404, 4614, 5137, 5566, 12025, 16644, 18776, 26958, 26994, 28704, 33616, 33639, 33678, 46741 ) -- Grand Master Herbalist
	AddTrainerRef( "professions", "HERBALISM", 74519, 908, 5137, 5566, 12025, 18776, 26958, 26994, 28704, 33616, 33678 ) -- Illustrious Grand Master Herbalist
	AddTrainerRef( "professions", "INSCRIPTION", 45357, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Apprentice Scribe
	AddTrainerRef( "professions", "INSCRIPTION", 45358, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Journeyman Scribe
	AddTrainerRef( "professions", "INSCRIPTION", 45359, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Expert Scribe
	AddTrainerRef( "professions", "INSCRIPTION", 45360, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Artisan Scribe
	AddTrainerRef( "professions", "INSCRIPTION", 45361, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Master Scribe
	AddTrainerRef( "professions", "INSCRIPTION", 45363, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Grand Master Scribe
	AddTrainerRef( "professions", "INSCRIPTION", 48121, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Entangling Roots
	AddTrainerRef( "professions", "INSCRIPTION", 48247, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Mysterious Tarot
	AddTrainerRef( "professions", "INSCRIPTION", 48248, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Scroll of Recall
	AddTrainerRef( "professions", "INSCRIPTION", 50598, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Scroll of Intellect II
	AddTrainerRef( "professions", "INSCRIPTION", 50599, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Scroll of Intellect III
	AddTrainerRef( "professions", "INSCRIPTION", 50600, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Scroll of Intellect IV
	AddTrainerRef( "professions", "INSCRIPTION", 50601, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Scroll of Intellect V
	AddTrainerRef( "professions", "INSCRIPTION", 50602, 26916, 26959, 28702, 30706, 30709, 30713, 30716, 30721, 33615 ) -- Scroll of Intellect VI
	AddTrainerRef( "professions", "INSCRIPTION", 50603, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Scroll of Intellect VII
	AddTrainerRef( "professions", "INSCRIPTION", 50604, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Scroll of Intellect VIII
	AddTrainerRef( "professions", "INSCRIPTION", 50605, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Scroll of Spirit II
	AddTrainerRef( "professions", "INSCRIPTION", 50606, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Scroll of Spirit III
	AddTrainerRef( "professions", "INSCRIPTION", 50607, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Scroll of Spirit IV
	AddTrainerRef( "professions", "INSCRIPTION", 50608, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Scroll of Spirit V
	AddTrainerRef( "professions", "INSCRIPTION", 50609, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Scroll of Spirit VI
	AddTrainerRef( "professions", "INSCRIPTION", 50610, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Scroll of Spirit VII
	AddTrainerRef( "professions", "INSCRIPTION", 50611, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Scroll of Spirit VIII
	AddTrainerRef( "professions", "INSCRIPTION", 50612, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Scroll of Stamina II
	AddTrainerRef( "professions", "INSCRIPTION", 50614, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Scroll of Stamina III
	AddTrainerRef( "professions", "INSCRIPTION", 50616, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Scroll of Stamina IV
	AddTrainerRef( "professions", "INSCRIPTION", 50617, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Scroll of Stamina V
	AddTrainerRef( "professions", "INSCRIPTION", 50618, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Scroll of Stamina VI
	AddTrainerRef( "professions", "INSCRIPTION", 50619, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Scroll of Stamina VII
	AddTrainerRef( "professions", "INSCRIPTION", 50620, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Scroll of Stamina VIII
	AddTrainerRef( "professions", "INSCRIPTION", 52739, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Enchanting Vellum
	AddTrainerRef( "professions", "INSCRIPTION", 52843, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Moonglow Ink
	AddTrainerRef( "professions", "INSCRIPTION", 53462, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Midnight Ink
	AddTrainerRef( "professions", "INSCRIPTION", 56943, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Frenzied Regeneration
	AddTrainerRef( "professions", "INSCRIPTION", 56945, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Healing Touch
	AddTrainerRef( "professions", "INSCRIPTION", 56948, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Insect Swarm
	AddTrainerRef( "professions", "INSCRIPTION", 56951, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Moonfire
	AddTrainerRef( "professions", "INSCRIPTION", 56952, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Pounce
	AddTrainerRef( "professions", "INSCRIPTION", 56953, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Rebirth
	AddTrainerRef( "professions", "INSCRIPTION", 56955, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Rejuvenation
	AddTrainerRef( "professions", "INSCRIPTION", 56956, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Rip
	AddTrainerRef( "professions", "INSCRIPTION", 56957, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Shred
	AddTrainerRef( "professions", "INSCRIPTION", 56959, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Starfire
	AddTrainerRef( "professions", "INSCRIPTION", 56961, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Maul
	AddTrainerRef( "professions", "INSCRIPTION", 56963, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Wrath
	AddTrainerRef( "professions", "INSCRIPTION", 56971, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Arcane Missiles
	AddTrainerRef( "professions", "INSCRIPTION", 56972, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Arcane Power
	AddTrainerRef( "professions", "INSCRIPTION", 56973, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Blink
	AddTrainerRef( "professions", "INSCRIPTION", 56974, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Evocation
	AddTrainerRef( "professions", "INSCRIPTION", 56976, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Frost Nova
	AddTrainerRef( "professions", "INSCRIPTION", 56978, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Pyroblast
	AddTrainerRef( "professions", "INSCRIPTION", 56979, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Ice Block
	AddTrainerRef( "professions", "INSCRIPTION", 56980, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Ice Lance
	AddTrainerRef( "professions", "INSCRIPTION", 56981, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Icy Veins
	AddTrainerRef( "professions", "INSCRIPTION", 56984, 26916, 26959, 26995, 28702, 30706, 30709, 30711, 30713, 30716, 30717, 30721, 33615, 33679, 46716 ) -- Glyph of Mage Armor
	AddTrainerRef( "professions", "INSCRIPTION", 56987, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Polymorph
	AddTrainerRef( "professions", "INSCRIPTION", 56991, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Arcane Blast
	AddTrainerRef( "professions", "INSCRIPTION", 56994, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Aimed Shot
	AddTrainerRef( "professions", "INSCRIPTION", 56995, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Arcane Shot
	AddTrainerRef( "professions", "INSCRIPTION", 56997, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Mending
	AddTrainerRef( "professions", "INSCRIPTION", 57000, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Deterrence
	AddTrainerRef( "professions", "INSCRIPTION", 57001, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Disengage
	AddTrainerRef( "professions", "INSCRIPTION", 57002, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Freezing Trap
	AddTrainerRef( "professions", "INSCRIPTION", 57003, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Ice Trap
	AddTrainerRef( "professions", "INSCRIPTION", 57004, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Misdirection
	AddTrainerRef( "professions", "INSCRIPTION", 57005, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Immolation Trap
	AddTrainerRef( "professions", "INSCRIPTION", 57006, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of the Dazzled Prey
	AddTrainerRef( "professions", "INSCRIPTION", 57007, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Silencing Shot
	AddTrainerRef( "professions", "INSCRIPTION", 57008, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Rapid Fire
	AddTrainerRef( "professions", "INSCRIPTION", 57009, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Serpent Sting
	AddTrainerRef( "professions", "INSCRIPTION", 57020, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Cleansing
	AddTrainerRef( "professions", "INSCRIPTION", 57022, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Divine Protection
	AddTrainerRef( "professions", "INSCRIPTION", 57023, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Consecration
	AddTrainerRef( "professions", "INSCRIPTION", 57024, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Crusader Strike
	AddTrainerRef( "professions", "INSCRIPTION", 57025, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Exorcism
	AddTrainerRef( "professions", "INSCRIPTION", 57026, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Word of Glory
	AddTrainerRef( "professions", "INSCRIPTION", 57027, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Hammer of Justice
	AddTrainerRef( "professions", "INSCRIPTION", 57029, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Divine Favor
	AddTrainerRef( "professions", "INSCRIPTION", 57030, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Judgement
	AddTrainerRef( "professions", "INSCRIPTION", 57031, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Divinity
	AddTrainerRef( "professions", "INSCRIPTION", 57033, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Rebuke
	AddTrainerRef( "professions", "INSCRIPTION", 57036, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Turn Evil
	AddTrainerRef( "professions", "INSCRIPTION", 57113, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Ambush
	AddTrainerRef( "professions", "INSCRIPTION", 57114, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Backstab
	AddTrainerRef( "professions", "INSCRIPTION", 57119, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Evasion
	AddTrainerRef( "professions", "INSCRIPTION", 57120, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Eviscerate
	AddTrainerRef( "professions", "INSCRIPTION", 57121, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Expose Armor
	AddTrainerRef( "professions", "INSCRIPTION", 57122, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Feint
	AddTrainerRef( "professions", "INSCRIPTION", 57123, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Garrote
	AddTrainerRef( "professions", "INSCRIPTION", 57125, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Gouge
	AddTrainerRef( "professions", "INSCRIPTION", 57129, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Sap
	AddTrainerRef( "professions", "INSCRIPTION", 57131, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Sinister Strike
	AddTrainerRef( "professions", "INSCRIPTION", 57132, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Slice and Dice
	AddTrainerRef( "professions", "INSCRIPTION", 57133, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Sprint
	AddTrainerRef( "professions", "INSCRIPTION", 57154, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Cleaving
	AddTrainerRef( "professions", "INSCRIPTION", 57156, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Bloodthirst
	AddTrainerRef( "professions", "INSCRIPTION", 57157, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Piercing Howl
	AddTrainerRef( "professions", "INSCRIPTION", 57158, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Heroic Throw
	AddTrainerRef( "professions", "INSCRIPTION", 57161, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Overpower
	AddTrainerRef( "professions", "INSCRIPTION", 57162, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Rapid Charge
	AddTrainerRef( "professions", "INSCRIPTION", 57163, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Slam
	AddTrainerRef( "professions", "INSCRIPTION", 57165, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Revenge
	AddTrainerRef( "professions", "INSCRIPTION", 57167, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Sunder Armor
	AddTrainerRef( "professions", "INSCRIPTION", 57168, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Sweeping Strikes
	AddTrainerRef( "professions", "INSCRIPTION", 57172, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Raging Blow
	AddTrainerRef( "professions", "INSCRIPTION", 57183, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Dispel Magic
	AddTrainerRef( "professions", "INSCRIPTION", 57184, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Fade
	AddTrainerRef( "professions", "INSCRIPTION", 57185, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Fear Ward
	AddTrainerRef( "professions", "INSCRIPTION", 57186, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Flash Heal
	AddTrainerRef( "professions", "INSCRIPTION", 57187, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Holy Nova
	AddTrainerRef( "professions", "INSCRIPTION", 57188, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Inner Fire
	AddTrainerRef( "professions", "INSCRIPTION", 57192, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Shadow Word: Pain
	AddTrainerRef( "professions", "INSCRIPTION", 57194, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Power Word: Shield
	AddTrainerRef( "professions", "INSCRIPTION", 57196, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Psychic Scream
	AddTrainerRef( "professions", "INSCRIPTION", 57197, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Renew
	AddTrainerRef( "professions", "INSCRIPTION", 57198, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Scourge Imprisonment
	AddTrainerRef( "professions", "INSCRIPTION", 57200, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Mind Flay
	AddTrainerRef( "professions", "INSCRIPTION", 57201, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Smite
	AddTrainerRef( "professions", "INSCRIPTION", 57210, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Bone Shield
	AddTrainerRef( "professions", "INSCRIPTION", 57213, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Death Grip
	AddTrainerRef( "professions", "INSCRIPTION", 57216, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Frost Strike
	AddTrainerRef( "professions", "INSCRIPTION", 57219, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Icy Touch
	AddTrainerRef( "professions", "INSCRIPTION", 57221, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Pestilence
	AddTrainerRef( "professions", "INSCRIPTION", 57222, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Raise Dead
	AddTrainerRef( "professions", "INSCRIPTION", 57224, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Scourge Strike
	AddTrainerRef( "professions", "INSCRIPTION", 57225, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Strangulate
	AddTrainerRef( "professions", "INSCRIPTION", 57226, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Pillar of Frost
	AddTrainerRef( "professions", "INSCRIPTION", 57227, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Vampiric Blood
	AddTrainerRef( "professions", "INSCRIPTION", 57236, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Earthliving Weapon
	AddTrainerRef( "professions", "INSCRIPTION", 57238, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Fire Nova
	AddTrainerRef( "professions", "INSCRIPTION", 57239, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Flame Shock
	AddTrainerRef( "professions", "INSCRIPTION", 57240, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Flametongue Weapon
	AddTrainerRef( "professions", "INSCRIPTION", 57241, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Frost Shock
	AddTrainerRef( "professions", "INSCRIPTION", 57242, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Healing Stream Totem
	AddTrainerRef( "professions", "INSCRIPTION", 57244, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Totemic Recall
	AddTrainerRef( "professions", "INSCRIPTION", 57245, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Lightning Bolt
	AddTrainerRef( "professions", "INSCRIPTION", 57246, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Lightning Shield
	AddTrainerRef( "professions", "INSCRIPTION", 57248, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Stormstrike
	AddTrainerRef( "professions", "INSCRIPTION", 57249, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Lava Lash
	AddTrainerRef( "professions", "INSCRIPTION", 57251, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Water Shield
	AddTrainerRef( "professions", "INSCRIPTION", 57252, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Windfury Weapon
	AddTrainerRef( "professions", "INSCRIPTION", 57257, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Incinerate
	AddTrainerRef( "professions", "INSCRIPTION", 57259, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Corruption
	AddTrainerRef( "professions", "INSCRIPTION", 57262, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Fear
	AddTrainerRef( "professions", "INSCRIPTION", 57265, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Health Funnel
	AddTrainerRef( "professions", "INSCRIPTION", 57266, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Healthstone
	AddTrainerRef( "professions", "INSCRIPTION", 57269, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Imp
	AddTrainerRef( "professions", "INSCRIPTION", 57270, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Soul Swap
	AddTrainerRef( "professions", "INSCRIPTION", 57271, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Shadow Bolt
	AddTrainerRef( "professions", "INSCRIPTION", 57272, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Shadowburn
	AddTrainerRef( "professions", "INSCRIPTION", 57274, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Soulstone
	AddTrainerRef( "professions", "INSCRIPTION", 57275, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Seduction
	AddTrainerRef( "professions", "INSCRIPTION", 57277, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Voidwalker
	AddTrainerRef( "professions", "INSCRIPTION", 57703, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Hunter's Ink
	AddTrainerRef( "professions", "INSCRIPTION", 57704, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Lion's Ink
	AddTrainerRef( "professions", "INSCRIPTION", 57706, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Dawnstar Ink
	AddTrainerRef( "professions", "INSCRIPTION", 57707, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Jadefire Ink
	AddTrainerRef( "professions", "INSCRIPTION", 57708, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Royal Ink
	AddTrainerRef( "professions", "INSCRIPTION", 57709, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Celestial Ink
	AddTrainerRef( "professions", "INSCRIPTION", 57710, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Fiery Ink
	AddTrainerRef( "professions", "INSCRIPTION", 57711, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Shimmering Ink
	AddTrainerRef( "professions", "INSCRIPTION", 57712, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Ink of the Sky
	AddTrainerRef( "professions", "INSCRIPTION", 57713, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Ethereal Ink
	AddTrainerRef( "professions", "INSCRIPTION", 57714, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Darkflame Ink
	AddTrainerRef( "professions", "INSCRIPTION", 57715, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Ink of the Sea
	AddTrainerRef( "professions", "INSCRIPTION", 57716, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Snowfall Ink
	AddTrainerRef( "professions", "INSCRIPTION", 58344, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Long Charge
	AddTrainerRef( "professions", "INSCRIPTION", 58346, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Thunder Clap
	AddTrainerRef( "professions", "INSCRIPTION", 58472, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Scroll of Agility
	AddTrainerRef( "professions", "INSCRIPTION", 58473, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Scroll of Agility II
	AddTrainerRef( "professions", "INSCRIPTION", 58476, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Scroll of Agility III
	AddTrainerRef( "professions", "INSCRIPTION", 58478, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Scroll of Agility IV
	AddTrainerRef( "professions", "INSCRIPTION", 58480, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Scroll of Agility V
	AddTrainerRef( "professions", "INSCRIPTION", 58481, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Scroll of Agility VI
	AddTrainerRef( "professions", "INSCRIPTION", 58482, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Scroll of Agility VII
	AddTrainerRef( "professions", "INSCRIPTION", 58483, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Scroll of Agility VIII
	AddTrainerRef( "professions", "INSCRIPTION", 58484, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Scroll of Strength
	AddTrainerRef( "professions", "INSCRIPTION", 58485, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Scroll of Strength II
	AddTrainerRef( "professions", "INSCRIPTION", 58486, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Scroll of Strength III
	AddTrainerRef( "professions", "INSCRIPTION", 58487, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Scroll of Strength IV
	AddTrainerRef( "professions", "INSCRIPTION", 58488, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Scroll of Strength V
	AddTrainerRef( "professions", "INSCRIPTION", 58489, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Scroll of Strength VI
	AddTrainerRef( "professions", "INSCRIPTION", 58490, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Scroll of Strength VII
	AddTrainerRef( "professions", "INSCRIPTION", 58491, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Scroll of Strength VIII
	AddTrainerRef( "professions", "INSCRIPTION", 58565, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Mystic Tome
	AddTrainerRef( "professions", "INSCRIPTION", 59326, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Ghost Wolf
	AddTrainerRef( "professions", "INSCRIPTION", 59338, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Rune Tap
	AddTrainerRef( "professions", "INSCRIPTION", 59339, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Blood Boil
	AddTrainerRef( "professions", "INSCRIPTION", 59340, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Death Strike
	AddTrainerRef( "professions", "INSCRIPTION", 59387, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Certificate of Ownership
	AddTrainerRef( "professions", "INSCRIPTION", 59475, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Tome of the Dawn
	AddTrainerRef( "professions", "INSCRIPTION", 59478, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Book of Survival
	AddTrainerRef( "professions", "INSCRIPTION", 59480, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Strange Tarot
	AddTrainerRef( "professions", "INSCRIPTION", 59484, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Tome of Kings
	AddTrainerRef( "professions", "INSCRIPTION", 59486, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Royal Guide of Escape Routes
	AddTrainerRef( "professions", "INSCRIPTION", 59487, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Arcane Tarot
	AddTrainerRef( "professions", "INSCRIPTION", 59489, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Fire Eater's Guide
	AddTrainerRef( "professions", "INSCRIPTION", 59490, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Book of Stars
	AddTrainerRef( "professions", "INSCRIPTION", 59491, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Shadowy Tarot
	AddTrainerRef( "professions", "INSCRIPTION", 59493, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Stormbound Tome
	AddTrainerRef( "professions", "INSCRIPTION", 59494, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Manual of Clouds
	AddTrainerRef( "professions", "INSCRIPTION", 59495, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Hellfire Tome
	AddTrainerRef( "professions", "INSCRIPTION", 59496, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Book of Clever Tricks
	AddTrainerRef( "professions", "INSCRIPTION", 59497, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Iron-bound Tome
	AddTrainerRef( "professions", "INSCRIPTION", 59498, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Faces of Doom
	AddTrainerRef( "professions", "INSCRIPTION", 59502, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Darkmoon Card
	AddTrainerRef( "professions", "INSCRIPTION", 59503, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Greater Darkmoon Card
	AddTrainerRef( "professions", "INSCRIPTION", 59504, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Darkmoon Card of the North
	AddTrainerRef( "professions", "INSCRIPTION", 60336, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Scroll of Recall II
	AddTrainerRef( "professions", "INSCRIPTION", 60337, 26916, 26959, 26995, 28702, 30706, 30709, 30711, 30713, 30716, 30717, 30721, 33615, 33679, 46716 ) -- Scroll of Recall III
	AddTrainerRef( "professions", "INSCRIPTION", 61117, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Master's Inscription of the Axe
	AddTrainerRef( "professions", "INSCRIPTION", 61118, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Master's Inscription of the Crag
	AddTrainerRef( "professions", "INSCRIPTION", 61119, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Master's Inscription of the Pinnacle
	AddTrainerRef( "professions", "INSCRIPTION", 61120, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Master's Inscription of the Storm
	AddTrainerRef( "professions", "INSCRIPTION", 61177, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Northrend Inscription Research
	AddTrainerRef( "professions", "INSCRIPTION", 61288, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Minor Inscription Research
	AddTrainerRef( "professions", "INSCRIPTION", 62162, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Focus
	AddTrainerRef( "professions", "INSCRIPTION", 64053, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Twilight Tome
	AddTrainerRef( "professions", "INSCRIPTION", 64258, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Monsoon
	AddTrainerRef( "professions", "INSCRIPTION", 64259, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Desperation
	AddTrainerRef( "professions", "INSCRIPTION", 64260, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Mutilate
	AddTrainerRef( "professions", "INSCRIPTION", 64261, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Earth Shield
	AddTrainerRef( "professions", "INSCRIPTION", 64262, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Shamanistic Rage
	AddTrainerRef( "professions", "INSCRIPTION", 64266, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Death Coil
	AddTrainerRef( "professions", "INSCRIPTION", 67600, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Ferocious Bite
	AddTrainerRef( "professions", "INSCRIPTION", 69385, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Runescroll of Fortitude
	AddTrainerRef( "professions", "INSCRIPTION", 85785, 26916, 26959, 28702, 30706, 30709, 30713, 30716, 30717, 30721, 33615, 33679, 46716 ) -- Runescroll of Fortitude II
	AddTrainerRef( "professions", "INSCRIPTION", 86004, 26916, 26959, 28702, 30706, 30709, 30713, 30716, 30717, 30721, 33615, 33679, 46716 ) -- Blackfallow Ink
	AddTrainerRef( "professions", "INSCRIPTION", 86005, 26916, 26959, 28702, 30706, 30709, 30713, 30716, 30717, 30721, 33615, 33679, 46716 ) -- Inferno Ink
	AddTrainerRef( "professions", "INSCRIPTION", 86008, 26916, 26959, 28702, 30706, 30709, 30713, 30716, 30717, 30721, 33615, 33679, 46716 ) -- Illustrious Grand Master Scribe
	AddTrainerRef( "professions", "INSCRIPTION", 86375, 26916, 26959, 28702, 30706, 30709, 30713, 30716, 30717, 30721, 33615, 33679, 46716 ) -- Swiftsteel Inscription
	AddTrainerRef( "professions", "INSCRIPTION", 86401, 26916, 26959, 28702, 30706, 30709, 30713, 30716, 30717, 30721, 33615, 33679, 46716 ) -- Lionsmane Inscription
	AddTrainerRef( "professions", "INSCRIPTION", 86402, 26916, 26959, 28702, 30706, 30709, 30713, 30716, 30717, 30721, 33615, 33679, 46716 ) -- Inscription of the Earth Prince
	AddTrainerRef( "professions", "INSCRIPTION", 86403, 26916, 26959, 28702, 30706, 30709, 30713, 30716, 30717, 30721, 33615, 33679, 46716 ) -- Felfire Inscription
	AddTrainerRef( "professions", "INSCRIPTION", 86609, 26916, 26959, 28702, 30706, 30709, 30713, 30716, 30717, 30721, 33615, 33679, 46716 ) -- Mysterious Fortune Card
	AddTrainerRef( "professions", "INSCRIPTION", 86615, 26916, 26959, 28702, 30706, 30709, 30713, 30716, 30717, 30721, 33615, 33679, 46716 ) -- Darkmoon Card of Destruction
	AddTrainerRef( "professions", "INSCRIPTION", 86616, 26916, 26959, 28702, 30706, 30709, 30713, 30716, 30717, 30721, 33615, 33679, 46716 ) -- Book of Blood
	AddTrainerRef( "professions", "INSCRIPTION", 86640, 26916, 26959, 28702, 30706, 30709, 30713, 30716, 30717, 30721, 33615, 33679, 46716 ) -- Lord Rottington's Pressed Wisp Book
	AddTrainerRef( "professions", "INSCRIPTION", 86641, 26916, 26959, 28702, 30706, 30709, 30713, 30716, 30717, 30721, 33615, 33679, 46716 ) -- Dungeoneering Guide
	AddTrainerRef( "professions", "INSCRIPTION", 86642, 26916, 26959, 28702, 30706, 30709, 30713, 30716, 30717, 30721, 33615, 33679, 46716 ) -- Divine Companion
	AddTrainerRef( "professions", "INSCRIPTION", 86643, 26916, 26959, 28702, 30706, 30709, 30713, 30716, 30717, 30721, 33615, 33679, 46716 ) -- Battle Tome
	AddTrainerRef( "professions", "INSCRIPTION", 86647, 26916, 26959, 28702, 30706, 30709, 30713, 30716, 30717, 30721, 33615, 33679, 46716 ) -- Etched Horn
	AddTrainerRef( "professions", "INSCRIPTION", 86648, 26916, 26959, 28702, 30706, 30709, 30713, 30716, 30717, 30721, 33615, 33679, 46716 ) -- Manual of the Planes
	AddTrainerRef( "professions", "INSCRIPTION", 86649, 26916, 26959, 28702, 30706, 30709, 30713, 30716, 30717, 30721, 33615, 33679, 46716 ) -- Runed Dragonscale
	AddTrainerRef( "professions", "INSCRIPTION", 86650, 26916, 26959, 28702, 30706, 30709, 30713, 30716, 30717, 30721, 33615, 33679, 46716 ) -- Notched Jawbone
	AddTrainerRef( "professions", "INSCRIPTION", 86652, 26916, 26959, 28702, 30706, 30709, 30713, 30716, 30717, 30721, 33615, 33679, 46716 ) -- Tattooed Eyeball
	AddTrainerRef( "professions", "INSCRIPTION", 86653, 26916, 26959, 28702, 30706, 30709, 30713, 30716, 30717, 30721, 33615, 33679, 46716 ) -- Silver Inlaid Leaf
	AddTrainerRef( "professions", "INSCRIPTION", 86654, 26959, 30706, 30709, 46716 ) -- Forged Documents
	AddTrainerRef( "professions", "INSCRIPTION", 89244, 26916, 28702, 30713, 30716, 30717, 30721, 33615, 33679 ) -- Forged Documents
	AddTrainerRef( "professions", "INSCRIPTION", 89367, 26916, 26959, 28702, 30706, 30709, 30713, 30716, 30717, 30721, 33615, 33679, 46716 ) -- Adventurer's Journal
	AddTrainerRef( "professions", "INSCRIPTION", 89368, 26916, 26959, 28702, 30706, 30709, 30713, 30716, 30717, 30721, 33615, 33679, 46716 ) -- Scroll of Intellect IX
	AddTrainerRef( "professions", "INSCRIPTION", 89369, 26916, 26959, 28702, 30706, 30709, 30713, 30716, 30717, 30721, 33615, 33679, 46716 ) -- Scroll of Strength IX
	AddTrainerRef( "professions", "INSCRIPTION", 89370, 26916, 26959, 28702, 30706, 30709, 30713, 30716, 30717, 30721, 33615, 33679, 46716 ) -- Scroll of Agility IX
	AddTrainerRef( "professions", "INSCRIPTION", 89371, 26916, 26959, 28702, 30706, 30709, 30713, 30716, 30717, 30721, 33615, 33679, 46716 ) -- Scroll of Spirit IX
	AddTrainerRef( "professions", "INSCRIPTION", 89372, 26916, 26959, 28702, 30706, 30709, 30713, 30716, 30717, 30721, 33615, 33679, 46716 ) -- Scroll of Stamina IX
	AddTrainerRef( "professions", "INSCRIPTION", 89373, 26916, 26959, 28702, 30706, 30709, 30713, 30716, 30717, 30721, 33615, 33679, 46716 ) -- Scroll of Protection IX
	AddTrainerRef( "professions", "INSCRIPTION", 92026, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Vanishing Powder
	AddTrainerRef( "professions", "INSCRIPTION", 92027, 26916, 26959, 28702, 30706, 30709, 30713, 30716, 30717, 30721, 33615, 33679, 46716 ) -- Dust of Disappearance
	AddTrainerRef( "professions", "INSCRIPTION", 92579, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Blind
	AddTrainerRef( "professions", "INSCRIPTION", 94401, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Tiger's Fury
	AddTrainerRef( "professions", "INSCRIPTION", 94402, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Lacerate
	AddTrainerRef( "professions", "INSCRIPTION", 94403, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Faerie Fire
	AddTrainerRef( "professions", "INSCRIPTION", 94404, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Feral Charge
	AddTrainerRef( "professions", "INSCRIPTION", 94405, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Death Wish
	AddTrainerRef( "professions", "INSCRIPTION", 94406, 26916, 26959, 26995, 28702, 30706, 30709, 30710, 30711, 30713, 30716, 30717, 30721, 33603, 33615, 33638, 33679, 46716 ) -- Glyph of Intercept
	AddTrainerRef( "professions", "INSCRIPTION", 96284, 26916, 26959, 28702, 30706, 30709, 30713, 30716, 30721, 33615 ) -- Glyph of Dark Succor
	AddTrainerRef( "professions", "JEWELCRAFTING", 25229, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Apprentice Jewelcrafter
	AddTrainerRef( "professions", "JEWELCRAFTING", 25230, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Journeyman Jewelcrafter
	AddTrainerRef( "professions", "JEWELCRAFTING", 25278, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Bronze Setting
	AddTrainerRef( "professions", "JEWELCRAFTING", 25280, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Elegant Silver Ring
	AddTrainerRef( "professions", "JEWELCRAFTING", 25283, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Inlaid Malachite Ring
	AddTrainerRef( "professions", "JEWELCRAFTING", 25284, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Simple Pearl Ring
	AddTrainerRef( "professions", "JEWELCRAFTING", 25287, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Gloom Band
	AddTrainerRef( "professions", "JEWELCRAFTING", 25305, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Heavy Silver Ring
	AddTrainerRef( "professions", "JEWELCRAFTING", 25317, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Ring of Silver Might
	AddTrainerRef( "professions", "JEWELCRAFTING", 25318, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Ring of Twilight Shadows
	AddTrainerRef( "professions", "JEWELCRAFTING", 25321, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Moonsoul Crown
	AddTrainerRef( "professions", "JEWELCRAFTING", 25490, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Solid Bronze Ring
	AddTrainerRef( "professions", "JEWELCRAFTING", 25498, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Barbaric Iron Collar
	AddTrainerRef( "professions", "JEWELCRAFTING", 25610, 18774, 19778, 26915, 26997, 28701, 33614, 44582 ) -- Pendant of the Agate Shield
	AddTrainerRef( "professions", "JEWELCRAFTING", 25612, 18774, 19778, 26915, 26997, 28701, 33614, 44582 ) -- Heavy Iron Knuckles
	AddTrainerRef( "professions", "JEWELCRAFTING", 25613, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Golden Dragon Ring
	AddTrainerRef( "professions", "JEWELCRAFTING", 25615, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Mithril Filigree
	AddTrainerRef( "professions", "JEWELCRAFTING", 25617, 18774, 19778, 26915, 26997, 28701, 33614, 44582 ) -- Blazing Citrine Ring
	AddTrainerRef( "professions", "JEWELCRAFTING", 25620, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Engraved Truesilver Ring
	AddTrainerRef( "professions", "JEWELCRAFTING", 25621, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Citrine Ring of Rapid Healing
	AddTrainerRef( "professions", "JEWELCRAFTING", 26872, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Figurine - Jade Owl
	AddTrainerRef( "professions", "JEWELCRAFTING", 26874, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Aquamarine Signet
	AddTrainerRef( "professions", "JEWELCRAFTING", 26876, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Aquamarine Pendant of the Warrior
	AddTrainerRef( "professions", "JEWELCRAFTING", 26880, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Thorium Setting
	AddTrainerRef( "professions", "JEWELCRAFTING", 26883, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Ruby Pendant of Fire
	AddTrainerRef( "professions", "JEWELCRAFTING", 26885, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Truesilver Healing Ring
	AddTrainerRef( "professions", "JEWELCRAFTING", 26902, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Simple Opal Ring
	AddTrainerRef( "professions", "JEWELCRAFTING", 26903, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Sapphire Signet
	AddTrainerRef( "professions", "JEWELCRAFTING", 26907, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Onslaught Ring
	AddTrainerRef( "professions", "JEWELCRAFTING", 26908, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Sapphire Pendant of Winter Night
	AddTrainerRef( "professions", "JEWELCRAFTING", 26911, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Living Emerald Pendant
	AddTrainerRef( "professions", "JEWELCRAFTING", 26916, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Band of Natural Fire
	AddTrainerRef( "professions", "JEWELCRAFTING", 26926, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Heavy Copper Ring
	AddTrainerRef( "professions", "JEWELCRAFTING", 26927, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Thick Bronze Necklace
	AddTrainerRef( "professions", "JEWELCRAFTING", 26928, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Ornate Tigerseye Necklace
	AddTrainerRef( "professions", "JEWELCRAFTING", 28894, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Expert Jewelcrafter
	AddTrainerRef( "professions", "JEWELCRAFTING", 28895, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Artisan Jewelcrafter
	AddTrainerRef( "professions", "JEWELCRAFTING", 28897, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Master Jewelcrafter
	AddTrainerRef( "professions", "JEWELCRAFTING", 28905, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Bold Blood Garnet
	AddTrainerRef( "professions", "JEWELCRAFTING", 28910, 18774, 19063, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33680, 44582, 46675 ) -- Inscribed Flame Spessarite
	AddTrainerRef( "professions", "JEWELCRAFTING", 28914, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Glinting Shadow Draenite
	AddTrainerRef( "professions", "JEWELCRAFTING", 28916, 18774, 19778, 26915, 26997, 28701, 33614, 44582 ) -- Radiant Deep Peridot
	AddTrainerRef( "professions", "JEWELCRAFTING", 28917, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Jagged Deep Peridot
	AddTrainerRef( "professions", "JEWELCRAFTING", 28925, 18774, 19778, 26915, 26997, 28701, 33614, 44582 ) -- Timeless Shadow Draenite
	AddTrainerRef( "professions", "JEWELCRAFTING", 28936, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Sovereign Shadow Draenite
	AddTrainerRef( "professions", "JEWELCRAFTING", 28948, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Rigid Azure Moonstone
	AddTrainerRef( "professions", "JEWELCRAFTING", 28950, 18774, 19778, 26915, 26997, 28701, 33614, 44582 ) -- Solid Azure Moonstone
	AddTrainerRef( "professions", "JEWELCRAFTING", 28953, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Sparkling Azure Moonstone
	AddTrainerRef( "professions", "JEWELCRAFTING", 31048, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Fel Iron Blood Ring
	AddTrainerRef( "professions", "JEWELCRAFTING", 31049, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Golden Draenite Ring
	AddTrainerRef( "professions", "JEWELCRAFTING", 31050, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Azure Moonstone Ring
	AddTrainerRef( "professions", "JEWELCRAFTING", 31051, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Thick Adamantite Necklace
	AddTrainerRef( "professions", "JEWELCRAFTING", 31052, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Heavy Adamantite Ring
	AddTrainerRef( "professions", "JEWELCRAFTING", 31252, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Prospecting
	AddTrainerRef( "professions", "JEWELCRAFTING", 32178, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Malachite Pendant
	AddTrainerRef( "professions", "JEWELCRAFTING", 32179, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Tigerseye Band
	AddTrainerRef( "professions", "JEWELCRAFTING", 32801, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Coarse Stone Statue
	AddTrainerRef( "professions", "JEWELCRAFTING", 32807, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Heavy Stone Statue
	AddTrainerRef( "professions", "JEWELCRAFTING", 32808, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Solid Stone Statue
	AddTrainerRef( "professions", "JEWELCRAFTING", 32809, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Dense Stone Statue
	AddTrainerRef( "professions", "JEWELCRAFTING", 34590, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Delicate Blood Garnet
	AddTrainerRef( "professions", "JEWELCRAFTING", 34955, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Golden Ring of Power
	AddTrainerRef( "professions", "JEWELCRAFTING", 34959, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Truesilver Commander's Ring
	AddTrainerRef( "professions", "JEWELCRAFTING", 34960, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Glowing Thorium Band
	AddTrainerRef( "professions", "JEWELCRAFTING", 34961, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Emerald Lion Ring
	AddTrainerRef( "professions", "JEWELCRAFTING", 36523, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Brilliant Necklace
	AddTrainerRef( "professions", "JEWELCRAFTING", 36524, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Heavy Jade Ring
	AddTrainerRef( "professions", "JEWELCRAFTING", 36525, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Red Ring of Destruction
	AddTrainerRef( "professions", "JEWELCRAFTING", 36526, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Diamond Focus Ring
	AddTrainerRef( "professions", "JEWELCRAFTING", 37818, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Bronze Band of Force
	AddTrainerRef( "professions", "JEWELCRAFTING", 38068, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Mercurial Adamantite
	AddTrainerRef( "professions", "JEWELCRAFTING", 38175, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Bronze Torc
	AddTrainerRef( "professions", "JEWELCRAFTING", 40514, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Necklace of the Deep
	AddTrainerRef( "professions", "JEWELCRAFTING", 41414, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Brilliant Pearl Band
	AddTrainerRef( "professions", "JEWELCRAFTING", 41415, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- The Black Pearl
	AddTrainerRef( "professions", "JEWELCRAFTING", 41418, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Crown of the Sea Witch
	AddTrainerRef( "professions", "JEWELCRAFTING", 41420, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Purified Jaggal Pearl
	AddTrainerRef( "professions", "JEWELCRAFTING", 41429, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Purified Shadow Pearl
	AddTrainerRef( "professions", "JEWELCRAFTING", 47280, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Brilliant Glass
	AddTrainerRef( "professions", "JEWELCRAFTING", 51311, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Grand Master Jewelcrafter
	AddTrainerRef( "professions", "JEWELCRAFTING", 53831, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Bold Bloodstone
	AddTrainerRef( "professions", "JEWELCRAFTING", 53832, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Delicate Bloodstone
	AddTrainerRef( "professions", "JEWELCRAFTING", 53843, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Subtle Sun Crystal
	AddTrainerRef( "professions", "JEWELCRAFTING", 53844, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Flashing Bloodstone
	AddTrainerRef( "professions", "JEWELCRAFTING", 53845, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Smooth Sun Crystal
	AddTrainerRef( "professions", "JEWELCRAFTING", 53852, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Brilliant Bloodstone
	AddTrainerRef( "professions", "JEWELCRAFTING", 53854, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Rigid Chalcedony
	AddTrainerRef( "professions", "JEWELCRAFTING", 53856, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Quick Sun Crystal
	AddTrainerRef( "professions", "JEWELCRAFTING", 53859, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Sovereign Shadow Crystal
	AddTrainerRef( "professions", "JEWELCRAFTING", 53860, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Shifting Shadow Crystal
	AddTrainerRef( "professions", "JEWELCRAFTING", 53861, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Glinting Shadow Crystal
	AddTrainerRef( "professions", "JEWELCRAFTING", 53870, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Jagged Dark Jade
	AddTrainerRef( "professions", "JEWELCRAFTING", 53871, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Guardian's Shadow Crystal
	AddTrainerRef( "professions", "JEWELCRAFTING", 53872, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Inscribed Huge Citrine
	AddTrainerRef( "professions", "JEWELCRAFTING", 53873, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Etched Shadow Crystal
	AddTrainerRef( "professions", "JEWELCRAFTING", 53874, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Champion's Huge Citrine
	AddTrainerRef( "professions", "JEWELCRAFTING", 53876, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Fierce Huge Citrine
	AddTrainerRef( "professions", "JEWELCRAFTING", 53880, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Deft Huge Citrine
	AddTrainerRef( "professions", "JEWELCRAFTING", 53882, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Potent Huge Citrine
	AddTrainerRef( "professions", "JEWELCRAFTING", 53883, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Veiled Shadow Crystal
	AddTrainerRef( "professions", "JEWELCRAFTING", 53891, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Stalwart Huge Citrine
	AddTrainerRef( "professions", "JEWELCRAFTING", 53892, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Accurate Shadow Crystal
	AddTrainerRef( "professions", "JEWELCRAFTING", 53893, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Resolute Huge Citrine
	AddTrainerRef( "professions", "JEWELCRAFTING", 53894, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Timeless Shadow Crystal
	AddTrainerRef( "professions", "JEWELCRAFTING", 53918, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Regal Dark Jade
	AddTrainerRef( "professions", "JEWELCRAFTING", 53920, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Forceful Dark Jade
	AddTrainerRef( "professions", "JEWELCRAFTING", 53922, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Misty Dark Jade
	AddTrainerRef( "professions", "JEWELCRAFTING", 53923, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Lightning Dark Jade
	AddTrainerRef( "professions", "JEWELCRAFTING", 53925, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Energized Dark Jade
	AddTrainerRef( "professions", "JEWELCRAFTING", 53934, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Solid Chalcedony
	AddTrainerRef( "professions", "JEWELCRAFTING", 53941, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Sparkling Chalcedony
	AddTrainerRef( "professions", "JEWELCRAFTING", 54017, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Precise Bloodstone
	AddTrainerRef( "professions", "JEWELCRAFTING", 55386, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Tireless Skyflare Diamond
	AddTrainerRef( "professions", "JEWELCRAFTING", 55394, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Swift Skyflare Diamond
	AddTrainerRef( "professions", "JEWELCRAFTING", 55399, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Powerful Earthsiege Diamond
	AddTrainerRef( "professions", "JEWELCRAFTING", 55402, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Persistent Earthsiege Diamond
	AddTrainerRef( "professions", "JEWELCRAFTING", 56193, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Bloodstone Band
	AddTrainerRef( "professions", "JEWELCRAFTING", 56194, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Sun Rock Ring
	AddTrainerRef( "professions", "JEWELCRAFTING", 56195, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Jade Dagger Pendant
	AddTrainerRef( "professions", "JEWELCRAFTING", 56196, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Blood Sun Necklace
	AddTrainerRef( "professions", "JEWELCRAFTING", 56197, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Dream Signet
	AddTrainerRef( "professions", "JEWELCRAFTING", 56199, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Figurine - Ruby Hare
	AddTrainerRef( "professions", "JEWELCRAFTING", 56201, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Figurine - Twilight Serpent
	AddTrainerRef( "professions", "JEWELCRAFTING", 56202, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Figurine - Sapphire Owl
	AddTrainerRef( "professions", "JEWELCRAFTING", 56203, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Figurine - Emerald Boar
	AddTrainerRef( "professions", "JEWELCRAFTING", 56205, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Dark Jade Focusing Lens
	AddTrainerRef( "professions", "JEWELCRAFTING", 56206, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Shadow Crystal Focusing Lens
	AddTrainerRef( "professions", "JEWELCRAFTING", 56208, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Shadow Jade Focusing Lens
	AddTrainerRef( "professions", "JEWELCRAFTING", 56530, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Enchanted Pearl
	AddTrainerRef( "professions", "JEWELCRAFTING", 56531, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Enchanted Tear
	AddTrainerRef( "professions", "JEWELCRAFTING", 58141, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Crystal Citrine Necklace
	AddTrainerRef( "professions", "JEWELCRAFTING", 58142, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Crystal Chalcedony Amulet
	AddTrainerRef( "professions", "JEWELCRAFTING", 58143, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Earthshadow Ring
	AddTrainerRef( "professions", "JEWELCRAFTING", 58144, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Jade Ring of Slaying
	AddTrainerRef( "professions", "JEWELCRAFTING", 58145, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Stoneguard Band
	AddTrainerRef( "professions", "JEWELCRAFTING", 58146, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Shadowmight Ring
	AddTrainerRef( "professions", "JEWELCRAFTING", 59759, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Figurine - Monarch Crab
	AddTrainerRef( "professions", "JEWELCRAFTING", 62242, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Icy Prism
	AddTrainerRef( "professions", "JEWELCRAFTING", 62941, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Prismatic Black Diamond
	AddTrainerRef( "professions", "JEWELCRAFTING", 63743, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Amulet of Truesight
	AddTrainerRef( "professions", "JEWELCRAFTING", 64725, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Emerald Choker
	AddTrainerRef( "professions", "JEWELCRAFTING", 64726, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Sky Sapphire Amulet
	AddTrainerRef( "professions", "JEWELCRAFTING", 64727, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Runed Mana Band
	AddTrainerRef( "professions", "JEWELCRAFTING", 64728, 18774, 19063, 19775, 19778, 26915, 26960, 26997, 28701, 33590, 33614, 33637, 33680, 44582, 46675 ) -- Scarlet Signet
	AddTrainerRef( "professions", "JEWELCRAFTING", 73222, 18774, 19063, 19778, 26915, 26960, 26997, 28701, 33614, 33680, 44582, 46675 ) -- Bold Carnelian
	AddTrainerRef( "professions", "JEWELCRAFTING", 73223, 18774, 19063, 19778, 26915, 26960, 26997, 28701, 33614, 33680, 44582, 46675 ) -- Delicate Carnelian
	AddTrainerRef( "professions", "JEWELCRAFTING", 73225, 18774, 19063, 19778, 26915, 26960, 26997, 28701, 33614, 33680, 44582, 46675 ) -- Brilliant Carnelian
	AddTrainerRef( "professions", "JEWELCRAFTING", 73226, 18774, 19063, 19778, 26915, 26960, 26997, 28701, 33614, 33680, 44582, 46675 ) -- Precise Carnelian
	AddTrainerRef( "professions", "JEWELCRAFTING", 73227, 18774, 19063, 19778, 26915, 26960, 26997, 28701, 33614, 33680, 44582, 46675 ) -- Solid Zephyrite
	AddTrainerRef( "professions", "JEWELCRAFTING", 73228, 18774, 19063, 19778, 26915, 26960, 26997, 28701, 33614, 33680, 44582, 46675 ) -- Sparkling Zephyrite
	AddTrainerRef( "professions", "JEWELCRAFTING", 73230, 18774, 19063, 19778, 26915, 26960, 26997, 28701, 33614, 33680, 44582, 46675 ) -- Rigid Zephyrite
	AddTrainerRef( "professions", "JEWELCRAFTING", 73232, 18774, 19063, 19778, 26915, 26960, 26997, 28701, 33614, 33680, 44582, 46675 ) -- Smooth Alicite
	AddTrainerRef( "professions", "JEWELCRAFTING", 73234, 18774, 19063, 19778, 26915, 26960, 26997, 28701, 33614, 33680, 44582, 46675 ) -- Quick Alicite
	AddTrainerRef( "professions", "JEWELCRAFTING", 73239, 18774, 19063, 19778, 26915, 26960, 26997, 28701, 33614, 33680, 44582, 46675 ) -- Fractured Alicite
	AddTrainerRef( "professions", "JEWELCRAFTING", 73240, 18774, 19063, 19778, 26915, 26960, 26997, 28701, 33614, 33680, 44582, 46675 ) -- Sovereign Nightstone
	AddTrainerRef( "professions", "JEWELCRAFTING", 73241, 18774, 19063, 19778, 26915, 26960, 26997, 28701, 33614, 33680, 44582, 46675 ) -- Shifting Nightstone
	AddTrainerRef( "professions", "JEWELCRAFTING", 73243, 18774, 19063, 19778, 26915, 26960, 26997, 28701, 33614, 33680, 44582, 46675 ) -- Timeless Nightstone
	AddTrainerRef( "professions", "JEWELCRAFTING", 73246, 18774, 19063, 19778, 26915, 26960, 26997, 28701, 33614, 33680, 44582, 46675 ) -- Etched Nightstone
	AddTrainerRef( "professions", "JEWELCRAFTING", 73247, 18774, 19063, 19778, 26915, 26960, 26997, 28701, 33614, 33680, 44582, 46675 ) -- Glinting Nightstone
	AddTrainerRef( "professions", "JEWELCRAFTING", 73249, 18774, 19063, 19778, 26915, 26960, 26997, 28701, 33614, 33680, 44582, 46675 ) -- Veiled Nightstone
	AddTrainerRef( "professions", "JEWELCRAFTING", 73250, 18774, 19063, 19778, 26915, 26960, 26997, 28701, 33614, 33680, 44582, 46675 ) -- Accurate Nightstone
	AddTrainerRef( "professions", "JEWELCRAFTING", 73266, 18774, 19778, 26915, 26960, 26997, 28701, 33614, 33680, 44582 ) -- Reckless Hessonite
	AddTrainerRef( "professions", "JEWELCRAFTING", 73267, 18774, 19063, 19778, 26915, 26960, 26997, 28701, 33614, 33680, 44582, 46675 ) -- Skillful Hessonite
	AddTrainerRef( "professions", "JEWELCRAFTING", 73268, 18774, 19063, 19778, 26915, 26960, 26997, 28701, 33614, 33680, 44582, 46675 ) -- Adept Hessonite
	AddTrainerRef( "professions", "JEWELCRAFTING", 73270, 18774, 19063, 19778, 26915, 26960, 26997, 28701, 33614, 33680, 44582, 46675 ) -- Artful Hessonite
	AddTrainerRef( "professions", "JEWELCRAFTING", 73274, 18774, 19063, 19778, 26915, 26960, 26997, 28701, 33614, 33680, 44582, 46675 ) -- Jagged Jasper
	AddTrainerRef( "professions", "JEWELCRAFTING", 73279, 18774, 19063, 19778, 26915, 26960, 26997, 28701, 33614, 33680, 44582, 46675 ) -- Puissant Jasper
	AddTrainerRef( "professions", "JEWELCRAFTING", 73281, 18774, 19063, 19778, 26915, 26960, 26997, 28701, 33614, 33680, 44582, 46675 ) -- Sensei's Jasper
	AddTrainerRef( "professions", "JEWELCRAFTING", 73318, 18774, 19063, 19778, 26915, 26960, 26997, 28701, 33614, 33680, 44582, 46675 ) -- Illustrious Grand Master Jewelcrafter
	AddTrainerRef( "professions", "JEWELCRAFTING", 73478, 18774, 19063, 19778, 26915, 26960, 26997, 28701, 33614, 33680, 44582, 46675 ) -- Fire Prism
	AddTrainerRef( "professions", "JEWELCRAFTING", 73494, 18774, 19063, 19778, 26915, 26960, 26997, 28701, 33614, 33680, 44582, 46675 ) -- Jasper Ring
	AddTrainerRef( "professions", "JEWELCRAFTING", 73495, 18774, 19063, 19778, 26915, 26960, 26997, 28701, 33614, 33680, 44582, 46675 ) -- Hessonite Band
	AddTrainerRef( "professions", "JEWELCRAFTING", 73496, 18774, 19063, 19778, 26915, 26960, 26997, 28701, 33614, 33680, 44582, 46675 ) -- Alicite Pendant
	AddTrainerRef( "professions", "JEWELCRAFTING", 73497, 18774, 19063, 19778, 26915, 26960, 26997, 28701, 33614, 33680, 44582, 46675 ) -- Nightstone Choker
	AddTrainerRef( "professions", "JEWELCRAFTING", 73620, 18774, 19063, 19778, 26915, 26960, 26997, 28701, 33614, 33680, 44582, 46675 ) -- Carnelian Spikes
	AddTrainerRef( "professions", "JEWELCRAFTING", 73621, 18774, 19063, 19778, 26915, 26960, 26997, 28701, 33614, 33680, 44582, 46675 ) -- The Perforator
	AddTrainerRef( "professions", "LEATHERWORKING",  2108, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Apprentice Leatherworker
	AddTrainerRef( "professions", "LEATHERWORKING",  2153, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Handstitched Leather Pants
	AddTrainerRef( "professions", "LEATHERWORKING",  2159, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Fine Leather Cloak
	AddTrainerRef( "professions", "LEATHERWORKING",  2160, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Embossed Leather Vest
	AddTrainerRef( "professions", "LEATHERWORKING",  2161, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Embossed Leather Boots
	AddTrainerRef( "professions", "LEATHERWORKING",  2162, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Embossed Leather Cloak
	AddTrainerRef( "professions", "LEATHERWORKING",  2165, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Medium Armor Kit
	AddTrainerRef( "professions", "LEATHERWORKING",  2166, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Toughened Leather Armor
	AddTrainerRef( "professions", "LEATHERWORKING",  2167, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Dark Leather Boots
	AddTrainerRef( "professions", "LEATHERWORKING",  2168, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Dark Leather Cloak
	AddTrainerRef( "professions", "LEATHERWORKING",  3104, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Journeyman Leatherworker
	AddTrainerRef( "professions", "LEATHERWORKING",  3753, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Handstitched Leather Belt
	AddTrainerRef( "professions", "LEATHERWORKING",  3756, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Embossed Leather Gloves
	AddTrainerRef( "professions", "LEATHERWORKING",  3759, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Embossed Leather Pants
	AddTrainerRef( "professions", "LEATHERWORKING",  3760, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Hillman's Cloak
	AddTrainerRef( "professions", "LEATHERWORKING",  3761, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Fine Leather Tunic
	AddTrainerRef( "professions", "LEATHERWORKING",  3763, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Fine Leather Belt
	AddTrainerRef( "professions", "LEATHERWORKING",  3764, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Hillman's Leather Gloves
	AddTrainerRef( "professions", "LEATHERWORKING",  3766, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Dark Leather Belt
	AddTrainerRef( "professions", "LEATHERWORKING",  3768, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Hillman's Shoulders
	AddTrainerRef( "professions", "LEATHERWORKING",  3770, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Toughened Leather Gloves
	AddTrainerRef( "professions", "LEATHERWORKING",  3774, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Green Leather Belt
	AddTrainerRef( "professions", "LEATHERWORKING",  3776, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Green Leather Bracers
	AddTrainerRef( "professions", "LEATHERWORKING",  3780, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Heavy Armor Kit
	AddTrainerRef( "professions", "LEATHERWORKING",  3811, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Expert Leatherworker
	AddTrainerRef( "professions", "LEATHERWORKING",  3816, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Cured Light Hide
	AddTrainerRef( "professions", "LEATHERWORKING",  3817, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Cured Medium Hide
	AddTrainerRef( "professions", "LEATHERWORKING",  3818, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Cured Heavy Hide
	AddTrainerRef( "professions", "LEATHERWORKING",  6661, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Barbaric Harness
	AddTrainerRef( "professions", "LEATHERWORKING",  7135, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Dark Leather Pants
	AddTrainerRef( "professions", "LEATHERWORKING",  7147, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Guardian Pants
	AddTrainerRef( "professions", "LEATHERWORKING",  7151, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Barbaric Shoulders
	AddTrainerRef( "professions", "LEATHERWORKING",  7156, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Guardian Gloves
	AddTrainerRef( "professions", "LEATHERWORKING",  9065, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Light Leather Bracers
	AddTrainerRef( "professions", "LEATHERWORKING",  9068, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Light Leather Pants
	AddTrainerRef( "professions", "LEATHERWORKING",  9074, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Nimble Leather Gloves
	AddTrainerRef( "professions", "LEATHERWORKING",  9145, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Fletcher's Gloves
	AddTrainerRef( "professions", "LEATHERWORKING",  9196, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Dusky Leather Armor
	AddTrainerRef( "professions", "LEATHERWORKING",  9198, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Frost Leather Cloak
	AddTrainerRef( "professions", "LEATHERWORKING",  9201, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Dusky Bracers
	AddTrainerRef( "professions", "LEATHERWORKING",  9206, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Dusky Belt
	AddTrainerRef( "professions", "LEATHERWORKING", 10482, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Cured Thick Hide
	AddTrainerRef( "professions", "LEATHERWORKING", 10487, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Thick Armor Kit
	AddTrainerRef( "professions", "LEATHERWORKING", 10499, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Nightscape Tunic
	AddTrainerRef( "professions", "LEATHERWORKING", 10507, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Nightscape Headband
	AddTrainerRef( "professions", "LEATHERWORKING", 10511, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Turtle Scale Breastplate
	AddTrainerRef( "professions", "LEATHERWORKING", 10518, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Turtle Scale Bracers
	AddTrainerRef( "professions", "LEATHERWORKING", 10548, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Nightscape Pants
	AddTrainerRef( "professions", "LEATHERWORKING", 10552, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Turtle Scale Helm
	AddTrainerRef( "professions", "LEATHERWORKING", 10556, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Turtle Scale Leggings
	AddTrainerRef( "professions", "LEATHERWORKING", 10558, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Nightscape Boots
	AddTrainerRef( "professions", "LEATHERWORKING", 10630, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Gauntlets of the Sea
	AddTrainerRef( "professions", "LEATHERWORKING", 10632, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Helm of Fire
	AddTrainerRef( "professions", "LEATHERWORKING", 10647, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Feathered Breastplate
	AddTrainerRef( "professions", "LEATHERWORKING", 10650, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Dragonscale Breastplate
	AddTrainerRef( "professions", "LEATHERWORKING", 10662, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Artisan Leatherworker
	AddTrainerRef( "professions", "LEATHERWORKING", 19047, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Cured Rugged Hide
	AddTrainerRef( "professions", "LEATHERWORKING", 19052, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Wicked Leather Bracers
	AddTrainerRef( "professions", "LEATHERWORKING", 19055, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Runic Leather Gauntlets
	AddTrainerRef( "professions", "LEATHERWORKING", 19058, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Rugged Armor Kit
	AddTrainerRef( "professions", "LEATHERWORKING", 19065, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Runic Leather Bracers
	AddTrainerRef( "professions", "LEATHERWORKING", 19071, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Wicked Leather Headband
	AddTrainerRef( "professions", "LEATHERWORKING", 19072, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Runic Leather Belt
	AddTrainerRef( "professions", "LEATHERWORKING", 19082, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Runic Leather Headband
	AddTrainerRef( "professions", "LEATHERWORKING", 19083, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Wicked Leather Pants
	AddTrainerRef( "professions", "LEATHERWORKING", 19091, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Runic Leather Pants
	AddTrainerRef( "professions", "LEATHERWORKING", 19092, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Wicked Leather Belt
	AddTrainerRef( "professions", "LEATHERWORKING", 19098, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Wicked Leather Armor
	AddTrainerRef( "professions", "LEATHERWORKING", 19102, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Runic Leather Armor
	AddTrainerRef( "professions", "LEATHERWORKING", 19103, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Runic Leather Shoulders
	AddTrainerRef( "professions", "LEATHERWORKING", 20648, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Medium Leather
	AddTrainerRef( "professions", "LEATHERWORKING", 20649, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Heavy Leather
	AddTrainerRef( "professions", "LEATHERWORKING", 20650, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Thick Leather
	AddTrainerRef( "professions", "LEATHERWORKING", 22331, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Rugged Leather
	AddTrainerRef( "professions", "LEATHERWORKING", 24654, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Blue Dragonscale Leggings
	AddTrainerRef( "professions", "LEATHERWORKING", 24655, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Green Dragonscale Gauntlets
	AddTrainerRef( "professions", "LEATHERWORKING", 32454, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Knothide Leather
	AddTrainerRef( "professions", "LEATHERWORKING", 32455, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Heavy Knothide Leather
	AddTrainerRef( "professions", "LEATHERWORKING", 32456, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Knothide Armor Kit
	AddTrainerRef( "professions", "LEATHERWORKING", 32462, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Felscale Gloves
	AddTrainerRef( "professions", "LEATHERWORKING", 32463, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Felscale Boots
	AddTrainerRef( "professions", "LEATHERWORKING", 32464, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Felscale Pants
	AddTrainerRef( "professions", "LEATHERWORKING", 32465, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Felscale Breastplate
	AddTrainerRef( "professions", "LEATHERWORKING", 32466, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Scaled Draenic Pants
	AddTrainerRef( "professions", "LEATHERWORKING", 32467, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Scaled Draenic Gloves
	AddTrainerRef( "professions", "LEATHERWORKING", 32468, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Scaled Draenic Vest
	AddTrainerRef( "professions", "LEATHERWORKING", 32469, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Scaled Draenic Boots
	AddTrainerRef( "professions", "LEATHERWORKING", 32470, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Thick Draenic Gloves
	AddTrainerRef( "professions", "LEATHERWORKING", 32471, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Thick Draenic Pants
	AddTrainerRef( "professions", "LEATHERWORKING", 32472, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Thick Draenic Boots
	AddTrainerRef( "professions", "LEATHERWORKING", 32473, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Thick Draenic Vest
	AddTrainerRef( "professions", "LEATHERWORKING", 32478, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Wild Draenish Boots
	AddTrainerRef( "professions", "LEATHERWORKING", 32479, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Wild Draenish Gloves
	AddTrainerRef( "professions", "LEATHERWORKING", 32480, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Wild Draenish Leggings
	AddTrainerRef( "professions", "LEATHERWORKING", 32481, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Wild Draenish Vest
	AddTrainerRef( "professions", "LEATHERWORKING", 32549, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Master Leatherworker
	AddTrainerRef( "professions", "LEATHERWORKING", 35540, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Drums of War
	AddTrainerRef( "professions", "LEATHERWORKING", 36074, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Blackstorm Leggings
	AddTrainerRef( "professions", "LEATHERWORKING", 36075, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Wildfeather Leggings
	AddTrainerRef( "professions", "LEATHERWORKING", 36076, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Dragonstrike Leggings
	AddTrainerRef( "professions", "LEATHERWORKING", 36077, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Primalstorm Breastplate
	AddTrainerRef( "professions", "LEATHERWORKING", 36078, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Living Crystal Breastplate
	AddTrainerRef( "professions", "LEATHERWORKING", 36079, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Golden Dragonstrike Breastplate
	AddTrainerRef( "professions", "LEATHERWORKING", 44770, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Glove Reinforcements
	AddTrainerRef( "professions", "LEATHERWORKING", 44970, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Heavy Knothide Armor Kit
	AddTrainerRef( "professions", "LEATHERWORKING", 45100, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Leatherworker's Satchel
	AddTrainerRef( "professions", "LEATHERWORKING", 50936, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Heavy Borean Leather
	AddTrainerRef( "professions", "LEATHERWORKING", 50938, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Iceborne Chestguard
	AddTrainerRef( "professions", "LEATHERWORKING", 50939, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Iceborne Leggings
	AddTrainerRef( "professions", "LEATHERWORKING", 50940, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Iceborne Shoulderpads
	AddTrainerRef( "professions", "LEATHERWORKING", 50941, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Iceborne Gloves
	AddTrainerRef( "professions", "LEATHERWORKING", 50942, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Iceborne Boots
	AddTrainerRef( "professions", "LEATHERWORKING", 50943, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Iceborne Belt
	AddTrainerRef( "professions", "LEATHERWORKING", 50944, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Arctic Chestpiece
	AddTrainerRef( "professions", "LEATHERWORKING", 50945, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Arctic Leggings
	AddTrainerRef( "professions", "LEATHERWORKING", 50946, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Arctic Shoulderpads
	AddTrainerRef( "professions", "LEATHERWORKING", 50947, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Arctic Gloves
	AddTrainerRef( "professions", "LEATHERWORKING", 50948, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Arctic Boots
	AddTrainerRef( "professions", "LEATHERWORKING", 50949, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Arctic Belt
	AddTrainerRef( "professions", "LEATHERWORKING", 50950, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Frostscale Chestguard
	AddTrainerRef( "professions", "LEATHERWORKING", 50951, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Frostscale Leggings
	AddTrainerRef( "professions", "LEATHERWORKING", 50952, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Frostscale Shoulders
	AddTrainerRef( "professions", "LEATHERWORKING", 50953, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Frostscale Gloves
	AddTrainerRef( "professions", "LEATHERWORKING", 50954, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Frostscale Boots
	AddTrainerRef( "professions", "LEATHERWORKING", 50955, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Frostscale Belt
	AddTrainerRef( "professions", "LEATHERWORKING", 50956, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Nerubian Chestguard
	AddTrainerRef( "professions", "LEATHERWORKING", 50957, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Nerubian Legguards
	AddTrainerRef( "professions", "LEATHERWORKING", 50958, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Nerubian Shoulders
	AddTrainerRef( "professions", "LEATHERWORKING", 50959, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Nerubian Gloves
	AddTrainerRef( "professions", "LEATHERWORKING", 50960, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Nerubian Boots
	AddTrainerRef( "professions", "LEATHERWORKING", 50961, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Nerubian Belt
	AddTrainerRef( "professions", "LEATHERWORKING", 50962, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Borean Armor Kit
	AddTrainerRef( "professions", "LEATHERWORKING", 50963, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Heavy Borean Armor Kit
	AddTrainerRef( "professions", "LEATHERWORKING", 50964, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Jormungar Leg Armor
	AddTrainerRef( "professions", "LEATHERWORKING", 50965, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Frosthide Leg Armor
	AddTrainerRef( "professions", "LEATHERWORKING", 50966, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Nerubian Leg Armor
	AddTrainerRef( "professions", "LEATHERWORKING", 50967, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Icescale Leg Armor
	AddTrainerRef( "professions", "LEATHERWORKING", 51302, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Grand Master Leatherworker
	AddTrainerRef( "professions", "LEATHERWORKING", 51568, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Black Chitinguard Boots
	AddTrainerRef( "professions", "LEATHERWORKING", 51569, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Dark Arctic Leggings
	AddTrainerRef( "professions", "LEATHERWORKING", 51570, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Dark Arctic Chestpiece
	AddTrainerRef( "professions", "LEATHERWORKING", 51571, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Arctic Wristguards
	AddTrainerRef( "professions", "LEATHERWORKING", 51572, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Arctic Helm
	AddTrainerRef( "professions", "LEATHERWORKING", 55199, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Cloak of Tormented Skies
	AddTrainerRef( "professions", "LEATHERWORKING", 57683, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Fur Lining - Attack Power
	AddTrainerRef( "professions", "LEATHERWORKING", 57690, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Fur Lining - Stamina
	AddTrainerRef( "professions", "LEATHERWORKING", 57691, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Fur Lining - Spell Power
	AddTrainerRef( "professions", "LEATHERWORKING", 60583, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Jormungar Leg Reinforcements
	AddTrainerRef( "professions", "LEATHERWORKING", 60584, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Nerubian Leg Reinforcements
	AddTrainerRef( "professions", "LEATHERWORKING", 60599, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Frostscale Bracers
	AddTrainerRef( "professions", "LEATHERWORKING", 60600, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Frostscale Helm
	AddTrainerRef( "professions", "LEATHERWORKING", 60601, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Dark Frostscale Leggings
	AddTrainerRef( "professions", "LEATHERWORKING", 60604, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Dark Frostscale Breastplate
	AddTrainerRef( "professions", "LEATHERWORKING", 60605, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Dragonstompers
	AddTrainerRef( "professions", "LEATHERWORKING", 60607, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Iceborne Wristguards
	AddTrainerRef( "professions", "LEATHERWORKING", 60608, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Iceborne Helm
	AddTrainerRef( "professions", "LEATHERWORKING", 60611, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Dark Iceborne Leggings
	AddTrainerRef( "professions", "LEATHERWORKING", 60613, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Dark Iceborne Chestguard
	AddTrainerRef( "professions", "LEATHERWORKING", 60620, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Bugsquashers
	AddTrainerRef( "professions", "LEATHERWORKING", 60622, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Nerubian Bracers
	AddTrainerRef( "professions", "LEATHERWORKING", 60624, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Nerubian Helm
	AddTrainerRef( "professions", "LEATHERWORKING", 60627, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Dark Nerubian Leggings
	AddTrainerRef( "professions", "LEATHERWORKING", 60629, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Dark Nerubian Chestpiece
	AddTrainerRef( "professions", "LEATHERWORKING", 60630, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Scaled Icewalkers
	AddTrainerRef( "professions", "LEATHERWORKING", 60631, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Cloak of Harsh Winds
	AddTrainerRef( "professions", "LEATHERWORKING", 60637, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Ice Striker's Cloak
	AddTrainerRef( "professions", "LEATHERWORKING", 60640, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Durable Nerubhide Cape
	AddTrainerRef( "professions", "LEATHERWORKING", 60643, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Pack of Endless Pockets
	AddTrainerRef( "professions", "LEATHERWORKING", 60649, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Razorstrike Breastplate
	AddTrainerRef( "professions", "LEATHERWORKING", 60651, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Virulent Spaulders
	AddTrainerRef( "professions", "LEATHERWORKING", 60652, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Eaglebane Bracers
	AddTrainerRef( "professions", "LEATHERWORKING", 60655, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Nightshock Hood
	AddTrainerRef( "professions", "LEATHERWORKING", 60658, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Nightshock Girdle
	AddTrainerRef( "professions", "LEATHERWORKING", 60660, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Leggings of Visceral Strikes
	AddTrainerRef( "professions", "LEATHERWORKING", 60665, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Seafoam Gauntlets
	AddTrainerRef( "professions", "LEATHERWORKING", 60666, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Jormscale Footpads
	AddTrainerRef( "professions", "LEATHERWORKING", 60669, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Wildscale Breastplate
	AddTrainerRef( "professions", "LEATHERWORKING", 60671, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Purehorn Spaulders
	AddTrainerRef( "professions", "LEATHERWORKING", 62448, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Earthen Leg Armor
	AddTrainerRef( "professions", "LEATHERWORKING", 64661, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Borean Leather
	AddTrainerRef( "professions", "LEATHERWORKING", 69386, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Drums of Forgotten Kings
	AddTrainerRef( "professions", "LEATHERWORKING", 69388, 3007, 3365, 4588, 5127, 5564, 11098, 16728, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33581, 33612, 33635, 33681 ) -- Drums of the Wild
	AddTrainerRef( "professions", "LEATHERWORKING", 78379, 5564, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33612, 33681 ) -- Savage Armor Kit
	AddTrainerRef( "professions", "LEATHERWORKING", 78380, 5564, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33612, 33681 ) -- Savage Cloak
	AddTrainerRef( "professions", "LEATHERWORKING", 78388, 5564, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33612, 33681 ) -- Tsunami Bracers
	AddTrainerRef( "professions", "LEATHERWORKING", 78396, 5564, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33612, 33681 ) -- Tsunami Belt
	AddTrainerRef( "professions", "LEATHERWORKING", 78398, 5564, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33612, 33681 ) -- Darkbrand Bracers
	AddTrainerRef( "professions", "LEATHERWORKING", 78399, 5564, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33612, 33681 ) -- Darkbrand Gloves
	AddTrainerRef( "professions", "LEATHERWORKING", 78405, 5564, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33612, 33681 ) -- Hardened Scale Cloak
	AddTrainerRef( "professions", "LEATHERWORKING", 78406, 5564, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33612, 33681 ) -- Tsunami Gloves
	AddTrainerRef( "professions", "LEATHERWORKING", 78407, 5564, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33612, 33681 ) -- Darkbrand Boots
	AddTrainerRef( "professions", "LEATHERWORKING", 78410, 5564, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33612, 33681 ) -- Tsunami Boots
	AddTrainerRef( "professions", "LEATHERWORKING", 78411, 5564, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33612, 33681 ) -- Darkbrand Shoulders
	AddTrainerRef( "professions", "LEATHERWORKING", 78415, 5564, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33612, 33681 ) -- Tsunami Shoulders
	AddTrainerRef( "professions", "LEATHERWORKING", 78416, 5564, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33612, 33681 ) -- Darkbrand Belt
	AddTrainerRef( "professions", "LEATHERWORKING", 78419, 5564, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33612, 33681 ) -- Scorched Leg Armor
	AddTrainerRef( "professions", "LEATHERWORKING", 78420, 5564, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33612, 33681 ) -- Twilight Leg Armor
	AddTrainerRef( "professions", "LEATHERWORKING", 78423, 5564, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33612, 33681 ) -- Tsunami Chestguard
	AddTrainerRef( "professions", "LEATHERWORKING", 78424, 5564, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33612, 33681 ) -- Darkbrand Helm
	AddTrainerRef( "professions", "LEATHERWORKING", 78427, 5564, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33612, 33681 ) -- Tsunami Leggings
	AddTrainerRef( "professions", "LEATHERWORKING", 78428, 5564, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33612, 33681 ) -- Darkbrand Chestguard
	AddTrainerRef( "professions", "LEATHERWORKING", 78432, 5564, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33612, 33681 ) -- Tsunami Helm
	AddTrainerRef( "professions", "LEATHERWORKING", 78433, 5564, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33612, 33681 ) -- Darkbrand Leggings
	AddTrainerRef( "professions", "LEATHERWORKING", 78436, 5564, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33612, 33681 ) -- Heavy Savage Leather
	AddTrainerRef( "professions", "LEATHERWORKING", 78437, 5564, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33612, 33681 ) -- Heavy Savage Armor Kit
	AddTrainerRef( "professions", "LEATHERWORKING", 78438, 5564, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33612, 33681 ) -- Cloak of Beasts
	AddTrainerRef( "professions", "LEATHERWORKING", 78439, 5564, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33612, 33681 ) -- Cloak of War
	AddTrainerRef( "professions", "LEATHERWORKING", 81199, 5564, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33612, 33681 ) -- Illustrious Grand Master Leatherworker
	AddTrainerRef( "professions", "LEATHERWORKING", 84950, 5564, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33612, 33681 ) -- Savage Leather
	AddTrainerRef( "professions", "LEATHERWORKING", 85007, 5564, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33612, 33681 ) -- Draconic Embossment - Stamina
	AddTrainerRef( "professions", "LEATHERWORKING", 85008, 5564, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33612, 33681 ) -- Draconic Embossment - Agility
	AddTrainerRef( "professions", "LEATHERWORKING", 85009, 5564, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33612, 33681 ) -- Draconic Embossment - Strength
	AddTrainerRef( "professions", "LEATHERWORKING", 85010, 5564, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33612, 33681 ) -- Draconic Embossment - Intellect
	AddTrainerRef( "professions", "LEATHERWORKING", 85067, 5564, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33612, 33681 ) -- Dragonbone Leg Reinforcements
	AddTrainerRef( "professions", "LEATHERWORKING", 85068, 5564, 26911, 26961, 26998, 28700, 29507, 29508, 29509, 33612, 33681 ) -- Charscale Leg Reinforcements
	AddTrainerRef( "professions", "MINING",  2575, 1701, 3001, 3357, 4254, 4598, 5513, 16663, 16752, 18779, 26912, 26962, 26999, 28698, 33617, 33640, 33682, 43431, 46357, 52642 ) -- Apprentice Miner
	AddTrainerRef( "professions", "MINING",  2576, 1701, 3001, 3357, 4254, 4598, 5513, 16663, 16752, 18779, 26912, 26962, 26999, 28698, 33617, 33640, 33682, 43431, 46357, 52642 ) -- Journeyman Miner
	AddTrainerRef( "professions", "MINING",  2658, 1701, 3001, 3357, 4254, 4598, 5513, 16663, 16752, 18779, 26912, 26962, 26999, 28698, 33617, 33640, 33682, 43431, 46357, 52642 ) -- Smelt Silver
	AddTrainerRef( "professions", "MINING",  2659, 1701, 3001, 3357, 4254, 4598, 5513, 16663, 16752, 18779, 26912, 26962, 26999, 28698, 33617, 33640, 33682, 43431, 46357, 52642 ) -- Smelt Bronze
	AddTrainerRef( "professions", "MINING",  3304, 1701, 3001, 3357, 4254, 4598, 5513, 16663, 16752, 18779, 26912, 26962, 26999, 28698, 33617, 33640, 33682, 43431, 46357, 52642 ) -- Smelt Tin
	AddTrainerRef( "professions", "MINING",  3307, 1701, 3001, 3357, 4254, 4598, 5513, 16663, 16752, 18779, 26912, 26962, 26999, 28698, 33617, 33640, 33682, 43431, 46357, 52642 ) -- Smelt Iron
	AddTrainerRef( "professions", "MINING",  3308, 1701, 3001, 3357, 4254, 4598, 5513, 16663, 16752, 18779, 26912, 26962, 26999, 28698, 33617, 33640, 33682, 43431, 46357, 52642 ) -- Smelt Gold
	AddTrainerRef( "professions", "MINING",  3564, 1701, 3001, 3357, 4254, 4598, 5513, 16663, 16752, 18779, 26912, 26962, 26999, 28698, 33617, 33640, 33682, 43431, 46357, 52642 ) -- Expert Miner
	AddTrainerRef( "professions", "MINING",  3569, 1701, 3001, 3357, 4254, 4598, 5513, 16663, 16752, 18779, 26912, 26962, 26999, 28698, 33617, 33640, 33682, 43431, 46357, 52642 ) -- Smelt Steel
	AddTrainerRef( "professions", "MINING", 10097, 1701, 3001, 3357, 4254, 4598, 5513, 16663, 16752, 18779, 26912, 26962, 26999, 28698, 33617, 33640, 33682, 43431, 46357, 52642 ) -- Smelt Mithril
	AddTrainerRef( "professions", "MINING", 10098, 1701, 3001, 3357, 4254, 4598, 5513, 16663, 16752, 18779, 26912, 26962, 26999, 28698, 33617, 33640, 33682, 43431, 46357, 52642 ) -- Smelt Truesilver
	AddTrainerRef( "professions", "MINING", 10248, 1701, 3001, 3357, 4254, 4598, 5513, 16663, 16752, 18779, 26912, 26962, 26999, 28698, 33617, 33640, 33682, 43431, 46357, 52642 ) -- Artisan Miner
	AddTrainerRef( "professions", "MINING", 16153, 1701, 3001, 3357, 4254, 4598, 5513, 16663, 16752, 18779, 26912, 26962, 26999, 28698, 33617, 33640, 33682, 43431, 46357, 52642 ) -- Smelt Thorium
	AddTrainerRef( "professions", "MINING", 29354, 1701, 3001, 3357, 4254, 4598, 5513, 16663, 16752, 18779, 26912, 26962, 26999, 28698, 33617, 33640, 33682, 43431, 46357, 52642 ) -- Master Miner
	AddTrainerRef( "professions", "MINING", 29356, 1701, 3001, 3357, 4254, 4598, 5513, 16663, 16752, 18779, 26912, 26962, 26999, 28698, 33617, 33640, 33682, 43431, 46357, 52642 ) -- Smelt Fel Iron
	AddTrainerRef( "professions", "MINING", 29358, 1701, 3001, 3357, 4254, 4598, 5513, 16663, 16752, 18779, 26912, 26962, 26999, 28698, 33617, 33640, 33682, 43431, 46357, 52642 ) -- Smelt Adamantite
	AddTrainerRef( "professions", "MINING", 29359, 1701, 3001, 3357, 4254, 4598, 5513, 16663, 16752, 18779, 26912, 26962, 26999, 28698, 33617, 33640, 33682, 43431, 46357, 52642 ) -- Smelt Eternium
	AddTrainerRef( "professions", "MINING", 29360, 1701, 3001, 3357, 4254, 4598, 5513, 16663, 16752, 18779, 26912, 26962, 26999, 28698, 33617, 33640, 33682, 43431, 46357, 52642 ) -- Smelt Felsteel
	AddTrainerRef( "professions", "MINING", 29361, 1701, 3001, 3357, 4254, 4598, 5513, 16663, 16752, 18779, 26912, 26962, 26999, 28698, 33617, 33640, 33682, 43431, 46357, 52642 ) -- Smelt Khorium
	AddTrainerRef( "professions", "MINING", 29686, 1701, 3001, 3357, 4254, 4598, 5513, 16663, 16752, 18779, 26912, 26962, 26999, 28698, 33617, 33640, 33682, 43431, 46357, 52642 ) -- Smelt Hardened Adamantite
	AddTrainerRef( "professions", "MINING", 35750, 1701, 3001, 3357, 4254, 4598, 5513, 16663, 16752, 18779, 26912, 26962, 26999, 28698, 33617, 33640, 33682, 43431, 46357, 52642 ) -- Earth Shatter
	AddTrainerRef( "professions", "MINING", 35751, 1701, 3001, 3357, 4254, 4598, 5513, 16663, 16752, 18779, 26912, 26962, 26999, 28698, 33617, 33640, 33682, 43431, 46357, 52642 ) -- Fire Sunder
	AddTrainerRef( "professions", "MINING", 49252, 1701, 3001, 3357, 4254, 4598, 5513, 16663, 16752, 18779, 26912, 26962, 26999, 28698, 33617, 33640, 33682, 43431, 46357, 52642 ) -- Smelt Cobalt
	AddTrainerRef( "professions", "MINING", 49258, 1701, 3001, 3357, 4254, 4598, 5513, 16663, 16752, 18779, 26912, 26962, 26999, 28698, 33617, 33640, 33682, 43431, 46357, 52642 ) -- Smelt Saronite
	AddTrainerRef( "professions", "MINING", 50310, 1701, 3001, 3357, 4254, 4598, 5513, 16663, 16752, 18779, 26912, 26962, 26999, 28698, 33617, 33640, 33682, 43431, 46357, 52642 ) -- Grand Master Miner
	AddTrainerRef( "professions", "MINING", 55208, 1701, 3001, 3357, 4254, 4598, 5513, 16663, 16752, 18779, 26912, 26962, 26999, 28698, 33617, 33640, 33682, 43431, 46357, 52642 ) -- Smelt Titansteel
	AddTrainerRef( "professions", "MINING", 55211, 1701, 3001, 3357, 4254, 4598, 5513, 16663, 16752, 18779, 26912, 26962, 26999, 28698, 33617, 33640, 33682, 43431, 46357, 52642 ) -- Smelt Titanium
	AddTrainerRef( "professions", "MINING", 70524, 1701, 3001, 3357, 4254, 4598, 5513, 16663, 16752, 18779, 26912, 26962, 26999, 28698, 33617, 33640, 33682, 43431, 46357, 52642 ) -- Enchanted Thorium Bar
	AddTrainerRef( "professions", "MINING", 74517, 3357, 4254, 5513, 18779, 26912, 26962, 26999, 28698, 33617, 33682, 46357, 52642 ) -- Illustrious Grand Master Miner
	AddTrainerRef( "professions", "MINING", 74529, 3357, 4254, 5513, 18779, 26912, 26962, 26999, 28698, 33617, 33682, 46357, 52642 ) -- Smelt Pyrite
	AddTrainerRef( "professions", "MINING", 74530, 3357, 4254, 5513, 18779, 26912, 26962, 26999, 28698, 33617, 33682, 46357, 52642 ) -- Smelt Elementium
	AddTrainerRef( "professions", "MINING", 74537, 3357, 4254, 5513, 18779, 26912, 26962, 26999, 28698, 33617, 33682, 46357, 52642 ) -- Smelt Hardened Elementium
	AddTrainerRef( "professions", "MINING", 84038, 3357, 4254, 5513, 18779, 26912, 26962, 26999, 28698, 33617, 33682, 46357, 52642 ) -- Smelt Obsidium
	AddTrainerRef( "professions", "SKINNING",  8613, 1292, 6291, 7087, 7088, 7089, 8144, 18755, 18777, 26913, 26963, 27000, 28696, 33618, 33641, 33683, 44782 ) -- Apprentice Skinner
	AddTrainerRef( "professions", "SKINNING",  8617, 1292, 6291, 7087, 7088, 7089, 8144, 18755, 18777, 26913, 26963, 27000, 28696, 33618, 33641, 33683, 44782 ) -- Journeyman Skinner
	AddTrainerRef( "professions", "SKINNING",  8618, 1292, 6291, 7087, 7088, 7089, 8144, 18755, 18777, 26913, 26963, 27000, 28696, 33618, 33641, 33683, 44782 ) -- Expert Skinner
	AddTrainerRef( "professions", "SKINNING", 10768, 1292, 6291, 7087, 7088, 7089, 8144, 18755, 18777, 26913, 26963, 27000, 28696, 33618, 33641, 33683, 44782 ) -- Artisan Skinner
	AddTrainerRef( "professions", "SKINNING", 32678, 1292, 6291, 7087, 7088, 7089, 8144, 18755, 18777, 26913, 26963, 27000, 28696, 33618, 33641, 33683, 44782 ) -- Master Skinner
	AddTrainerRef( "professions", "SKINNING", 50305, 1292, 6291, 7087, 7088, 7089, 8144, 18755, 18777, 26913, 26963, 27000, 28696, 33618, 33641, 33683, 44782 ) -- Grand Master Skinner
	AddTrainerRef( "professions", "SKINNING", 74522, 1292, 6291, 7089, 18777, 26913, 26963, 27000, 28696, 33618, 33683, 44782 ) -- Illustrious Grand Master Skinner
	AddTrainerRef( "professions", "TAILORING",  2385, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- Brown Linen Vest
	AddTrainerRef( "professions", "TAILORING",  2386, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- Linen Boots
	AddTrainerRef( "professions", "TAILORING",  2392, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- Red Linen Shirt
	AddTrainerRef( "professions", "TAILORING",  2393, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- White Linen Shirt
	AddTrainerRef( "professions", "TAILORING",  2394, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- Blue Linen Shirt
	AddTrainerRef( "professions", "TAILORING",  2395, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- Barbaric Linen Vest
	AddTrainerRef( "professions", "TAILORING",  2396, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- Green Linen Shirt
	AddTrainerRef( "professions", "TAILORING",  2397, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- Reinforced Linen Cape
	AddTrainerRef( "professions", "TAILORING",  2399, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- Green Woolen Vest
	AddTrainerRef( "professions", "TAILORING",  2401, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- Woolen Boots
	AddTrainerRef( "professions", "TAILORING",  2402, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- Woolen Cape
	AddTrainerRef( "professions", "TAILORING",  2406, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- Gray Woolen Shirt
	AddTrainerRef( "professions", "TAILORING",  2964, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- Bolt of Woolen Cloth
	AddTrainerRef( "professions", "TAILORING",  3755, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- Linen Bag
	AddTrainerRef( "professions", "TAILORING",  3757, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- Woolen Bag
	AddTrainerRef( "professions", "TAILORING",  3813, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- Small Silk Pack
	AddTrainerRef( "professions", "TAILORING",  3839, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- Bolt of Silk Cloth
	AddTrainerRef( "professions", "TAILORING",  3840, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- Heavy Linen Gloves
	AddTrainerRef( "professions", "TAILORING",  3841, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- Green Linen Bracers
	AddTrainerRef( "professions", "TAILORING",  3842, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- Handstitched Linen Britches
	AddTrainerRef( "professions", "TAILORING",  3843, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- Heavy Woolen Gloves
	AddTrainerRef( "professions", "TAILORING",  3845, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- Soft-soled Linen Boots
	AddTrainerRef( "professions", "TAILORING",  3848, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- Double-stitched Woolen Shoulders
	AddTrainerRef( "professions", "TAILORING",  3850, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- Heavy Woolen Pants
	AddTrainerRef( "professions", "TAILORING",  3852, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- Gloves of Meditation
	AddTrainerRef( "professions", "TAILORING",  3855, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- Spidersilk Boots
	AddTrainerRef( "professions", "TAILORING",  3859, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- Azure Silk Vest
	AddTrainerRef( "professions", "TAILORING",  3861, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Long Silken Cloak
	AddTrainerRef( "professions", "TAILORING",  3865, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Bolt of Mageweave
	AddTrainerRef( "professions", "TAILORING",  3866, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- Stylish Red Shirt
	AddTrainerRef( "professions", "TAILORING",  3871, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Formal White Shirt
	AddTrainerRef( "professions", "TAILORING",  3908, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- Apprentice Tailor
	AddTrainerRef( "professions", "TAILORING",  3909, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- Journeyman Tailor
	AddTrainerRef( "professions", "TAILORING",  3910, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Expert Tailor
	AddTrainerRef( "professions", "TAILORING",  3914, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- Brown Linen Pants
	AddTrainerRef( "professions", "TAILORING",  6521, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- Pearl-clasped Cloak
	AddTrainerRef( "professions", "TAILORING",  6690, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- Lesser Wizard's Robe
	AddTrainerRef( "professions", "TAILORING",  7623, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- Brown Linen Robe
	AddTrainerRef( "professions", "TAILORING",  7624, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- White Linen Robe
	AddTrainerRef( "professions", "TAILORING",  8465, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- Simple Dress
	AddTrainerRef( "professions", "TAILORING",  8467, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- White Woolen Dress
	AddTrainerRef( "professions", "TAILORING",  8483, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- White Swashbuckler's Shirt
	AddTrainerRef( "professions", "TAILORING",  8489, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Red Swashbuckler's Shirt
	AddTrainerRef( "professions", "TAILORING",  8758, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- Azure Silk Pants
	AddTrainerRef( "professions", "TAILORING",  8760, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- Azure Silk Hood
	AddTrainerRef( "professions", "TAILORING",  8762, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Silk Headband
	AddTrainerRef( "professions", "TAILORING",  8764, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Earthen Vest
	AddTrainerRef( "professions", "TAILORING",  8766, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Azure Silk Belt
	AddTrainerRef( "professions", "TAILORING",  8770, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Robe of Power
	AddTrainerRef( "professions", "TAILORING",  8772, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Crimson Silk Belt
	AddTrainerRef( "professions", "TAILORING",  8774, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Green Silken Shoulders
	AddTrainerRef( "professions", "TAILORING",  8776, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- Linen Belt
	AddTrainerRef( "professions", "TAILORING",  8791, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Crimson Silk Vest
	AddTrainerRef( "professions", "TAILORING",  8799, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Crimson Silk Pantaloons
	AddTrainerRef( "professions", "TAILORING",  8804, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Crimson Silk Gloves
	AddTrainerRef( "professions", "TAILORING", 12045, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- Simple Linen Boots
	AddTrainerRef( "professions", "TAILORING", 12046, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- Simple Kilt
	AddTrainerRef( "professions", "TAILORING", 12048, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Black Mageweave Vest
	AddTrainerRef( "professions", "TAILORING", 12049, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Black Mageweave Leggings
	AddTrainerRef( "professions", "TAILORING", 12050, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Black Mageweave Robe
	AddTrainerRef( "professions", "TAILORING", 12052, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Shadoweave Pants
	AddTrainerRef( "professions", "TAILORING", 12053, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Black Mageweave Gloves
	AddTrainerRef( "professions", "TAILORING", 12055, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Shadoweave Robe
	AddTrainerRef( "professions", "TAILORING", 12061, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Orange Mageweave Shirt
	AddTrainerRef( "professions", "TAILORING", 12065, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Mageweave Bag
	AddTrainerRef( "professions", "TAILORING", 12067, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Dreamweave Gloves
	AddTrainerRef( "professions", "TAILORING", 12069, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Cindercloth Robe
	AddTrainerRef( "professions", "TAILORING", 12070, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Dreamweave Vest
	AddTrainerRef( "professions", "TAILORING", 12071, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Shadoweave Gloves
	AddTrainerRef( "professions", "TAILORING", 12072, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Black Mageweave Headband
	AddTrainerRef( "professions", "TAILORING", 12073, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Black Mageweave Boots
	AddTrainerRef( "professions", "TAILORING", 12074, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Black Mageweave Shoulders
	AddTrainerRef( "professions", "TAILORING", 12076, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Shadoweave Shoulders
	AddTrainerRef( "professions", "TAILORING", 12077, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Simple Black Dress
	AddTrainerRef( "professions", "TAILORING", 12079, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Red Mageweave Bag
	AddTrainerRef( "professions", "TAILORING", 12082, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Shadoweave Boots
	AddTrainerRef( "professions", "TAILORING", 12088, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Cindercloth Boots
	AddTrainerRef( "professions", "TAILORING", 12092, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Dreamweave Circlet
	AddTrainerRef( "professions", "TAILORING", 12180, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Artisan Tailor
	AddTrainerRef( "professions", "TAILORING", 18401, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Bolt of Runecloth
	AddTrainerRef( "professions", "TAILORING", 18402, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Runecloth Belt
	AddTrainerRef( "professions", "TAILORING", 18403, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Frostweave Tunic
	AddTrainerRef( "professions", "TAILORING", 18406, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Runecloth Robe
	AddTrainerRef( "professions", "TAILORING", 18407, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Runecloth Tunic
	AddTrainerRef( "professions", "TAILORING", 18409, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Runecloth Cloak
	AddTrainerRef( "professions", "TAILORING", 18410, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Ghostweave Belt
	AddTrainerRef( "professions", "TAILORING", 18411, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Frostweave Gloves
	AddTrainerRef( "professions", "TAILORING", 18413, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Ghostweave Gloves
	AddTrainerRef( "professions", "TAILORING", 18414, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Brightcloth Robe
	AddTrainerRef( "professions", "TAILORING", 18415, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Brightcloth Gloves
	AddTrainerRef( "professions", "TAILORING", 18416, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Ghostweave Vest
	AddTrainerRef( "professions", "TAILORING", 18417, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Runecloth Gloves
	AddTrainerRef( "professions", "TAILORING", 18420, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Brightcloth Cloak
	AddTrainerRef( "professions", "TAILORING", 18421, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Wizardweave Leggings
	AddTrainerRef( "professions", "TAILORING", 18423, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Runecloth Boots
	AddTrainerRef( "professions", "TAILORING", 18424, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Frostweave Pants
	AddTrainerRef( "professions", "TAILORING", 18437, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Felcloth Boots
	AddTrainerRef( "professions", "TAILORING", 18438, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Runecloth Pants
	AddTrainerRef( "professions", "TAILORING", 18441, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Ghostweave Pants
	AddTrainerRef( "professions", "TAILORING", 18442, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Felcloth Hood
	AddTrainerRef( "professions", "TAILORING", 18444, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Runecloth Headband
	AddTrainerRef( "professions", "TAILORING", 18446, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Wizardweave Robe
	AddTrainerRef( "professions", "TAILORING", 18449, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Runecloth Shoulders
	AddTrainerRef( "professions", "TAILORING", 18450, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Wizardweave Turban
	AddTrainerRef( "professions", "TAILORING", 18451, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Felcloth Robe
	AddTrainerRef( "professions", "TAILORING", 18453, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Felcloth Shoulders
	AddTrainerRef( "professions", "TAILORING", 26745, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Bolt of Netherweave
	AddTrainerRef( "professions", "TAILORING", 26746, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Netherweave Bag
	AddTrainerRef( "professions", "TAILORING", 26764, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Netherweave Bracers
	AddTrainerRef( "professions", "TAILORING", 26765, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Netherweave Belt
	AddTrainerRef( "professions", "TAILORING", 26770, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Netherweave Gloves
	AddTrainerRef( "professions", "TAILORING", 26771, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Netherweave Pants
	AddTrainerRef( "professions", "TAILORING", 26772, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Netherweave Boots
	AddTrainerRef( "professions", "TAILORING", 26790, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Master Tailor
	AddTrainerRef( "professions", "TAILORING", 31460, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Netherweave Net
	AddTrainerRef( "professions", "TAILORING", 51309, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Grand Master Tailor
	AddTrainerRef( "professions", "TAILORING", 55642, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 27001, 28699, 33613, 33636, 33684, 44783 ) -- Lightweave Embroidery
	AddTrainerRef( "professions", "TAILORING", 55769, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 27001, 28699, 33613, 33636, 33684, 44783 ) -- Darkglow Embroidery
	AddTrainerRef( "professions", "TAILORING", 55777, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 27001, 28699, 33613, 33636, 33684, 44783 ) -- Swordguard Embroidery
	AddTrainerRef( "professions", "TAILORING", 55898, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Frostweave Net
	AddTrainerRef( "professions", "TAILORING", 55899, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Bolt of Frostweave
	AddTrainerRef( "professions", "TAILORING", 55900, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Bolt of Imbued Frostweave
	AddTrainerRef( "professions", "TAILORING", 55901, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Duskweave Leggings
	AddTrainerRef( "professions", "TAILORING", 55902, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Frostwoven Shoulders
	AddTrainerRef( "professions", "TAILORING", 55903, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Frostwoven Robe
	AddTrainerRef( "professions", "TAILORING", 55904, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Frostwoven Gloves
	AddTrainerRef( "professions", "TAILORING", 55906, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Frostwoven Boots
	AddTrainerRef( "professions", "TAILORING", 55907, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Frostwoven Cowl
	AddTrainerRef( "professions", "TAILORING", 55908, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Frostwoven Belt
	AddTrainerRef( "professions", "TAILORING", 55910, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Mystic Frostwoven Shoulders
	AddTrainerRef( "professions", "TAILORING", 55911, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Mystic Frostwoven Robe
	AddTrainerRef( "professions", "TAILORING", 55913, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Mystic Frostwoven Wristwraps
	AddTrainerRef( "professions", "TAILORING", 55914, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Duskweave Belt
	AddTrainerRef( "professions", "TAILORING", 55919, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Duskweave Cowl
	AddTrainerRef( "professions", "TAILORING", 55920, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Duskweave Wristwraps
	AddTrainerRef( "professions", "TAILORING", 55921, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Duskweave Robe
	AddTrainerRef( "professions", "TAILORING", 55922, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Duskweave Gloves
	AddTrainerRef( "professions", "TAILORING", 55923, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Duskweave Shoulders
	AddTrainerRef( "professions", "TAILORING", 55924, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Duskweave Boots
	AddTrainerRef( "professions", "TAILORING", 55925, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Black Duskweave Leggings
	AddTrainerRef( "professions", "TAILORING", 55941, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Black Duskweave Robe
	AddTrainerRef( "professions", "TAILORING", 55943, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Black Duskweave Wristwraps
	AddTrainerRef( "professions", "TAILORING", 55995, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Yellow Lumberjack Shirt
	AddTrainerRef( "professions", "TAILORING", 56000, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Green Workman's Shirt
	AddTrainerRef( "professions", "TAILORING", 56001, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Moonshroud
	AddTrainerRef( "professions", "TAILORING", 56002, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Ebonweave
	AddTrainerRef( "professions", "TAILORING", 56003, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Spellweave
	AddTrainerRef( "professions", "TAILORING", 56007, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Frostweave Bag
	AddTrainerRef( "professions", "TAILORING", 56008, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Shining Spellthread
	AddTrainerRef( "professions", "TAILORING", 56010, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Azure Spellthread
	AddTrainerRef( "professions", "TAILORING", 56014, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Cloak of the Moon
	AddTrainerRef( "professions", "TAILORING", 56015, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Cloak of Frozen Spirits
	AddTrainerRef( "professions", "TAILORING", 56018, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Hat of Wintry Doom
	AddTrainerRef( "professions", "TAILORING", 56019, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Silky Iceshard Boots
	AddTrainerRef( "professions", "TAILORING", 56020, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Deep Frozen Cord
	AddTrainerRef( "professions", "TAILORING", 56021, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Frostmoon Pants
	AddTrainerRef( "professions", "TAILORING", 56022, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Light Blessed Mittens
	AddTrainerRef( "professions", "TAILORING", 56023, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Aurora Slippers
	AddTrainerRef( "professions", "TAILORING", 56024, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Moonshroud Robe
	AddTrainerRef( "professions", "TAILORING", 56025, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Moonshroud Gloves
	AddTrainerRef( "professions", "TAILORING", 56026, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Ebonweave Robe
	AddTrainerRef( "professions", "TAILORING", 56027, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Ebonweave Gloves
	AddTrainerRef( "professions", "TAILORING", 56028, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Spellweave Robe
	AddTrainerRef( "professions", "TAILORING", 56029, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Spellweave Gloves
	AddTrainerRef( "professions", "TAILORING", 56030, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Frostwoven Leggings
	AddTrainerRef( "professions", "TAILORING", 56031, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Frostwoven Wristwraps
	AddTrainerRef( "professions", "TAILORING", 56034, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 27001, 28699, 33613, 33636, 33684, 44783 ) -- Master's Spellthread
	AddTrainerRef( "professions", "TAILORING", 56039, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 27001, 28699, 33613, 33636, 33684, 44783 ) -- Sanctified Spellthread
	AddTrainerRef( "professions", "TAILORING", 59582, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Frostsavage Belt
	AddTrainerRef( "professions", "TAILORING", 59583, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Frostsavage Bracers
	AddTrainerRef( "professions", "TAILORING", 59584, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Frostsavage Shoulders
	AddTrainerRef( "professions", "TAILORING", 59585, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Frostsavage Boots
	AddTrainerRef( "professions", "TAILORING", 59586, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Frostsavage Gloves
	AddTrainerRef( "professions", "TAILORING", 59587, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Frostsavage Robe
	AddTrainerRef( "professions", "TAILORING", 59588, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Frostsavage Leggings
	AddTrainerRef( "professions", "TAILORING", 59589, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Frostsavage Cowl
	AddTrainerRef( "professions", "TAILORING", 60969, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Flying Carpet
	AddTrainerRef( "professions", "TAILORING", 60971, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Magnificent Flying Carpet
	AddTrainerRef( "professions", "TAILORING", 60990, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Glacial Waistband
	AddTrainerRef( "professions", "TAILORING", 60993, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Glacial Robe
	AddTrainerRef( "professions", "TAILORING", 60994, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Glacial Slippers
	AddTrainerRef( "professions", "TAILORING", 63742, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 43428, 44783 ) -- Spidersilk Drape
	AddTrainerRef( "professions", "TAILORING", 64729, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Frostguard Drape
	AddTrainerRef( "professions", "TAILORING", 64730, 1346, 2627, 3004, 3363, 4576, 4578, 5153, 16640, 16729, 27001, 28699, 33580, 33613, 33636, 33684, 44783 ) -- Cloak of Crimson Snow
	AddTrainerRef( "professions", "TAILORING", 74964, 1346, 2627, 3363, 5153, 27001, 28699, 33613, 33684, 44783 ) -- Bolt of Embersilk Cloth
	AddTrainerRef( "professions", "TAILORING", 75141, 1346, 2627, 3363, 5153, 27001, 28699, 33613, 33684, 44783 ) -- Dream of Skywall
	AddTrainerRef( "professions", "TAILORING", 75142, 1346, 2627, 3363, 5153, 27001, 28699, 33613, 33684, 44783 ) -- Dream of Deepholm
	AddTrainerRef( "professions", "TAILORING", 75144, 1346, 2627, 3363, 5153, 27001, 28699, 33613, 33684, 44783 ) -- Dream of Hyjal
	AddTrainerRef( "professions", "TAILORING", 75145, 1346, 2627, 3363, 5153, 27001, 28699, 33613, 33684, 44783 ) -- Dream of Ragnaros
	AddTrainerRef( "professions", "TAILORING", 75146, 1346, 2627, 3363, 5153, 27001, 28699, 33613, 33684, 44783 ) -- Dream of Azshara
	AddTrainerRef( "professions", "TAILORING", 75154, 1346, 2627, 3363, 5153, 16729, 27001, 28699, 33580, 33613, 33684, 44783 ) -- Master's Spellthread
	AddTrainerRef( "professions", "TAILORING", 75155, 1346, 2627, 3363, 5153, 16729, 27001, 28699, 33580, 33613, 33684, 44783 ) -- Sanctified Spellthread
	AddTrainerRef( "professions", "TAILORING", 75156, 1346, 2627, 3363, 5153, 27001, 28699, 33613, 33684, 44783 ) -- Illustrious Grand Master Tailor
	AddTrainerRef( "professions", "TAILORING", 75172, 1346, 2627, 3363, 5153, 16729, 27001, 28699, 33580, 33613, 33684, 44783 ) -- Lightweave Embroidery
	AddTrainerRef( "professions", "TAILORING", 75175, 1346, 2627, 3363, 5153, 16729, 27001, 28699, 33580, 33613, 33684, 44783 ) -- Darkglow Embroidery
	AddTrainerRef( "professions", "TAILORING", 75178, 1346, 2627, 3363, 5153, 16729, 27001, 28699, 33580, 33613, 33684, 44783 ) -- Swordguard Embroidery
	AddTrainerRef( "professions", "TAILORING", 75247, 1346, 2627, 3363, 5153, 27001, 28699, 33613, 33684, 44783 ) -- Embersilk Net
	AddTrainerRef( "professions", "TAILORING", 75248, 1346, 2627, 3363, 5153, 27001, 28699, 33613, 33684, 44783 ) -- Deathsilk Belt
	AddTrainerRef( "professions", "TAILORING", 75249, 1346, 2627, 3363, 5153, 27001, 28699, 33613, 33684, 44783 ) -- Deathsilk Bracers
	AddTrainerRef( "professions", "TAILORING", 75250, 1346, 2627, 3363, 5153, 27001, 28699, 33613, 33684, 44783 ) -- Enchanted Spellthread
	AddTrainerRef( "professions", "TAILORING", 75251, 1346, 2627, 3363, 5153, 27001, 28699, 33613, 33684, 44783 ) -- Deathsilk Shoulders
	AddTrainerRef( "professions", "TAILORING", 75252, 1346, 2627, 3363, 5153, 27001, 28699, 33613, 33684, 44783 ) -- Deathsilk Boots
	AddTrainerRef( "professions", "TAILORING", 75253, 1346, 2627, 3363, 5153, 27001, 28699, 33613, 33684, 44783 ) -- Deathsilk Gloves
	AddTrainerRef( "professions", "TAILORING", 75254, 1346, 2627, 3363, 5153, 27001, 28699, 33613, 33684, 44783 ) -- Deathsilk Leggings
	AddTrainerRef( "professions", "TAILORING", 75255, 1346, 2627, 3363, 5153, 27001, 28699, 33613, 33684, 44783 ) -- Ghostly Spellthread
	AddTrainerRef( "professions", "TAILORING", 75256, 1346, 2627, 3363, 5153, 27001, 28699, 33613, 33684, 44783 ) -- Deathsilk Cowl
	AddTrainerRef( "professions", "TAILORING", 75257, 1346, 2627, 3363, 5153, 27001, 28699, 33613, 33684, 44783 ) -- Deathsilk Robe
	AddTrainerRef( "professions", "TAILORING", 75258, 1346, 2627, 3363, 5153, 27001, 28699, 33613, 33684, 44783 ) -- Spiritmend Belt
	AddTrainerRef( "professions", "TAILORING", 75259, 1346, 2627, 3363, 5153, 27001, 28699, 33613, 33684, 44783 ) -- Spiritmend Bracers
	AddTrainerRef( "professions", "TAILORING", 75260, 1346, 2627, 3363, 5153, 27001, 28699, 33613, 33684, 44783 ) -- Spiritmend Shoulders
	AddTrainerRef( "professions", "TAILORING", 75261, 1346, 2627, 3363, 5153, 27001, 28699, 33613, 33684, 44783 ) -- Spiritmend Boots
	AddTrainerRef( "professions", "TAILORING", 75262, 1346, 2627, 3363, 5153, 27001, 28699, 33613, 33684, 44783 ) -- Spiritmend Gloves
	AddTrainerRef( "professions", "TAILORING", 75263, 1346, 2627, 3363, 5153, 27001, 28699, 33613, 33684, 44783 ) -- Spiritmend Leggings
	AddTrainerRef( "professions", "TAILORING", 75264, 1346, 2627, 3363, 5153, 27001, 28699, 33613, 33684, 44783 ) -- Embersilk Bag
	AddTrainerRef( "professions", "TAILORING", 75265, 1346, 2627, 3363, 5153, 27001, 28699, 33613, 33684, 44783 ) -- Otherworldly Bag
	AddTrainerRef( "professions", "TAILORING", 75266, 1346, 2627, 3363, 5153, 27001, 28699, 33613, 33684, 44783 ) -- Spiritmend Cowl
	AddTrainerRef( "professions", "TAILORING", 75267, 1346, 2627, 3363, 5153, 27001, 28699, 33613, 33684, 44783 ) -- Spiritmend Robe
	AddTrainerRef( "professions", "TAILORING", 75268, 1346, 2627, 3363, 5153, 27001, 28699, 33613, 33684, 44783 ) -- Hyjal Expedition Bag
	AddTrainerRef( "professions", "TAILORING", 75269, 1346, 2627, 3363, 5153, 27001, 28699, 33613, 33684, 44783 ) -- Fireweave Belt
	AddTrainerRef( "professions", "TAILORING", 75270, 1346, 2627, 3363, 5153, 27001, 28699, 33613, 33684, 44783 ) -- Emberfire Bracers
	AddTrainerRef( "professions", "TAILORING", 75290, 1346, 2627, 3363, 5153, 27001, 28699, 33613, 33684, 44783 ) -- Fireweave Bracers
	AddTrainerRef( "professions", "TAILORING", 75291, 1346, 2627, 3363, 5153, 27001, 28699, 33613, 33684, 44783 ) -- Emberfire Shoulders
	AddTrainerRef( "professions", "TAILORING", 75292, 1346, 2627, 3363, 5153, 27001, 28699, 33613, 33684, 44783 ) -- Fireweave Shoulders
	AddTrainerRef( "professions", "TAILORING", 75293, 1346, 2627, 3363, 5153, 27001, 28699, 33613, 33684, 44783 ) -- Emberfire Belt
	AddTrainerRef( "professions", "TAILORING", 75294, 1346, 2627, 3363, 5153, 27001, 28699, 33613, 33684, 44783 ) -- Fireweave Boots
	AddTrainerRef( "professions", "TAILORING", 75295, 1346, 2627, 3363, 5153, 27001, 28699, 33613, 33684, 44783 ) -- Emberfire Gloves
	AddTrainerRef( "professions", "TAILORING", 75296, 1346, 2627, 3363, 5153, 27001, 28699, 33613, 33684, 44783 ) -- Fireweave Gloves
	AddTrainerRef( "professions", "TAILORING", 75297, 1346, 2627, 3363, 5153, 27001, 28699, 33613, 33684, 44783 ) -- Emberfire Boots
	AddTrainerRef( "professions", "TAILORING", 94743, 1346, 2627, 3363, 5153, 27001, 28699, 33613, 33684, 44783 ) -- Dream of Destruction

end
